@@ -23,7 +23,6 @@ import org.apache.commons.collections.Predicate;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-
 /**
  * <p><code>Predicate</code> that evaluates a property value against a specified value.</p>
  * <p>
@@ -33,10 +32,11 @@ import org.apache.commons.logging.LogFactory;
  * The <code>BeanPropertyValueEqualsPredicate</code> constructor takes two parameters which
  * determine what property will be evaluated on the target object and what its expected value should
  * be.
+ * </p>
  * <dl>
  *    <dt>
  *       <strong><code>
- *           <pre>public BeanPropertyValueEqualsPredicate( String propertyName, Object propertyValue )</pre>
+ *           public BeanPropertyValueEqualsPredicate(String propertyName, Object propertyValue)
  *       </code></strong>
  *    </dt>
  *    <dd>
@@ -46,7 +46,6 @@ import org.apache.commons.logging.LogFactory;
  *       <code>false</code> otherwise.
  *    </dd>
  * </dl>
- * </p>
  * <p>
  * <strong>Note:</strong> Property names can be a simple, nested, indexed, or mapped property as defined by
  * <code>org.apache.commons.beanutils.PropertyUtils</code>.  If any object in the property path
@@ -55,18 +54,19 @@ import org.apache.commons.logging.LogFactory;
  * </p>
  * <p>
  * A typical usage might look like:
- * <code><pre>
+ * </p>
+ * <pre>
  * // create the closure
  * BeanPropertyValueEqualsPredicate predicate =
  *    new BeanPropertyValueEqualsPredicate( "activeEmployee", Boolean.FALSE );
  *
  * // filter the Collection
  * CollectionUtils.filter( peopleCollection, predicate );
- * </pre></code>
- * </p>
+ * </pre>
  * <p>
  * This would take a <code>Collection</code> of person objects and filter out any people whose
  * <code>activeEmployee</code> property is <code>false</code>. Assuming...
+ * </p>
  * <ul>
  *    <li>
  *       The top level object in the <code>peeopleCollection</code> is an object which represents a
@@ -77,20 +77,20 @@ import org.apache.commons.logging.LogFactory;
  *       the boolean value for the object's <code>activeEmployee</code> property.
  *    </li>
  * </ul>
- * </p>
  * <p>
  * Another typical usage might look like:
- * <code><pre>
+ * </p>
+ * <pre>
  * // create the closure
  * BeanPropertyValueEqualsPredicate predicate =
  *    new BeanPropertyValueEqualsPredicate( "personId", "456-12-1234" );
  *
  * // search the Collection
  * CollectionUtils.find( peopleCollection, predicate );
- * </pre></code>
- * </p>
+ * </pre>
  * <p>
  * This would search a <code>Collection</code> of person objects and return the first object whose
+ * </p>
  * <code>personId</code> property value equals <code>456-12-1234</code>. Assuming...
  * <ul>
  *    <li>
@@ -102,9 +102,7 @@ import org.apache.commons.logging.LogFactory;
  *       the value for the object's <code>personId</code> property.
  *    </li>
  * </ul>
- * </p>
  *
- * @version $Id$
  * @see org.apache.commons.beanutils.PropertyUtils
  * @see org.apache.commons.collections.Predicate
  */
@@ -116,13 +114,13 @@ public class BeanPropertyValueEqualsPredicate implements Predicate {
     /**
      * The name of the property which will be evaluated when this <code>Predicate</code> is executed.
      */
-    private String propertyName;
+    private final String propertyName;
 
     /**
      * The value that the property specified by <code>propertyName</code>
      * will be compared to when this <code>Predicate</code> executes.
      */
-    private Object propertyValue;
+    private final Object propertyValue;
 
     /**
      * <p>Should <code>null</code> objects in the property path be ignored?</p>
@@ -137,7 +135,7 @@ public class BeanPropertyValueEqualsPredicate implements Predicate {
      * rethrown.
      * </p>
      */
-    private boolean ignoreNull;
+    private final boolean ignoreNull;
 
     /**
      * Constructor which takes the name of the property, its expected value to be used in evaluation,
@@ -163,15 +161,12 @@ public class BeanPropertyValueEqualsPredicate implements Predicate {
      * @throws IllegalArgumentException If the property name provided is null or empty.
      */
     public BeanPropertyValueEqualsPredicate(final String propertyName, final Object propertyValue, final boolean ignoreNull) {
-        super();
-
-        if ((propertyName != null) && (propertyName.length() > 0)) {
-            this.propertyName = propertyName;
-            this.propertyValue = propertyValue;
-            this.ignoreNull = ignoreNull;
-        } else {
+        if (propertyName == null || propertyName.length() <= 0) {
             throw new IllegalArgumentException("propertyName cannot be null or empty");
         }
+        this.propertyName = propertyName;
+        this.propertyValue = propertyValue;
+        this.ignoreNull = ignoreNull;
     }
 
     /**
@@ -192,6 +187,7 @@ public class BeanPropertyValueEqualsPredicate implements Predicate {
      * provided. Or if an object in the property path provided is <code>null</code> and
      * <code>ignoreNull</code> is set to <code>false</code>.
      */
+    @Override
     public boolean evaluate(final Object object) {
 
         boolean evaluation = false;
@@ -202,36 +198,19 @@ public class BeanPropertyValueEqualsPredicate implements Predicate {
         } catch (final IllegalArgumentException e) {
             final String errorMsg = "Problem during evaluation. Null value encountered in property path...";
 
-            if (ignoreNull) {
-                log.warn("WARNING: " + errorMsg + e);
-            } else {
-                final IllegalArgumentException iae = new IllegalArgumentException(errorMsg);
-                if (!BeanUtils.initCause(iae, e)) {
-                    log.error(errorMsg, e);
-                }
-                throw iae;
+            if (!ignoreNull) {
+                throw new IllegalArgumentException(errorMsg, e);
             }
+            log.warn("WARNING: " + errorMsg + e);
         } catch (final IllegalAccessException e) {
             final String errorMsg = "Unable to access the property provided.";
-            final IllegalArgumentException iae = new IllegalArgumentException(errorMsg);
-            if (!BeanUtils.initCause(iae, e)) {
-                log.error(errorMsg, e);
-            }
-            throw iae;
+            throw new IllegalArgumentException(errorMsg, e);
         } catch (final InvocationTargetException e) {
             final String errorMsg = "Exception occurred in property's getter";
-            final IllegalArgumentException iae = new IllegalArgumentException(errorMsg);
-            if (!BeanUtils.initCause(iae, e)) {
-                log.error(errorMsg, e);
-            }
-            throw iae;
+            throw new IllegalArgumentException(errorMsg, e);
         } catch (final NoSuchMethodException e) {
             final String errorMsg = "Property not found.";
-            final IllegalArgumentException iae = new IllegalArgumentException(errorMsg);
-            if (!BeanUtils.initCause(iae, e)) {
-                log.error(errorMsg, e);
-            }
-            throw iae;
+            throw new IllegalArgumentException(errorMsg, e);
         }
 
         return evaluation;
@@ -246,7 +225,7 @@ public class BeanPropertyValueEqualsPredicate implements Predicate {
      * @return True if they are equal; false otherwise.
      */
     protected boolean evaluateValue(final Object expected, final Object actual) {
-        return (expected == actual) || ((expected != null) && expected.equals(actual));
+        return expected == actual || expected != null && expected.equals(actual);
     }
 
     /**
