@@ -15,31 +15,22 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
 import java.lang.reflect.InvocationTargetException;
 import java.util.Map;
 
-
-
 /**
  * <p>Utility methods for populating JavaBeans properties via reflection.</p>
  *
  * <p>The implementations are provided by {@link BeanUtilsBean}.
  * These static utility methods use the default instance.
- * More sophisticated behaviour can be provided by using a <code>BeanUtilsBean</code> instance.</p>
+ * More sophisticated behavior can be provided by using a <code>BeanUtilsBean</code> instance.</p>
  *
- * @version $Id: BeanUtils.java 1747095 2016-06-07 00:27:52Z ggregory $
  * @see BeanUtilsBean
  */
-
 public class BeanUtils {
 
-
-    // ------------------------------------------------------ Private Variables
-
-
     /**
      * The debugging detail level for this component.
      *
@@ -53,34 +44,7 @@ public class BeanUtils {
      *             this class.
      */
     @Deprecated
-    private static int debug = 0;
-
-    /**
-     * The <code>debug</code> static property is no longer used
-     * @return debug property
-     * @deprecated BeanUtils now uses commons-logging for all log messages.
-     *             Use your favorite logging tool to configure logging for
-     *             this class.
-     */
-    @Deprecated
-    public static int getDebug() {
-        return (debug);
-    }
-
-    /**
-     * The <code>debug</code> static property is no longer used
-     * @param newDebug debug property
-     * @deprecated BeanUtils now uses commons-logging for all log messages.
-     *             Use your favorite logging tool to configure logging for
-     *             this class.
-     */
-    @Deprecated
-    public static void setDebug(final int newDebug) {
-        debug = newDebug;
-    }
-
-    // --------------------------------------------------------- Class Methods
-
+    private static int debug;
 
     /**
      * <p>Clone a bean based on the available property getters and setters,
@@ -90,7 +54,6 @@ public class BeanUtils {
      *
      * @param bean Bean to be cloned
      * @return the cloned bean
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InstantiationException if a new instance of the bean's
@@ -104,12 +67,9 @@ public class BeanUtils {
     public static Object cloneBean(final Object bean)
             throws IllegalAccessException, InstantiationException,
             InvocationTargetException, NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().cloneBean(bean);
-
     }
 
-
     /**
      * <p>Copy property values from the origin bean to the destination bean
      * for all cases where the property names are the same.</p>
@@ -118,7 +78,6 @@ public class BeanUtils {
      *
      * @param dest Destination bean whose properties are modified
      * @param orig Origin bean whose properties are retrieved
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if the <code>dest</code> or
@@ -131,11 +90,9 @@ public class BeanUtils {
      */
     public static void copyProperties(final Object dest, final Object orig)
         throws IllegalAccessException, InvocationTargetException {
-
         BeanUtilsBean.getInstance().copyProperties(dest, orig);
     }
 
-
     /**
      * <p>Copy the specified property value to the specified destination bean,
      * performing any type conversion that is required.</p>
@@ -145,7 +102,6 @@ public class BeanUtils {
      * @param bean Bean on which setting is to be performed
      * @param name Property name (can be nested/indexed/mapped/combo)
      * @param value Value to be set
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -154,10 +110,19 @@ public class BeanUtils {
      */
     public static void copyProperty(final Object bean, final String name, final Object value)
         throws IllegalAccessException, InvocationTargetException {
-
         BeanUtilsBean.getInstance().copyProperty(bean, name, value);
     }
 
+    /**
+     * Create a cache.
+     * @param <K> the key type of the cache
+     * @param <V> the value type of the cache
+     * @return a new cache
+     * @since 1.8.0
+     */
+    public static <K, V> Map<K, V> createCache() {
+        return new WeakFastHashMap<>();
+    }
 
     /**
      * <p>Return the entire set of properties for which the specified bean
@@ -167,7 +132,6 @@ public class BeanUtils {
      *
      * @param bean Bean whose properties are to be extracted
      * @return Map of property descriptors
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -179,11 +143,9 @@ public class BeanUtils {
     public static Map<String, String> describe(final Object bean)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().describe(bean);
     }
 
-
     /**
      * <p>Return the value of the specified array property of the specified
      * bean, as a String array.</p>
@@ -193,7 +155,6 @@ public class BeanUtils {
      * @param bean Bean whose property is to be extracted
      * @param name Name of the property to be extracted
      * @return The array property value
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -205,10 +166,33 @@ public class BeanUtils {
     public static String[] getArrayProperty(final Object bean, final String name)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getArrayProperty(bean, name);
     }
 
+    /**
+     * Return whether a Map is fast
+     * @param map The map
+     * @return Whether it is fast or not.
+     * @since 1.8.0
+     */
+    public static boolean getCacheFast(final Map<?, ?> map) {
+        if (map instanceof WeakFastHashMap) {
+            return ((WeakFastHashMap<?, ?>) map).getFast();
+        }
+        return false;
+    }
+
+    /**
+     * The <code>debug</code> static property is no longer used
+     * @return debug property
+     * @deprecated BeanUtils now uses commons-logging for all log messages.
+     *             Use your favorite logging tool to configure logging for
+     *             this class.
+     */
+    @Deprecated
+    public static int getDebug() {
+        return debug;
+    }
 
     /**
      * <p>Return the value of the specified indexed property of the specified
@@ -220,7 +204,6 @@ public class BeanUtils {
      * @param name <code>propertyname[index]</code> of the property value
      *  to be extracted
      * @return The indexed property's value, converted to a String
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -232,12 +215,9 @@ public class BeanUtils {
     public static String getIndexedProperty(final Object bean, final String name)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getIndexedProperty(bean, name);
-
     }
 
-
     /**
      * Return the value of the specified indexed property of the specified
      * bean, as a String.  The index is specified as a method parameter and
@@ -249,7 +229,6 @@ public class BeanUtils {
      * @param name Simple property name of the property value to be extracted
      * @param index Index of the property value to be extracted
      * @return The indexed property's value, converted to a String
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -262,14 +241,12 @@ public class BeanUtils {
                                             final String name, final int index)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getIndexedProperty(bean, name, index);
 
     }
 
-
     /**
-     * </p>Return the value of the specified indexed property of the specified
+     * <p>Return the value of the specified indexed property of the specified
      * bean, as a String.</p>
      *
      * <p>For more details see <code>BeanUtilsBean</code>.</p>
@@ -278,7 +255,6 @@ public class BeanUtils {
      * @param name <code>propertyname(index)</code> of the property value
      *  to be extracted
      * @return The mapped property's value, converted to a String
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -290,14 +266,11 @@ public class BeanUtils {
     public static String getMappedProperty(final Object bean, final String name)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getMappedProperty(bean, name);
-
     }
 
-
     /**
-     * </p>Return the value of the specified mapped property of the specified
+     * <p>Return the value of the specified mapped property of the specified
      * bean, as a String.</p>
      *
      * <p>For more details see <code>BeanUtilsBean</code>.</p>
@@ -306,7 +279,6 @@ public class BeanUtils {
      * @param name Simple property name of the property value to be extracted
      * @param key Lookup key of the property value to be extracted
      * @return The mapped property's value, converted to a String
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -319,12 +291,10 @@ public class BeanUtils {
                                            final String name, final String key)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getMappedProperty(bean, name, key);
 
     }
 
-
     /**
      * <p>Return the value of the (possibly nested) property of the specified
      * name, for the specified bean, as a String.</p>
@@ -334,7 +304,6 @@ public class BeanUtils {
      * @param bean Bean whose property is to be extracted
      * @param name Possibly nested name of the property to be extracted
      * @return The nested property's value, converted to a String
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if a nested reference to a
@@ -348,12 +317,10 @@ public class BeanUtils {
     public static String getNestedProperty(final Object bean, final String name)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getNestedProperty(bean, name);
 
     }
 
-
     /**
      * <p>Return the value of the specified property of the specified bean,
      * no matter which property reference format is used, as a String.</p>
@@ -364,7 +331,6 @@ public class BeanUtils {
      * @param name Possibly indexed and/or nested name of the property
      *  to be extracted
      * @return The property's value, converted to a String
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -376,12 +342,9 @@ public class BeanUtils {
     public static String getProperty(final Object bean, final String name)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getProperty(bean, name);
-
     }
 
-
     /**
      * <p>Return the value of the specified simple property of the specified
      * bean, converted to a String.</p>
@@ -391,7 +354,6 @@ public class BeanUtils {
      * @param bean Bean whose property is to be extracted
      * @param name Name of the property to be extracted
      * @return The property's value, converted to a String
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -403,11 +365,24 @@ public class BeanUtils {
     public static String getSimpleProperty(final Object bean, final String name)
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
-
         return BeanUtilsBean.getInstance().getSimpleProperty(bean, name);
-
     }
 
+    /**
+     * If we're running on JDK 1.4 or later, initialize the cause for the given throwable.
+     *
+     * @param  throwable The throwable.
+     * @param  cause     The cause of the throwable.
+     * @return  always true in 1.10.0.
+     * @since 1.8.0
+     * @deprecated Use {@link Throwable#initCause(Throwable)}.
+     * @see Throwable#initCause(Throwable)
+     */
+    @Deprecated
+    public static boolean initCause(final Throwable throwable, final Throwable cause) {
+        throwable.initCause(cause);
+        return true;
+    }
 
     /**
      * <p>Populate the JavaBeans properties of the specified bean, based on
@@ -427,70 +402,9 @@ public class BeanUtils {
      */
     public static void populate(final Object bean, final Map<String, ? extends Object> properties)
         throws IllegalAccessException, InvocationTargetException {
-
         BeanUtilsBean.getInstance().populate(bean, properties);
     }
 
-
-    /**
-     * <p>Set the specified property value, performing type conversions as
-     * required to conform to the type of the destination property.</p>
-     *
-     * <p>For more details see <code>BeanUtilsBean</code>.</p>
-     *
-     * @param bean Bean on which setting is to be performed
-     * @param name Property name (can be nested/indexed/mapped/combo)
-     * @param value Value to be set
-     *
-     * @throws IllegalAccessException if the caller does not have
-     *  access to the property accessor method
-     * @throws InvocationTargetException if the property accessor method
-     *  throws an exception
-     * @see BeanUtilsBean#setProperty
-     */
-    public static void setProperty(final Object bean, final String name, final Object value)
-        throws IllegalAccessException, InvocationTargetException {
-
-        BeanUtilsBean.getInstance().setProperty(bean, name, value);
-    }
-
-    /**
-     * If we're running on JDK 1.4 or later, initialize the cause for the given throwable.
-     *
-     * @param  throwable The throwable.
-     * @param  cause     The cause of the throwable.
-     * @return  true if the cause was initialized, otherwise false.
-     * @since 1.8.0
-     */
-    public static boolean initCause(final Throwable throwable, final Throwable cause) {
-        return BeanUtilsBean.getInstance().initCause(throwable, cause);
-    }
-
-    /**
-     * Create a cache.
-     * @param <K> the key type of the cache
-     * @param <V> the value type of the cache
-     * @return a new cache
-     * @since 1.8.0
-     */
-    public static <K, V> Map<K, V> createCache() {
-        return new WeakFastHashMap<K, V>();
-    }
-
-    /**
-     * Return whether a Map is fast
-     * @param map The map
-     * @return Whether it is fast or not.
-     * @since 1.8.0
-     */
-    public static boolean getCacheFast(final Map<?, ?> map) {
-        if (map instanceof WeakFastHashMap) {
-            return ((WeakFastHashMap<?, ?>) map).getFast();
-        } else {
-            return false;
-        }
-    }
-
     /**
      * Set whether fast on a Map
      * @param map The map
@@ -502,4 +416,46 @@ public class BeanUtils {
             ((WeakFastHashMap<?, ?>)map).setFast(fast);
         }
     }
+
+    /**
+     * The <code>debug</code> static property is no longer used
+     * @param newDebug debug property
+     * @deprecated BeanUtils now uses commons-logging for all log messages.
+     *             Use your favorite logging tool to configure logging for
+     *             this class.
+     */
+    @Deprecated
+    public static void setDebug(final int newDebug) {
+        debug = newDebug;
+    }
+
+    /**
+     * <p>Set the specified property value, performing type conversions as
+     * required to conform to the type of the destination property.</p>
+     *
+     * <p>For more details see <code>BeanUtilsBean</code>.</p>
+     *
+     * @param bean Bean on which setting is to be performed
+     * @param name Property name (can be nested/indexed/mapped/combo)
+     * @param value Value to be set
+     * @throws IllegalAccessException if the caller does not have
+     *  access to the property accessor method
+     * @throws InvocationTargetException if the property accessor method
+     *  throws an exception
+     * @see BeanUtilsBean#setProperty
+     */
+    public static void setProperty(final Object bean, final String name, final Object value)
+        throws IllegalAccessException, InvocationTargetException {
+        BeanUtilsBean.getInstance().setProperty(bean, name, value);
+    }
+
+    /**
+     * Deprecated, all methods are static.
+     *
+     * @deprecated Will be private in 2.0.
+     */
+    @Deprecated
+    public BeanUtils() {
+        // empty
+    }
 }
