@@ -22,10 +22,9 @@ import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Modifier;
 
 /**
- * <p> Utility reflection methods focussed on constructors, modelled after {@link MethodUtils}. </p>
+ * <p>Utility reflection methods focused on constructors, modeled after {@link MethodUtils}.</p>
  *
- * <h3>Known Limitations</h3>
- * <h4>Accessing Public Constructors In A Default Access Superclass</h4>
+ * <strong>Known Limitations: Accessing Public Constructors In A Default Access Superclass</strong>
  * <p>There is an issue when invoking public constructors contained in a default access superclass.
  * Reflection locates these constructors fine and correctly assigns them as public.
  * However, an <code>IllegalAccessException</code> is thrown if the constructors is invoked.</p>
@@ -33,251 +32,22 @@ import java.lang.reflect.Modifier;
  * <p><code>ConstructorUtils</code> contains a workaround for this situation.
  * It will attempt to call <code>setAccessible</code> on this constructor.
  * If this call succeeds, then the method can be invoked as normal.
- * This call will only succeed when the application has sufficient security privilages.
+ * This call will only succeed when the application has sufficient security privileges.
  * If this call fails then a warning will be logged and the method may fail.</p>
- *
- * @version $Id: ConstructorUtils.java 1746219 2016-05-31 05:05:09Z ggregory $
  */
 public class ConstructorUtils {
 
-    // --------------------------------------------------------- Private Members
     /** An empty class array */
-    private static final Class<?>[] EMPTY_CLASS_PARAMETERS = new Class<?>[0];
+    private static final Class<?>[] EMPTY_CLASS_PARAMETERS = {};
     /** An empty object array */
-    private static final Object[] EMPTY_OBJECT_ARRAY = new Object[0];
-
-    // --------------------------------------------------------- Public Methods
-
-    /**
-     * <p>Convenience method returning new instance of <code>klazz</code> using a single argument constructor.
-     * The formal parameter type is inferred from the actual values of <code>arg</code>.
-     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
-     *
-     * <p>The signatures should be assignment compatible.</p>
-     *
-     * @param <T> the type of the object to be constructed
-     * @param klass the class to be constructed.
-     * @param arg the actual argument. May be null (this will result in calling the default constructor).
-     * @return new instance of <code>klazz</code>
-     *
-     * @throws NoSuchMethodException If the constructor cannot be found
-     * @throws IllegalAccessException If an error occurs accessing the constructor
-     * @throws InvocationTargetException If an error occurs invoking the constructor
-     * @throws InstantiationException If an error occurs instantiating the class
-     *
-     * @see #invokeConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
-     */
-    public static <T> T invokeConstructor(final Class<T> klass, final Object arg)
-        throws
-            NoSuchMethodException,
-            IllegalAccessException,
-            InvocationTargetException,
-            InstantiationException {
-
-        final Object[] args = toArray(arg);
-        return invokeConstructor(klass, args);
-    }
-
-    /**
-     * <p>Returns new instance of <code>klazz</code> created using the actual arguments <code>args</code>.
-     * The formal parameter types are inferred from the actual values of <code>args</code>.
-     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
-     *
-     * <p>The signatures should be assignment compatible.</p>
-     *
-     * @param <T> the type of the object to be constructed
-     * @param klass the class to be constructed.
-     * @param args actual argument array. May be null (this will result in calling the default constructor).
-     * @return new instance of <code>klazz</code>
-     *
-     * @throws NoSuchMethodException If the constructor cannot be found
-     * @throws IllegalAccessException If an error occurs accessing the constructor
-     * @throws InvocationTargetException If an error occurs invoking the constructor
-     * @throws InstantiationException If an error occurs instantiating the class
-     *
-     * @see #invokeConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
-     */
-    public static <T> T invokeConstructor(final Class<T> klass, Object[] args)
-        throws
-            NoSuchMethodException,
-            IllegalAccessException,
-            InvocationTargetException,
-            InstantiationException {
-
-        if (null == args) {
-            args = EMPTY_OBJECT_ARRAY;
-        }
-        final int arguments = args.length;
-        final Class<?> parameterTypes[] = new Class<?>[arguments];
-        for (int i = 0; i < arguments; i++) {
-            parameterTypes[i] = args[i].getClass();
-        }
-        return invokeConstructor(klass, args, parameterTypes);
-    }
-
-    /**
-     * <p>Returns new instance of <code>klazz</code> created using constructor
-     * with signature <code>parameterTypes</code> and actual arguments <code>args</code>.</p>
-     *
-     * <p>The signatures should be assignment compatible.</p>
-     *
-     * @param <T> the type of the object to be constructed
-     * @param klass the class to be constructed.
-     * @param args actual argument array. May be null (this will result in calling the default constructor).
-     * @param parameterTypes parameter types array
-     * @return new instance of <code>klazz</code>
-     *
-     * @throws NoSuchMethodException if matching constructor cannot be found
-     * @throws IllegalAccessException thrown on the constructor's invocation
-     * @throws InvocationTargetException thrown on the constructor's invocation
-     * @throws InstantiationException thrown on the constructor's invocation
-     * @see Constructor#newInstance
-     */
-    public static <T> T invokeConstructor(
-        final Class<T> klass,
-        Object[] args,
-        Class<?>[] parameterTypes)
-        throws
-            NoSuchMethodException,
-            IllegalAccessException,
-            InvocationTargetException,
-            InstantiationException {
-
-        if (parameterTypes == null) {
-            parameterTypes = EMPTY_CLASS_PARAMETERS;
-        }
-        if (args == null) {
-            args = EMPTY_OBJECT_ARRAY;
-        }
-
-        final Constructor<T> ctor =
-            getMatchingAccessibleConstructor(klass, parameterTypes);
-        if (null == ctor) {
-            throw new NoSuchMethodException(
-                "No such accessible constructor on object: " + klass.getName());
-        }
-        return ctor.newInstance(args);
-    }
-
-
-    /**
-     * <p>Convenience method returning new instance of <code>klazz</code> using a single argument constructor.
-     * The formal parameter type is inferred from the actual values of <code>arg</code>.
-     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
-     *
-     * <p>The signatures should match exactly.</p>
-     *
-     * @param <T> the type of the object to be constructed
-     * @param klass the class to be constructed.
-     * @param arg the actual argument. May be null (this will result in calling the default constructor).
-     * @return new instance of <code>klazz</code>
-     *
-     * @throws NoSuchMethodException If the constructor cannot be found
-     * @throws IllegalAccessException If an error occurs accessing the constructor
-     * @throws InvocationTargetException If an error occurs invoking the constructor
-     * @throws InstantiationException If an error occurs instantiating the class
-     *
-     * @see #invokeExactConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
-     */
-    public static <T> T invokeExactConstructor(final Class<T> klass, final Object arg)
-        throws
-            NoSuchMethodException,
-            IllegalAccessException,
-            InvocationTargetException,
-            InstantiationException {
-
-        final Object[] args = toArray(arg);
-        return invokeExactConstructor(klass, args);
-    }
-
-    /**
-     * <p>Returns new instance of <code>klazz</code> created using the actual arguments <code>args</code>.
-     * The formal parameter types are inferred from the actual values of <code>args</code>.
-     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
-     *
-     * <p>The signatures should match exactly.</p>
-     *
-     * @param <T> the type of the object to be constructed
-     * @param klass the class to be constructed.
-     * @param args actual argument array. May be null (this will result in calling the default constructor).
-     * @return new instance of <code>klazz</code>
-     *
-     * @throws NoSuchMethodException If the constructor cannot be found
-     * @throws IllegalAccessException If an error occurs accessing the constructor
-     * @throws InvocationTargetException If an error occurs invoking the constructor
-     * @throws InstantiationException If an error occurs instantiating the class
-     *
-     * @see #invokeExactConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
-     */
-    public static <T> T invokeExactConstructor(final Class<T> klass, Object[] args)
-        throws
-            NoSuchMethodException,
-            IllegalAccessException,
-            InvocationTargetException,
-            InstantiationException {
-
-        if (null == args) {
-            args = EMPTY_OBJECT_ARRAY;
-        }
-        final int arguments = args.length;
-        final Class<?> parameterTypes[] = new Class[arguments];
-        for (int i = 0; i < arguments; i++) {
-            parameterTypes[i] = args[i].getClass();
-        }
-        return invokeExactConstructor(klass, args, parameterTypes);
-    }
-
-    /**
-     * <p>Returns new instance of <code>klazz</code> created using constructor
-     * with signature <code>parameterTypes</code> and actual arguments
-     * <code>args</code>.</p>
-     *
-     * <p>The signatures should match exactly.</p>
-     *
-     * @param <T> the type of the object to be constructed
-     * @param klass the class to be constructed.
-     * @param args actual argument array. May be null (this will result in calling the default constructor).
-     * @param parameterTypes parameter types array
-     * @return new instance of <code>klazz</code>
-     *
-     * @throws NoSuchMethodException if matching constructor cannot be found
-     * @throws IllegalAccessException thrown on the constructor's invocation
-     * @throws InvocationTargetException thrown on the constructor's invocation
-     * @throws InstantiationException thrown on the constructor's invocation
-     * @see Constructor#newInstance
-     */
-    public static <T> T invokeExactConstructor(
-        final Class<T> klass,
-        Object[] args,
-        Class<?>[] parameterTypes)
-        throws
-            NoSuchMethodException,
-            IllegalAccessException,
-            InvocationTargetException,
-            InstantiationException {
-
-        if (args == null) {
-            args = EMPTY_OBJECT_ARRAY;
-        }
-
-        if (parameterTypes == null) {
-            parameterTypes = EMPTY_CLASS_PARAMETERS;
-        }
-
-        final Constructor<T> ctor = getAccessibleConstructor(klass, parameterTypes);
-        if (null == ctor) {
-            throw new NoSuchMethodException(
-                "No such accessible constructor on object: " + klass.getName());
-        }
-        return ctor.newInstance(args);
-    }
+    private static final Object[] EMPTY_OBJECT_ARRAY = {};
 
     /**
      * Returns a constructor with single argument.
      * @param <T> the type of the constructor
      * @param klass the class to be constructed
      * @param parameterType The constructor parameter type
-     * @return null if matching accessible constructor can not be found.
+     * @return null if matching accessible constructor cannot be found.
      * @see Class#getConstructor
      * @see #getAccessibleConstructor(java.lang.reflect.Constructor)
      */
@@ -294,7 +64,7 @@ public class ConstructorUtils {
      * @param <T> the type to be constructed
      * @param klass the class to be constructed
      * @param parameterTypes the parameter array
-     * @return null if matching accessible constructor can not be found
+     * @return null if matching accessible constructor cannot be found
      * @see Class#getConstructor
      * @see #getAccessibleConstructor(java.lang.reflect.Constructor)
      */
@@ -306,7 +76,7 @@ public class ConstructorUtils {
             return getAccessibleConstructor(
                 klass.getConstructor(parameterTypes));
         } catch (final NoSuchMethodException e) {
-            return (null);
+            return null;
         }
     }
 
@@ -314,40 +84,27 @@ public class ConstructorUtils {
      * Returns accessible version of the given constructor.
      * @param <T> the type of the constructor
      * @param ctor prototype constructor object.
-     * @return <code>null</code> if accessible constructor can not be found.
+     * @return <code>null</code> if accessible constructor cannot be found.
      * @see java.lang.SecurityManager
      */
     public static <T> Constructor<T> getAccessibleConstructor(final Constructor<T> ctor) {
 
         // Make sure we have a method to check
-        if (ctor == null) {
-            return (null);
-        }
-
         // If the requested method is not public we cannot call it
-        if (!Modifier.isPublic(ctor.getModifiers())) {
-            return (null);
+        if (ctor == null || !Modifier.isPublic(ctor.getModifiers())) {
+            return null;
         }
 
         // If the declaring class is public, we are done
         final Class<T> clazz = ctor.getDeclaringClass();
         if (Modifier.isPublic(clazz.getModifiers())) {
-            return (ctor);
+            return ctor;
         }
 
         // what else can we do?
         return null;
     }
 
-    private static Object[] toArray(final Object arg) {
-        Object[] args = null;
-        if (arg != null) {
-            args = new Object[] { arg };
-        }
-        return args;
-    }
-
-    // -------------------------------------------------------- Private Methods
     /**
      * <p>Find an accessible constructor with compatible parameters.
      * Compatible parameters mean that every method parameter is assignable from
@@ -384,7 +141,7 @@ public class ConstructorUtils {
                 // modifer is public.
                 //
                 // The following workaround solves the problem but will only
-                // work from sufficiently privilages code.
+                // work from sufficiently privileges code.
                 //
                 // Better workarounds would be greatfully accepted.
                 //
@@ -400,7 +157,7 @@ public class ConstructorUtils {
         // search through all methods
         final int paramSize = parameterTypes.length;
         final Constructor<?>[] ctors = clazz.getConstructors();
-        for (Constructor<?> ctor2 : ctors) {
+        for (final Constructor<?> ctor2 : ctors) {
             // compare parameters
             final Class<?>[] ctorParams = ctor2.getParameterTypes();
             final int ctorParamSize = ctorParams.length;
@@ -441,4 +198,235 @@ public class ConstructorUtils {
         return null;
     }
 
+    /**
+     * <p>Convenience method returning new instance of <code>klazz</code> using a single argument constructor.
+     * The formal parameter type is inferred from the actual values of <code>arg</code>.
+     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
+     *
+     * <p>The signatures should be assignment compatible.</p>
+     *
+     * @param <T> the type of the object to be constructed
+     * @param klass the class to be constructed.
+     * @param arg the actual argument. May be null (this will result in calling the default constructor).
+     * @return new instance of <code>klazz</code>
+     * @throws NoSuchMethodException If the constructor cannot be found
+     * @throws IllegalAccessException If an error occurs accessing the constructor
+     * @throws InvocationTargetException If an error occurs invoking the constructor
+     * @throws InstantiationException If an error occurs instantiating the class
+     * @see #invokeConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
+     */
+    public static <T> T invokeConstructor(final Class<T> klass, final Object arg)
+        throws
+            NoSuchMethodException,
+            IllegalAccessException,
+            InvocationTargetException,
+            InstantiationException {
+
+        final Object[] args = toArray(arg);
+        return invokeConstructor(klass, args);
+    }
+
+    /**
+     * <p>Returns new instance of <code>klazz</code> created using the actual arguments <code>args</code>.
+     * The formal parameter types are inferred from the actual values of <code>args</code>.
+     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
+     *
+     * <p>The signatures should be assignment compatible.</p>
+     *
+     * @param <T> the type of the object to be constructed
+     * @param klass the class to be constructed.
+     * @param args actual argument array. May be null (this will result in calling the default constructor).
+     * @return new instance of <code>klazz</code>
+     * @throws NoSuchMethodException If the constructor cannot be found
+     * @throws IllegalAccessException If an error occurs accessing the constructor
+     * @throws InvocationTargetException If an error occurs invoking the constructor
+     * @throws InstantiationException If an error occurs instantiating the class
+     * @see #invokeConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
+     */
+    public static <T> T invokeConstructor(final Class<T> klass, Object[] args)
+        throws
+            NoSuchMethodException,
+            IllegalAccessException,
+            InvocationTargetException,
+            InstantiationException {
+
+        if (null == args) {
+            args = EMPTY_OBJECT_ARRAY;
+        }
+        final int arguments = args.length;
+        final Class<?> parameterTypes[] = new Class<?>[arguments];
+        for (int i = 0; i < arguments; i++) {
+            parameterTypes[i] = args[i].getClass();
+        }
+        return invokeConstructor(klass, args, parameterTypes);
+    }
+
+    /**
+     * <p>Returns new instance of <code>klazz</code> created using constructor
+     * with signature <code>parameterTypes</code> and actual arguments <code>args</code>.</p>
+     *
+     * <p>The signatures should be assignment compatible.</p>
+     *
+     * @param <T> the type of the object to be constructed
+     * @param klass the class to be constructed.
+     * @param args actual argument array. May be null (this will result in calling the default constructor).
+     * @param parameterTypes parameter types array
+     * @return new instance of <code>klazz</code>
+     * @throws NoSuchMethodException if matching constructor cannot be found
+     * @throws IllegalAccessException thrown on the constructor's invocation
+     * @throws InvocationTargetException thrown on the constructor's invocation
+     * @throws InstantiationException thrown on the constructor's invocation
+     * @see Constructor#newInstance
+     */
+    public static <T> T invokeConstructor(
+        final Class<T> klass,
+        Object[] args,
+        Class<?>[] parameterTypes)
+        throws
+            NoSuchMethodException,
+            IllegalAccessException,
+            InvocationTargetException,
+            InstantiationException {
+
+        if (parameterTypes == null) {
+            parameterTypes = EMPTY_CLASS_PARAMETERS;
+        }
+        if (args == null) {
+            args = EMPTY_OBJECT_ARRAY;
+        }
+
+        final Constructor<T> ctor =
+            getMatchingAccessibleConstructor(klass, parameterTypes);
+        if (null == ctor) {
+            throw new NoSuchMethodException(
+                "No such accessible constructor on object: " + klass.getName());
+        }
+        return ctor.newInstance(args);
+    }
+
+    /**
+     * <p>Convenience method returning new instance of <code>klazz</code> using a single argument constructor.
+     * The formal parameter type is inferred from the actual values of <code>arg</code>.
+     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
+     *
+     * <p>The signatures should match exactly.</p>
+     *
+     * @param <T> the type of the object to be constructed
+     * @param klass the class to be constructed.
+     * @param arg the actual argument. May be null (this will result in calling the default constructor).
+     * @return new instance of <code>klazz</code>
+     * @throws NoSuchMethodException If the constructor cannot be found
+     * @throws IllegalAccessException If an error occurs accessing the constructor
+     * @throws InvocationTargetException If an error occurs invoking the constructor
+     * @throws InstantiationException If an error occurs instantiating the class
+     * @see #invokeExactConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
+     */
+    public static <T> T invokeExactConstructor(final Class<T> klass, final Object arg)
+        throws
+            NoSuchMethodException,
+            IllegalAccessException,
+            InvocationTargetException,
+            InstantiationException {
+
+        final Object[] args = toArray(arg);
+        return invokeExactConstructor(klass, args);
+    }
+
+    /**
+     * <p>Returns new instance of <code>klazz</code> created using the actual arguments <code>args</code>.
+     * The formal parameter types are inferred from the actual values of <code>args</code>.
+     * See {@link #invokeExactConstructor(Class, Object[], Class[])} for more details.</p>
+     *
+     * <p>The signatures should match exactly.</p>
+     *
+     * @param <T> the type of the object to be constructed
+     * @param klass the class to be constructed.
+     * @param args actual argument array. May be null (this will result in calling the default constructor).
+     * @return new instance of <code>klazz</code>
+     * @throws NoSuchMethodException If the constructor cannot be found
+     * @throws IllegalAccessException If an error occurs accessing the constructor
+     * @throws InvocationTargetException If an error occurs invoking the constructor
+     * @throws InstantiationException If an error occurs instantiating the class
+     * @see #invokeExactConstructor(java.lang.Class, java.lang.Object[], java.lang.Class[])
+     */
+    public static <T> T invokeExactConstructor(final Class<T> klass, Object[] args)
+        throws
+            NoSuchMethodException,
+            IllegalAccessException,
+            InvocationTargetException,
+            InstantiationException {
+
+        if (null == args) {
+            args = EMPTY_OBJECT_ARRAY;
+        }
+        final int arguments = args.length;
+        final Class<?> parameterTypes[] = new Class[arguments];
+        for (int i = 0; i < arguments; i++) {
+            parameterTypes[i] = args[i].getClass();
+        }
+        return invokeExactConstructor(klass, args, parameterTypes);
+    }
+
+    /**
+     * <p>Returns new instance of <code>klazz</code> created using constructor
+     * with signature <code>parameterTypes</code> and actual arguments
+     * <code>args</code>.</p>
+     *
+     * <p>The signatures should match exactly.</p>
+     *
+     * @param <T> the type of the object to be constructed
+     * @param klass the class to be constructed.
+     * @param args actual argument array. May be null (this will result in calling the default constructor).
+     * @param parameterTypes parameter types array
+     * @return new instance of <code>klazz</code>
+     * @throws NoSuchMethodException if matching constructor cannot be found
+     * @throws IllegalAccessException thrown on the constructor's invocation
+     * @throws InvocationTargetException thrown on the constructor's invocation
+     * @throws InstantiationException thrown on the constructor's invocation
+     * @see Constructor#newInstance
+     */
+    public static <T> T invokeExactConstructor(
+        final Class<T> klass,
+        Object[] args,
+        Class<?>[] parameterTypes)
+        throws
+            NoSuchMethodException,
+            IllegalAccessException,
+            InvocationTargetException,
+            InstantiationException {
+
+        if (args == null) {
+            args = EMPTY_OBJECT_ARRAY;
+        }
+
+        if (parameterTypes == null) {
+            parameterTypes = EMPTY_CLASS_PARAMETERS;
+        }
+
+        final Constructor<T> ctor = getAccessibleConstructor(klass, parameterTypes);
+        if (null == ctor) {
+            throw new NoSuchMethodException(
+                "No such accessible constructor on object: " + klass.getName());
+        }
+        return ctor.newInstance(args);
+    }
+
+    private static Object[] toArray(final Object arg) {
+        Object[] args = null;
+        if (arg != null) {
+            args = new Object[] { arg };
+        }
+        return args;
+    }
+
+    /**
+     * Deprecated, all methods are static.
+     *
+     * @deprecated Will be private in 2.0.
+     */
+    @Deprecated
+    public ConstructorUtils() {
+        // empty
+    }
+
 }
