@@ -62,17 +62,16 @@ import java.util.WeakHashMap;
  *      buf.set("New Value");
  *    }
  * </pre>
- * </p>
- *
  * <p><strong>Note:</strong> This class takes some care to ensure that when
  * a component which uses this class is "undeployed" by a container the
  * component-specific classloader and all its associated classes (and their
  * static variables) are garbage-collected. Unfortunately there is one
- * scenario in which this does <i>not</i> work correctly and there
+ * scenario in which this does <em>not</em> work correctly and there
  * is unfortunately no known workaround other than ensuring that the
  * component (or its container) calls the "unset" method on this class for
  * each instance of this class when the component is undeployed. The problem
  * occurs if:
+ * </p>
  * <ul>
  * <li>the class containing a static instance of this class was loaded via
  * a shared classloader, and</li>
@@ -80,6 +79,7 @@ import java.util.WeakHashMap;
  * via the component-specific classloader (or any of the objects it refers
  * to were loaded via that classloader).</li>
  * </ul>
+ * <p>
  * The result is that the map managed by this object still contains a strong
  * reference to the stored object, which contains a strong reference to the
  * classloader that loaded it, meaning that although the container has
@@ -98,36 +98,17 @@ import java.util.WeakHashMap;
  * needs, ie avoided providing classes loaded via a "shared" classloader.</p>
  *
  * @param <T> the type of data stored in an instance
- * @version $Id$
  * @see java.lang.Thread#getContextClassLoader
  */
 public class ContextClassLoaderLocal<T> {
-    private final Map<ClassLoader, T> valueByClassLoader = new WeakHashMap<ClassLoader, T>();
-    private boolean globalValueInitialized = false;
+    private final Map<ClassLoader, T> valueByClassLoader = new WeakHashMap<>();
+    private boolean globalValueInitialized;
     private T globalValue;
 
     /**
      * Construct a context classloader instance
      */
     public ContextClassLoaderLocal() {
-        super();
-    }
-
-    /**
-     * Returns the initial value for this ContextClassLoaderLocal
-     * variable. This method will be called once per Context ClassLoader for
-     * each ContextClassLoaderLocal, the first time it is accessed
-     * with get or set.  If the programmer desires ContextClassLoaderLocal variables
-     * to be initialized to some value other than null, ContextClassLoaderLocal must
-     * be subclassed, and this method overridden.  Typically, an anonymous
-     * inner class will be used.  Typical implementations of initialValue
-     * will call an appropriate constructor and return the newly constructed
-     * object.
-     *
-     * @return a new Object to be used as an initial value for this ContextClassLoaderLocal
-     */
-    protected T initialValue() {
-        return null;
     }
 
     /**
@@ -149,7 +130,7 @@ public class ContextClassLoaderLocal<T> {
             if (contextClassLoader != null) {
 
                 T value = valueByClassLoader.get(contextClassLoader);
-                if ((value == null)
+                if (value == null
                 && !valueByClassLoader.containsKey(contextClassLoader)) {
                     value = initialValue();
                     valueByClassLoader.put(contextClassLoader, value);
@@ -168,6 +149,23 @@ public class ContextClassLoaderLocal<T> {
         return globalValue;
     }
 
+    /**
+     * Returns the initial value for this ContextClassLoaderLocal
+     * variable. This method will be called once per Context ClassLoader for
+     * each ContextClassLoaderLocal, the first time it is accessed
+     * with get or set.  If the programmer desires ContextClassLoaderLocal variables
+     * to be initialized to some value other than null, ContextClassLoaderLocal must
+     * be subclassed, and this method overridden.  Typically, an anonymous
+     * inner class will be used.  Typical implementations of initialValue
+     * will call an appropriate constructor and return the newly constructed
+     * object.
+     *
+     * @return a new Object to be used as an initial value for this ContextClassLoaderLocal
+     */
+    protected T initialValue() {
+        return null;
+    }
+
     /**
      * Sets the value - a value is provided per (thread) context classloader.
      * This mechanism provides isolation for web apps deployed in the same container.
@@ -209,9 +207,9 @@ public class ContextClassLoaderLocal<T> {
 
     /**
      * Unsets the value associated with the given classloader
-     * @param classLoader The classloader to <i>unset</i> for
+     * @param classLoader The classloader to <em>unset</em> for
      */
     public synchronized void unset(final ClassLoader classLoader) {
         valueByClassLoader.remove(classLoader);
     }
-}
\ No newline at end of file
+}
