@@ -26,18 +26,23 @@ package org.apache.commons.beanutils;
  * </p>
  *
  * @see BeanUtilsBean2
- * @version $Id$
  * @since 1.8.0
  */
 public class ConvertUtilsBean2 extends ConvertUtilsBean {
 
+    /**
+     * Constructs a new instance.
+     */
+    public ConvertUtilsBean2() {
+        // empty
+    }
+
     /**
      * Delegates to the new {@link ConvertUtilsBean#convert(Object, Class)}
      * method.
      *
      * @param value Value to be converted (may be null)
      * @return The converted String value or null if value is null
-     *
      * @see ConvertUtilsBean#convert(String[], Class)
      */
     @Override
@@ -52,7 +57,6 @@ public class ConvertUtilsBean2 extends ConvertUtilsBean {
      * @param value Value to be converted (may be null)
      * @param clazz Java class to be converted to (must not be null)
      * @return The converted value or null if value is null
-     *
      * @see ConvertUtilsBean#convert(String[], Class)
      */
     @Override
@@ -67,7 +71,6 @@ public class ConvertUtilsBean2 extends ConvertUtilsBean {
      * @param value Array of values to be converted
      * @param clazz Java array or element class to be converted to (must not be null)
      * @return The converted value
-     *
      * @see ConvertUtilsBean#convert(String[], Class)
      */
     @Override
