@@ -20,7 +20,7 @@ package org.apache.commons.beanutils;
 import java.lang.reflect.InvocationTargetException;
 
 /**
- * <p>Implementation of <code>DynaBean</code> that wraps a standard JavaBean
+ * <p>Implements <code>DynaBean</code> to wrap a standard JavaBean
  * instance, so that DynaBean APIs can be used to access its properties,
  * though this implementation allows type conversion to occur when properties are set.
  * This means that (say) Strings can be passed in as values in setter methods and
@@ -29,12 +29,11 @@ import java.lang.reflect.InvocationTargetException;
  * <p><strong>IMPLEMENTATION NOTE</strong> - This implementation does not
  * support the <code>contains()</code> and <code>remove()</code> methods.</p>
  *
- * @version $Id$
  */
 
 public class ConvertingWrapDynaBean extends WrapDynaBean {
 
-
+    private static final long serialVersionUID = 1L;
 
     /**
      * Construct a new <code>DynaBean</code> associated with the specified
@@ -48,7 +47,6 @@ public class ConvertingWrapDynaBean extends WrapDynaBean {
 
     }
 
-
     /**
      * Set the value of the property with the specified name
      * performing any type conversions if necessary. So this method
@@ -56,27 +54,18 @@ public class ConvertingWrapDynaBean extends WrapDynaBean {
      *
      * @param name Name of the property whose value is to be set
      * @param value Value to which this property is to be set
-     *
      * @throws IllegalArgumentException if there are any problems
      *            copying the property.
      */
     @Override
     public void set(final String name, final Object value) {
-
         try {
             BeanUtils.copyProperty(instance, name, value);
         } catch (final InvocationTargetException ite) {
             final Throwable cause = ite.getTargetException();
-            throw new IllegalArgumentException
-                    ("Error setting property '" + name +
-                              "' nested exception - " + cause);
+            throw new IllegalArgumentException("Error setting property '" + name + "' nested exception - " + cause);
         } catch (final Throwable t) {
-            final IllegalArgumentException iae = new IllegalArgumentException
-                    ("Error setting property '" + name +
-                              "', exception - " + t);
-            BeanUtils.initCause(iae, t);
-            throw iae;
+            throw new IllegalArgumentException("Error setting property '" + name + "', exception - " + t, t);
         }
-
     }
 }
