@@ -15,10 +15,8 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
-
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
@@ -27,7 +25,6 @@ import java.io.StreamCorruptedException;
 import java.util.List;
 import java.util.Map;
 
-
 /**
  * <p>The metadata describing an individual property of a DynaBean.</p>
  *
@@ -38,13 +35,11 @@ import java.util.Map;
  * Alternatively, an implementatin may choose to ignore this property.
  * All keys for maps must be of type String so no meta data is needed for map keys.</p>
  *
- * @version $Id$
  */
 
 public class DynaProperty implements Serializable {
 
-    // ----------------------------------------------------------- Constants
-
+    private static final long serialVersionUID = 1L;
     /*
      * There are issues with serializing primitive class types on certain JVM versions
      * (including java 1.3).
@@ -62,9 +57,14 @@ public class DynaProperty implements Serializable {
     private static final int LONG_TYPE = 7;
     private static final int SHORT_TYPE = 8;
 
+    /** Property name */
+    protected String name;
 
-    // ----------------------------------------------------------- Constructors
+    /** Property type */
+    protected transient Class<?> type;
 
+    /** The <em>(optional)</em> type of content elements for indexed <code>DynaProperty</code> */
+    protected transient Class<?> contentType;
 
     /**
      * Construct a property that accepts any data type.
@@ -76,8 +76,6 @@ public class DynaProperty implements Serializable {
         this(name, Object.class);
 
     }
-
-
     /**
      * Construct a property of the specified data type.
      *
@@ -86,7 +84,6 @@ public class DynaProperty implements Serializable {
      */
     public DynaProperty(final String name, final Class<?> type) {
 
-        super();
         this.name = name;
         this.type = type;
         if (type != null && type.isArray()) {
@@ -105,46 +102,37 @@ public class DynaProperty implements Serializable {
      */
     public DynaProperty(final String name, final Class<?> type, final Class<?> contentType) {
 
-        super();
         this.name = name;
         this.type = type;
         this.contentType = contentType;
 
     }
-
-    // ------------------------------------------------------------- Properties
-
-    /** Property name */
-    protected String name = null;
     /**
-     * Get the name of this property.
-     * @return the name of the property
+     * Checks this instance against the specified Object for equality. Overrides the
+     * default refererence test for equality provided by {@link java.lang.Object#equals(Object)}
+     * @param obj The object to compare to
+     * @return <code>true</code> if object is a dyna property with the same name
+     * type and content type, otherwise <code>false</code>
+     * @since 1.8.0
      */
-    public String getName() {
-        return (this.name);
+    @Override
+    public boolean equals(final Object obj) {
+
+        boolean result = false;
+
+        result = obj == this;
+
+        if (!result && obj instanceof DynaProperty) {
+            final DynaProperty that = (DynaProperty) obj;
+            result =
+               (this.name == null ? that.name == null : this.name.equals(that.name)) &&
+               (this.type == null ? that.type == null : this.type.equals(that.type)) &&
+               (this.contentType == null ? that.contentType == null : this.contentType.equals(that.contentType));
+        }
+
+        return result;
     }
 
-    /** Property type */
-    protected transient Class<?> type = null;
-    /**
-     * <p>Gets the Java class representing the data type of the underlying property
-     * values.</p>
-     *
-     * <p>There are issues with serializing primitive class types on certain JVM versions
-     * (including java 1.3).
-     * Therefore, this field <strong>must not be serialized using the standard methods</strong>.</p>
-     *
-     * <p><strong>Please leave this field as <code>transient</code></strong></p>
-     *
-     * @return the property type
-     */
-    public Class<?> getType() {
-        return (this.type);
-    }
-
-
-    /** The <em>(optional)</em> type of content elements for indexed <code>DynaProperty</code> */
-    protected transient Class<?> contentType;
     /**
      * Gets the <em>(optional)</em> type of the indexed content for <code>DynaProperty</code>'s
      * that support this feature.
@@ -159,71 +147,28 @@ public class DynaProperty implements Serializable {
     public Class<?> getContentType() {
         return contentType;
     }
-
-    // --------------------------------------------------------- Public Methods
-
-
     /**
-     * Does this property represent an indexed value (ie an array or List)?
-     *
-     * @return <code>true</code> if the property is indexed (i.e. is a List or
-     * array), otherwise <code>false</code>
+     * Get the name of this property.
+     * @return the name of the property
      */
-    public boolean isIndexed() {
-
-        if (type == null) {
-            return (false);
-        } else if (type.isArray()) {
-            return (true);
-        } else if (List.class.isAssignableFrom(type)) {
-            return (true);
-        } else {
-            return (false);
-        }
-
-    }
-
-
-    /**
-     * Does this property represent a mapped value (ie a Map)?
-     *
-     * @return <code>true</code> if the property is a Map
-     * otherwise <code>false</code>
-     */
-    public boolean isMapped() {
-
-        if (type == null) {
-            return (false);
-        } else {
-            return (Map.class.isAssignableFrom(type));
-        }
-
+    public String getName() {
+        return this.name;
     }
 
     /**
-     * Checks this instance against the specified Object for equality. Overrides the
-     * default refererence test for equality provided by {@link java.lang.Object#equals(Object)}
-     * @param obj The object to compare to
-     * @return <code>true</code> if object is a dyna property with the same name
-     * type and content type, otherwise <code>false</code>
-     * @since 1.8.0
+     * <p>Gets the Java class representing the data type of the underlying property
+     * values.</p>
+     *
+     * <p>There are issues with serializing primitive class types on certain JVM versions
+     * (including java 1.3).
+     * Therefore, this field <strong>must not be serialized using the standard methods</strong>.</p>
+     *
+     * <p><strong>Please leave this field as <code>transient</code></strong></p>
+     *
+     * @return the property type
      */
-    @Override
-    public boolean equals(final Object obj) {
-
-        boolean result = false;
-
-        result = (obj == this);
-
-        if ((!result) && obj instanceof DynaProperty) {
-            final DynaProperty that = (DynaProperty) obj;
-            result =
-               ((this.name == null) ? (that.name == null) : (this.name.equals(that.name))) &&
-               ((this.type == null) ? (that.type == null) : (this.type.equals(that.type))) &&
-               ((this.contentType == null) ? (that.contentType == null) : (this.contentType.equals(that.contentType)));
-        }
-
-        return result;
+    public Class<?> getType() {
+        return this.type;
     }
 
     /**
@@ -236,20 +181,97 @@ public class DynaProperty implements Serializable {
 
        int result = 1;
 
-       result = result * 31 + ((name == null) ? 0 : name.hashCode());
-       result = result * 31 + ((type == null) ? 0 : type.hashCode());
-       result = result * 31 + ((contentType == null) ? 0 : contentType.hashCode());
+       result = result * 31 + (name == null ? 0 : name.hashCode());
+       result = result * 31 + (type == null ? 0 : type.hashCode());
+       return result * 31 + (contentType == null ? 0 : contentType.hashCode());
+    }
 
-       return result;
+    /**
+     * Does this property represent an indexed value (ie an array or List)?
+     *
+     * @return <code>true</code> if the property is indexed (i.e. is a List or
+     * array), otherwise <code>false</code>
+     */
+    public boolean isIndexed() {
+
+        if (type == null) {
+            return false;
+        }
+        if (type.isArray() || List.class.isAssignableFrom(type)) {
+            return true;
+        }
+        return false;
+
+    }
+
+    /**
+     * Does this property represent a mapped value (ie a Map)?
+     *
+     * @return <code>true</code> if the property is a Map
+     * otherwise <code>false</code>
+     */
+    public boolean isMapped() {
+
+        if (type == null) {
+            return false;
+        }
+        return Map.class.isAssignableFrom(type);
+
+    }
+
+    /**
+     * Reads a class using safe encoding to workaround java 1.3 serialization bug.
+     */
+    private Class<?> readAnyClass(final ObjectInputStream in) throws IOException, ClassNotFoundException {
+        // read back type class safely
+        if (!in.readBoolean()) {
+            // it's another class
+            return (Class<?>) in.readObject();
+        }
+        // it's a type constant
+        switch (in.readInt()) {
+
+            case BOOLEAN_TYPE: return   Boolean.TYPE;
+            case BYTE_TYPE:    return      Byte.TYPE;
+            case CHAR_TYPE:    return Character.TYPE;
+            case DOUBLE_TYPE:  return    Double.TYPE;
+            case FLOAT_TYPE:   return     Float.TYPE;
+            case INT_TYPE:     return   Integer.TYPE;
+            case LONG_TYPE:    return      Long.TYPE;
+            case SHORT_TYPE:   return     Short.TYPE;
+            default:
+                // something's gone wrong
+                throw new StreamCorruptedException(
+                    "Invalid primitive type. "
+                    + "Check version of beanutils used to serialize is compatible.");
+
+        }
+    }
+
+    /**
+     * Reads field values for this object safely. There are issues with serializing primitive class types on certain JVM versions (including java 1.3). This
+     * method provides a workaround.
+     *
+     * @param in the content source.
+     * @throws IOException            when the stream data values are outside expected range
+     * @throws ClassNotFoundException Class of a serialized object cannot be found.
+     */
+    private void readObject(final ObjectInputStream in) throws IOException, ClassNotFoundException {
+        this.type = readAnyClass(in);
+        if (isMapped() || isIndexed()) {
+            this.contentType = readAnyClass(in);
+        }
+        // read other values
+        in.defaultReadObject();
     }
 
     /**
      * Return a String representation of this Object.
+     *
      * @return a String representation of the dyna property
      */
     @Override
     public String toString() {
-
         final StringBuilder sb = new StringBuilder("DynaProperty[name=");
         sb.append(this.name);
         sb.append(",type=");
@@ -258,32 +280,14 @@ public class DynaProperty implements Serializable {
             sb.append(" <").append(this.contentType).append(">");
         }
         sb.append("]");
-        return (sb.toString());
+        return sb.toString();
 
     }
 
-    // --------------------------------------------------------- Serialization helper methods
-
     /**
-     * Writes this object safely.
-     * There are issues with serializing primitive class types on certain JVM versions
-     * (including java 1.3).
-     * This method provides a workaround.
-     */
-    private void writeObject(final ObjectOutputStream out) throws IOException {
-
-        writeAnyClass(this.type,out);
-
-        if (isMapped() || isIndexed()) {
-            writeAnyClass(this.contentType,out);
-        }
-
-        // write out other values
-        out.defaultWriteObject();
-    }
-
-    /**
-     * Write a class using safe encoding to workaround java 1.3 serialization bug.
+     * Writes a class using safe encoding to workaround java 1.3 serialization bug.
+     *
+     * @throws IOException if I/O errors occur while writing to the underlying stream.
      */
     private void writeAnyClass(final Class<?> clazz, final ObjectOutputStream out) throws IOException {
         // safely write out any class
@@ -305,7 +309,6 @@ public class DynaProperty implements Serializable {
         } else if (Short.TYPE.equals(clazz)) {
             primitiveType = SHORT_TYPE;
         }
-
         if (primitiveType == 0) {
             // then it's not a primitive type
             out.writeBoolean(false);
@@ -318,54 +321,18 @@ public class DynaProperty implements Serializable {
     }
 
     /**
-     * Reads field values for this object safely.
-     * There are issues with serializing primitive class types on certain JVM versions
-     * (including java 1.3).
-     * This method provides a workaround.
+     * Writes this object safely. There are issues with serializing primitive class types on certain JVM versions (including java 1.3). This method provides a
+     * workaround.
      *
-     * @throws StreamCorruptedException when the stream data values are outside expected range
+     * @param out Where to write.
+     * @throws IOException if I/O errors occur while writing to the underlying stream.
      */
-    private void readObject(final ObjectInputStream in) throws IOException, ClassNotFoundException {
-
-        this.type = readAnyClass(in);
-
+    private void writeObject(final ObjectOutputStream out) throws IOException {
+        writeAnyClass(this.type,out);
         if (isMapped() || isIndexed()) {
-            this.contentType = readAnyClass(in);
+            writeAnyClass(this.contentType,out);
         }
-
-        // read other values
-        in.defaultReadObject();
+        // write out other values
+        out.defaultWriteObject();
     }
-
-
-    /**
-     * Reads a class using safe encoding to workaround java 1.3 serialization bug.
-     */
-    private Class<?> readAnyClass(final ObjectInputStream in) throws IOException, ClassNotFoundException {
-        // read back type class safely
-        if (in.readBoolean()) {
-            // it's a type constant
-            switch (in.readInt()) {
-
-                case BOOLEAN_TYPE: return   Boolean.TYPE;
-                case BYTE_TYPE:    return      Byte.TYPE;
-                case CHAR_TYPE:    return Character.TYPE;
-                case DOUBLE_TYPE:  return    Double.TYPE;
-                case FLOAT_TYPE:   return     Float.TYPE;
-                case INT_TYPE:     return   Integer.TYPE;
-                case LONG_TYPE:    return      Long.TYPE;
-                case SHORT_TYPE:   return     Short.TYPE;
-                default:
-                    // something's gone wrong
-                    throw new StreamCorruptedException(
-                        "Invalid primitive type. "
-                        + "Check version of beanutils used to serialize is compatible.");
-
-            }
-
-        } else {
-            // it's another class
-            return ((Class<?>) in.readObject());
-        }
-    }
-}
\ No newline at end of file
+}
