@@ -31,12 +31,11 @@ import java.util.Map;
 /**
  * <p>Provides common logic for JDBC implementations of {@link DynaClass}.</p>
  *
- * @version $Id$
  */
 
 abstract class JDBCDynaClass implements DynaClass, Serializable {
 
-    // ----------------------------------------------------- Instance Variables
+    private static final long serialVersionUID = 1L;
 
     /**
      * <p>Flag defining whether column names should be lower cased when
@@ -53,7 +52,7 @@ abstract class JDBCDynaClass implements DynaClass, Serializable {
      * <p>The set of dynamic properties that are part of this
      * {@link DynaClass}.</p>
      */
-    protected DynaProperty[] properties = null;
+    protected DynaProperty[] properties;
 
     /**
      * <p>The set of dynamic properties that are part of this
@@ -61,111 +60,14 @@ abstract class JDBCDynaClass implements DynaClass, Serializable {
      * instances will be the same instances as those in the
      * <code>properties</code> list.</p>
      */
-    protected Map<String, DynaProperty> propertiesMap = new HashMap<String, DynaProperty>();
+    protected Map<String, DynaProperty> propertiesMap = new HashMap<>();
 
     /**
-     * Cross Reference for column name --> dyna property name
+     * Cross Reference for column name to dyna property name
      * (needed when lowerCase option is true)
      */
     private Map<String, String> columnNameXref;
 
-    // ------------------------------------------------------ DynaClass Methods
-
-    /**
-     * <p>Return the name of this DynaClass (analogous to the
-     * <code>getName()</code> method of <code>java.lang.Class</code), which
-     * allows the same <code>DynaClass</code> implementation class to support
-     * different dynamic classes, with different sets of properties.</p>
-     */
-    public String getName() {
-
-        return (this.getClass().getName());
-
-    }
-
-    /**
-     * <p>Return a property descriptor for the specified property, if it
-     * exists; otherwise, return <code>null</code>.</p>
-     *
-     * @param name Name of the dynamic property for which a descriptor
-     *  is requested
-     *
-     * @throws IllegalArgumentException if no property name is specified
-     */
-    public DynaProperty getDynaProperty(final String name) {
-
-        if (name == null) {
-            throw new IllegalArgumentException("No property name specified");
-        }
-        return (propertiesMap.get(name));
-
-    }
-
-    /**
-     * <p>Return an array of <code>ProperyDescriptors</code> for the properties
-     * currently defined in this DynaClass.  If no properties are defined, a
-     * zero-length array will be returned.</p>
-     */
-    public DynaProperty[] getDynaProperties() {
-
-        return (properties);
-
-    }
-
-    /**
-     * <p>Instantiate and return a new DynaBean instance, associated
-     * with this DynaClass.  <strong>NOTE</strong> - This operation is not
-     * supported, and throws an exception.</p>
-     *
-     * @throws IllegalAccessException if the Class or the appropriate
-     *  constructor is not accessible
-     * @throws InstantiationException if this Class represents an abstract
-     *  class, an array class, a primitive type, or void; or if instantiation
-     *  fails for some other reason
-     */
-    public DynaBean newInstance()
-            throws IllegalAccessException, InstantiationException {
-
-        throw new UnsupportedOperationException("newInstance() not supported");
-
-    }
-
-    /**
-     * Set whether the column label or name should be used for the property name.
-     *
-     * @param useColumnLabel true if the column label should be used, otherwise false
-     */
-    public void setUseColumnLabel(final boolean useColumnLabel) {
-        this.useColumnLabel = useColumnLabel;
-    }
-
-    /**
-     * <p>Loads and returns the <code>Class</code> of the given name.
-     * By default, a load from the thread context class loader is attempted.
-     * If there is no such class loader, the class loader used to load this
-     * class will be utilized.</p>
-     *
-     * @param className The name of the class to load
-     * @return The loaded class
-     * @throws SQLException if an exception was thrown trying to load
-     *  the specified class
-     */
-    protected Class<?> loadClass(final String className) throws SQLException {
-
-        try {
-            ClassLoader cl = Thread.currentThread().getContextClassLoader();
-            if (cl == null) {
-                    cl = this.getClass().getClassLoader();
-            }
-            // use Class.forName() - see BEANUTILS-327
-            return Class.forName(className, false, cl);
-        } catch (final Exception e) {
-            throw new SQLException(
-                    "Cannot load column class '" + className + "': " + e);
-        }
-
-    }
-
     /**
      * <p>Factory method to create a new DynaProperty for the given index
      * into the result set metadata.</p>
@@ -190,7 +92,7 @@ abstract class JDBCDynaClass implements DynaClass, Serializable {
         final String name = lowerCase ? columnName.toLowerCase() : columnName;
         if (!name.equals(columnName)) {
             if (columnNameXref == null) {
-                columnNameXref = new HashMap<String, String>();
+                columnNameXref = new HashMap<>();
             }
             columnNameXref.put(name, columnName);
         }
@@ -223,35 +125,60 @@ abstract class JDBCDynaClass implements DynaClass, Serializable {
     }
 
     /**
-     * <p>Introspect the metadata associated with our result set, and populate
-     * the <code>properties</code> and <code>propertiesMap</code> instance
-     * variables.</p>
+     * Get the table column name for the specified property name.
      *
-     * @param resultSet The <code>resultSet</code> whose metadata is to
-     *  be introspected
-     *
-     * @throws SQLException if an error is encountered processing the
-     *  result set metadata
+     * @param name The property name
+     * @return The column name (which can be different if the <em>lowerCase</em>
+     * option is used).
      */
-    protected void introspect(final ResultSet resultSet) throws SQLException {
-
-        // Accumulate an ordered list of DynaProperties
-        final ArrayList<DynaProperty> list = new ArrayList<DynaProperty>();
-        final ResultSetMetaData metadata = resultSet.getMetaData();
-        final int n = metadata.getColumnCount();
-        for (int i = 1; i <= n; i++) { // JDBC is one-relative!
-            final DynaProperty dynaProperty = createDynaProperty(metadata, i);
-            if (dynaProperty != null) {
-                    list.add(dynaProperty);
-            }
+    protected String getColumnName(final String name) {
+        if (columnNameXref != null && columnNameXref.containsKey(name)) {
+            return columnNameXref.get(name);
         }
+        return name;
+    }
 
-        // Convert this list into the internal data structures we need
-        properties =
-            list.toArray(new DynaProperty[list.size()]);
-        for (DynaProperty propertie : properties) {
-            propertiesMap.put(propertie.getName(), propertie);
+    /**
+     * <p>Return an array of <code>ProperyDescriptors</code> for the properties
+     * currently defined in this DynaClass.  If no properties are defined, a
+     * zero-length array will be returned.</p>
+     */
+    @Override
+    public DynaProperty[] getDynaProperties() {
+
+        return properties;
+
+    }
+
+    /**
+     * <p>Return a property descriptor for the specified property, if it
+     * exists; otherwise, return <code>null</code>.</p>
+     *
+     * @param name Name of the dynamic property for which a descriptor
+     *  is requested
+     *
+     * @throws IllegalArgumentException if no property name is specified
+     */
+    @Override
+    public DynaProperty getDynaProperty(final String name) {
+
+        if (name == null) {
+            throw new IllegalArgumentException("No property name specified");
         }
+        return propertiesMap.get(name);
+
+    }
+
+    /**
+     * <p>Return the name of this DynaClass (analogous to the
+     * <code>getName()</code> method of <code>java.lang.Class</code>), which
+     * allows the same <code>DynaClass</code> implementation class to support
+     * different dynamic classes, with different sets of properties.</p>
+     */
+    @Override
+    public String getName() {
+
+        return this.getClass().getName();
 
     }
 
@@ -291,18 +218,91 @@ abstract class JDBCDynaClass implements DynaClass, Serializable {
     }
 
     /**
-     * Get the table column name for the specified property name.
+     * <p>Introspect the metadata associated with our result set, and populate
+     * the <code>properties</code> and <code>propertiesMap</code> instance
+     * variables.</p>
      *
-     * @param name The property name
-     * @return The column name (which can be different if the <i>lowerCase</i>
-     * option is used).
+     * @param resultSet The <code>resultSet</code> whose metadata is to
+     *  be introspected
+     *
+     * @throws SQLException if an error is encountered processing the
+     *  result set metadata
      */
-    protected String getColumnName(final String name) {
-        if (columnNameXref != null && columnNameXref.containsKey(name)) {
-            return columnNameXref.get(name);
-        } else {
-            return name;
+    protected void introspect(final ResultSet resultSet) throws SQLException {
+
+        // Accumulate an ordered list of DynaProperties
+        final ArrayList<DynaProperty> list = new ArrayList<>();
+        final ResultSetMetaData metadata = resultSet.getMetaData();
+        final int n = metadata.getColumnCount();
+        for (int i = 1; i <= n; i++) { // JDBC is one-relative!
+            final DynaProperty dynaProperty = createDynaProperty(metadata, i);
+            if (dynaProperty != null) {
+                    list.add(dynaProperty);
+            }
         }
+
+        // Convert this list into the internal data structures we need
+        properties =
+            list.toArray(new DynaProperty[list.size()]);
+        for (final DynaProperty propertie : properties) {
+            propertiesMap.put(propertie.getName(), propertie);
+        }
+
+    }
+
+    /**
+     * <p>Loads and returns the <code>Class</code> of the given name.
+     * By default, a load from the thread context class loader is attempted.
+     * If there is no such class loader, the class loader used to load this
+     * class will be utilized.</p>
+     *
+     * @param className The name of the class to load
+     * @return The loaded class
+     * @throws SQLException if an exception was thrown trying to load
+     *  the specified class
+     */
+    protected Class<?> loadClass(final String className) throws SQLException {
+
+        try {
+            ClassLoader cl = Thread.currentThread().getContextClassLoader();
+            if (cl == null) {
+                    cl = this.getClass().getClassLoader();
+            }
+            // use Class.forName() - see BEANUTILS-327
+            return Class.forName(className, false, cl);
+        } catch (final Exception e) {
+            throw new SQLException(
+                    "Cannot load column class '" + className + "': " + e);
+        }
+
+    }
+
+    /**
+     * <p>Instantiate and return a new DynaBean instance, associated
+     * with this DynaClass.  <strong>NOTE</strong> - This operation is not
+     * supported, and throws an exception.</p>
+     *
+     * @throws IllegalAccessException if the Class or the appropriate
+     *  constructor is not accessible
+     * @throws InstantiationException if this Class represents an abstract
+     *  class, an array class, a primitive type, or void; or if instantiation
+     *  fails for some other reason
+     */
+    @Override
+    public DynaBean newInstance()
+            throws IllegalAccessException, InstantiationException {
+
+        throw new UnsupportedOperationException("newInstance() not supported");
+
+    }
+
+    /**
+     * Set whether the column label or name should be used for the property name.
+     *
+     * @param useColumnLabel true if the column label should be used, otherwise false
+     */
+    public void setUseColumnLabel(final boolean useColumnLabel) {
+        this.useColumnLabel = useColumnLabel;
     }
 
 }
