@@ -22,27 +22,27 @@ import java.util.Collection;
 import java.util.Map;
 
 /**
- * <h2><i>Lazy</i> DynaBean List.</h2>
+ * <h2><em>Lazy</em> DynaBean List.</h2>
  *
  * <p>There are two main purposes for this class:</p>
  *    <ul>
- *        <li>To provide <i>Lazy List</i> behaviour - automatically
- *            <i>growing</i> and <i>populating</i> the <code>List</code>
+ *        <li>To provide <em>Lazy List</em> behavior - automatically
+ *            <em>growing</em> and <em>populating</em> the <code>List</code>
  *            with either <code>DynaBean</code>, <code>java.util.Map</code>
  *            or POJO Beans.</li>
  *        <li>To provide a straight forward way of putting a Collection
- *            or Array into the lazy list <i>and</i> a straight forward
+ *            or Array into the lazy list <em>and</em> a straight forward
  *            way to get it out again at the end.</li>
  *    </ul>
  *
  * <p>All elements added to the List are stored as <code>DynaBean</code>'s:</p>
  * <ul>
- *    <li><code>java.util.Map</code> elements are "wrapped" in a <code>LazyDynaMap</code>.</i>
- *    <li>POJO Bean elements are "wrapped" in a <code>WrapDynaBean.</code></i>
- *    <li><code>DynaBean</code>'s are stored un-changed.</i>
+ *    <li><code>java.util.Map</code> elements are "wrapped" in a <code>LazyDynaMap</code>.</li>
+ *    <li>POJO Bean elements are "wrapped" in a <code>WrapDynaBean.</code></li>
+ *    <li><code>DynaBean</code>'s are stored un-changed.</li>
  * </ul>
  *
- * <h4><code>toArray()</code></h4>
+ * <h3><code>toArray()</code></h3>
  * <p>The <code>toArray()</code> method returns an array of the
  *    elements of the appropriate type. If the <code>LazyDynaList</code>
  *    is populated with <code>java.util.Map</code> objects a
@@ -52,7 +52,7 @@ import java.util.Map;
  *    array is returned.
  * </p>
  *
- * <h4><code>toDynaBeanArray()</code></h4>
+ * <h3><code>toDynaBeanArray()</code></h3>
  * <p>The <code>toDynaBeanArray()</code> method returns a
  *    <code>DynaBean[]</code> array of the elements in the List.
  * </p>
@@ -92,36 +92,36 @@ import java.util.Map;
  *
  *
  * <h3>Example 2</h3>
- * <p>Alternatively you can create an <i>empty</i> List and
+ * <p>Alternatively you can create an <em>empty</em> List and
  *    specify the Class for List's elements. The LazyDynaList
  *    uses the Class to automatically populate elements:</p>
  *
  * <pre><code>
- *    // e.g. For Maps
+ *    // for example For Maps
  *    List lazyList = new LazyDynaList(TreeMap.class);
  *
- *    // e.g. For POJO Beans
+ *    // for example For POJO Beans
  *    List lazyList = new LazyDynaList(MyPojo.class);
  *
- *    // e.g. For DynaBeans
+ *    // for example For DynaBeans
  *    List lazyList = new LazyDynaList(MyDynaBean.class);
  * </code></pre>
  *
  * <h3>Example 3</h3>
- * <p>Alternatively you can create an <i>empty</i> List and specify the
+ * <p>Alternatively you can create an <em>empty</em> List and specify the
  *    DynaClass for List's elements. The LazyDynaList uses
  *    the DynaClass to automatically populate elements:</p>
  *
  * <pre><code>
- *    // e.g. For Maps
+ *    // for example For Maps
  *    DynaClass dynaClass = new LazyDynaMap(new HashMap());
  *    List lazyList = new LazyDynaList(dynaClass);
  *
- *    // e.g. For POJO Beans
+ *    // for example For POJO Beans
  *    DynaClass dynaClass = (new WrapDynaBean(myPojo)).getDynaClass();
  *    List lazyList = new LazyDynaList(dynaClass);
  *
- *    // e.g. For DynaBeans
+ *    // for example For DynaBeans
  *    DynaClass dynaClass = new BasicDynaClass(properties);
  *    List lazyList = new LazyDynaList(dynaClass);
  * </code></pre>
@@ -129,7 +129,7 @@ import java.util.Map;
  * <p><strong>N.B.</strong> You may wonder why control the type
  *    using a <code>DynaClass</code> rather than the <code>Class</code>
  *    as in the previous example - the reason is that some <code>DynaBean</code>
- *    implementations don't have a <i>default</i> empty constructor and
+ *    implementations don't have a <em>default</em> empty constructor and
  *    therefore need to be instantiated using the <code>DynaClass.newInstance()</code>
  *    method.</p>
  *
@@ -155,11 +155,12 @@ import java.util.Map;
  *
  * </code></pre>
  *
- * @version $Id$
  * @since 1.8.0
  */
 public class LazyDynaList extends ArrayList<Object> {
 
+    private static final long serialVersionUID = 1L;
+
     /**
      * The DynaClass of the List's elements.
      */
@@ -185,36 +186,10 @@ public class LazyDynaList extends ArrayList<Object> {
      */
     private Class<?> elementDynaBeanType;
 
-
-    // ------------------- Constructors ------------------------------
-
     /**
-     * Default Constructor.
+     * Constructs a new instance.
      */
     public LazyDynaList() {
-        super();
-    }
-
-    /**
-     * Construct a LazyDynaList with the
-     * specified capacity.
-     *
-     * @param capacity The initial capacity of the list.
-     */
-    public LazyDynaList(final int capacity) {
-        super(capacity);
-
-    }
-
-    /**
-     * Construct a  LazyDynaList with a
-     * specified DynaClass for its elements.
-     *
-     * @param elementDynaClass The DynaClass of the List's elements.
-     */
-    public LazyDynaList(final DynaClass elementDynaClass) {
-        super();
-        setElementDynaClass(elementDynaClass);
     }
 
     /**
@@ -224,7 +199,6 @@ public class LazyDynaList extends ArrayList<Object> {
      * @param elementType The Type of the List's elements.
      */
     public LazyDynaList(final Class<?> elementType) {
-        super();
         setElementType(elementType);
     }
 
@@ -239,6 +213,27 @@ public class LazyDynaList extends ArrayList<Object> {
         addAll(collection);
     }
 
+    /**
+     * Construct a  LazyDynaList with a
+     * specified DynaClass for its elements.
+     *
+     * @param elementDynaClass The DynaClass of the List's elements.
+     */
+    public LazyDynaList(final DynaClass elementDynaClass) {
+        setElementDynaClass(elementDynaClass);
+    }
+
+    /**
+     * Construct a LazyDynaList with the
+     * specified capacity.
+     *
+     * @param capacity The initial capacity of the list.
+     */
+    public LazyDynaList(final int capacity) {
+        super(capacity);
+
+    }
+
     /**
      * Construct a  LazyDynaList populated with the
      * elements of an Array.
@@ -247,20 +242,17 @@ public class LazyDynaList extends ArrayList<Object> {
      */
     public LazyDynaList(final Object[] array) {
         super(array.length);
-        for (Object element : array) {
+        for (final Object element : array) {
             add(element);
         }
     }
 
-
-    // ------------------- java.util.List Methods --------------------
-
     /**
      * <p>Insert an element at the specified index position.</p>
      *
      * <p>If the index position is greater than the current
      *    size of the List, then the List is automatically
-     *    <i>grown</i> to the appropriate size.</p>
+     *    <em>grown</em> to the appropriate size.</p>
      *
      * @param index The index position to insert the new element.
      * @param element The new element to add.
@@ -320,7 +312,7 @@ public class LazyDynaList extends ArrayList<Object> {
      *
      * <p>If the index position is greater than the current
      *    size of the List, then the List is automatically
-     *    <i>grown</i> to the appropriate size.</p>
+     *    <em>grown</em> to the appropriate size.</p>
      *
      * @param collection The Collection of new elements.
      * @param index The index position to insert the new elements at.
@@ -353,12 +345,26 @@ public class LazyDynaList extends ArrayList<Object> {
 
     }
 
+    /**
+     * Creates a new {@code LazyDynaMap} object for the given property value.
+     *
+     * @param value the property value
+     * @return the newly created {@code LazyDynaMap}
+     */
+    private LazyDynaMap createDynaBeanForMapProperty(final Object value) {
+        @SuppressWarnings("unchecked")
+        final
+        // map properties are always stored as Map<String, Object>
+        Map<String, Object> valueMap = (Map<String, Object>) value;
+        return new LazyDynaMap(valueMap);
+    }
+
     /**
      * <p>Return the element at the specified position.</p>
      *
      * <p>If the position requested is greater than the current
      *    size of the List, then the List is automatically
-     *    <i>grown</i> (and populated) to the appropriate size.</p>
+     *    <em>grown</em> (and populated) to the appropriate size.</p>
      *
      * @param index The index position to insert the new elements at.
      * @return The element at the specified position.
@@ -372,12 +378,41 @@ public class LazyDynaList extends ArrayList<Object> {
 
     }
 
+    /**
+     * Return the DynaClass.
+     */
+    private DynaClass getDynaClass() {
+        return elementDynaClass == null ? wrapDynaClass : elementDynaClass;
+    }
+
+    /**
+     * <p>Automatically <em>grown</em> the List
+     *    to the appropriate size, populating with
+     *    DynaBeans.</p>
+     *
+     * @param requiredSize the required size of the List.
+     */
+    private void growList(final int requiredSize) {
+
+        if (requiredSize < size()) {
+            return;
+        }
+
+        ensureCapacity(requiredSize + 1);
+
+        for (int i = size(); i < requiredSize; i++) {
+            final DynaBean dynaBean = transform(null);
+            super.add(dynaBean);
+        }
+
+    }
+
     /**
      * <p>Set the element at the specified position.</p>
      *
      * <p>If the position requested is greater than the current
      *    size of the List, then the List is automatically
-     *    <i>grown</i> (and populated) to the appropriate size.</p>
+     *    <em>grown</em> (and populated) to the appropriate size.</p>
      *
      * @param index The index position to insert the new element at.
      * @param element The new element.
@@ -394,6 +429,99 @@ public class LazyDynaList extends ArrayList<Object> {
 
     }
 
+    /**
+     * <p>Set the element Type and DynaClass.</p>
+     *
+     * @param elementDynaClass The DynaClass of the elements.
+     * @throws IllegalArgumentException if the List already
+     *            contains elements or the DynaClass is null.
+     */
+    public void setElementDynaClass(final DynaClass elementDynaClass) {
+
+        if (elementDynaClass == null) {
+            throw new IllegalArgumentException("Element DynaClass is missing");
+        }
+
+        if (size() > 0) {
+            throw new IllegalStateException("Element DynaClass cannot be reset");
+        }
+
+        // Try to create a new instance of the DynaBean
+        try {
+            final DynaBean dynaBean  = elementDynaClass.newInstance();
+            this.elementDynaBeanType = dynaBean.getClass();
+            if (WrapDynaBean.class.isAssignableFrom(elementDynaBeanType)) {
+                this.elementType = ((WrapDynaBean)dynaBean).getInstance().getClass();
+                this.wrapDynaClass = (WrapDynaClass)elementDynaClass;
+            } else {
+                if (LazyDynaMap.class.isAssignableFrom(elementDynaBeanType)) {
+                    this.elementType = ((LazyDynaMap)dynaBean).getMap().getClass();
+                } else {
+                    this.elementType = dynaBean.getClass();
+                }
+                this.elementDynaClass = elementDynaClass;
+            }
+        } catch (final Exception e) {
+            throw new IllegalArgumentException(
+                        "Error creating DynaBean from " +
+                        elementDynaClass.getClass().getName() + " - " + e);
+        }
+
+    }
+
+    /**
+     * <p>Set the element Type and DynaClass.</p>
+     *
+     * @param elementType The type of the elements.
+     * @throws IllegalArgumentException if the List already
+     *            contains elements or the DynaClass is null.
+     */
+    public void setElementType(final Class<?> elementType) {
+
+        if (elementType == null) {
+            throw new IllegalArgumentException("Element Type is missing");
+        }
+
+        final boolean changeType = this.elementType != null && !this.elementType.equals(elementType);
+        if (changeType && size() > 0) {
+            throw new IllegalStateException("Element Type cannot be reset");
+        }
+
+        this.elementType = elementType;
+
+        // Create a new object of the specified type
+        Object object = null;
+        try {
+            object = elementType.getConstructor().newInstance();
+        } catch (final Exception e) {
+            throw new IllegalArgumentException("Error creating type: "
+                           + elementType.getName() + " - " + e);
+        }
+
+        // Create a DynaBean
+        DynaBean dynaBean = null;
+        if (Map.class.isAssignableFrom(elementType)) {
+            dynaBean = createDynaBeanForMapProperty(object);
+            this.elementDynaClass = dynaBean.getDynaClass();
+        } else if (DynaBean.class.isAssignableFrom(elementType)) {
+            dynaBean = (DynaBean)object;
+            this.elementDynaClass = dynaBean.getDynaClass();
+        } else {
+            dynaBean = new WrapDynaBean(object);
+            this.wrapDynaClass = (WrapDynaClass)dynaBean.getDynaClass();
+        }
+
+        this.elementDynaBeanType = dynaBean.getClass();
+
+        // Re-calculate the type
+        if (WrapDynaBean.class.isAssignableFrom(elementDynaBeanType)) {
+            this.elementType = ((WrapDynaBean) dynaBean).getInstance().getClass();
+        } else if (LazyDynaMap.class.isAssignableFrom(elementDynaBeanType)) {
+            this.elementType = ((LazyDynaMap) dynaBean).getMap().getClass();
+        }
+
+    }
+
     /**
      * <p>Converts the List to an Array.</p>
      *
@@ -406,6 +534,7 @@ public class LazyDynaList extends ArrayList<Object> {
      *        "wrapped" DynaBeans then an Object[] of the most
      *        suitable type will be created.</li>
      *    <li>...otherwise a DynaBean[] will be created.</li>
+     * </ul>
      *
      * @return An Array of the elements in this List.
      */
@@ -441,12 +570,12 @@ public class LazyDynaList extends ArrayList<Object> {
     public <T> T[] toArray(final T[] model) {
 
         final Class<?> arrayType = model.getClass().getComponentType();
-        if ((DynaBean.class.isAssignableFrom(arrayType))
-                || (size() == 0 && elementType == null)) {
+        if (DynaBean.class.isAssignableFrom(arrayType)
+                || size() == 0 && elementType == null) {
             return super.toArray(model);
         }
 
-        if ((arrayType.isAssignableFrom(elementType))) {
+        if (arrayType.isAssignableFrom(elementType)) {
             T[] array;
             if (model.length >= size()) {
                 array = model;
@@ -478,9 +607,6 @@ public class LazyDynaList extends ArrayList<Object> {
 
     }
 
-
-    // ------------------- Public Methods ----------------------------
-
     /**
      * <p>Converts the List to an DynaBean Array.</p>
      *
@@ -500,123 +626,6 @@ public class LazyDynaList extends ArrayList<Object> {
 
     }
 
-    /**
-     * <p>Set the element Type and DynaClass.</p>
-     *
-     * @param elementType The type of the elements.
-     * @throws IllegalArgumentException if the List already
-     *            contains elements or the DynaClass is null.
-     */
-    public void setElementType(final Class<?> elementType) {
-
-        if (elementType == null) {
-            throw new IllegalArgumentException("Element Type is missing");
-        }
-
-        final boolean changeType = (this.elementType != null && !this.elementType.equals(elementType));
-        if (changeType && size() > 0) {
-            throw new IllegalStateException("Element Type cannot be reset");
-        }
-
-        this.elementType = elementType;
-
-        // Create a new object of the specified type
-        Object object = null;
-        try {
-            object = elementType.newInstance();
-        } catch (final Exception e) {
-            throw new IllegalArgumentException("Error creating type: "
-                           + elementType.getName() + " - " + e);
-        }
-
-        // Create a DynaBean
-        DynaBean dynaBean = null;
-        if (Map.class.isAssignableFrom(elementType)) {
-            dynaBean = createDynaBeanForMapProperty(object);
-            this.elementDynaClass = dynaBean.getDynaClass();
-        } else if (DynaBean.class.isAssignableFrom(elementType)) {
-            dynaBean = (DynaBean)object;
-            this.elementDynaClass = dynaBean.getDynaClass();
-        } else {
-            dynaBean = new WrapDynaBean(object);
-            this.wrapDynaClass = (WrapDynaClass)dynaBean.getDynaClass();
-        }
-
-        this.elementDynaBeanType = dynaBean.getClass();
-
-        // Re-calculate the type
-        if (WrapDynaBean.class.isAssignableFrom(elementDynaBeanType )) {
-            this.elementType = ((WrapDynaBean)dynaBean).getInstance().getClass();
-        } else if (LazyDynaMap.class.isAssignableFrom(elementDynaBeanType )) {
-            this.elementType = ((LazyDynaMap)dynaBean).getMap().getClass();
-        }
-
-    }
-
-    /**
-     * <p>Set the element Type and DynaClass.</p>
-     *
-     * @param elementDynaClass The DynaClass of the elements.
-     * @throws IllegalArgumentException if the List already
-     *            contains elements or the DynaClass is null.
-     */
-    public void setElementDynaClass(final DynaClass elementDynaClass) {
-
-        if (elementDynaClass == null) {
-            throw new IllegalArgumentException("Element DynaClass is missing");
-        }
-
-        if (size() > 0) {
-            throw new IllegalStateException("Element DynaClass cannot be reset");
-        }
-
-        // Try to create a new instance of the DynaBean
-        try {
-            final DynaBean dynaBean  = elementDynaClass.newInstance();
-            this.elementDynaBeanType = dynaBean.getClass();
-            if (WrapDynaBean.class.isAssignableFrom(elementDynaBeanType)) {
-                this.elementType = ((WrapDynaBean)dynaBean).getInstance().getClass();
-                this.wrapDynaClass = (WrapDynaClass)elementDynaClass;
-            } else if (LazyDynaMap.class.isAssignableFrom(elementDynaBeanType)) {
-                this.elementType = ((LazyDynaMap)dynaBean).getMap().getClass();
-                this.elementDynaClass = elementDynaClass;
-            } else {
-                this.elementType = dynaBean.getClass();
-                this.elementDynaClass = elementDynaClass;
-            }
-        } catch (final Exception e) {
-            throw new IllegalArgumentException(
-                        "Error creating DynaBean from " +
-                        elementDynaClass.getClass().getName() + " - " + e);
-        }
-
-    }
-
-
-    // ------------------- Private Methods ---------------------------
-
-    /**
-     * <p>Automatically <i>grown</i> the List
-     *    to the appropriate size, populating with
-     *    DynaBeans.</p>
-     *
-     * @param requiredSize the required size of the List.
-     */
-    private void growList(final int requiredSize) {
-
-        if (requiredSize < size()) {
-            return;
-        }
-
-        ensureCapacity(requiredSize + 1);
-
-        for (int i = size(); i < requiredSize; i++) {
-            final DynaBean dynaBean = transform(null);
-            super.add(dynaBean);
-        }
-
-    }
-
     /**
      * <p>Transform the element into a DynaBean:</p>
      *
@@ -693,25 +702,4 @@ public class LazyDynaList extends ArrayList<Object> {
         return dynaBean;
 
     }
-
-    /**
-     * Creates a new {@code LazyDynaMap} object for the given property value.
-     *
-     * @param value the property value
-     * @return the newly created {@code LazyDynaMap}
-     */
-    private LazyDynaMap createDynaBeanForMapProperty(final Object value) {
-        @SuppressWarnings("unchecked")
-        final
-        // map properties are always stored as Map<String, Object>
-        Map<String, Object> valueMap = (Map<String, Object>) value;
-        return new LazyDynaMap(valueMap);
-    }
-
-    /**
-     * Return the DynaClass.
-     */
-    private DynaClass getDynaClass() {
-        return (elementDynaClass == null ? wrapDynaClass : elementDynaClass);
-    }
 }
