@@ -19,34 +19,35 @@ package org.apache.commons.beanutils;
 import java.util.Map;
 
 /**
- * <p>Provides a <i>light weight</i> <code>DynaBean</code> facade to a <code>Map</code>
- *  with <i>lazy</i> map/list processing.</p>
+ * <p>Provides a <em>light weight</em> <code>DynaBean</code> facade to a <code>Map</code>
+ *  with <em>lazy</em> map/list processing.</p>
  *
- * <p>Its a <i>light weight</i> <code>DynaBean</code> implementation because there is no
+ * <p>Its a <em>light weight</em> <code>DynaBean</code> implementation because there is no
  *    actual <code>DynaClass</code> associated with this <code>DynaBean</code> - in fact
- *    it implements the <code>DynaClass</code> interface itself providing <i>pseudo</i> DynaClass
- *    behaviour from the actual values stored in the <code>Map</code>.</p>
+ *    it implements the <code>DynaClass</code> interface itself providing <em>pseudo</em> DynaClass
+ *    behavior from the actual values stored in the <code>Map</code>.</p>
  *
  * <p>As well providing rhe standard <code>DynaBean</code> access to the <code>Map</code>'s properties
- *    this class also provides the usual <i>Lazy</i> behaviour:</p>
+ *    this class also provides the usual <em>Lazy</em> behavior:</p>
  *    <ul>
  *       <li>Properties don't need to be pre-defined in a <code>DynaClass</code></li>
  *       <li>Indexed properties (<code>Lists</code> or <code>Arrays</code>) are automatically instantiated
- *           and <i>grown</i> so that they are large enough to cater for the index being set.</li>
+ *           and <em>grown</em> so that they are large enough to cater for the index being set.</li>
  *       <li>Mapped properties are automatically instantiated.</li>
  *    </ul>
  *
- * <p><b><u><i>Restricted</i> DynaClass</u></b></p>
+ * <p><strong><u><em>Restricted</em> DynaClass</u></strong></p>
  *    <p>This class implements the <code>MutableDynaClass</code> interface.
- *       <code>MutableDynaClass</code> have a facility to <i>restrict</i> the <code>DynaClass</code>
+ *       <code>MutableDynaClass</code> have a facility to <em>restrict</em> the <code>DynaClass</code>
  *       so that its properties cannot be modified. If the <code>MutableDynaClass</code> is
  *       restricted then calling any of the <code>set()</code> methods for a property which
  *       doesn't exist will result in a <code>IllegalArgumentException</code> being thrown.</p>
  *
- * @version $Id$
  */
 public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
 
+    private static final long serialVersionUID = 1L;
+
     /**
      * The name of this DynaClass (analogous to the
      * <code>getName()</code> method of <code>java.lang.Class</code>).
@@ -64,18 +65,42 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
      *
      * <p>Default is <code>false</code>.
      */
-    protected boolean returnNull = false;
-
-
-    // ------------------- Constructors ----------------------------------
+    protected boolean returnNull;
 
     /**
-     * Default Constructor.
+     * Constructs a new instance.
      */
     public LazyDynaMap() {
         this(null, (Map<String, Object>)null);
     }
 
+    /**
+     * Construct a new <code>LazyDynaMap</code> based on an exisiting DynaClass
+     *
+     * @param dynaClass DynaClass to copy the name and properties from
+     */
+    public LazyDynaMap(final DynaClass dynaClass) {
+        this(dynaClass.getName(), dynaClass.getDynaProperties());
+    }
+
+    /**
+     * Construct a new <code>LazyDynaMap</code> with the specified properties.
+     *
+     * @param properties Property descriptors for the supported properties
+     */
+    public LazyDynaMap(final DynaProperty[] properties) {
+        this(null, properties);
+    }
+
+    /**
+     * Construct a new <code>LazyDynaMap</code> with the specified <code>Map</code>.
+     *
+     * @param values The Map backing this <code>LazyDynaMap</code>
+     */
+    public LazyDynaMap(final Map<String, Object> values) {
+        this(null, values);
+    }
+
     /**
      * Construct a new <code>LazyDynaMap</code> with the specified name.
      *
@@ -86,12 +111,18 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
     }
 
     /**
-     * Construct a new <code>LazyDynaMap</code> with the specified <code>Map</code>.
+     * Construct a new <code>LazyDynaMap</code> with the specified name and properties.
      *
-     * @param values The Map backing this <code>LazyDynaMap</code>
+     * @param name Name of this DynaBean class
+     * @param properties Property descriptors for the supported properties
      */
-    public LazyDynaMap(final Map<String, Object> values) {
-        this(null, values);
+    public LazyDynaMap(final String name, final DynaProperty[] properties) {
+        this(name, (Map<String, Object>)null);
+        if (properties != null) {
+            for (final DynaProperty propertie : properties) {
+                add(propertie);
+            }
+        }
     }
 
     /**
@@ -107,215 +138,13 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
     }
 
     /**
-     * Construct a new <code>LazyDynaMap</code> with the specified properties.
+     * Add a new dynamic property.
      *
-     * @param properties Property descriptors for the supported properties
+     * @param property Property the new dynamic property to add.
+     * @throws IllegalArgumentException if name is null
      */
-    public LazyDynaMap(final DynaProperty[] properties) {
-        this(null, properties);
-    }
-
-    /**
-     * Construct a new <code>LazyDynaMap</code> with the specified name and properties.
-     *
-     * @param name Name of this DynaBean class
-     * @param properties Property descriptors for the supported properties
-     */
-    public LazyDynaMap(final String name, final DynaProperty[] properties) {
-        this(name, (Map<String, Object>)null);
-        if (properties != null) {
-            for (DynaProperty propertie : properties) {
-                add(propertie);
-            }
-        }
-    }
-
-    /**
-     * Construct a new <code>LazyDynaMap</code> based on an exisiting DynaClass
-     *
-     * @param dynaClass DynaClass to copy the name and properties from
-     */
-    public LazyDynaMap(final DynaClass dynaClass) {
-        this(dynaClass.getName(), dynaClass.getDynaProperties());
-    }
-
-    // ------------------- Public Methods ----------------------------------
-
-    /**
-     * Set the Map backing this <code>DynaBean</code>
-     *
-     * @param values The new Map of values
-     */
-    public void setMap(final Map<String, Object> values) {
-        this.values = values;
-    }
-
-    /**
-     * Return the underlying Map backing this <code>DynaBean</code>
-     * @return the underlying Map
-     * @since 1.8.0
-     */
-    @Override
-    public Map<String, Object> getMap() {
-        return values;
-    }
-
-    // ------------------- DynaBean Methods ----------------------------------
-
-    /**
-     * Set the value of a simple property with the specified name.
-     *
-     * @param name Name of the property whose value is to be set
-     * @param value Value to which this property is to be set
-     */
-    @Override
-    public void set(final String name, final Object value) {
-
-        if (isRestricted() && !values.containsKey(name)) {
-            throw new IllegalArgumentException
-                    ("Invalid property name '" + name + "' (DynaClass is restricted)");
-        }
-
-        values.put(name, value);
-
-    }
-
-    // ------------------- DynaClass Methods ----------------------------------
-
-    /**
-     * Return the name of this DynaClass (analogous to the
-     * <code>getName()</code> method of <code>java.lang.Class</code>)
-     *
-     * @return the name of the DynaClass
-     */
-    public String getName() {
-        return this.name;
-    }
-
-    /**
-     * <p>Return a property descriptor for the specified property.</p>
-     *
-     * <p>If the property is not found and the <code>returnNull</code> indicator is
-     *    <code>true</code>, this method always returns <code>null</code>.</p>
-     *
-     * <p>If the property is not found and the <code>returnNull</code> indicator is
-     *    <code>false</code> a new property descriptor is created and returned (although
-     *    its not actually added to the DynaClass's properties). This is the default
-     *    beahviour.</p>
-     *
-     * <p>The reason for not returning a <code>null</code> property descriptor is that
-     *    <code>BeanUtils</code> uses this method to check if a property exists
-     *    before trying to set it - since these <i>Map</i> implementations automatically
-     *    add any new properties when they are set, returning <code>null</code> from
-     *    this method would defeat their purpose.</p>
-     *
-     * @param name Name of the dynamic property for which a descriptor
-     *  is requested
-     * @return The descriptor for the specified property
-     *
-     * @throws IllegalArgumentException if no property name is specified
-     */
-    public DynaProperty getDynaProperty(final String name) {
-
-        if (name == null) {
-            throw new IllegalArgumentException("Property name is missing.");
-        }
-
-        // If it doesn't exist and returnNull is false
-        // create a new DynaProperty
-        if (!values.containsKey(name) && isReturnNull()) {
-            return null;
-        }
-
-        final Object value = values.get(name);
-
-        if (value == null) {
-            return new DynaProperty(name);
-        } else {
-            return new DynaProperty(name, value.getClass());
-        }
-
-    }
-
-    /**
-     * <p>Return an array of <code>ProperyDescriptors</code> for the properties
-     * currently defined in this DynaClass.  If no properties are defined, a
-     * zero-length array will be returned.</p>
-     *
-     * <p><strong>FIXME</strong> - Should we really be implementing
-     * <code>getBeanInfo()</code> instead, which returns property descriptors
-     * and a bunch of other stuff?</p>
-     * @return the set of properties for this DynaClass
-     */
-    public DynaProperty[] getDynaProperties() {
-
-        int i = 0;
-        final DynaProperty[] properties = new DynaProperty[values.size()];
-        for (final Map.Entry<String, Object> e : values.entrySet()) {
-            final String name = e.getKey();
-            final Object value = values.get(name);
-            properties[i++] = new DynaProperty(name, value == null ? null
-                    : value.getClass());
-        }
-
-        return properties;
-
-    }
-
-    /**
-     * Instantiate and return a new DynaBean instance, associated
-     * with this DynaClass.
-     * @return A new <code>DynaBean</code> instance
-     */
-    public DynaBean newInstance()  {
-
-        // Create a new instance of the Map
-        Map<String, Object> newMap = null;
-        try {
-            @SuppressWarnings("unchecked")
-            final
-            // The new map is used as properties map
-            Map<String, Object> temp = getMap().getClass().newInstance();
-            newMap = temp;
-        } catch(final Exception ex) {
-            newMap = newMap();
-        }
-
-        // Crate new LazyDynaMap and initialize properties
-        final LazyDynaMap lazyMap = new LazyDynaMap(newMap);
-        final DynaProperty[] properties = this.getDynaProperties();
-        if (properties != null) {
-            for (DynaProperty propertie : properties) {
-                lazyMap.add(propertie);
-            }
-        }
-        return lazyMap;
-    }
-
-
-    // ------------------- MutableDynaClass Methods ----------------------------------
-
-    /**
-     * <p>Is this DynaClass currently restricted.</p>
-     * <p>If restricted, no changes to the existing registration of
-     *  property names, data types, readability, or writeability are allowed.</p>
-     *
-     * @return <code>true</code> if this Mutable {@link DynaClass} is restricted,
-     * otherwise <code>false</code>
-     */
-    public boolean isRestricted() {
-        return restricted;
-    }
-
-    /**
-     * <p>Set whether this DynaClass is currently restricted.</p>
-     * <p>If restricted, no changes to the existing registration of
-     *  property names, data types, readability, or writeability are allowed.</p>
-     *
-     * @param restricted The new restricted state
-     */
-    public void setRestricted(final boolean restricted) {
-        this.restricted = restricted;
+    protected void add(final DynaProperty property) {
+        add(property.getName(), property.getType());
     }
 
     /**
@@ -323,9 +152,9 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
      * readability, or writeability.
      *
      * @param name Name of the new dynamic property
-     *
      * @throws IllegalArgumentException if name is null
      */
+    @Override
     public void add(final String name) {
         add(name, null);
     }
@@ -342,6 +171,7 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
      * @throws IllegalStateException if this DynaClass is currently
      *  restricted, so no new properties can be added
      */
+    @Override
     public void add(final String name, final Class<?> type) {
 
         if (name == null) {
@@ -382,19 +212,181 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
      *
      * @throws UnsupportedOperationException anytime this method is called
      */
+    @Override
     public void add(final String name, final Class<?> type, final boolean readable, final boolean writeable) {
-        throw new java.lang.UnsupportedOperationException("readable/writable properties not supported");
+        throw new UnsupportedOperationException("readable/writable properties not supported");
     }
 
     /**
-     * Add a new dynamic property.
+     * <p>Return an array of <code>ProperyDescriptors</code> for the properties
+     * currently defined in this DynaClass.  If no properties are defined, a
+     * zero-length array will be returned.</p>
      *
-     * @param property Property the new dynamic property to add.
-     *
-     * @throws IllegalArgumentException if name is null
+     * <p><strong>FIXME</strong> - Should we really be implementing
+     * <code>getBeanInfo()</code> instead, which returns property descriptors
+     * and a bunch of other stuff?</p>
+     * @return the set of properties for this DynaClass
      */
-    protected void add(final DynaProperty property) {
-        add(property.getName(), property.getType());
+    @Override
+    public DynaProperty[] getDynaProperties() {
+
+        int i = 0;
+        final DynaProperty[] properties = new DynaProperty[values.size()];
+        for (final Map.Entry<String, Object> e : values.entrySet()) {
+            final String name = e.getKey();
+            final Object value = values.get(name);
+            properties[i++] = new DynaProperty(name, value == null ? null
+                    : value.getClass());
+        }
+
+        return properties;
+
+    }
+
+    /**
+     * <p>Return a property descriptor for the specified property.</p>
+     *
+     * <p>If the property is not found and the <code>returnNull</code> indicator is
+     *    <code>true</code>, this method always returns <code>null</code>.</p>
+     *
+     * <p>If the property is not found and the <code>returnNull</code> indicator is
+     *    <code>false</code> a new property descriptor is created and returned (although
+     *    its not actually added to the DynaClass's properties). This is the default
+     *    beahviour.</p>
+     *
+     * <p>The reason for not returning a <code>null</code> property descriptor is that
+     *    <code>BeanUtils</code> uses this method to check if a property exists
+     *    before trying to set it - since these <em>Map</em> implementations automatically
+     *    add any new properties when they are set, returning <code>null</code> from
+     *    this method would defeat their purpose.</p>
+     *
+     * @param name Name of the dynamic property for which a descriptor
+     *  is requested
+     * @return The descriptor for the specified property
+     * @throws IllegalArgumentException if no property name is specified
+     */
+    @Override
+    public DynaProperty getDynaProperty(final String name) {
+
+        if (name == null) {
+            throw new IllegalArgumentException("Property name is missing.");
+        }
+
+        // If it doesn't exist and returnNull is false
+        // create a new DynaProperty
+        if (!values.containsKey(name) && isReturnNull()) {
+            return null;
+        }
+
+        final Object value = values.get(name);
+
+        if (value == null) {
+            return new DynaProperty(name);
+        }
+        return new DynaProperty(name, value.getClass());
+
+    }
+
+    /**
+     * Return the underlying Map backing this <code>DynaBean</code>
+     * @return the underlying Map
+     * @since 1.8.0
+     */
+    @Override
+    public Map<String, Object> getMap() {
+        return values;
+    }
+
+    /**
+     * Return the name of this DynaClass (analogous to the
+     * <code>getName()</code> method of <code>java.lang.Class</code>)
+     *
+     * @return the name of the DynaClass
+     */
+    @Override
+    public String getName() {
+        return this.name;
+    }
+
+    /**
+         * <p>Indicate whether a property actually exists.</p>
+         *
+         * <p><strong>N.B.</strong> Using <code>getDynaProperty(name) == null</code>
+         * doesn't work in this implementation because that method might
+         * return a DynaProperty if it doesn't exist (depending on the
+         * <code>returnNull</code> indicator).</p>
+         *
+         * @param name Name of the dynamic property
+         * @return <code>true</code> if the property exists,
+         * otherwise <code>false</code>
+         * @throws IllegalArgumentException if no property name is specified
+         */
+        @Override
+        protected boolean isDynaProperty(final String name) {
+
+            if (name == null) {
+                throw new IllegalArgumentException("Property name is missing.");
+            }
+
+            return values.containsKey(name);
+
+        }
+
+    /**
+     * <p>Is this DynaClass currently restricted.</p>
+     * <p>If restricted, no changes to the existing registration of
+     *  property names, data types, readability, or writeability are allowed.</p>
+     *
+     * @return <code>true</code> if this Mutable {@link DynaClass} is restricted,
+     * otherwise <code>false</code>
+     */
+    @Override
+    public boolean isRestricted() {
+        return restricted;
+    }
+
+    /**
+     * Should this DynaClass return a <code>null</code> from
+     * the <code>getDynaProperty(name)</code> method if the property
+     * doesn't exist.
+     *
+     * @return <code>true</code> if a <code>null</code> {@link DynaProperty}
+     * should be returned if the property doesn't exist, otherwise
+     * <code>false</code> if a new {@link DynaProperty} should be created.
+     */
+    public boolean isReturnNull() {
+        return returnNull;
+    }
+
+    /**
+     * Instantiate and return a new DynaBean instance, associated
+     * with this DynaClass.
+     * @return A new <code>DynaBean</code> instance
+     */
+    @Override
+    public DynaBean newInstance()  {
+
+        // Create a new instance of the Map
+        Map<String, Object> newMap = null;
+        try {
+            @SuppressWarnings("unchecked")
+            final
+            // The new map is used as properties map
+            Map<String, Object> temp = getMap().getClass().getConstructor().newInstance();
+            newMap = temp;
+        } catch(final Exception ex) {
+            newMap = newMap();
+        }
+
+        // Crate new LazyDynaMap and initialize properties
+        final LazyDynaMap lazyMap = new LazyDynaMap(newMap);
+        final DynaProperty[] properties = getDynaProperties();
+        if (properties != null) {
+            for (final DynaProperty propertie : properties) {
+                lazyMap.add(propertie);
+            }
+        }
+        return lazyMap;
     }
 
     /**
@@ -405,11 +397,11 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
      * associated with this DynaClass.
      *
      * @param name Name of the dynamic property to remove
-     *
      * @throws IllegalArgumentException if name is null
      * @throws IllegalStateException if this DynaClass is currently
      *  restricted, so no properties can be removed
      */
+    @Override
     public void remove(final String name) {
 
         if (name == null) {
@@ -427,60 +419,53 @@ public class LazyDynaMap extends LazyDynaBean implements MutableDynaClass {
 
     }
 
-
-    // ------------------- Additional Public Methods ----------------------------------
-
     /**
-     * Should this DynaClass return a <code>null</code> from
-     * the <code>getDynaProperty(name)</code> method if the property
-     * doesn't exist.
+     * Set the value of a simple property with the specified name.
      *
-     * @return <code>true</code> if a <code>null</code> {@link DynaProperty}
-     * should be returned if the property doesn't exist, otherwise
-     * <code>false</code> if a new {@link DynaProperty} should be created.
+     * @param name Name of the property whose value is to be set
+     * @param value Value to which this property is to be set
      */
-    public boolean isReturnNull() {
-        return returnNull;
+    @Override
+    public void set(final String name, final Object value) {
+
+        if (isRestricted() && !values.containsKey(name)) {
+            throw new IllegalArgumentException
+                    ("Invalid property name '" + name + "' (DynaClass is restricted)");
+        }
+
+        values.put(name, value);
+
     }
 
     /**
-     * Set whether this DynaClass should return a <code>null</code> from
-     * the <code>getDynaProperty(name)</code> method if the property
-     * doesn't exist.
+     * Set the Map backing this <code>DynaBean</code>
      *
-     * @param returnNull <code>true</code> if a <code>null</code> {@link DynaProperty}
-     * should be returned if the property doesn't exist, otherwise
-     * <code>false</code> if a new {@link DynaProperty} should be created.
+     * @param values The new Map of values
+     */
+    public void setMap(final Map<String, Object> values) {
+        this.values = values;
+    }
+
+    /**
+     * <p>Set whether this DynaClass is currently restricted.</p>
+     * <p>If restricted, no changes to the existing registration of
+     *  property names, data types, readability, or writeability are allowed.</p>
+     *
+     * @param restricted The new restricted state
+     */
+    @Override
+    public void setRestricted(final boolean restricted) {
+        this.restricted = restricted;
+    }
+
+    /**
+     * Set whether this DynaClass should return a <code>null</code> from the <code>getDynaProperty(name)</code> method if the property doesn't exist.
+     *
+     * @param returnNull <code>true</code> if a <code>null</code> {@link DynaProperty} should be returned if the property doesn't exist, otherwise
+     *                   <code>false</code> if a new {@link DynaProperty} should be created.
      */
     public void setReturnNull(final boolean returnNull) {
         this.returnNull = returnNull;
     }
 
-
-    // ------------------- Protected Methods ----------------------------------
-
-   /**
-     * <p>Indicate whether a property actually exists.</p>
-     *
-     * <p><strong>N.B.</strong> Using <code>getDynaProperty(name) == null</code>
-     * doesn't work in this implementation because that method might
-     * return a DynaProperty if it doesn't exist (depending on the
-     * <code>returnNull</code> indicator).</p>
-     *
-     * @param name Name of the dynamic property
-     * @return <code>true</code> if the property exists,
-     * otherwise <code>false</code>
-     * @throws IllegalArgumentException if no property name is specified
-     */
-    @Override
-    protected boolean isDynaProperty(final String name) {
-
-        if (name == null) {
-            throw new IllegalArgumentException("Property name is missing.");
-        }
-
-        return values.containsKey(name);
-
-    }
-
-}
\ No newline at end of file
+}
