@@ -15,7 +15,6 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
 import java.beans.PropertyDescriptor;
@@ -25,7 +24,6 @@ import java.util.Map;
 
 import org.apache.commons.collections.FastHashMap;
 
-
 /**
  * <p>Utility methods for using Java Reflection APIs to facilitate generic
  * property getter and setter operations on Java objects.</p>
@@ -33,17 +31,12 @@ import org.apache.commons.collections.FastHashMap;
  * <p>The implementations for these methods are provided by <code>PropertyUtilsBean</code>.
  * For more details see {@link PropertyUtilsBean}.</p>
  *
- * @version $Id$
  * @see PropertyUtilsBean
  * @see org.apache.commons.beanutils.expression.Resolver
  */
 
 public class PropertyUtils {
 
-
-    // ----------------------------------------------------- Manifest Constants
-
-
     /**
      * The delimiter that preceeds the zero-relative subscript for an
      * indexed reference.
@@ -55,7 +48,6 @@ public class PropertyUtils {
     @Deprecated
     public static final char INDEXED_DELIM = '[';
 
-
     /**
      * The delimiter that follows the zero-relative subscript for an
      * indexed reference.
@@ -67,7 +59,6 @@ public class PropertyUtils {
     @Deprecated
     public static final char INDEXED_DELIM2 = ']';
 
-
     /**
      * The delimiter that preceeds the key of a mapped property.
      *
@@ -78,7 +69,6 @@ public class PropertyUtils {
     @Deprecated
     public static final char MAPPED_DELIM = '(';
 
-
     /**
      * The delimiter that follows the key of a mapped property.
      *
@@ -89,7 +79,6 @@ public class PropertyUtils {
     @Deprecated
     public static final char MAPPED_DELIM2 = ')';
 
-
     /**
      * The delimiter that separates the components of a nested reference.
      *
@@ -100,10 +89,6 @@ public class PropertyUtils {
     @Deprecated
     public static final char NESTED_DELIM = '.';
 
-
-    // ------------------------------------------------------- Static Variables
-
-
     /**
      * The debugging detail level for this component.
      *
@@ -115,31 +100,21 @@ public class PropertyUtils {
      * @deprecated The <code>debug</code> static property is no longer used
      */
     @Deprecated
-    private static int debug = 0;
+    private static int debug;
 
     /**
-     * The <code>debug</code> static property is no longer used
-     * @return debug property
-     * @deprecated The <code>debug</code> static property is no longer used
+     * Adds a <code>BeanIntrospector</code>. This object is invoked when the
+     * property descriptors of a class need to be obtained.
+     *
+     * @param introspector the <code>BeanIntrospector</code> to be added (must
+     *        not be <strong>null</strong>
+     * @throws IllegalArgumentException if the argument is <strong>null</strong>
+     * @since 1.9
      */
-    @Deprecated
-    public static int getDebug() {
-        return (debug);
+    public static void addBeanIntrospector(final BeanIntrospector introspector) {
+        PropertyUtilsBean.getInstance().addBeanIntrospector(introspector);
     }
 
-    /**
-     * The <code>debug</code> static property is no longer used
-     * @param newDebug debug property
-     * @deprecated The <code>debug</code> static property is no longer used
-     */
-    @Deprecated
-    public static void setDebug(final int newDebug) {
-        debug = newDebug;
-    }
-
-    // --------------------------------------------------------- Public Methods
-
-
     /**
      * Clear any cached property descriptors information for all classes
      * loaded by any class loaders.  This is useful in cases where class
@@ -155,42 +130,6 @@ public class PropertyUtils {
 
     }
 
-    /**
-     * Resets the registered {@link BeanIntrospector} objects to the initial default
-     * state.
-     *
-     * @since 1.9
-     */
-    public static void resetBeanIntrospectors() {
-        PropertyUtilsBean.getInstance().resetBeanIntrospectors();
-    }
-
-    /**
-     * Adds a <code>BeanIntrospector</code>. This object is invoked when the
-     * property descriptors of a class need to be obtained.
-     *
-     * @param introspector the <code>BeanIntrospector</code> to be added (must
-     *        not be <b>null</b>
-     * @throws IllegalArgumentException if the argument is <b>null</b>
-     * @since 1.9
-     */
-    public static void addBeanIntrospector(final BeanIntrospector introspector) {
-        PropertyUtilsBean.getInstance().addBeanIntrospector(introspector);
-    }
-
-    /**
-     * Removes the specified <code>BeanIntrospector</code>.
-     *
-     * @param introspector the <code>BeanIntrospector</code> to be removed
-     * @return <b>true</b> if the <code>BeanIntrospector</code> existed and
-     *         could be removed, <b>false</b> otherwise
-     * @since 1.9
-     */
-    public static boolean removeBeanIntrospector(final BeanIntrospector introspector) {
-        return PropertyUtilsBean.getInstance().removeBeanIntrospector(
-                introspector);
-    }
-
     /**
      * <p>Copy property values from the "origin" bean to the "destination" bean
      * for all cases where the property names are the same (even though the
@@ -201,7 +140,6 @@ public class PropertyUtils {
      *
      * @param dest Destination bean whose properties are modified
      * @param orig Origin bean whose properties are retrieved
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if the <code>dest</code> or
@@ -219,7 +157,6 @@ public class PropertyUtils {
         PropertyUtilsBean.getInstance().copyProperties(dest, orig);
     }
 
-
     /**
      * <p>Return the entire set of properties for which the specified bean
      * provides a read method.</p>
@@ -228,7 +165,6 @@ public class PropertyUtils {
      *
      * @param bean Bean whose properties are to be extracted
      * @return The set of properties for the bean
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> is null
@@ -242,10 +178,19 @@ public class PropertyUtils {
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
 
-        return (PropertyUtilsBean.getInstance().describe(bean));
+        return PropertyUtilsBean.getInstance().describe(bean);
 
     }
 
+    /**
+     * The <code>debug</code> static property is no longer used
+     * @return debug property
+     * @deprecated The <code>debug</code> static property is no longer used
+     */
+    @Deprecated
+    public static int getDebug() {
+        return debug;
+    }
 
     /**
      * <p>Return the value of the specified indexed property of the specified
@@ -257,7 +202,6 @@ public class PropertyUtils {
      * @param name <code>propertyname[index]</code> of the property value
      *  to be extracted
      * @return the indexed property value
-     *
      * @throws IndexOutOfBoundsException if the specified index
      *  is outside the valid range for the underlying property
      * @throws IllegalAccessException if the caller does not have
@@ -274,11 +218,10 @@ public class PropertyUtils {
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
 
-        return (PropertyUtilsBean.getInstance().getIndexedProperty(bean, name));
+        return PropertyUtilsBean.getInstance().getIndexedProperty(bean, name);
 
     }
 
-
     /**
      * <p>Return the value of the specified indexed property of the specified
      * bean, with no type conversions.</p>
@@ -289,7 +232,6 @@ public class PropertyUtils {
      * @param name Simple property name of the property value to be extracted
      * @param index Index of the property value to be extracted
      * @return the indexed property value
-     *
      * @throws IndexOutOfBoundsException if the specified index
      *  is outside the valid range for the underlying property
      * @throws IllegalAccessException if the caller does not have
@@ -307,10 +249,9 @@ public class PropertyUtils {
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
 
-        return (PropertyUtilsBean.getInstance().getIndexedProperty(bean, name, index));
+        return PropertyUtilsBean.getInstance().getIndexedProperty(bean, name, index);
     }
 
-
     /**
      * <p>Return the value of the specified mapped property of the
      * specified bean, with no type conversions.</p>
@@ -321,7 +262,6 @@ public class PropertyUtils {
      * @param name <code>propertyname(key)</code> of the property value
      *  to be extracted
      * @return the mapped property value
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -334,11 +274,10 @@ public class PropertyUtils {
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
 
-        return (PropertyUtilsBean.getInstance().getMappedProperty(bean, name));
+        return PropertyUtilsBean.getInstance().getMappedProperty(bean, name);
 
     }
 
-
     /**
      * <p>Return the value of the specified mapped property of the specified
      * bean, with no type conversions.</p>
@@ -349,7 +288,6 @@ public class PropertyUtils {
      * @param name Mapped property name of the property value to be extracted
      * @param key Key of the property value to be extracted
      * @return the mapped property value
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -367,7 +305,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return the mapped property descriptors for this bean class.</p>
      *
@@ -385,7 +322,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return the mapped property descriptors for this bean.</p>
      *
@@ -403,7 +339,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return the value of the (possibly nested) property of the specified
      * name, for the specified bean, with no type conversions.</p>
@@ -413,7 +348,6 @@ public class PropertyUtils {
      * @param bean Bean whose property is to be extracted
      * @param name Possibly nested name of the property to be extracted
      * @return the nested property value
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -434,7 +368,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return the value of the specified property of the specified bean,
      * no matter which property reference format is used, with no
@@ -446,7 +379,6 @@ public class PropertyUtils {
      * @param name Possibly indexed and/or nested name of the property
      *  to be extracted
      * @return the property value
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -461,11 +393,10 @@ public class PropertyUtils {
             throws IllegalAccessException, InvocationTargetException,
             NoSuchMethodException {
 
-        return (PropertyUtilsBean.getInstance().getProperty(bean, name));
+        return PropertyUtilsBean.getInstance().getProperty(bean, name);
 
     }
 
-
     /**
      * <p>Retrieve the property descriptor for the specified property of the
      * specified bean, or return <code>null</code> if there is no such
@@ -477,7 +408,6 @@ public class PropertyUtils {
      * @param name Possibly indexed and/or nested name of the property for
      *  which a property descriptor is requested
      * @return the property descriptor
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -499,7 +429,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Retrieve the property descriptors for the specified class,
      * introspecting and caching them the first time a particular bean class
@@ -519,7 +448,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Retrieve the property descriptors for the specified bean,
      * introspecting and caching them the first time a particular bean class
@@ -538,7 +466,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return the Java Class repesenting the property editor class that has
      * been registered for this property (if any).</p>
@@ -549,7 +476,6 @@ public class PropertyUtils {
      * @param name Possibly indexed and/or nested name of the property for
      *  which a property descriptor is requested
      * @return the property editor class
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -570,7 +496,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return the Java Class representing the property type of the specified
      * property, or <code>null</code> if there is no such property for the
@@ -582,7 +507,6 @@ public class PropertyUtils {
      * @param name Possibly indexed and/or nested name of the property for
      *  which a property descriptor is requested
      * @return The property type
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -602,7 +526,6 @@ public class PropertyUtils {
         return PropertyUtilsBean.getInstance().getPropertyType(bean, name);
     }
 
-
     /**
      * <p>Return an accessible property getter method for this property,
      * if there is one; otherwise return <code>null</code>.</p>
@@ -615,11 +538,10 @@ public class PropertyUtils {
      */
     public static Method getReadMethod(final PropertyDescriptor descriptor) {
 
-        return (PropertyUtilsBean.getInstance().getReadMethod(descriptor));
+        return PropertyUtilsBean.getInstance().getReadMethod(descriptor);
 
     }
 
-
     /**
      * <p>Return the value of the specified simple property of the specified
      * bean, with no type conversions.</p>
@@ -629,7 +551,6 @@ public class PropertyUtils {
      * @param bean Bean whose property is to be extracted
      * @param name Name of the property to be extracted
      * @return The property value
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -650,7 +571,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return an accessible property setter method for this property,
      * if there is one; otherwise return <code>null</code>.</p>
@@ -667,7 +587,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Return <code>true</code> if the specified property name identifies
      * a readable property on the specified bean; otherwise, return
@@ -690,7 +609,6 @@ public class PropertyUtils {
         return PropertyUtilsBean.getInstance().isReadable(bean, name);
     }
 
-
     /**
      * <p>Return <code>true</code> if the specified property name identifies
      * a writeable property on the specified bean; otherwise, return
@@ -713,6 +631,68 @@ public class PropertyUtils {
         return PropertyUtilsBean.getInstance().isWriteable(bean, name);
     }
 
+    /**
+     * Removes the specified <code>BeanIntrospector</code>.
+     *
+     * @param introspector the <code>BeanIntrospector</code> to be removed
+     * @return <strong>true</strong> if the <code>BeanIntrospector</code> existed and
+     *         could be removed, <strong>false</strong> otherwise
+     * @since 1.9
+     */
+    public static boolean removeBeanIntrospector(final BeanIntrospector introspector) {
+        return PropertyUtilsBean.getInstance().removeBeanIntrospector(
+                introspector);
+    }
+
+    /**
+     * Resets the registered {@link BeanIntrospector} objects to the initial default
+     * state.
+     *
+     * @since 1.9
+     */
+    public static void resetBeanIntrospectors() {
+        PropertyUtilsBean.getInstance().resetBeanIntrospectors();
+    }
+
+    /**
+     * The <code>debug</code> static property is no longer used
+     * @param newDebug debug property
+     * @deprecated The <code>debug</code> static property is no longer used
+     */
+    @Deprecated
+    public static void setDebug(final int newDebug) {
+        debug = newDebug;
+    }
+
+    /**
+     * <p>Sets the value of the specified indexed property of the specified
+     * bean, with no type conversions.</p>
+     *
+     * <p>For more details see <code>PropertyUtilsBean</code>.</p>
+     *
+     * @param bean Bean whose property is to be set
+     * @param name Simple property name of the property value to be set
+     * @param index Index of the property value to be set
+     * @param value Value to which the indexed property element is to be set
+     * @throws IndexOutOfBoundsException if the specified index
+     *  is outside the valid range for the underlying property
+     * @throws IllegalAccessException if the caller does not have
+     *  access to the property accessor method
+     * @throws IllegalArgumentException if <code>bean</code> or
+     *  <code>name</code> is null
+     * @throws InvocationTargetException if the property accessor method
+     *  throws an exception
+     * @throws NoSuchMethodException if an accessor method for this
+     *  propety cannot be found
+     * @see PropertyUtilsBean#setIndexedProperty(Object, String, Object)
+     */
+    public static void setIndexedProperty(final Object bean, final String name,
+                                          final int index, final Object value)
+            throws IllegalAccessException, InvocationTargetException,
+            NoSuchMethodException {
+
+        PropertyUtilsBean.getInstance().setIndexedProperty(bean, name, index, value);
+    }
 
     /**
      * <p>Sets the value of the specified indexed property of the specified
@@ -747,39 +727,6 @@ public class PropertyUtils {
 
     }
 
-
-    /**
-     * <p>Sets the value of the specified indexed property of the specified
-     * bean, with no type conversions.</p>
-     *
-     * <p>For more details see <code>PropertyUtilsBean</code>.</p>
-     *
-     * @param bean Bean whose property is to be set
-     * @param name Simple property name of the property value to be set
-     * @param index Index of the property value to be set
-     * @param value Value to which the indexed property element is to be set
-     *
-     * @throws IndexOutOfBoundsException if the specified index
-     *  is outside the valid range for the underlying property
-     * @throws IllegalAccessException if the caller does not have
-     *  access to the property accessor method
-     * @throws IllegalArgumentException if <code>bean</code> or
-     *  <code>name</code> is null
-     * @throws InvocationTargetException if the property accessor method
-     *  throws an exception
-     * @throws NoSuchMethodException if an accessor method for this
-     *  propety cannot be found
-     * @see PropertyUtilsBean#setIndexedProperty(Object, String, Object)
-     */
-    public static void setIndexedProperty(final Object bean, final String name,
-                                          final int index, final Object value)
-            throws IllegalAccessException, InvocationTargetException,
-            NoSuchMethodException {
-
-        PropertyUtilsBean.getInstance().setIndexedProperty(bean, name, index, value);
-    }
-
-
     /**
      * <p>Sets the value of the specified mapped property of the
      * specified bean, with no type conversions.</p>
@@ -790,7 +737,6 @@ public class PropertyUtils {
      * @param name <code>propertyname(key)</code> of the property value
      *  to be set
      * @param value The property value to be set
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -807,7 +753,6 @@ public class PropertyUtils {
         PropertyUtilsBean.getInstance().setMappedProperty(bean, name, value);
     }
 
-
     /**
      * <p>Sets the value of the specified mapped property of the specified
      * bean, with no type conversions.</p>
@@ -818,7 +763,6 @@ public class PropertyUtils {
      * @param name Mapped property name of the property value to be set
      * @param key Key of the property value to be set
      * @param value The property value to be set
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws InvocationTargetException if the property accessor method
@@ -835,7 +779,6 @@ public class PropertyUtils {
         PropertyUtilsBean.getInstance().setMappedProperty(bean, name, key, value);
     }
 
-
     /**
      * <p>Sets the value of the (possibly nested) property of the specified
      * name, for the specified bean, with no type conversions.</p>
@@ -845,7 +788,6 @@ public class PropertyUtils {
      * @param bean Bean whose property is to be modified
      * @param name Possibly nested name of the property to be modified
      * @param value Value to which the property is to be set
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -866,7 +808,6 @@ public class PropertyUtils {
         PropertyUtilsBean.getInstance().setNestedProperty(bean, name, value);
     }
 
-
     /**
      * <p>Set the value of the specified property of the specified bean,
      * no matter which property reference format is used, with no
@@ -878,7 +819,6 @@ public class PropertyUtils {
      * @param name Possibly indexed and/or nested name of the property
      *  to be modified
      * @param value Value to which this property is to be set
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -897,7 +837,6 @@ public class PropertyUtils {
 
     }
 
-
     /**
      * <p>Set the value of the specified simple property of the specified bean,
      * with no type conversions.</p>
@@ -907,7 +846,6 @@ public class PropertyUtils {
      * @param bean Bean whose property is to be modified
      * @param name Name of the property to be modified
      * @param value Value to which the property should be set
-     *
      * @throws IllegalAccessException if the caller does not have
      *  access to the property accessor method
      * @throws IllegalArgumentException if <code>bean</code> or
@@ -928,5 +866,13 @@ public class PropertyUtils {
         PropertyUtilsBean.getInstance().setSimpleProperty(bean, name, value);
     }
 
-
+    /**
+     * Deprecated, all methods are static.
+     *
+     * @deprecated Will be private in 2.0.
+     */
+    @Deprecated
+    public PropertyUtils() {
+        // empty
+    }
 }
