@@ -15,19 +15,16 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
-
-import java.io.Serializable;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.List;
-
+import java.util.Objects;
 
 /**
- * <p>Implementation of {@link DynaClass} that creates an in-memory collection
+ * <p>Implements {@link DynaClass} to create an in-memory collection
  * of {@link DynaBean}s representing the results of an SQL query.  Once the
  * {@link DynaClass} instance has been created, the JDBC <code>ResultSet</code>
  * and <code>Statement</code> on which it is based can be closed, and the
@@ -62,13 +59,11 @@ import java.util.List;
  * convenient mechanism for transporting data sets to remote Java-based
  * application components.</p>
  *
- * @version $Id$
  */
 
-public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Serializable {
+public class RowSetDynaClass extends JDBCDynaClass {
 
-
-    // ----------------------------------------------------- Instance variables
+    private static final long serialVersionUID = 1L;
 
     /**
      * <p>Limits the size of the returned list.  The call to
@@ -82,10 +77,7 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
      * the original <code>ResultSet</code> on which this
      * {@link RowSetDynaClass} was based.</p>
      */
-    protected List<DynaBean> rows = new ArrayList<DynaBean>();
-
-    // ----------------------------------------------------------- Constructors
-
+    protected List<DynaBean> rows = new ArrayList<>();
 
     /**
      * <p>Construct a new {@link RowSetDynaClass} for the specified
@@ -93,7 +85,6 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
      * to column names in the result set will be lower cased.</p>
      *
      * @param resultSet The result set to be wrapped
-     *
      * @throws NullPointerException if <code>resultSet</code>
      *  is <code>null</code>
      * @throws SQLException if the metadata for this result set
@@ -105,29 +96,6 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
 
     }
 
-    /**
-     * <p>Construct a new {@link RowSetDynaClass} for the specified
-     * <code>ResultSet</code>.  The property names corresponding
-     * to column names in the result set will be lower cased.</p>
-     *
-     * If <code>limit</code> is not less than 0, max <code>limit</code>
-     * number of rows will be copied into the list.
-     *
-     * @param resultSet The result set to be wrapped
-     * @param limit The maximum for the size of the result.
-     *
-     * @throws NullPointerException if <code>resultSet</code>
-     *  is <code>null</code>
-     * @throws SQLException if the metadata for this result set
-     *  cannot be introspected
-     */
-    public RowSetDynaClass(final ResultSet resultSet, final int limit) throws SQLException {
-
-        this(resultSet, true, limit);
-
-    }
-
-
     /**
      * <p>Construct a new {@link RowSetDynaClass} for the specified
      * <code>ResultSet</code>.  The property names corresponding
@@ -140,7 +108,6 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
      *
      * @param resultSet The result set to be wrapped
      * @param lowerCase Should property names be lower cased?
-     *
      * @throws NullPointerException if <code>resultSet</code>
      *  is <code>null</code>
      * @throws SQLException if the metadata for this result set
@@ -152,35 +119,6 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
 
     }
 
-    /**
-     * <p>Construct a new {@link RowSetDynaClass} for the specified
-     * <code>ResultSet</code>.  The property names corresponding
-     * to the column names in the result set will be lower cased or not,
-     * depending on the specified <code>lowerCase</code> value.</p>
-     *
-     * <p><strong>WARNING</strong> - If you specify <code>false</code>
-     * for <code>lowerCase</code>, the returned property names will
-     * exactly match the column names returned by your JDBC driver.
-     * Because different drivers might return column names in different
-     * cases, the property names seen by your application will vary
-     * depending on which JDBC driver you are using.</p>
-     *
-     * @param resultSet The result set to be wrapped
-     * @param lowerCase Should property names be lower cased?
-     * @param limit Maximum limit for the <code>List</code> of {@link DynaBean}
-     *
-     * @throws NullPointerException if <code>resultSet</code>
-     *  is <code>null</code>
-     * @throws SQLException if the metadata for this result set
-     *  cannot be introspected
-     */
-    public RowSetDynaClass(final ResultSet resultSet, final boolean lowerCase, final int limit)
-                                                            throws SQLException {
-
-        this(resultSet, lowerCase, limit, false);
-
-    }
-
     /**
      * <p>Construct a new {@link RowSetDynaClass} for the specified
      * <code>ResultSet</code>.  The property names corresponding
@@ -197,7 +135,6 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
      * @param resultSet The result set to be wrapped
      * @param lowerCase Should property names be lower cased?
      * @param useColumnLabel true if the column label should be used, otherwise false
-     *
      * @throws NullPointerException if <code>resultSet</code>
      *  is <code>null</code>
      * @throws SQLException if the metadata for this result set
@@ -226,8 +163,35 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
      * @param resultSet The result set to be wrapped
      * @param lowerCase Should property names be lower cased?
      * @param limit Maximum limit for the <code>List</code> of {@link DynaBean}
-     * @param useColumnLabel true if the column label should be used, otherwise false
+     * @throws NullPointerException if <code>resultSet</code>
+     *  is <code>null</code>
+     * @throws SQLException if the metadata for this result set
+     *  cannot be introspected
+     */
+    public RowSetDynaClass(final ResultSet resultSet, final boolean lowerCase, final int limit)
+                                                            throws SQLException {
+
+        this(resultSet, lowerCase, limit, false);
+
+    }
+
+    /**
+     * <p>Construct a new {@link RowSetDynaClass} for the specified
+     * <code>ResultSet</code>.  The property names corresponding
+     * to the column names in the result set will be lower cased or not,
+     * depending on the specified <code>lowerCase</code> value.</p>
      *
+     * <p><strong>WARNING</strong> - If you specify <code>false</code>
+     * for <code>lowerCase</code>, the returned property names will
+     * exactly match the column names returned by your JDBC driver.
+     * Because different drivers might return column names in different
+     * cases, the property names seen by your application will vary
+     * depending on which JDBC driver you are using.</p>
+     *
+     * @param resultSet The result set to be wrapped
+     * @param lowerCase Should property names be lower cased?
+     * @param limit Maximum limit for the <code>List</code> of {@link DynaBean}
+     * @param useColumnLabel true if the column label should be used, otherwise false
      * @throws NullPointerException if <code>resultSet</code>
      *  is <code>null</code>
      * @throws SQLException if the metadata for this result set
@@ -235,16 +199,71 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
      * @since 1.8.3
      */
     public RowSetDynaClass(final ResultSet resultSet, final boolean lowerCase, final int limit, final boolean useColumnLabel)
-                                                            throws SQLException {
-
-        if (resultSet == null) {
-            throw new NullPointerException();
-        }
+            throws SQLException {
+        Objects.requireNonNull(resultSet, "resultSet");
         this.lowerCase = lowerCase;
         this.limit = limit;
         setUseColumnLabel(useColumnLabel);
         introspect(resultSet);
         copy(resultSet);
+    }
+
+    /**
+     * <p>Construct a new {@link RowSetDynaClass} for the specified
+     * <code>ResultSet</code>.  The property names corresponding
+     * to column names in the result set will be lower cased.</p>
+     *
+     * If <code>limit</code> is not less than 0, max <code>limit</code>
+     * number of rows will be copied into the list.
+     *
+     * @param resultSet The result set to be wrapped
+     * @param limit The maximum for the size of the result.
+     * @throws NullPointerException if <code>resultSet</code>
+     *  is <code>null</code>
+     * @throws SQLException if the metadata for this result set
+     *  cannot be introspected
+     */
+    public RowSetDynaClass(final ResultSet resultSet, final int limit) throws SQLException {
+
+        this(resultSet, true, limit);
+
+    }
+
+    /**
+     * <p>Copy the column values for each row in the specified
+     * <code>ResultSet</code> into a newly created {@link DynaBean}, and add
+     * this bean to the list of {@link DynaBean}s that will later by
+     * returned by a call to <code>getRows()</code>.</p>
+     *
+     * @param resultSet The <code>ResultSet</code> whose data is to be
+     *  copied
+     *
+     * @throws SQLException if an error is encountered copying the data
+     */
+    protected void copy(final ResultSet resultSet) throws SQLException {
+
+        int cnt = 0;
+        while (resultSet.next() && (limit < 0 || cnt++ < limit)) {
+            final DynaBean bean = createDynaBean();
+            for (final DynaProperty propertie : properties) {
+                final String name = propertie.getName();
+                final Object value = getObject(resultSet, name);
+                bean.set(name, value);
+            }
+            rows.add(bean);
+        }
+
+    }
+
+    /**
+     * <p>Create and return a new {@link DynaBean} instance to be used for
+     * representing a row in the underlying result set.</p>
+     *
+     * @return A new <code>DynaBean</code> instance
+     */
+    protected DynaBean createDynaBean() {
+
+        return new BasicDynaBean(this);
 
     }
 
@@ -263,52 +282,8 @@ public class RowSetDynaClass extends JDBCDynaClass implements DynaClass, Seriali
      */
     public List<DynaBean> getRows() {
 
-        return (this.rows);
+        return this.rows;
 
     }
 
-
-    // ------------------------------------------------------ Protected Methods
-
-
-    /**
-     * <p>Copy the column values for each row in the specified
-     * <code>ResultSet</code> into a newly created {@link DynaBean}, and add
-     * this bean to the list of {@link DynaBean}s that will later by
-     * returned by a call to <code>getRows()</code>.</p>
-     *
-     * @param resultSet The <code>ResultSet</code> whose data is to be
-     *  copied
-     *
-     * @throws SQLException if an error is encountered copying the data
-     */
-    protected void copy(final ResultSet resultSet) throws SQLException {
-
-        int cnt = 0;
-        while (resultSet.next() && (limit < 0  || cnt++ < limit) ) {
-            final DynaBean bean = createDynaBean();
-            for (DynaProperty propertie : properties) {
-                final String name = propertie.getName();
-                final Object value = getObject(resultSet, name);
-                bean.set(name, value);
-            }
-            rows.add(bean);
-        }
-
-    }
-
-
-    /**
-     * <p>Create and return a new {@link DynaBean} instance to be used for
-     * representing a row in the underlying result set.</p>
-     *
-     * @return A new <code>DynaBean</code> instance
-     */
-    protected DynaBean createDynaBean() {
-
-        return (new BasicDynaBean(this));
-
-    }
-
-
 }
