@@ -33,7 +33,6 @@ import java.util.Set;
  * {@code BeanIntrospector} are removed again.
  * </p>
  *
- * @version $Id$
  * @since 1.9.2
  */
 public class SuppressPropertiesBeanIntrospector implements BeanIntrospector {
@@ -56,16 +55,16 @@ public class SuppressPropertiesBeanIntrospector implements BeanIntrospector {
      * names of the properties to be suppressed.
      *
      * @param propertiesToSuppress the names of the properties to be suppressed (must not
-     * be <b>null</b>)
+     * be <strong>null</strong>)
      * @throws IllegalArgumentException if the collection with property names is
-     * <b>null</b>
+     * <strong>null</strong>
      */
     public SuppressPropertiesBeanIntrospector(final Collection<String> propertiesToSuppress) {
         if (propertiesToSuppress == null) {
             throw new IllegalArgumentException("Property names must not be null!");
         }
 
-        propertyNames = Collections.unmodifiableSet(new HashSet<String>(
+        propertyNames = Collections.unmodifiableSet(new HashSet<>(
                 propertiesToSuppress));
     }
 
@@ -83,6 +82,7 @@ public class SuppressPropertiesBeanIntrospector implements BeanIntrospector {
      * {@inheritDoc} This implementation removes all properties from the given context it
      * is configured for.
      */
+    @Override
     public void introspect(final IntrospectionContext icontext) throws IntrospectionException {
         for (final String property : getSuppressedProperties()) {
             icontext.removePropertyDescriptor(property);
