@@ -58,29 +58,301 @@ import java.util.WeakHashMap;
  * <a href="http://www.cs.umd.edu/~pugh/java/memoryModel/DoubleCheckedLocking.html">
  * Double-Checked Locking Idiom Is Broken Declaration</a>.</p>
  *
+ * @param <K> the type of keys maintained by this map
+ * @param <V> the type of mapped values
  * @since Commons Collections 1.0
- * @version $Id$
  */
 class WeakFastHashMap<K, V> extends HashMap<K, V> {
 
+    /**
+     * Abstract collection implementation shared by keySet(), values() and entrySet().
+     *
+     * @param <E> the element type
+     */
+    private abstract class CollectionView<E> implements Collection<E> {
+
+        private class CollectionViewIterator implements Iterator<E> {
+
+            private Map<K, V> expected;
+            private Map.Entry<K, V> lastReturned;
+            private final Iterator<Map.Entry<K, V>> iterator;
+
+            public CollectionViewIterator() {
+                this.expected = map;
+                this.iterator = expected.entrySet().iterator();
+            }
+
+            @Override
+            public boolean hasNext() {
+                if (expected != map) {
+                    throw new ConcurrentModificationException();
+                }
+                return iterator.hasNext();
+            }
+
+            @Override
+            public E next() {
+                if (expected != map) {
+                    throw new ConcurrentModificationException();
+                }
+                lastReturned = iterator.next();
+                return iteratorNext(lastReturned);
+            }
+
+            @Override
+            public void remove() {
+                if (lastReturned == null) {
+                    throw new IllegalStateException();
+                }
+                if (fast) {
+                    synchronized (WeakFastHashMap.this) {
+                        if (expected != map) {
+                            throw new ConcurrentModificationException();
+                        }
+                        WeakFastHashMap.this.remove(lastReturned.getKey());
+                        lastReturned = null;
+                        expected = map;
+                    }
+                } else {
+                    iterator.remove();
+                    lastReturned = null;
+                }
+            }
+        }
+
+        public CollectionView() {
+        }
+        @Override
+        public boolean add(final E o) {
+            throw new UnsupportedOperationException();
+        }
+
+        @Override
+        public boolean addAll(final Collection<? extends E> c) {
+            throw new UnsupportedOperationException();
+        }
+
+        @Override
+        public void clear() {
+            if (fast) {
+                synchronized (WeakFastHashMap.this) {
+                    map = createMap();
+                }
+            } else {
+                synchronized (map) {
+                    get(map).clear();
+                }
+            }
+        }
+
+        @Override
+        public boolean contains(final Object o) {
+            if (fast) {
+                return get(map).contains(o);
+            }
+            synchronized (map) {
+                return get(map).contains(o);
+            }
+        }
+
+        @Override
+        public boolean containsAll(final Collection<?> o) {
+            if (fast) {
+                return get(map).containsAll(o);
+            }
+            synchronized (map) {
+                return get(map).containsAll(o);
+            }
+        }
+
+        @Override
+        public boolean equals(final Object o) {
+            if (o == this) {
+                return true;
+            }
+            if (fast) {
+                return get(map).equals(o);
+            }
+            synchronized (map) {
+                return get(map).equals(o);
+            }
+        }
+
+        protected abstract Collection<E> get(Map<K, V> map);
+
+        @Override
+        public int hashCode() {
+            if (fast) {
+                return get(map).hashCode();
+            }
+            synchronized (map) {
+                return get(map).hashCode();
+            }
+        }
+
+        @Override
+        public boolean isEmpty() {
+            if (fast) {
+                return get(map).isEmpty();
+            }
+            synchronized (map) {
+                return get(map).isEmpty();
+            }
+        }
+
+        @Override
+        public Iterator<E> iterator() {
+            return new CollectionViewIterator();
+        }
+
+        protected abstract E iteratorNext(Map.Entry<K, V> entry);
+
+        @Override
+        public boolean remove(final Object o) {
+            if (fast) {
+                synchronized (WeakFastHashMap.this) {
+                    final Map<K, V> temp = cloneMap(map);
+                    final boolean r = get(temp).remove(o);
+                    map = temp;
+                    return r;
+                }
+            }
+            synchronized (map) {
+                return get(map).remove(o);
+            }
+        }
+
+        @Override
+        public boolean removeAll(final Collection<?> o) {
+            if (fast) {
+                synchronized (WeakFastHashMap.this) {
+                    final Map<K, V> temp = cloneMap(map);
+                    final boolean r = get(temp).removeAll(o);
+                    map = temp;
+                    return r;
+                }
+            }
+            synchronized (map) {
+                return get(map).removeAll(o);
+            }
+        }
+
+        @Override
+        public boolean retainAll(final Collection<?> o) {
+            if (fast) {
+                synchronized (WeakFastHashMap.this) {
+                    final Map<K, V> temp = cloneMap(map);
+                    final boolean r = get(temp).retainAll(o);
+                    map = temp;
+                    return r;
+                }
+            }
+            synchronized (map) {
+                return get(map).retainAll(o);
+            }
+        }
+
+        @Override
+        public int size() {
+            if (fast) {
+                return get(map).size();
+            }
+            synchronized (map) {
+                return get(map).size();
+            }
+        }
+
+        @Override
+        public Object[] toArray() {
+            if (fast) {
+                return get(map).toArray();
+            }
+            synchronized (map) {
+                return get(map).toArray();
+            }
+        }
+
+        @Override
+        public <T> T[] toArray(final T[] o) {
+            if (fast) {
+                return get(map).toArray(o);
+            }
+            synchronized (map) {
+                return get(map).toArray(o);
+            }
+        }
+    }
+
+    /**
+     * Set implementation over the entries of the FastHashMap
+     */
+    private class EntrySet extends CollectionView<Map.Entry<K, V>> implements Set<Map.Entry<K, V>> {
+
+        @Override
+        protected Collection<Map.Entry<K, V>> get(final Map<K, V> map) {
+            return map.entrySet();
+        }
+
+        @Override
+        protected Map.Entry<K, V> iteratorNext(final Map.Entry<K, V> entry) {
+            return entry;
+        }
+
+    }
+
+    /**
+     * Set implementation over the keys of the FastHashMap
+     */
+    private class KeySet extends CollectionView<K> implements Set<K> {
+
+        @Override
+        protected Collection<K> get(final Map<K, V> map) {
+            return map.keySet();
+        }
+
+        @Override
+        protected K iteratorNext(final Map.Entry<K, V> entry) {
+            return entry.getKey();
+        }
+
+    }
+
+    // Constructors
+
+    /**
+     * Collection implementation over the values of the FastHashMap
+     */
+    private class Values extends CollectionView<V> {
+
+        @Override
+        protected Collection<V> get(final Map<K, V> map) {
+            return map.values();
+        }
+
+        @Override
+        protected V iteratorNext(final Map.Entry<K, V> entry) {
+            return entry.getValue();
+        }
+    }
+
+    private static final long serialVersionUID = 1L;
+
     /**
      * The underlying map we are managing.
      */
-    private Map<K, V> map = null;
+    private Map<K, V> map;
 
     /**
      * Are we currently operating in "fast" mode?
      */
-    private boolean fast = false;
+    private boolean fast;
 
-    // Constructors
-    // ----------------------------------------------------------------------
+    // Property access
 
     /**
      * Construct an empty map.
      */
     public WeakFastHashMap() {
-        super();
         this.map = createMap();
     }
 
@@ -90,10 +362,13 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
      * @param capacity  the initial capacity of the empty map
      */
     public WeakFastHashMap(final int capacity) {
-        super();
         this.map = createMap(capacity);
     }
 
+    // Map access
+    // These methods can forward straight to the wrapped Map in 'fast' mode.
+    // (because they are query methods)
+
     /**
      * Construct an empty map with the specified capacity and load factor.
      *
@@ -101,7 +376,6 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
      * @param factor  the load factor of the new map
      */
     public WeakFastHashMap(final int capacity, final float factor) {
-        super();
         this.map = createMap(capacity, factor);
     }
 
@@ -111,90 +385,54 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
      * @param map  the map whose mappings are to be copied
      */
     public WeakFastHashMap(final Map<? extends K, ? extends V> map) {
-        super();
         this.map = createMap(map);
     }
 
-
-    // Property access
-    // ----------------------------------------------------------------------
-
     /**
-     *  Returns true if this map is operating in fast mode.
-     *
-     *  @return true if this map is operating in fast mode
-     */
-    public boolean getFast() {
-        return (this.fast);
-    }
-
-    /**
-     *  Sets whether this map is operating in fast mode.
-     *
-     *  @param fast true if this map should operate in fast mode
-     */
-    public void setFast(final boolean fast) {
-        this.fast = fast;
-    }
-
-
-    // Map access
-    // ----------------------------------------------------------------------
-    // These methods can forward straight to the wrapped Map in 'fast' mode.
-    // (because they are query methods)
-
-    /**
-     * Return the value to which this map maps the specified key.  Returns
-     * <code>null</code> if the map contains no mapping for this key, or if
-     * there is a mapping with a value of <code>null</code>.  Use the
-     * <code>containsKey()</code> method to disambiguate these cases.
-     *
-     * @param key  the key whose value is to be returned
-     * @return the value mapped to that key, or null
+     * Remove all mappings from this map.
      */
     @Override
-    public V get(final Object key) {
+    public void clear() {
         if (fast) {
-            return (map.get(key));
+            synchronized (this) {
+                map = createMap();
+            }
         } else {
             synchronized (map) {
-                return (map.get(key));
+                map.clear();
             }
         }
     }
 
     /**
-     * Return the number of key-value mappings in this map.
+     * Return a shallow copy of this <code>FastHashMap</code> instance.
+     * The keys and values themselves are not copied.
      *
-     * @return the current size of the map
+     * @return a clone of this map
      */
     @Override
-    public int size() {
+    public Object clone() {
+        WeakFastHashMap<K, V> results = null;
         if (fast) {
-            return (map.size());
+            results = new WeakFastHashMap<>(map);
         } else {
             synchronized (map) {
-                return (map.size());
+                results = new WeakFastHashMap<>(map);
             }
         }
+        results.setFast(getFast());
+        return results;
     }
 
-    /**
-     * Return <code>true</code> if this map contains no mappings.
-     *
-     * @return is the map currently empty
-     */
-    @Override
-    public boolean isEmpty() {
-        if (fast) {
-            return (map.isEmpty());
-        } else {
-            synchronized (map) {
-                return (map.isEmpty());
-            }
-        }
+    protected Map<K, V> cloneMap(final Map<? extends K, ? extends V> map) {
+        return createMap(map);
     }
 
+    // Map modification
+    // These methods perform special behavior in 'fast' mode.
+    // The map is cloned, updated and then assigned back.
+    // See the comments at the top as to why this won't always work.
+
     /**
      * Return <code>true</code> if this map contains a mapping for the
      * specified key.
@@ -205,11 +443,10 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
     @Override
     public boolean containsKey(final Object key) {
         if (fast) {
-            return (map.containsKey(key));
-        } else {
-            synchronized (map) {
-                return (map.containsKey(key));
-            }
+            return map.containsKey(key);
+        }
+        synchronized (map) {
+            return map.containsKey(key);
         }
     }
 
@@ -223,19 +460,179 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
     @Override
     public boolean containsValue(final Object value) {
         if (fast) {
-            return (map.containsValue(value));
-        } else {
-            synchronized (map) {
-                return (map.containsValue(value));
-            }
+            return map.containsValue(value);
+        }
+        synchronized (map) {
+            return map.containsValue(value);
         }
     }
 
-    // Map modification
-    // ----------------------------------------------------------------------
-    // These methods perform special behaviour in 'fast' mode.
-    // The map is cloned, updated and then assigned back.
-    // See the comments at the top as to why this won't always work.
+    protected Map<K, V> createMap() {
+        return new WeakHashMap<>();
+    }
+
+    protected Map<K, V> createMap(final int capacity) {
+        return new WeakHashMap<>(capacity);
+    }
+
+    // Basic object methods
+
+    protected Map<K, V> createMap(final int capacity, final float factor) {
+        return new WeakHashMap<>(capacity, factor);
+    }
+
+    protected Map<K, V> createMap(final Map<? extends K, ? extends V> map) {
+        return new WeakHashMap<>(map);
+    }
+
+    /**
+     * Return a collection view of the mappings contained in this map.  Each
+     * element in the returned collection is a <code>Map.Entry</code>.
+     * @return the set of map Map entries
+     */
+    @Override
+    public Set<Map.Entry<K, V>> entrySet() {
+        return new EntrySet();
+    }
+
+    // Map views
+
+    /**
+     * Compare the specified object with this list for equality.  This
+     * implementation uses exactly the code that is used to define the
+     * list equals function in the documentation for the
+     * <code>Map.equals</code> method.
+     *
+     * @param o  the object to be compared to this list
+     * @return true if the two maps are equal
+     */
+    @Override
+    public boolean equals(final Object o) {
+        // Simple tests that require no synchronization
+        if (o == this) {
+            return true;
+        }
+        if (!(o instanceof Map)) {
+            return false;
+        }
+        final Map<?, ?> mo = (Map<?, ?>) o;
+
+        // Compare the two maps for equality
+        if (fast) {
+            if (mo.size() != map.size()) {
+                return false;
+            }
+            for (final Map.Entry<K, V> e : map.entrySet()) {
+                final K key = e.getKey();
+                final V value = e.getValue();
+                if (value == null) {
+                    if (!(mo.get(key) == null && mo.containsKey(key))) {
+                        return false;
+                    }
+                } else if (!value.equals(mo.get(key))) {
+                    return false;
+                }
+            }
+            return true;
+
+        }
+        synchronized (map) {
+            if (mo.size() != map.size()) {
+                return false;
+            }
+            for (final Map.Entry<K, V> e : map.entrySet()) {
+                final K key = e.getKey();
+                final V value = e.getValue();
+                if (value == null) {
+                    if (!(mo.get(key) == null && mo.containsKey(key))) {
+                        return false;
+                    }
+                } else if (!value.equals(mo.get(key))) {
+                    return false;
+                }
+            }
+            return true;
+        }
+    }
+
+    /**
+     * Return the value to which this map maps the specified key.  Returns
+     * <code>null</code> if the map contains no mapping for this key, or if
+     * there is a mapping with a value of <code>null</code>.  Use the
+     * <code>containsKey()</code> method to disambiguate these cases.
+     *
+     * @param key  the key whose value is to be returned
+     * @return the value mapped to that key, or null
+     */
+    @Override
+    public V get(final Object key) {
+        if (fast) {
+            return map.get(key);
+        }
+        synchronized (map) {
+            return map.get(key);
+        }
+    }
+
+    /**
+     *  Returns true if this map is operating in fast mode.
+     *
+     *  @return true if this map is operating in fast mode
+     */
+    public boolean getFast() {
+        return this.fast;
+    }
+
+    // Abstractions on Map creations (for subclasses such as WeakFastHashMap)
+
+    /**
+     * Return the hash code value for this map.  This implementation uses
+     * exactly the code that is used to define the list hash function in the
+     * documentation for the <code>Map.hashCode</code> method.
+     *
+     * @return suitable integer hash code
+     */
+    @Override
+    public int hashCode() {
+        if (fast) {
+            int h = 0;
+            for (final Map.Entry<K, V> e : map.entrySet()) {
+                h += e.hashCode();
+            }
+            return h;
+        }
+        synchronized (map) {
+            int h = 0;
+            for (final Map.Entry<K, V> e : map.entrySet()) {
+                h += e.hashCode();
+            }
+            return h;
+        }
+    }
+
+    /**
+     * Return <code>true</code> if this map contains no mappings.
+     *
+     * @return is the map currently empty
+     */
+    @Override
+    public boolean isEmpty() {
+        if (fast) {
+            return map.isEmpty();
+        }
+        synchronized (map) {
+            return map.isEmpty();
+        }
+    }
+
+    /**
+     * Return a set view of the keys contained in this map.
+     * @return the set of the Map's keys
+     */
+    @Override
+    public Set<K> keySet() {
+        return new KeySet();
+    }
 
     /**
      * Associate the specified value with the specified key in this map.
@@ -253,13 +650,12 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
                 final Map<K, V> temp = cloneMap(map);
                 final V result = temp.put(key, value);
                 map = temp;
-                return (result);
-            }
-        } else {
-            synchronized (map) {
-                return (map.put(key, value));
+                return result;
             }
         }
+        synchronized (map) {
+            return map.put(key, value);
+        }
     }
 
     /**
@@ -283,6 +679,8 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
         }
     }
 
+    // Map view inner classes
+
     /**
      * Remove any mapping for this key, and return any previously
      * mapped value.
@@ -297,162 +695,36 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
                 final Map<K, V> temp = cloneMap(map);
                 final V result = temp.remove(key);
                 map = temp;
-                return (result);
-            }
-        } else {
-            synchronized (map) {
-                return (map.remove(key));
+                return result;
             }
         }
+        synchronized (map) {
+            return map.remove(key);
+        }
     }
 
     /**
-     * Remove all mappings from this map.
-     */
-    @Override
-    public void clear() {
-        if (fast) {
-            synchronized (this) {
-                map = createMap();
-            }
-        } else {
-            synchronized (map) {
-                map.clear();
-            }
-        }
-    }
-
-    // Basic object methods
-    // ----------------------------------------------------------------------
-
-    /**
-     * Compare the specified object with this list for equality.  This
-     * implementation uses exactly the code that is used to define the
-     * list equals function in the documentation for the
-     * <code>Map.equals</code> method.
+     *  Sets whether this map is operating in fast mode.
      *
-     * @param o  the object to be compared to this list
-     * @return true if the two maps are equal
+     *  @param fast true if this map should operate in fast mode
      */
-    @Override
-    public boolean equals(final Object o) {
-        // Simple tests that require no synchronization
-        if (o == this) {
-            return (true);
-        } else if (!(o instanceof Map)) {
-            return (false);
-        }
-        final Map<?, ?> mo = (Map<?, ?>) o;
-
-        // Compare the two maps for equality
-        if (fast) {
-            if (mo.size() != map.size()) {
-                return (false);
-            }
-            for (final Map.Entry<K, V> e : map.entrySet()) {
-                final K key = e.getKey();
-                final V value = e.getValue();
-                if (value == null) {
-                    if (!(mo.get(key) == null && mo.containsKey(key))) {
-                        return (false);
-                    }
-                } else {
-                    if (!value.equals(mo.get(key))) {
-                        return (false);
-                    }
-                }
-            }
-            return (true);
-
-        } else {
-            synchronized (map) {
-                if (mo.size() != map.size()) {
-                    return (false);
-                }
-                for (final Map.Entry<K, V> e : map.entrySet()) {
-                    final K key = e.getKey();
-                    final V value = e.getValue();
-                    if (value == null) {
-                        if (!(mo.get(key) == null && mo.containsKey(key))) {
-                            return (false);
-                        }
-                    } else {
-                        if (!value.equals(mo.get(key))) {
-                            return (false);
-                        }
-                    }
-                }
-                return (true);
-            }
-        }
+    public void setFast(final boolean fast) {
+        this.fast = fast;
     }
 
     /**
-     * Return the hash code value for this map.  This implementation uses
-     * exactly the code that is used to define the list hash function in the
-     * documentation for the <code>Map.hashCode</code> method.
+     * Return the number of key-value mappings in this map.
      *
-     * @return suitable integer hash code
+     * @return the current size of the map
      */
     @Override
-    public int hashCode() {
+    public int size() {
         if (fast) {
-            int h = 0;
-            for (final Map.Entry<K, V> e : map.entrySet()) {
-                h += e.hashCode();
-            }
-            return (h);
-        } else {
-            synchronized (map) {
-                int h = 0;
-                for (final Map.Entry<K, V> e : map.entrySet()) {
-                    h += e.hashCode();
-                }
-                return (h);
-            }
+            return map.size();
         }
-    }
-
-    /**
-     * Return a shallow copy of this <code>FastHashMap</code> instance.
-     * The keys and values themselves are not copied.
-     *
-     * @return a clone of this map
-     */
-    @Override
-    public Object clone() {
-        WeakFastHashMap<K, V> results = null;
-        if (fast) {
-            results = new WeakFastHashMap<K, V>(map);
-        } else {
-            synchronized (map) {
-                results = new WeakFastHashMap<K, V>(map);
-            }
+        synchronized (map) {
+            return map.size();
         }
-        results.setFast(getFast());
-        return (results);
-    }
-
-    // Map views
-    // ----------------------------------------------------------------------
-
-    /**
-     * Return a collection view of the mappings contained in this map.  Each
-     * element in the returned collection is a <code>Map.Entry</code>.
-     * @return the set of map Map entries
-     */
-    @Override
-    public Set<Map.Entry<K, V>> entrySet() {
-        return new EntrySet();
-    }
-
-    /**
-     * Return a set view of the keys contained in this map.
-     * @return the set of the Map's keys
-     */
-    @Override
-    public Set<K> keySet() {
-        return new KeySet();
     }
 
     /**
@@ -464,297 +736,4 @@ class WeakFastHashMap<K, V> extends HashMap<K, V> {
         return new Values();
     }
 
-    // Abstractions on Map creations (for subclasses such as WeakFastHashMap)
-    // ----------------------------------------------------------------------
-
-    protected Map<K, V> createMap() {
-        return new WeakHashMap<K, V>();
-    }
-
-    protected Map<K, V> createMap(final int capacity) {
-        return new WeakHashMap<K, V>(capacity);
-    }
-
-    protected Map<K, V> createMap(final int capacity, final float factor) {
-        return new WeakHashMap<K, V>(capacity, factor);
-    }
-
-    protected Map<K, V> createMap(final Map<? extends K, ? extends V> map) {
-        return new WeakHashMap<K, V>(map);
-    }
-
-    protected Map<K, V> cloneMap(final Map<? extends K, ? extends V> map) {
-        return createMap(map);
-    }
-
-    // Map view inner classes
-    // ----------------------------------------------------------------------
-
-    /**
-     * Abstract collection implementation shared by keySet(), values() and entrySet().
-     *
-     * @param <E> the element type
-     */
-    private abstract class CollectionView<E> implements Collection<E> {
-
-        public CollectionView() {
-        }
-
-        protected abstract Collection<E> get(Map<K, V> map);
-        protected abstract E iteratorNext(Map.Entry<K, V> entry);
-
-
-        public void clear() {
-            if (fast) {
-                synchronized (WeakFastHashMap.this) {
-                    map = createMap();
-                }
-            } else {
-                synchronized (map) {
-                    get(map).clear();
-                }
-            }
-        }
-
-        public boolean remove(final Object o) {
-            if (fast) {
-                synchronized (WeakFastHashMap.this) {
-                    final Map<K, V> temp = cloneMap(map);
-                    final boolean r = get(temp).remove(o);
-                    map = temp;
-                    return r;
-                }
-            } else {
-                synchronized (map) {
-                    return get(map).remove(o);
-                }
-            }
-        }
-
-        public boolean removeAll(final Collection<?> o) {
-            if (fast) {
-                synchronized (WeakFastHashMap.this) {
-                    final Map<K, V> temp = cloneMap(map);
-                    final boolean r = get(temp).removeAll(o);
-                    map = temp;
-                    return r;
-                }
-            } else {
-                synchronized (map) {
-                    return get(map).removeAll(o);
-                }
-            }
-        }
-
-        public boolean retainAll(final Collection<?> o) {
-            if (fast) {
-                synchronized (WeakFastHashMap.this) {
-                    final Map<K, V> temp = cloneMap(map);
-                    final boolean r = get(temp).retainAll(o);
-                    map = temp;
-                    return r;
-                }
-            } else {
-                synchronized (map) {
-                    return get(map).retainAll(o);
-                }
-            }
-        }
-
-        public int size() {
-            if (fast) {
-                return get(map).size();
-            } else {
-                synchronized (map) {
-                    return get(map).size();
-                }
-            }
-        }
-
-
-        public boolean isEmpty() {
-            if (fast) {
-                return get(map).isEmpty();
-            } else {
-                synchronized (map) {
-                    return get(map).isEmpty();
-                }
-            }
-        }
-
-        public boolean contains(final Object o) {
-            if (fast) {
-                return get(map).contains(o);
-            } else {
-                synchronized (map) {
-                    return get(map).contains(o);
-                }
-            }
-        }
-
-        public boolean containsAll(final Collection<?> o) {
-            if (fast) {
-                return get(map).containsAll(o);
-            } else {
-                synchronized (map) {
-                    return get(map).containsAll(o);
-                }
-            }
-        }
-
-        public <T> T[] toArray(final T[] o) {
-            if (fast) {
-                return get(map).toArray(o);
-            } else {
-                synchronized (map) {
-                    return get(map).toArray(o);
-                }
-            }
-        }
-
-        public Object[] toArray() {
-            if (fast) {
-                return get(map).toArray();
-            } else {
-                synchronized (map) {
-                    return get(map).toArray();
-                }
-            }
-        }
-
-
-        @Override
-        public boolean equals(final Object o) {
-            if (o == this) {
-                return true;
-            }
-            if (fast) {
-                return get(map).equals(o);
-            } else {
-                synchronized (map) {
-                    return get(map).equals(o);
-                }
-            }
-        }
-
-        @Override
-        public int hashCode() {
-            if (fast) {
-                return get(map).hashCode();
-            } else {
-                synchronized (map) {
-                    return get(map).hashCode();
-                }
-            }
-        }
-
-        public boolean add(final E o) {
-            throw new UnsupportedOperationException();
-        }
-
-        public boolean addAll(final Collection<? extends E> c) {
-            throw new UnsupportedOperationException();
-        }
-
-        public Iterator<E> iterator() {
-            return new CollectionViewIterator();
-        }
-
-        private class CollectionViewIterator implements Iterator<E> {
-
-            private Map<K, V> expected;
-            private Map.Entry<K, V> lastReturned = null;
-            private final Iterator<Map.Entry<K, V>> iterator;
-
-            public CollectionViewIterator() {
-                this.expected = map;
-                this.iterator = expected.entrySet().iterator();
-            }
-
-            public boolean hasNext() {
-                if (expected != map) {
-                    throw new ConcurrentModificationException();
-                }
-                return iterator.hasNext();
-            }
-
-            public E next() {
-                if (expected != map) {
-                    throw new ConcurrentModificationException();
-                }
-                lastReturned = iterator.next();
-                return iteratorNext(lastReturned);
-            }
-
-            public void remove() {
-                if (lastReturned == null) {
-                    throw new IllegalStateException();
-                }
-                if (fast) {
-                    synchronized (WeakFastHashMap.this) {
-                        if (expected != map) {
-                            throw new ConcurrentModificationException();
-                        }
-                        WeakFastHashMap.this.remove(lastReturned.getKey());
-                        lastReturned = null;
-                        expected = map;
-                    }
-                } else {
-                    iterator.remove();
-                    lastReturned = null;
-                }
-            }
-        }
-    }
-
-    /**
-     * Set implementation over the keys of the FastHashMap
-     */
-    private class KeySet extends CollectionView<K> implements Set<K> {
-
-        @Override
-        protected Collection<K> get(final Map<K, V> map) {
-            return map.keySet();
-        }
-
-        @Override
-        protected K iteratorNext(final Map.Entry<K, V> entry) {
-            return entry.getKey();
-        }
-
-    }
-
-    /**
-     * Collection implementation over the values of the FastHashMap
-     */
-    private class Values extends CollectionView<V> {
-
-        @Override
-        protected Collection<V> get(final Map<K, V> map) {
-            return map.values();
-        }
-
-        @Override
-        protected V iteratorNext(final Map.Entry<K, V> entry) {
-            return entry.getValue();
-        }
-    }
-
-    /**
-     * Set implementation over the entries of the FastHashMap
-     */
-    private class EntrySet extends CollectionView<Map.Entry<K, V>> implements Set<Map.Entry<K, V>> {
-
-        @Override
-        protected Collection<Map.Entry<K, V>> get(final Map<K, V> map) {
-            return map.entrySet();
-        }
-
-        @Override
-        protected Map.Entry<K, V> iteratorNext(final Map.Entry<K, V> entry) {
-            return entry;
-        }
-
-    }
-
 }
