@@ -17,7 +17,6 @@
 
 package org.apache.commons.beanutils;
 
-
 import java.beans.PropertyDescriptor;
 import java.lang.ref.Reference;
 import java.lang.ref.SoftReference;
@@ -29,9 +28,8 @@ import java.util.Map;
 import java.util.Set;
 import java.util.WeakHashMap;
 
-
 /**
- * <p>Implementation of <code>DynaClass</code> for DynaBeans that wrap
+ * <p>Implements <code>DynaClass</code> for DynaBeans that wrap
  * standard JavaBean instances.</p>
  *
  * <p>
@@ -39,125 +37,66 @@ import java.util.WeakHashMap;
  * to create new <code>WrapDynaBean</code> instances.
  * It's usually better to call the <code>WrapDynaBean</code> constructor directly.
  * For example:</p>
- * <code><pre>
+ * <pre>
  *   Object javaBean = ...;
  *   DynaBean wrapper = new WrapDynaBean(javaBean);
- * </pre></code>
- * <p>
- *
- * @version $Id: WrapDynaClass.java 1761746 2016-09-21 14:02:52Z stain $
+ * </pre>
  */
-
 public class WrapDynaClass implements DynaClass {
 
-
-    // ----------------------------------------------------------- Constructors
-
-
     /**
-     * Construct a new WrapDynaClass for the specified JavaBean class.  This
-     * constructor is private; WrapDynaClass instances will be created as
-     * needed via calls to the <code>createDynaClass(Class)</code> method.
-     *
-     * @param beanClass JavaBean class to be introspected around
-     * @param propUtils the {@code PropertyUtilsBean} associated with this class
+     * A class representing the combined key for the cache of {@code WrapDynaClass}
+     * instances. A single key consists of a bean class and an instance of
+     * {@code PropertyUtilsBean}. Instances are immutable.
      */
-    private WrapDynaClass(final Class<?> beanClass, final PropertyUtilsBean propUtils) {
+    private static class CacheKey {
+        /** The bean class. */
+        private final Class<?> beanClass;
 
-        this.beanClassRef = new SoftReference<Class<?>>(beanClass);
-        this.beanClassName = beanClass.getName();
-        propertyUtilsBean = propUtils;
-        introspect();
+        /** The instance of PropertyUtilsBean. */
+        private final PropertyUtilsBean propUtils;
 
+        /**
+         * Creates a new instance of {@code CacheKey}.
+         *
+         * @param beanCls the bean class
+         * @param pu the instance of {@code PropertyUtilsBean}
+         */
+        public CacheKey(final Class<?> beanCls, final PropertyUtilsBean pu) {
+            beanClass = beanCls;
+            propUtils = pu;
+        }
+
+        @Override
+        public boolean equals(final Object obj) {
+            if (this == obj) {
+                return true;
+            }
+            if (!(obj instanceof CacheKey)) {
+                return false;
+            }
+
+            final CacheKey c = (CacheKey) obj;
+            return beanClass.equals(c.beanClass) && propUtils.equals(c.propUtils);
+        }
+
+        @Override
+        public int hashCode() {
+            final int factor = 31;
+            int result = 17;
+            result = factor * beanClass.hashCode() + result;
+            return factor * propUtils.hashCode() + result;
+        }
     }
 
-
-    // ----------------------------------------------------- Instance Variables
-
-    /**
-     * Name of the JavaBean class represented by this WrapDynaClass.
-     */
-    private String beanClassName = null;
-
-    /**
-     * Reference to the JavaBean class represented by this WrapDynaClass.
-     */
-    private Reference<Class<?>> beanClassRef = null;
-
-    /** Stores the associated {@code PropertyUtilsBean} instance. */
-    private final PropertyUtilsBean propertyUtilsBean;
-
-    /**
-     * The JavaBean <code>Class</code> which is represented by this
-     * <code>WrapDynaClass</code>.
-     *
-     * @deprecated No longer initialized, use getBeanClass() method instead
-     */
-    @Deprecated
-    protected Class<?> beanClass = null;
-
-
-    /**
-     * The set of PropertyDescriptors for this bean class.
-     */
-    protected PropertyDescriptor[] descriptors = null;
-
-
-    /**
-     * The set of PropertyDescriptors for this bean class, keyed by the
-     * property name.  Individual descriptor instances will be the same
-     * instances as those in the <code>descriptors</code> list.
-     */
-    protected HashMap<String, PropertyDescriptor> descriptorsMap = new HashMap<String, PropertyDescriptor>();
-
-
-    /**
-     * The set of dynamic properties that are part of this DynaClass.
-     */
-    protected DynaProperty[] properties = null;
-
-
-    /**
-     * The set of dynamic properties that are part of this DynaClass,
-     * keyed by the property name.  Individual descriptor instances will
-     * be the same instances as those in the <code>properties</code> list.
-     */
-    protected HashMap<String, DynaProperty> propertiesMap = new HashMap<String, DynaProperty>();
-
-
-    // ------------------------------------------------------- Static Variables
-
-
     private static final ContextClassLoaderLocal<Map<CacheKey, WrapDynaClass>> CLASSLOADER_CACHE =
         new ContextClassLoaderLocal<Map<CacheKey, WrapDynaClass>>() {
             @Override
             protected Map<CacheKey, WrapDynaClass> initialValue() {
-                return new WeakHashMap<CacheKey, WrapDynaClass>();
+                return new WeakHashMap<>();
         }
     };
 
-    /**
-     * Get the wrap dyna classes cache. Note: This method only exists to
-     * satisfy the deprecated {@code dynaClasses} hash map.
-     */
-    @SuppressWarnings("unchecked")
-    private static Map<Object, Object> getDynaClassesMap() {
-        @SuppressWarnings("rawtypes")
-        final
-        Map cache = CLASSLOADER_CACHE.get();
-        return cache;
-    }
-
-    /**
-     * Returns the cache for the already created class instances. For each
-     * combination of bean class and {@code PropertyUtilsBean} instance an
-     * entry is created in the cache.
-     * @return the cache for already created {@code WrapDynaClass} instances
-     */
-    private static Map<CacheKey, WrapDynaClass> getClassesCache() {
-        return CLASSLOADER_CACHE.get();
-    }
-
     /**
      * The set of <code>WrapDynaClass</code> instances that have ever been
      * created, keyed by the underlying bean Class. The keys to this map
@@ -196,6 +135,7 @@ public class WrapDynaClass implements DynaClass {
      */
     @Deprecated
     protected static HashMap<Object, Object> dynaClasses = new HashMap<Object, Object>() {
+        private static final long serialVersionUID = 1L;
         @Override
         public void clear() {
             getDynaClassesMap().clear();
@@ -231,7 +171,7 @@ public class WrapDynaClass implements DynaClass {
         @Override
         public Set<Object> keySet() {
             // extract the classes from the key to stay backwards compatible
-            final Set<Object> result = new HashSet<Object>();
+            final Set<Object> result = new HashSet<>();
             for (final CacheKey k : getClassesCache().keySet()) {
                 result.add(k.beanClass);
             }
@@ -263,8 +203,130 @@ public class WrapDynaClass implements DynaClass {
         }
     };
 
+    /**
+     * Clear our cache of WrapDynaClass instances.
+     */
+    public static void clear() {
+        getClassesCache().clear();
+    }
 
-    // ------------------------------------------------------ DynaClass Methods
+    /**
+     * Create (if necessary) and return a new <code>WrapDynaClass</code>
+     * instance for the specified bean class.
+     *
+     * @param beanClass Bean class for which a WrapDynaClass is requested
+     * @return A new <em>Wrap</em> {@link DynaClass}
+     */
+    public static WrapDynaClass createDynaClass(final Class<?> beanClass) {
+        return createDynaClass(beanClass, null);
+    }
+
+    /**
+     * Create (if necessary) and return a new {@code WrapDynaClass} instance
+     * for the specified bean class using the given {@code PropertyUtilsBean}
+     * instance for introspection. Using this method a specially configured
+     * {@code PropertyUtilsBean} instance can be hooked into the introspection
+     * mechanism of the managed bean. The argument is optional; if no
+     * {@code PropertyUtilsBean} object is provided, the default instance is used.
+     * @param beanClass Bean class for which a WrapDynaClass is requested
+     * @param pu the optional {@code PropertyUtilsBean} to be used for introspection
+     * @return A new <em>Wrap</em> {@link DynaClass}
+     * @since 1.9
+     */
+    public static WrapDynaClass createDynaClass(final Class<?> beanClass, final PropertyUtilsBean pu) {
+        final PropertyUtilsBean propUtils = pu != null ? pu : PropertyUtilsBean.getInstance();
+        final CacheKey key = new CacheKey(beanClass, propUtils);
+        WrapDynaClass dynaClass = getClassesCache().get(key);
+        if (dynaClass == null) {
+            dynaClass = new WrapDynaClass(beanClass, propUtils);
+            getClassesCache().put(key, dynaClass);
+        }
+        return dynaClass;
+    }
+
+    /**
+     * Returns the cache for the already created class instances. For each
+     * combination of bean class and {@code PropertyUtilsBean} instance an
+     * entry is created in the cache.
+     * @return the cache for already created {@code WrapDynaClass} instances
+     */
+    private static Map<CacheKey, WrapDynaClass> getClassesCache() {
+        return CLASSLOADER_CACHE.get();
+    }
+
+    /**
+     * Get the wrap dyna classes cache. Note: This method only exists to
+     * satisfy the deprecated {@code dynaClasses} hash map.
+     */
+    @SuppressWarnings("unchecked")
+    private static Map<Object, Object> getDynaClassesMap() {
+        @SuppressWarnings("rawtypes")
+        final
+        Map cache = CLASSLOADER_CACHE.get();
+        return cache;
+    }
+
+    /**
+     * Name of the JavaBean class represented by this WrapDynaClass.
+     */
+    private final String beanClassName;
+
+    /**
+     * Reference to the JavaBean class represented by this WrapDynaClass.
+     */
+    private final Reference<Class<?>> beanClassRef;
+
+    /** Stores the associated {@code PropertyUtilsBean} instance. */
+    private final PropertyUtilsBean propertyUtilsBean;
+
+    /**
+     * The JavaBean <code>Class</code> which is represented by this
+     * <code>WrapDynaClass</code>.
+     *
+     * @deprecated No longer initialized, use getBeanClass() method instead
+     */
+    @Deprecated
+    protected Class<?> beanClass;
+
+    /**
+     * The set of PropertyDescriptors for this bean class.
+     */
+    protected PropertyDescriptor[] descriptors;
+
+    /**
+     * The set of PropertyDescriptors for this bean class, keyed by the
+     * property name.  Individual descriptor instances will be the same
+     * instances as those in the <code>descriptors</code> list.
+     */
+    protected HashMap<String, PropertyDescriptor> descriptorsMap = new HashMap<>();
+
+    /**
+     * The set of dynamic properties that are part of this DynaClass.
+     */
+    protected DynaProperty[] properties;
+
+    /**
+     * The set of dynamic properties that are part of this DynaClass,
+     * keyed by the property name.  Individual descriptor instances will
+     * be the same instances as those in the <code>properties</code> list.
+     */
+    protected HashMap<String, DynaProperty> propertiesMap = new HashMap<>();
+
+    /**
+     * Construct a new WrapDynaClass for the specified JavaBean class.  This
+     * constructor is private; WrapDynaClass instances will be created as
+     * needed via calls to the <code>createDynaClass(Class)</code> method.
+     *
+     * @param beanClass JavaBean class to be introspected around
+     * @param propUtils the {@code PropertyUtilsBean} associated with this class
+     */
+    private WrapDynaClass(final Class<?> beanClass, final PropertyUtilsBean propUtils) {
+        // Compiler needs generic.
+        this.beanClassRef = new SoftReference<>(beanClass);
+        this.beanClassName = beanClass.getName();
+        propertyUtilsBean = propUtils;
+        introspect();
+    }
 
     /**
      * Return the class of the underlying wrapped bean.
@@ -276,42 +338,6 @@ public class WrapDynaClass implements DynaClass {
         return beanClassRef.get();
     }
 
-    /**
-     * Return the name of this DynaClass (analogous to the
-     * <code>getName()</code> method of <code>java.lang.Class</code), which
-     * allows the same <code>DynaClass</code> implementation class to support
-     * different dynamic classes, with different sets of properties.
-     *
-     * @return the name of the DynaClass
-     */
-    public String getName() {
-
-        return beanClassName;
-
-    }
-
-
-    /**
-     * Return a property descriptor for the specified property, if it exists;
-     * otherwise, return <code>null</code>.
-     *
-     * @param name Name of the dynamic property for which a descriptor
-     *  is requested
-     * @return The descriptor for the specified property
-     *
-     * @throws IllegalArgumentException if no property name is specified
-     */
-    public DynaProperty getDynaProperty(final String name) {
-
-        if (name == null) {
-            throw new IllegalArgumentException
-                    ("No property name specified");
-        }
-        return (propertiesMap.get(name));
-
-    }
-
-
     /**
      * <p>Return an array of <code>ProperyDescriptors</code> for the properties
      * currently defined in this DynaClass.  If no properties are defined, a
@@ -323,48 +349,41 @@ public class WrapDynaClass implements DynaClass {
      *
      * @return the set of properties for this DynaClass
      */
+    @Override
     public DynaProperty[] getDynaProperties() {
-
-        return (properties);
-
+        return properties;
     }
 
-
     /**
-     * <p>Instantiates a new standard JavaBean instance associated with
-     * this DynaClass and return it wrapped in a new WrapDynaBean
-     * instance. <strong>NOTE</strong> the JavaBean should have a
-     * no argument constructor.</p>
+     * Return a property descriptor for the specified property, if it exists;
+     * otherwise, return <code>null</code>.
      *
-     * <strong>NOTE</strong> - Most common use cases should not need to use
-     * this method. It is usually better to create new
-     * <code>WrapDynaBean</code> instances by calling its constructor.
-     * For example:</p>
-     * <code><pre>
-     *   Object javaBean = ...;
-     *   DynaBean wrapper = new WrapDynaBean(javaBean);
-     * </pre></code>
-     * <p>
-     * (This method is needed for some kinds of <code>DynaBean</code> framework.)
-     * </p>
-     *
-     * @return A new <code>DynaBean</code> instance
-     * @throws IllegalAccessException if the Class or the appropriate
-     *  constructor is not accessible
-     * @throws InstantiationException if this Class represents an abstract
-     *  class, an array class, a primitive type, or void; or if instantiation
-     *  fails for some other reason
+     * @param name Name of the dynamic property for which a descriptor
+     *  is requested
+     * @return The descriptor for the specified property
+     * @throws IllegalArgumentException if no property name is specified
      */
-    public DynaBean newInstance()
-            throws IllegalAccessException, InstantiationException {
-
-        return new WrapDynaBean(getBeanClass().newInstance());
-
+    @Override
+    public DynaProperty getDynaProperty(final String name) {
+        if (name == null) {
+            throw new IllegalArgumentException
+                    ("No property name specified");
+        }
+        return propertiesMap.get(name);
     }
 
-
-    // --------------------------------------------------------- Public Methods
-
+    /**
+     * Return the name of this DynaClass (analogous to the
+     * <code>getName()</code> method of <code>java.lang.Class</code>), which
+     * allows the same <code>DynaClass</code> implementation class to support
+     * different dynamic classes, with different sets of properties.
+     *
+     * @return the name of the DynaClass
+     */
+    @Override
+    public String getName() {
+        return beanClassName;
+    }
 
     /**
      * Return the PropertyDescriptor for the specified property name, if any;
@@ -374,67 +393,9 @@ public class WrapDynaClass implements DynaClass {
      * @return The descriptor for the specified property
      */
     public PropertyDescriptor getPropertyDescriptor(final String name) {
-
-        return (descriptorsMap.get(name));
-
+        return descriptorsMap.get(name);
     }
 
-
-    // --------------------------------------------------------- Static Methods
-
-
-    /**
-     * Clear our cache of WrapDynaClass instances.
-     */
-    public static void clear() {
-
-        getClassesCache().clear();
-
-    }
-
-
-    /**
-     * Create (if necessary) and return a new <code>WrapDynaClass</code>
-     * instance for the specified bean class.
-     *
-     * @param beanClass Bean class for which a WrapDynaClass is requested
-     * @return A new <i>Wrap</i> {@link DynaClass}
-     */
-    public static WrapDynaClass createDynaClass(final Class<?> beanClass) {
-
-        return createDynaClass(beanClass, null);
-
-    }
-
-
-    /**
-     * Create (if necessary) and return a new {@code WrapDynaClass} instance
-     * for the specified bean class using the given {@code PropertyUtilsBean}
-     * instance for introspection. Using this method a specially configured
-     * {@code PropertyUtilsBean} instance can be hooked into the introspection
-     * mechanism of the managed bean. The argument is optional; if no
-     * {@code PropertyUtilsBean} object is provided, the default instance is used.
-     * @param beanClass Bean class for which a WrapDynaClass is requested
-     * @param pu the optional {@code PropertyUtilsBean} to be used for introspection
-     * @return A new <i>Wrap</i> {@link DynaClass}
-     * @since 1.9
-     */
-    public static WrapDynaClass createDynaClass(final Class<?> beanClass, final PropertyUtilsBean pu) {
-
-        final PropertyUtilsBean propUtils = (pu != null) ? pu : PropertyUtilsBean.getInstance();
-        final CacheKey key = new CacheKey(beanClass, propUtils);
-        WrapDynaClass dynaClass = getClassesCache().get(key);
-        if (dynaClass == null) {
-            dynaClass = new WrapDynaClass(beanClass, propUtils);
-            getClassesCache().put(key, dynaClass);
-        }
-        return (dynaClass);
-
-    }
-
-
-    // ------------------------------------------------------ Protected Methods
-
     /**
      * Returns the {@code PropertyUtilsBean} instance associated with this class. This
      * bean is used for introspection.
@@ -450,7 +411,6 @@ public class WrapDynaClass implements DynaClass {
      * Introspect our bean class to identify the supported properties.
      */
     protected void introspect() {
-
         // Look up the property descriptors for this bean class
         final Class<?> beanClass = getBeanClass();
         PropertyDescriptor[] regulars =
@@ -462,9 +422,8 @@ public class WrapDynaClass implements DynaClass {
         Map<?, ?> mappeds =
                 PropertyUtils.getMappedPropertyDescriptors(beanClass);
         if (mappeds == null) {
-            mappeds = new HashMap<Object, Object>();
+            mappeds = new HashMap<>();
         }
-
         // Construct corresponding DynaProperty information
         properties = new DynaProperty[regulars.length + mappeds.size()];
         for (int i = 0; i < regulars.length; i++) {
@@ -489,52 +448,38 @@ public class WrapDynaClass implements DynaClass {
                     properties[j]);
             j++;
         }
-
     }
 
     /**
-     * A class representing the combined key for the cache of {@code WrapDynaClass}
-     * instances. A single key consists of a bean class and an instance of
-     * {@code PropertyUtilsBean}. Instances are immutable.
+     * <p>Instantiates a new standard JavaBean instance associated with
+     * this DynaClass and return it wrapped in a new WrapDynaBean
+     * instance. <strong>NOTE</strong> the JavaBean should have a
+     * no argument constructor.</p>
+     * <p>
+     * <strong>NOTE</strong> - Most common use cases should not need to use
+     * this method. It is usually better to create new
+     * <code>WrapDynaBean</code> instances by calling its constructor.
+     * For example:
+     * </p>
+     * <pre>
+     *   Object javaBean = ...;
+     *   DynaBean wrapper = new WrapDynaBean(javaBean);
+     * </pre>
+     * <p>
+     * (This method is needed for some kinds of <code>DynaBean</code> framework.)
+     * </p>
+     *
+     * @return A new <code>DynaBean</code> instance
+     * @throws IllegalAccessException if the Class or the appropriate
+     *  constructor is not accessible
+     * @throws InstantiationException if this Class represents an abstract
+     *  class, an array class, a primitive type, or void; or if instantiation
+     *  fails for some other reason
      */
-    private static class CacheKey {
-        /** The bean class. */
-        private final Class<?> beanClass;
+    @Override
+    public DynaBean newInstance()
+            throws IllegalAccessException, InstantiationException {
+        return new WrapDynaBean(getBeanClass().newInstance());
 
-        /** The instance of PropertyUtilsBean. */
-        private final PropertyUtilsBean propUtils;
-
-        /**
-         * Creates a new instance of {@code CacheKey}.
-         *
-         * @param beanCls the bean class
-         * @param pu the instance of {@code PropertyUtilsBean}
-         */
-        public CacheKey(final Class<?> beanCls, final PropertyUtilsBean pu) {
-            beanClass = beanCls;
-            propUtils = pu;
-        }
-
-        @Override
-        public int hashCode() {
-            final int factor = 31;
-            int result = 17;
-            result = factor * beanClass.hashCode() + result;
-            result = factor * propUtils.hashCode() + result;
-            return result;
-        }
-
-        @Override
-        public boolean equals(final Object obj) {
-            if (this == obj) {
-                return true;
-            }
-            if (!(obj instanceof CacheKey)) {
-                return false;
-            }
-
-            final CacheKey c = (CacheKey) obj;
-            return beanClass.equals(c.beanClass) && propUtils.equals(c.propUtils);
-        }
     }
 }
