@@ -15,20 +15,18 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.converters;
 
-
 import java.io.IOException;
 import java.io.StreamTokenizer;
 import java.io.StringReader;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Objects;
+
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.Converter;
 
-
-
 /**
  * <p>Convenience base class for converters that translate the String
  * representation of an array into a corresponding array of primitives
@@ -43,7 +41,6 @@ import org.apache.commons.beanutils.Converter;
  * characters are optional, and individual elements may be separated by
  * any combination of whitespace and comma characters.</p>
  *
- * @version $Id$
  * @since 1.4
  * @deprecated Replaced by the new {@link ArrayConverter} implementation
  */
@@ -51,9 +48,29 @@ import org.apache.commons.beanutils.Converter;
 @Deprecated
 public abstract class AbstractArrayConverter implements Converter {
 
+    /**
+     * This is a special reference that can be passed as the "default object"
+     * to the constructor to indicate that no default is desired. Note that
+     * the value 'null' cannot be used for this purpose, as the caller may
+     * want a null to be returned as the default.
+     * @since 1.8.0
+     */
+    public static final Object NO_DEFAULT = new Object();
 
-    // ----------------------------------------------------------- Constructors
+    /**
+     * <p>Model object for string arrays.</p>
+     */
+    protected static String[] strings = {};
 
+    /**
+     * The default value specified to our Constructor, if any.
+     */
+    protected Object defaultValue;
+
+    /**
+     * Should we return the default value on conversion errors?
+     */
+    protected boolean useDefault = true;
 
     /**
      * Create a {@link Converter} that will throw a {@link ConversionException}
@@ -84,41 +101,6 @@ public abstract class AbstractArrayConverter implements Converter {
 
     }
 
-    // ------------------------------------------------------- Static Variables
-
-    /**
-     * This is a special reference that can be passed as the "default object"
-     * to the constructor to indicate that no default is desired. Note that
-     * the value 'null' cannot be used for this purpose, as the caller may
-     * want a null to be returned as the default.
-     * @since 1.8.0
-     */
-    public static final Object NO_DEFAULT = new Object();
-
-    // ----------------------------------------------------- Instance Variables
-
-
-    /**
-     * <p>Model object for string arrays.</p>
-     */
-    protected static String[] strings = new String[0];
-
-
-    /**
-     * The default value specified to our Constructor, if any.
-     */
-    protected Object defaultValue = null;
-
-
-    /**
-     * Should we return the default value on conversion errors?
-     */
-    protected boolean useDefault = true;
-
-
-    // --------------------------------------------------------- Public Methods
-
-
     /**
      * Convert the specified input object into an output object of the
      * specified type.  This method must be implemented by a concrete
@@ -127,16 +109,12 @@ public abstract class AbstractArrayConverter implements Converter {
      * @param type Data type to which this value should be converted
      * @param value The input value to be converted
      * @return The converted value
-     *
      * @throws ConversionException if conversion cannot be performed
      *  successfully
      */
+    @Override
     public abstract Object convert(Class type, Object value);
 
-
-    // ------------------------------------------------------ Protected Methods
-
-
     /**
      * <p>Parse an incoming String of the form similar to an array initializer
      * in the Java language into a <code>List</code> individual Strings
@@ -152,65 +130,47 @@ public abstract class AbstractArrayConverter implements Converter {
      *
      * @param svalue String value to be parsed
      * @return The parsed list of String values
-     *
      * @throws ConversionException if the syntax of <code>svalue</code>
      *  is not syntactically valid
      * @throws NullPointerException if <code>svalue</code>
      *  is <code>null</code>
      */
-    protected List parseElements(String svalue) {
-
+    protected List<String> parseElements(String svalue) {
         // Validate the passed argument
-        if (svalue == null) {
-            throw new NullPointerException();
-        }
-
+        Objects.requireNonNull(svalue, "svalue");
         // Trim any matching '{' and '}' delimiters
         svalue = svalue.trim();
         if (svalue.startsWith("{") && svalue.endsWith("}")) {
             svalue = svalue.substring(1, svalue.length() - 1);
         }
-
         try {
 
             // Set up a StreamTokenizer on the characters in this String
-            final StreamTokenizer st =
-                new StreamTokenizer(new StringReader(svalue));
-            st.whitespaceChars(',',','); // Commas are delimiters
-            st.ordinaryChars('0', '9');  // Needed to turn off numeric flag
+            final StreamTokenizer st = new StreamTokenizer(new StringReader(svalue));
+            st.whitespaceChars(',', ','); // Commas are delimiters
+            st.ordinaryChars('0', '9'); // Needed to turn off numeric flag
             st.ordinaryChars('.', '.');
             st.ordinaryChars('-', '-');
-            st.wordChars('0', '9');      // Needed to make part of tokens
+            st.wordChars('0', '9'); // Needed to make part of tokens
             st.wordChars('.', '.');
             st.wordChars('-', '-');
-
             // Split comma-delimited tokens into a List
-            final ArrayList list = new ArrayList();
+            final ArrayList<String> list = new ArrayList<>();
             while (true) {
                 final int ttype = st.nextToken();
-                if ((ttype == StreamTokenizer.TT_WORD) ||
-                    (ttype > 0)) {
+                if (ttype == StreamTokenizer.TT_WORD || ttype > 0) {
                     list.add(st.sval);
                 } else if (ttype == StreamTokenizer.TT_EOF) {
                     break;
                 } else {
-                    throw new ConversionException
-                        ("Encountered token of type " + ttype);
+                    throw new ConversionException("Encountered token of type " + ttype);
                 }
             }
-
             // Return the completed list
-            return (list);
-
+            return list;
         } catch (final IOException e) {
-
             throw new ConversionException(e);
-
         }
-
-
-
     }
 
-
 }
