@@ -19,7 +19,6 @@ package org.apache.commons.beanutils.converters;
 import java.lang.reflect.Array;
 import java.util.Collection;
 
-import org.apache.commons.beanutils.BeanUtils;
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.ConvertUtils;
 import org.apache.commons.beanutils.Converter;
@@ -28,7 +27,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * Base {@link Converter} implementation that provides the structure
- * for handling conversion <b>to</b> and <b>from</b> a specified type.
+ * for handling conversion <strong>to</strong> and <strong>from</strong> a specified type.
  * <p>
  * This implementation provides the basic structure for
  * converting to/from a specified type optionally using a default
@@ -52,7 +51,6 @@ import org.apache.commons.logging.LogFactory;
  * tries to transform the default value to the requested target type.
  * If this fails, a {@code ConversionException} if thrown.
  *
- * @version $Id$
  * @since 1.8.0
  */
 public abstract class AbstractConverter implements Converter {
@@ -74,24 +72,22 @@ public abstract class AbstractConverter implements Converter {
     /**
      * Should we return the default value on conversion errors?
      */
-    private boolean useDefault = false;
+    private boolean useDefault;
 
     /**
      * The default value specified to our Constructor, if any.
      */
-    private Object defaultValue = null;
-
-    // ----------------------------------------------------------- Constructors
+    private Object defaultValue;
 
     /**
-     * Construct a <i>Converter</i> that throws a
+     * Construct a <em>Converter</em> that throws a
      * <code>ConversionException</code> if an error occurs.
      */
     public AbstractConverter() {
     }
 
     /**
-     * Construct a <i>Converter</i> that returns a default
+     * Construct a <em>Converter</em> that returns a default
      * value if an error occurs.
      *
      * @param defaultValue The default value to be returned
@@ -102,18 +98,18 @@ public abstract class AbstractConverter implements Converter {
         setDefaultValue(defaultValue);
     }
 
-    // --------------------------------------------------------- Public Methods
-
     /**
-     * Indicates whether a default value will be returned or exception
-     * thrown in the event of a conversion error.
+     * Generates a standard conversion exception with a message indicating that
+     * the passed in value cannot be converted to the desired target type.
      *
-     * @return <code>true</code> if a default value will be returned for
-     * conversion errors or <code>false</code> if a {@link ConversionException}
-     * will be thrown.
+     * @param type the target type
+     * @param value the value to be converted
+     * @return a {@code ConversionException} with a standard message
+     * @since 1.9
      */
-    public boolean isUseDefault() {
-        return useDefault;
+    protected ConversionException conversionException(final Class<?> type, final Object value) {
+        return new ConversionException("Can't convert value '" + value
+                + "' to type " + type);
     }
 
     /**
@@ -127,6 +123,7 @@ public abstract class AbstractConverter implements Converter {
      * @throws ConversionException if conversion cannot be performed
      * successfully and no default is specified.
      */
+    @Override
     public <T> T convert(final Class<T> type, Object value) {
 
         if (type == null) {
@@ -157,7 +154,8 @@ public abstract class AbstractConverter implements Converter {
                 return targetType.cast(convertToString(value));
 
             // No conversion necessary
-            } else if (targetType.equals(sourceType)) {
+            }
+            if (targetType.equals(sourceType)) {
                 if (log().isDebugEnabled()) {
                     log().debug("    No conversion required, value is already a "
                                     + toString(targetType));
@@ -165,51 +163,19 @@ public abstract class AbstractConverter implements Converter {
                 return targetType.cast(value);
 
             // Convert --> Type
-            } else {
-                final Object result = convertToType(targetType, value);
-                if (log().isDebugEnabled()) {
-                    log().debug("    Converted to " + toString(targetType) +
-                                   " value '" + result + "'");
-                }
-                return targetType.cast(result);
             }
+            final Object result = convertToType(targetType, value);
+            if (log().isDebugEnabled()) {
+                log().debug("    Converted to " + toString(targetType) +
+                               " value '" + result + "'");
+            }
+            return targetType.cast(result);
         } catch (final Throwable t) {
             return handleError(targetType, value, t);
         }
 
     }
 
-    /**
-     * Convert the input object into a String.
-     * <p>
-     * <b>N.B.</b>This implementation simply uses the value's
-     * <code>toString()</code> method and should be overriden if a
-     * more sophisticated mechanism for <i>conversion to a String</i>
-     * is required.
-     *
-     * @param value The input value to be converted.
-     * @return the converted String value.
-     * @throws Throwable if an error occurs converting to a String
-     */
-    protected String convertToString(final Object value) throws Throwable {
-        return value.toString();
-    }
-
-    /**
-     * Convert the input object into an output object of the
-     * specified type.
-     * <p>
-     * Typical implementations will provide a minimum of
-     * <code>String --> type</code> conversion.
-     *
-     * @param <T> Target type of the conversion.
-     * @param type Data type to which this value should be converted.
-     * @param value The input value to be converted.
-     * @return The converted value.
-     * @throws Throwable if an error occurs converting to the specified type
-     */
-    protected abstract <T> T convertToType(Class<T> type, Object value) throws Throwable;
-
     /**
      * Return the first element from an Array (or Collection)
      * or the value unchanged if not an Array (or Collection).
@@ -227,21 +193,85 @@ public abstract class AbstractConverter implements Converter {
         if (value.getClass().isArray()) {
             if (Array.getLength(value) > 0) {
                 return Array.get(value, 0);
-            } else {
-                return null;
             }
+            return null;
         }
         if (value instanceof Collection) {
             final Collection<?> collection = (Collection<?>)value;
             if (collection.size() > 0) {
                 return collection.iterator().next();
-            } else {
-                return null;
             }
+            return null;
         }
         return value;
     }
 
+    /**
+     * Performs a conversion to the default type. This method is called if we do
+     * not have a target class. In this case, the T parameter is not set.
+     * Therefore, we can cast to it (which is required to fulfill the contract
+     * of the method signature).
+     *
+     * @param <T> the type of the result object
+     * @param targetClass the target class of the conversion
+     * @param value the value to be converted
+     * @return the converted value
+     */
+    private <T> T convertToDefaultType(final Class<T> targetClass, final Object value) {
+        return (T) convert(getDefaultType(), value);
+    }
+
+    /**
+     * Convert the input object into a String.
+     * <p>
+     * <strong>N.B.</strong>This implementation simply uses the value's
+     * <code>toString()</code> method and should be overriden if a
+     * more sophisticated mechanism for <em>conversion to a String</em>
+     * is required.
+     *
+     * @param value The input value to be converted.
+     * @return the converted String value.
+     * @throws Throwable if an error occurs converting to a String
+     */
+    protected String convertToString(final Object value) throws Throwable {
+        return value.toString();
+    }
+
+    /**
+     * Convert the input object into an output object of the
+     * specified type.
+     * <p>
+     * Typical implementations will provide a minimum of
+     * <code>String to type</code> conversion.
+     *
+     * @param <T> Target type of the conversion.
+     * @param type Data type to which this value should be converted.
+     * @param value The input value to be converted.
+     * @return The converted value.
+     * @throws Throwable if an error occurs converting to the specified type
+     */
+    protected abstract <T> T convertToType(Class<T> type, Object value) throws Throwable;
+
+    /**
+     * Return the default value for conversions to the specified
+     * type.
+     * @param type Data type to which this value should be converted.
+     * @return The default value for the specified type.
+     */
+    protected Object getDefault(final Class<?> type) {
+        if (type.equals(String.class)) {
+            return null;
+        }
+        return defaultValue;
+    }
+
+    /**
+     * Return the default type this <code>Converter</code> handles.
+     *
+     * @return The default type this <code>Converter</code> handles.
+     */
+    protected abstract Class<?> getDefaultType();
+
     /**
      * Handle Conversion Errors.
      * <p>
@@ -284,7 +314,6 @@ public abstract class AbstractConverter implements Converter {
                 log().debug("    Throwing ConversionException: " + msg);
                 log().debug("    " + DEFAULT_CONFIG_MSG);
             }
-            BeanUtils.initCause(cex, cause);
         }
 
         throw cex;
@@ -307,7 +336,7 @@ public abstract class AbstractConverter implements Converter {
 
         if (useDefault || type.equals(String.class)) {
             Object value = getDefault(type);
-            if (useDefault && value != null && !(type.equals(value.getClass()))) {
+            if (useDefault && value != null && !type.equals(value.getClass())) {
                 try {
                     value = convertToType(type, defaultValue);
                 } catch (final Throwable t) {
@@ -334,6 +363,35 @@ public abstract class AbstractConverter implements Converter {
 
     }
 
+    /**
+     * Indicates whether a default value will be returned or exception
+     * thrown in the event of a conversion error.
+     *
+     * @return <code>true</code> if a default value will be returned for
+     * conversion errors or <code>false</code> if a {@link ConversionException}
+     * will be thrown.
+     */
+    public boolean isUseDefault() {
+        return useDefault;
+    }
+
+    /**
+     * Accessor method for Log instance.
+     * <p>
+     * The Log instance variable is transient and
+     * accessing it through this method ensures it
+     * is re-initialized when this instance is
+     * de-serialized.
+     *
+     * @return The Log instance.
+     */
+    Log log() {
+        if (log == null) {
+            log = LogFactory.getLog(getClass());
+        }
+        return log;
+    }
+
     /**
      * Set the default value, converting as required.
      * <p>
@@ -360,27 +418,6 @@ public abstract class AbstractConverter implements Converter {
         useDefault = true;
     }
 
-    /**
-     * Return the default type this <code>Converter</code> handles.
-     *
-     * @return The default type this <code>Converter</code> handles.
-     */
-    protected abstract Class<?> getDefaultType();
-
-    /**
-     * Return the default value for conversions to the specified
-     * type.
-     * @param type Data type to which this value should be converted.
-     * @return The default value for the specified type.
-     */
-    protected Object getDefault(final Class<?> type) {
-        if (type.equals(String.class)) {
-            return null;
-        } else  {
-            return defaultValue;
-        }
-    }
-
     /**
      * Provide a String representation of this converter.
      *
@@ -391,25 +428,6 @@ public abstract class AbstractConverter implements Converter {
         return toString(getClass()) + "[UseDefault=" + useDefault + "]";
     }
 
-    // ----------------------------------------------------------- Package Methods
-
-    /**
-     * Accessor method for Log instance.
-     * <p>
-     * The Log instance variable is transient and
-     * accessing it through this method ensures it
-     * is re-initialized when this instance is
-     * de-serialized.
-     *
-     * @return The Log instance.
-     */
-    Log log() {
-        if (log == null) {
-            log = LogFactory.getLog(getClass());
-        }
-        return log;
-    }
-
     /**
      * Provide a String representation of a <code>java.lang.Class</code>.
      * @param type The <code>java.lang.Class</code>.
@@ -442,36 +460,4 @@ public abstract class AbstractConverter implements Converter {
         }
         return typeName;
     }
-
-    /**
-     * Performs a conversion to the default type. This method is called if we do
-     * not have a target class. In this case, the T parameter is not set.
-     * Therefore, we can cast to it (which is required to fulfill the contract
-     * of the method signature).
-     *
-     * @param <T> the type of the result object
-     * @param targetClass the target class of the conversion
-     * @param value the value to be converted
-     * @return the converted value
-     */
-    private <T> T convertToDefaultType(final Class<T> targetClass, final Object value) {
-        @SuppressWarnings("unchecked")
-        final
-        T result = (T) convert(getDefaultType(), value);
-        return result;
-    }
-
-    /**
-     * Generates a standard conversion exception with a message indicating that
-     * the passed in value cannot be converted to the desired target type.
-     *
-     * @param type the target type
-     * @param value the value to be converted
-     * @return a {@code ConversionException} with a standard message
-     * @since 1.9
-     */
-    protected ConversionException conversionException(final Class<?> type, final Object value) {
-        return new ConversionException("Can't convert value '" + value
-                + "' to type " + type);
-    }
 }
