@@ -23,6 +23,7 @@ import java.lang.reflect.Array;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 
@@ -31,55 +32,59 @@ import org.apache.commons.beanutils.Converter;
 
 /**
  * Generic {@link Converter} implementation that handles conversion
- * to and from <b>array</b> objects.
+ * to and from <strong>array</strong> objects.
  * <p>
- * Can be configured to either return a <i>default value</i> or throw a
+ * Can be configured to either return a <em>default value</em> or throw a
  * <code>ConversionException</code> if a conversion error occurs.
+ * </p>
  * <p>
  * The main features of this implementation are:
+ * </p>
  * <ul>
- *     <li><b>Element Conversion</b> - delegates to a {@link Converter},
+ *     <li><strong>Element Conversion</strong> - delegates to a {@link Converter},
  *         appropriate for the type, to convert individual elements
  *         of the array. This leverages the power of existing converters
  *         without having to replicate their functionality for converting
  *         to the element type and removes the need to create a specifc
  *         array type converters.</li>
- *     <li><b>Arrays or Collections</b> - can convert from either arrays or
+ *     <li><strong>Arrays or Collections</strong> - can convert from either arrays or
  *         Collections to an array, limited only by the capability
  *         of the delegate {@link Converter}.</li>
- *     <li><b>Delimited Lists</b> - can Convert <b>to</b> and <b>from</b> a
+ *     <li><strong>Delimited Lists</strong> - can Convert <strong>to</strong> and <strong>from</strong> a
  *         delimited list in String format.</li>
- *     <li><b>Conversion to String</b> - converts an array to a
- *         <code>String</code> in one of two ways: as a <i>delimited list</i>
+ *     <li><strong>Conversion to String</strong> - converts an array to a
+ *         <code>String</code> in one of two ways: as a <em>delimited list</em>
  *         or by converting the first element in the array to a String - this
  *         is controlled by the {@link ArrayConverter#setOnlyFirstToString(boolean)}
  *         parameter.</li>
- *     <li><b>Multi Dimensional Arrays</b> - it is possible to convert a <code>String</code>
+ *     <li><strong>Multi Dimensional Arrays</strong> - it is possible to convert a <code>String</code>
  *         to a multi-dimensional arrays, by embedding {@link ArrayConverter}
  *         within each other - see example below.</li>
- *     <li><b>Default Value</b></li>
+ *     <li><strong>Default Value</strong>
  *         <ul>
- *             <li><b><i>No Default</b></i> - use the
+ *             <li><strong><em>No Default</em></strong> - use the
  *                 {@link ArrayConverter#ArrayConverter(Class, Converter)}
  *                 constructor to create a converter which throws a
  *                 {@link ConversionException} if the value is missing or
  *                 invalid.</li>
- *             <li><b><i>Default values</b></i> - use the
+ *             <li><strong><em>Default values</em></strong> - use the
  *                 {@link ArrayConverter#ArrayConverter(Class, Converter, int)}
  *                 constructor to create a converter which returns a <i>default
- *                 value</i>. The <i>defaultSize</i> parameter controls the
- *                 <i>default value</i> in the following way:</li>
+ *                 value</i>. The <em>defaultSize</em> parameter controls the
+ *                 <em>default value</em> in the following way:
  *                 <ul>
- *                    <li><i>defaultSize &lt; 0</i> - default is <code>null</code></li>
- *                    <li><i>defaultSize = 0</i> - default is an array of length zero</li>
- *                    <li><i>defaultSize &gt; 0</i> - default is an array with a
+ *                    <li><em>defaultSize &lt; 0</em> - default is <code>null</code></li>
+ *                    <li><em>defaultSize = 0</em> - default is an array of length zero</li>
+ *                    <li><em>defaultSize &gt; 0</em> - default is an array with a
  *                        length specified by <code>defaultSize</code> (N.B. elements
  *                        in the array will be <code>null</code>)</li>
  *                 </ul>
+ *             </li>
  *         </ul>
+ *     </li>
  * </ul>
  *
- * <h3>Parsing Delimited Lists</h3>
+ * <h2>Parsing Delimited Lists</h2>
  * This implementation can convert a delimited list in <code>String</code> format
  * into an array of the appropriate type. By default, it uses a comma as the delimiter
  * but the following methods can be used to configure parsing:
@@ -91,14 +96,14 @@ import org.apache.commons.beanutils.Converter;
  *         valid token characters.
  * </ul>
  *
- * <h3>Multi Dimensional Arrays</h3>
+ * <h2>Multi Dimensional Arrays</h2>
  * It is possible to convert a <code>String</code> to mulit-dimensional arrays by using
  * {@link ArrayConverter} as the element {@link Converter}
  * within another {@link ArrayConverter}.
  * <p>
  * For example, the following code demonstrates how to construct a {@link Converter}
  * to convert a delimited <code>String</code> into a two dimensional integer array:
- * <p>
+ * </p>
  * <pre>
  *    // Construct an Integer Converter
  *    IntegerConverter integerConverter = new IntegerConverter();
@@ -122,7 +127,6 @@ import org.apache.commons.beanutils.Converter;
  *    int[][] result = (int[][])matrixConverter.convert(int[][].class, matrixString);
  * </pre>
  *
- * @version $Id: ArrayConverter.java 1746219 2016-05-31 05:05:09Z ggregory $
  * @since 1.8.0
  */
 public class ArrayConverter extends AbstractConverter {
@@ -131,14 +135,12 @@ public class ArrayConverter extends AbstractConverter {
     private final Converter elementConverter;
     private int defaultSize;
     private char delimiter    = ',';
-    private char[] allowedChars = new char[] {'.', '-'};
+    private char[] allowedChars = {'.', '-'};
     private boolean onlyFirstToString = true;
 
-    // ----------------------------------------------------------- Constructors
-
     /**
-     * Construct an <b>array</b> <code>Converter</code> with the specified
-     * <b>component</b> <code>Converter</code> that throws a
+     * Construct an <strong>array</strong> <code>Converter</code> with the specified
+     * <strong>component</strong> <code>Converter</code> that throws a
      * <code>ConversionException</code> if an error occurs.
      *
      * @param defaultType The default array type this
@@ -147,7 +149,6 @@ public class ArrayConverter extends AbstractConverter {
      *  individual array elements.
      */
     public ArrayConverter(final Class<?> defaultType, final Converter elementConverter) {
-        super();
         if (defaultType == null) {
             throw new IllegalArgumentException("Default type is missing");
         }
@@ -162,8 +163,8 @@ public class ArrayConverter extends AbstractConverter {
     }
 
     /**
-     * Construct an <b>array</b> <code>Converter</code> with the specified
-     * <b>component</b> <code>Converter</code> that returns a default
+     * Construct an <strong>array</strong> <code>Converter</code> with the specified
+     * <strong>component</strong> <code>Converter</code> that returns a default
      * array of the specified size (or <code>null</code>) if an error occurs.
      *
      * @param defaultType The default array type this
@@ -184,45 +185,50 @@ public class ArrayConverter extends AbstractConverter {
     }
 
     /**
-     * Set the delimiter to be used for parsing a delimited String.
+     * Returns the value unchanged.
      *
-     * @param delimiter The delimiter [default ',']
-     */
-    public void setDelimiter(final char delimiter) {
-        this.delimiter = delimiter;
-    }
-
-    /**
-     * Set the allowed characters to be used for parsing a delimited String.
-     *
-     * @param allowedChars Characters which are to be considered as part of
-     * the tokens when parsing a delimited String [default is '.' and '-']
-     */
-    public void setAllowedChars(final char[] allowedChars) {
-        this.allowedChars = allowedChars;
-    }
-
-    /**
-     * Indicates whether converting to a String should create
-     * a delimited list or just convert the first value.
-     *
-     * @param onlyFirstToString <code>true</code> converts only
-     * the first value in the array to a String, <code>false</code>
-     * converts all values in the array into a delimited list (default
-     * is <code>true</code>
-     */
-    public void setOnlyFirstToString(final boolean onlyFirstToString) {
-        this.onlyFirstToString = onlyFirstToString;
-    }
-
-    /**
-     * Return the default type this <code>Converter</code> handles.
-     *
-     * @return The default type this <code>Converter</code> handles.
+     * @param value The value to convert
+     * @return The value unchanged
      */
     @Override
-    protected Class<?> getDefaultType() {
-        return defaultType;
+    protected Object convertArray(final Object value) {
+        return value;
+    }
+
+    /**
+     * Converts non-array values to a Collection prior
+     * to being converted either to an array or a String.
+     * <ul>
+     *   <li>{@link Collection} values are returned unchanged</li>
+     *   <li>{@link Number}, {@link Boolean}  and {@link java.util.Date}
+     *       values returned as a the only element in a List.</li>
+     *   <li>All other types are converted to a String and parsed
+     *       as a delimited list.</li>
+     * </ul>
+     * <p>
+     * <strong>N.B.</strong> The method is called by both the
+     * {@link ArrayConverter#convertToType(Class, Object)} and
+     * {@link ArrayConverter#convertToString(Object)} methods for
+     * <em>non-array</em> types.
+     * </p>
+     *
+     * @param type The type to convert the value to
+     * @param value value to be converted
+     * @return Collection elements.
+     */
+    protected Collection<?> convertToCollection(final Class<?> type, final Object value) {
+        if (value instanceof Collection) {
+            return (Collection<?>)value;
+        }
+        if (value instanceof Number ||
+            value instanceof Boolean ||
+            value instanceof Date) {
+            final List<Object> list = new ArrayList<>(1);
+            list.add(value);
+            return list;
+        }
+
+        return parseElements(type, value.toString());
     }
 
     /**
@@ -321,53 +327,6 @@ public class ArrayConverter extends AbstractConverter {
         return result;
     }
 
-    /**
-     * Returns the value unchanged.
-     *
-     * @param value The value to convert
-     * @return The value unchanged
-     */
-    @Override
-    protected Object convertArray(final Object value) {
-        return value;
-    }
-
-    /**
-     * Converts non-array values to a Collection prior
-     * to being converted either to an array or a String.
-     * </p>
-     * <ul>
-     *   <li>{@link Collection} values are returned unchanged</li>
-     *   <li>{@link Number}, {@link Boolean}  and {@link java.util.Date}
-     *       values returned as a the only element in a List.</li>
-     *   <li>All other types are converted to a String and parsed
-     *       as a delimited list.</li>
-     * </ul>
-     *
-     * <strong>N.B.</strong> The method is called by both the
-     * {@link ArrayConverter#convertToType(Class, Object)} and
-     * {@link ArrayConverter#convertToString(Object)} methods for
-     * <i>non-array</i> types.
-     *
-     * @param type The type to convert the value to
-     * @param value value to be converted
-     * @return Collection elements.
-     */
-    protected Collection<?> convertToCollection(final Class<?> type, final Object value) {
-        if (value instanceof Collection) {
-            return (Collection<?>)value;
-        }
-        if (value instanceof Number ||
-            value instanceof Boolean ||
-            value instanceof java.util.Date) {
-            final List<Object> list = new ArrayList<Object>(1);
-            list.add(value);
-            return list;
-        }
-
-        return parseElements(type, value.toString());
-    }
-
     /**
      * Return the default value for conversions to the specified
      * type.
@@ -387,27 +346,19 @@ public class ArrayConverter extends AbstractConverter {
 
         if (defaultValue.getClass().equals(type)) {
             return defaultValue;
-        } else {
-            return Array.newInstance(type.getComponentType(), defaultSize);
         }
+        return Array.newInstance(type.getComponentType(), defaultSize);
 
     }
 
     /**
-     * Provide a String representation of this array converter.
+     * Return the default type this <code>Converter</code> handles.
      *
-     * @return A String representation of this array converter
+     * @return The default type this <code>Converter</code> handles.
      */
     @Override
-    public String toString() {
-        final StringBuilder buffer = new StringBuilder();
-        buffer.append(toString(getClass()));
-        buffer.append("[UseDefault=");
-        buffer.append(isUseDefault());
-        buffer.append(", ");
-        buffer.append(elementConverter.toString());
-        buffer.append(']');
-        return buffer.toString();
+    protected Class<?> getDefaultType() {
+        return defaultType;
     }
 
     /**
@@ -426,7 +377,6 @@ public class ArrayConverter extends AbstractConverter {
      * @param type The type to convert the value to
      * @param value String value to be parsed
      * @return List of parsed elements.
-     *
      * @throws ConversionException if the syntax of <code>svalue</code>
      *  is not syntactically valid
      * @throws NullPointerException if <code>svalue</code>
@@ -451,7 +401,7 @@ public class ArrayConverter extends AbstractConverter {
             st.whitespaceChars(delimiter , delimiter); // Set the delimiters
             st.ordinaryChars('0', '9');  // Needed to turn off numeric flag
             st.wordChars('0', '9');      // Needed to make part of tokens
-            for (char allowedChar : allowedChars) {
+            for (final char allowedChar : allowedChars) {
                 st.ordinaryChars(allowedChar, allowedChar);
                 st.wordChars(allowedChar, allowedChar);
             }
@@ -460,10 +410,10 @@ public class ArrayConverter extends AbstractConverter {
             List<String> list = null;
             while (true) {
                 final int ttype = st.nextToken();
-                if ((ttype == StreamTokenizer.TT_WORD) || (ttype > 0)) {
+                if (ttype == StreamTokenizer.TT_WORD || ttype > 0) {
                     if (st.sval != null) {
                         if (list == null) {
-                            list = new ArrayList<String>();
+                            list = new ArrayList<>();
                         }
                         list.add(st.sval);
                     }
@@ -483,7 +433,7 @@ public class ArrayConverter extends AbstractConverter {
             }
 
             // Return the completed list
-            return (list);
+            return list;
 
         } catch (final IOException e) {
 
@@ -494,4 +444,53 @@ public class ArrayConverter extends AbstractConverter {
 
     }
 
+    /**
+     * Set the allowed characters to be used for parsing a delimited String.
+     *
+     * @param allowedChars Characters which are to be considered as part of
+     * the tokens when parsing a delimited String [default is '.' and '-']
+     */
+    public void setAllowedChars(final char[] allowedChars) {
+        this.allowedChars = allowedChars;
+    }
+
+    /**
+     * Set the delimiter to be used for parsing a delimited String.
+     *
+     * @param delimiter The delimiter [default ',']
+     */
+    public void setDelimiter(final char delimiter) {
+        this.delimiter = delimiter;
+    }
+
+    /**
+     * Indicates whether converting to a String should create
+     * a delimited list or just convert the first value.
+     *
+     * @param onlyFirstToString <code>true</code> converts only
+     * the first value in the array to a String, <code>false</code>
+     * converts all values in the array into a delimited list (default
+     * is <code>true</code>
+     */
+    public void setOnlyFirstToString(final boolean onlyFirstToString) {
+        this.onlyFirstToString = onlyFirstToString;
+    }
+
+    /**
+     * Provide a String representation of this array converter.
+     *
+     * @return A String representation of this array converter
+     */
+    @Override
+    public String toString() {
+        final StringBuilder buffer = new StringBuilder();
+        buffer.append(toString(getClass()));
+        buffer.append("[UseDefault=");
+        buffer.append(isUseDefault());
+        buffer.append(", ");
+        buffer.append(elementConverter.toString());
+        buffer.append(']');
+        return buffer.toString();
+    }
+
 }
