@@ -15,13 +15,11 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.converters;
 
-
 import java.util.List;
-import org.apache.commons.beanutils.ConversionException;
 
+import org.apache.commons.beanutils.ConversionException;
 
 /**
  * <p>Standard {@link org.apache.commons.beanutils.Converter} implementation that converts an incoming
@@ -30,11 +28,10 @@ import org.apache.commons.beanutils.ConversionException;
  * on how this instance is constructed.</p>
  *
  * <p>By default, the values to be converted are expected to be those
- * recognized by a default instance of BooleanConverter. A customised
+ * recognized by a default instance of BooleanConverter. A customized
  * BooleanConverter can be provided in order to recognise alternative values
  * as true/false. </p>
  *
- * @version $Id$
  * @since 1.4
  * @deprecated Replaced by the new {@link ArrayConverter} implementation
  */
@@ -42,9 +39,26 @@ import org.apache.commons.beanutils.ConversionException;
 @Deprecated
 public final class BooleanArrayConverter extends AbstractArrayConverter {
 
+    /**
+     * Type which this class converts its input to. This value can be
+     * used as a parameter to the ConvertUtils.register method.
+     * @since 1.8.0
+     */
+    public static final Class MODEL = new boolean[0].getClass();
 
-    // ----------------------------------------------------------- Constructors
+    /**
+     * The converter that all instances of this class will use to
+     * do individual string to boolean conversions, unless overridden
+     * in the constructor.
+     */
+    private static final BooleanConverter DEFAULT_CONVERTER
+        = new BooleanConverter();
 
+    /**
+     * This object is used to perform the conversion of individual strings
+     * into Boolean/boolean values.
+     */
+    protected final BooleanConverter booleanConverter;
 
     /**
      * Create a {@link org.apache.commons.beanutils.Converter} that will throw
@@ -55,29 +69,10 @@ public final class BooleanArrayConverter extends AbstractArrayConverter {
      */
     public BooleanArrayConverter() {
 
-        super();
         this.booleanConverter = DEFAULT_CONVERTER;
 
     }
 
-
-    /**
-     * Create a {@link org.apache.commons.beanutils.Converter} that will return
-     * the specified default value if a conversion error occurs.
-     *
-     * <p>Conversion of strings to boolean values will be done via a default
-     * instance of class BooleanConverter.</p>
-     *
-     * @param defaultValue The default value to be returned
-     */
-    public BooleanArrayConverter(final Object defaultValue) {
-
-        super(defaultValue);
-        this.booleanConverter = DEFAULT_CONVERTER;
-
-    }
-
-
     /**
      * Create a {@link org.apache.commons.beanutils.Converter} that will return
      * the specified default value if a conversion error occurs.
@@ -102,33 +97,21 @@ public final class BooleanArrayConverter extends AbstractArrayConverter {
 
     }
 
-    // ------------------------------------------------------- Static Variables
-
     /**
-     * Type which this class converts its input to. This value can be
-     * used as a parameter to the ConvertUtils.register method.
-     * @since 1.8.0
+     * Create a {@link org.apache.commons.beanutils.Converter} that will return
+     * the specified default value if a conversion error occurs.
+     *
+     * <p>Conversion of strings to boolean values will be done via a default
+     * instance of class BooleanConverter.</p>
+     *
+     * @param defaultValue The default value to be returned
      */
-    public static final Class MODEL = new boolean[0].getClass();
+    public BooleanArrayConverter(final Object defaultValue) {
 
-    /**
-     * The converter that all instances of this class will use to
-     * do individual string->boolean conversions, unless overridden
-     * in the constructor.
-     */
-    private static final BooleanConverter DEFAULT_CONVERTER
-        = new BooleanConverter();
-
-    // ---------------------------------------------------- Instance Variables
-
-    /**
-     * This object is used to perform the conversion of individual strings
-     * into Boolean/boolean values.
-     */
-    protected final BooleanConverter booleanConverter;
-
-    // --------------------------------------------------------- Public Methods
+        super(defaultValue);
+        this.booleanConverter = DEFAULT_CONVERTER;
 
+    }
 
     /**
      * Convert the specified input object into an output object of type
@@ -158,16 +141,15 @@ public final class BooleanArrayConverter extends AbstractArrayConverter {
      * BooleanConverter associated with this object, then what happens depends
      * on whether that BooleanConverter has a default value or not: if it does,
      * then that unrecognized element is converted into the BooleanConverter's
-     * default value. If the BooleanConverter does <i>not</i> have a default
+     * default value. If the BooleanConverter does <em>not</em> have a default
      * value, then the default value for this object is returned as the
-     * <i>complete</i> conversion result (not just for the element), or an
+     * <em>complete</em> conversion result (not just for the element), or an
      * exception is thrown if this object has no default value defined.</p>
      *
      * @param type is the type to which this value should be converted. In the
      *  case of this BooleanArrayConverter class, this value is ignored.
      *
      * @param value is the input value to be converted.
-     *
      * @return an object of type boolean[], or the default value if there was
      *  any sort of error during conversion and the constructor
      *  was provided with a default value.
@@ -185,15 +167,14 @@ public final class BooleanArrayConverter extends AbstractArrayConverter {
         // Deal with a null value
         if (value == null) {
             if (useDefault) {
-                return (defaultValue);
-            } else {
-                throw new ConversionException("No value specified");
+                return defaultValue;
             }
+            throw new ConversionException("No value specified");
         }
 
         // Deal with the no-conversion-needed case
         if (MODEL == value.getClass()) {
-            return (value);
+            return value;
         }
 
         // Deal with input value as a String array
@@ -209,13 +190,12 @@ public final class BooleanArrayConverter extends AbstractArrayConverter {
                     final Object result = booleanConverter.convert(Boolean.class, stringValue);
                     results[i] = ((Boolean) result).booleanValue();
                 }
-                return (results);
+                return results;
             } catch (final Exception e) {
                 if (useDefault) {
-                    return (defaultValue);
-                } else {
-                    throw new ConversionException(value.toString(), e);
+                    return defaultValue;
                 }
+                throw new ConversionException(value.toString(), e);
             }
         }
 
@@ -224,23 +204,21 @@ public final class BooleanArrayConverter extends AbstractArrayConverter {
         // sequence of values; see method AbstractArrayConverter.parseElements
         // for more information.
         try {
-            final List list = parseElements(value.toString());
+            final List<String> list = parseElements(value.toString());
             final boolean[] results = new boolean[list.size()];
             for (int i = 0; i < results.length; i++) {
-                final String stringValue = (String) list.get(i);
+                final String stringValue = list.get(i);
                 final Object result = booleanConverter.convert(Boolean.class, stringValue);
                 results[i] = ((Boolean) result).booleanValue();
             }
-            return (results);
+            return results;
         } catch (final Exception e) {
             if (useDefault) {
-                return (defaultValue);
-            } else {
-                throw new ConversionException(value.toString(), e);
+                return defaultValue;
             }
+            throw new ConversionException(value.toString(), e);
         }
 
     }
 
-
 }
