@@ -22,12 +22,12 @@ import org.apache.commons.beanutils.Converter;
  * Provides a facade for {@link Converter} implementations
  * preventing access to any public API in the implementation,
  * other than that specified by {@link Converter}.
- * <p />
+ * <p>
  * This implementation can be used to prevent registered {@link Converter}
  * implementations that provide configuration options from being
  * retrieved and modified.
+ * </p>
  *
- * @version $Id$
  * @since 1.8.0
  */
 public final class ConverterFacade implements Converter {
@@ -57,6 +57,7 @@ public final class ConverterFacade implements Converter {
      * @param value The input value to be converted
      * @return The converted value.
      */
+    @Override
     public <T> T convert(final Class<T> type, final Object value) {
         return converter.convert(type, value);
     }
