@@ -20,31 +20,29 @@ import java.util.Date;
 
 /**
  * {@link DateTimeConverter} implementation that handles conversion to
- * and from <b>java.util.Date</b> objects.
+ * and from <strong>java.util.Date</strong> objects.
  * <p>
  * This implementation can be configured to handle conversion either
  * by using a Locale's default format or by specifying a set of format
  * patterns (note, there is no default String conversion for Date).
  * See the {@link DateTimeConverter} documentation for further details.
  * <p>
- * Can be configured to either return a <i>default value</i> or throw a
+ * Can be configured to either return a <em>default value</em> or throw a
  * <code>ConversionException</code> if a conversion error occurs.
  *
- * @version $Id$
  * @since 1.8.0
  */
 public final class DateConverter extends DateTimeConverter {
 
     /**
-     * Construct a <b>java.util.Date</b> <i>Converter</i> that throws
+     * Construct a <strong>java.util.Date</strong> <em>Converter</em> that throws
      * a <code>ConversionException</code> if an error occurs.
      */
     public DateConverter() {
-        super();
     }
 
     /**
-     * Construct a <b>java.util.Date</b> <i>Converter</i> that returns
+     * Construct a <strong>java.util.Date</strong> <em>Converter</em> that returns
      * a default value if an error occurs.
      *
      * @param defaultValue The default value to be returned
