@@ -27,11 +27,12 @@ import java.util.TimeZone;
 import org.apache.commons.beanutils.ConversionException;
 
 /**
- * {@link org.apache.commons.beanutils.Converter} implementaion
- * that handles conversion to and from <b>date/time</b> objects.
+ * {@link org.apache.commons.beanutils.Converter} implementation
+ * that handles conversion to and from <strong>date/time</strong> objects.
  * <p>
  * This implementation handles conversion for the following
- * <i>date/time</i> types.
+ * <em>date/time</em> types.
+ * </p>
  * <ul>
  *     <li><code>java.util.Date</code></li>
  *     <li><code>java.util.Calendar</code></li>
@@ -40,41 +41,44 @@ import org.apache.commons.beanutils.ConversionException;
  *     <li><code>java.sql.Timestamp</code></li>
  * </ul>
  *
- * <h3>String Conversions (to and from)</h3>
+ * <h2>String Conversions (to and from)</h2>
  * This class provides a number of ways in which date/time
  * conversions to/from Strings can be achieved:
  * <ul>
- *    <li>Using the SHORT date format for the default Locale, configure using:</li>
+ *    <li>Using the SHORT date format for the default Locale, configure using:
  *        <ul>
  *           <li><code>setUseLocaleFormat(true)</code></li>
  *        </ul>
- *    <li>Using the SHORT date format for a specified Locale, configure using:</li>
+ *    </li>
+ *    <li>Using the SHORT date format for a specified Locale, configure using:
  *        <ul>
  *           <li><code>setLocale(Locale)</code></li>
  *        </ul>
- *    <li>Using the specified date pattern(s) for the default Locale, configure using:</li>
+ *    </li>
+ *    <li>Using the specified date pattern(s) for the default Locale, configure using:
  *        <ul>
  *           <li>Either <code>setPattern(String)</code> or
  *                      <code>setPatterns(String[])</code></li>
  *        </ul>
- *    <li>Using the specified date pattern(s) for a specified Locale, configure using:</li>
+ *    </li>
+ *    <li>Using the specified date pattern(s) for a specified Locale, configure using:
  *        <ul>
  *           <li><code>setPattern(String)</code> or
  *                    <code>setPatterns(String[]) and...</code></li>
  *           <li><code>setLocale(Locale)</code></li>
  *        </ul>
+ *    </li>
  *    <li>If none of the above are configured the
  *        <code>toDate(String)</code> method is used to convert
  *        from String to Date and the Dates's
  *        <code>toString()</code> method used to convert from
  *        Date to String.</li>
  * </ul>
- *
  * <p>
- * The <b>Time Zone</b> to use with the date format can be specified
+ * The <strong>Time Zone</strong> to use with the date format can be specified
  * using the <code>setTimeZone()</code> method.
+ * </p>
  *
- * @version $Id$
  * @since 1.8.0
  */
 public abstract class DateTimeConverter extends AbstractConverter {
@@ -85,19 +89,15 @@ public abstract class DateTimeConverter extends AbstractConverter {
     private TimeZone timeZone;
     private boolean useLocaleFormat;
 
-
-    // ----------------------------------------------------------- Constructors
-
     /**
-     * Construct a Date/Time <i>Converter</i> that throws a
+     * Construct a Date/Time <em>Converter</em> that throws a
      * <code>ConversionException</code> if an error occurs.
      */
     public DateTimeConverter() {
-        super();
     }
 
     /**
-     * Construct a Date/Time <i>Converter</i> that returns a default
+     * Construct a Date/Time <em>Converter</em> that returns a default
      * value if an error occurs.
      *
      * @param defaultValue The default value to be returned
@@ -108,113 +108,14 @@ public abstract class DateTimeConverter extends AbstractConverter {
         super(defaultValue);
     }
 
-
-    // --------------------------------------------------------- Public Methods
-
-    /**
-     * Indicate whether conversion should use a format/pattern or not.
-     *
-     * @param useLocaleFormat <code>true</code> if the format
-     * for the locale should be used, otherwise <code>false</code>
-     */
-    public void setUseLocaleFormat(final boolean useLocaleFormat) {
-        this.useLocaleFormat = useLocaleFormat;
-    }
-
-    /**
-     * Return the Time Zone to use when converting dates
-     * (or <code>null</code> if none specified.
-     *
-     * @return The Time Zone.
-     */
-    public TimeZone getTimeZone() {
-        return timeZone;
-    }
-
-    /**
-     * Set the Time Zone to use when converting dates.
-     *
-     * @param timeZone The Time Zone.
-     */
-    public void setTimeZone(final TimeZone timeZone) {
-        this.timeZone = timeZone;
-    }
-
-    /**
-     * Return the Locale for the <i>Converter</i>
-     * (or <code>null</code> if none specified).
-     *
-     * @return The locale to use for conversion
-     */
-    public Locale getLocale() {
-        return locale;
-    }
-
-    /**
-     * Set the Locale for the <i>Converter</i>.
-     *
-     * @param locale The Locale.
-     */
-    public void setLocale(final Locale locale) {
-        this.locale = locale;
-        setUseLocaleFormat(true);
-    }
-
-    /**
-     * Set a date format pattern to use to convert
-     * dates to/from a <code>java.lang.String</code>.
-     *
-     * @see SimpleDateFormat
-     * @param pattern The format pattern.
-     */
-    public void setPattern(final String pattern) {
-        setPatterns(new String[] {pattern});
-    }
-
-    /**
-     * Return the date format patterns used to convert
-     * dates to/from a <code>java.lang.String</code>
-     * (or <code>null</code> if none specified).
-     *
-     * @see SimpleDateFormat
-     * @return Array of format patterns.
-     */
-    public String[] getPatterns() {
-        return patterns;
-    }
-
-    /**
-     * Set the date format patterns to use to convert
-     * dates to/from a <code>java.lang.String</code>.
-     *
-     * @see SimpleDateFormat
-     * @param patterns Array of format patterns.
-     */
-    public void setPatterns(final String[] patterns) {
-        this.patterns = patterns;
-        if (patterns != null && patterns.length > 1) {
-            final StringBuilder buffer = new StringBuilder();
-            for (int i = 0; i < patterns.length; i++) {
-                if (i > 0) {
-                    buffer.append(", ");
-                }
-                buffer.append(patterns[i]);
-            }
-            displayPatterns = buffer.toString();
-        }
-        setUseLocaleFormat(true);
-    }
-
-    // ------------------------------------------------------ Protected Methods
-
     /**
      * Convert an input Date/Calendar object into a String.
      * <p>
-     * <b>N.B.</b>If the converter has been configured to with
+     * <strong>N.B.</strong>If the converter has been configured to with
      * one or more patterns (using <code>setPatterns()</code>), then
      * the first pattern will be used to format the date into a String.
      * Otherwise the default <code>DateFormat</code> for the default locale
-     * (and <i>style</i> if configured) will be used.
+     * (and <em>style</em> if configured) will be used.
      *
      * @param value The input value to be converted
      * @return the converted String value.
@@ -276,7 +177,7 @@ public abstract class DateTimeConverter extends AbstractConverter {
      * with one or more patterns (using <code>setPatterns()</code>), then
      * the conversion is attempted with each of the specified patterns.
      * Otherwise the default <code>DateFormat</code> for the default locale
-     * (and <i>style</i> if configured) will be used.
+     * (and <em>style</em> if configured) will be used.
      *
      * @param <T> The desired target type of the conversion.
      * @param targetType Data type to which this value should be converted.
@@ -292,14 +193,12 @@ public abstract class DateTimeConverter extends AbstractConverter {
         // Handle java.sql.Timestamp
         if (value instanceof java.sql.Timestamp) {
 
-            // ---------------------- JDK 1.3 Fix ----------------------
             // N.B. Prior to JDK 1.4 the Timestamp's getTime() method
             //      didn't include the milliseconds. The following code
             //      ensures it works consistently accross JDK versions
             final java.sql.Timestamp timestamp = (java.sql.Timestamp)value;
-            long timeInMillis = ((timestamp.getTime() / 1000) * 1000);
+            long timeInMillis = timestamp.getTime() / 1000 * 1000;
             timeInMillis += timestamp.getNanos() / 1000000;
-            // ---------------------- JDK 1.3 Fix ----------------------
             return toDate(targetType, timeInMillis);
         }
 
@@ -338,9 +237,8 @@ public abstract class DateTimeConverter extends AbstractConverter {
             }
             if (Calendar.class.isAssignableFrom(targetType)) {
                 return targetType.cast(calendar);
-            } else {
-                return toDate(targetType, calendar.getTime().getTime());
             }
+            return toDate(targetType, calendar.getTime().getTime());
         }
 
         // Default String conversion
@@ -348,9 +246,220 @@ public abstract class DateTimeConverter extends AbstractConverter {
 
     }
 
+    /**
+     * Return a <code>DateFormat</code> for the Locale.
+     * @param locale The Locale to create the Format with (may be null)
+     * @param timeZone The Time Zone create the Format with (may be null)
+     * @return A Date Format.
+     */
+    protected DateFormat getFormat(final Locale locale, final TimeZone timeZone) {
+        DateFormat format = null;
+        if (locale == null) {
+            format = DateFormat.getDateInstance(DateFormat.SHORT);
+        } else {
+            format = DateFormat.getDateInstance(DateFormat.SHORT, locale);
+        }
+        if (timeZone != null) {
+            format.setTimeZone(timeZone);
+        }
+        return format;
+    }
+
+    /**
+     * Create a date format for the specified pattern.
+     *
+     * @param pattern The date pattern
+     * @return The DateFormat
+     */
+    private DateFormat getFormat(final String pattern) {
+        final DateFormat format = new SimpleDateFormat(pattern);
+        if (timeZone != null) {
+            format.setTimeZone(timeZone);
+        }
+        return format;
+    }
+
+    /**
+     * Return the Locale for the <em>Converter</em>
+     * (or <code>null</code> if none specified).
+     *
+     * @return The locale to use for conversion
+     */
+    public Locale getLocale() {
+        return locale;
+    }
+
+    /**
+     * Return the date format patterns used to convert
+     * dates to/from a <code>java.lang.String</code>
+     * (or <code>null</code> if none specified).
+     *
+     * @see SimpleDateFormat
+     * @return Array of format patterns.
+     */
+    public String[] getPatterns() {
+        return patterns;
+    }
+
+    /**
+     * Return the Time Zone to use when converting dates
+     * (or <code>null</code> if none specified.
+     *
+     * @return The Time Zone.
+     */
+    public TimeZone getTimeZone() {
+        return timeZone;
+    }
+
+    /**
+     * Log the <code>DateFormat<code> creation.
+     * @param action The action the format is being used for
+     * @param format The Date format
+     */
+    private void logFormat(final String action, final DateFormat format) {
+        if (log().isDebugEnabled()) {
+            final StringBuilder buffer = new StringBuilder(45);
+            buffer.append("    ");
+            buffer.append(action);
+            buffer.append(" with Format");
+            if (format instanceof SimpleDateFormat) {
+                buffer.append("[");
+                buffer.append(((SimpleDateFormat)format).toPattern());
+                buffer.append("]");
+            }
+            buffer.append(" for ");
+            if (locale == null) {
+                buffer.append("default locale");
+            } else {
+                buffer.append("locale[");
+                buffer.append(locale);
+                buffer.append("]");
+            }
+            if (timeZone != null) {
+                buffer.append(", TimeZone[");
+                buffer.append(timeZone);
+                buffer.append("]");
+            }
+            log().debug(buffer.toString());
+        }
+    }
+
+    /**
+     * Parse a String date value using the set of patterns.
+     *
+     * @param sourceType The type of the value being converted
+     * @param targetType The type to convert the value to.
+     * @param value The String date value.
+     * @return The converted Date object.
+     * @throws Exception if an error occurs parsing the date.
+     */
+    private Calendar parse(final Class<?> sourceType, final Class<?> targetType, final String value) throws Exception {
+        Exception firstEx = null;
+        for (final String pattern : patterns) {
+            try {
+                final DateFormat format = getFormat(pattern);
+                return parse(sourceType, targetType, value, format);
+            } catch (final Exception ex) {
+                if (firstEx == null) {
+                    firstEx = ex;
+                }
+            }
+        }
+        if (patterns.length > 1) {
+            throw new ConversionException("Error converting '" + toString(sourceType) + "' to '" + toString(targetType)
+                    + "' using  patterns '" + displayPatterns + "'");
+        }
+        throw firstEx;
+    }
+
+    /**
+     * Parse a String into a <code>Calendar</code> object
+     * using the specified <code>DateFormat</code>.
+     *
+     * @param sourceType The type of the value being converted
+     * @param targetType The type to convert the value to
+     * @param value The String date value.
+     * @param format The DateFormat to parse the String value.
+     * @return The converted Calendar object.
+     * @throws ConversionException if the String cannot be converted.
+     */
+    private Calendar parse(final Class<?> sourceType, final Class<?> targetType, final String value, final DateFormat format) {
+        logFormat("Parsing", format);
+        format.setLenient(false);
+        final ParsePosition pos = new ParsePosition(0);
+        final Date parsedDate = format.parse(value, pos); // ignore the result (use the Calendar)
+        if (pos.getErrorIndex() >= 0 || pos.getIndex() != value.length() || parsedDate == null) {
+            String msg = "Error converting '" + toString(sourceType) + "' to '" + toString(targetType) + "'";
+            if (format instanceof SimpleDateFormat) {
+                msg += " using pattern '" + ((SimpleDateFormat)format).toPattern() + "'";
+            }
+            if (log().isDebugEnabled()) {
+                log().debug("    " + msg);
+            }
+            throw new ConversionException(msg);
+        }
+        return format.getCalendar();
+    }
+
+    /**
+     * Set the Locale for the <em>Converter</em>.
+     *
+     * @param locale The Locale.
+     */
+    public void setLocale(final Locale locale) {
+        this.locale = locale;
+        setUseLocaleFormat(true);
+    }
+
+    /**
+     * Set a date format pattern to use to convert
+     * dates to/from a <code>java.lang.String</code>.
+     *
+     * @see SimpleDateFormat
+     * @param pattern The format pattern.
+     */
+    public void setPattern(final String pattern) {
+        setPatterns(new String[] {pattern});
+    }
+
+    /**
+     * Set the date format patterns to use to convert
+     * dates to/from a <code>java.lang.String</code>.
+     *
+     * @see SimpleDateFormat
+     * @param patterns Array of format patterns.
+     */
+    public void setPatterns(final String[] patterns) {
+        this.patterns = patterns;
+        if (patterns != null && patterns.length > 1) {
+            final String buffer = String.join(", ", patterns);
+            displayPatterns = buffer;
+        }
+        setUseLocaleFormat(true);
+    }
+
+    /**
+     * Set the Time Zone to use when converting dates.
+     *
+     * @param timeZone The Time Zone.
+     */
+    public void setTimeZone(final TimeZone timeZone) {
+        this.timeZone = timeZone;
+    }
+
+    /**
+     * Indicate whether conversion should use a format/pattern or not.
+     *
+     * @param useLocaleFormat <code>true</code> if the format
+     * for the locale should be used, otherwise <code>false</code>
+     */
+    public void setUseLocaleFormat(final boolean useLocaleFormat) {
+        this.useLocaleFormat = useLocaleFormat;
+    }
+
     /**
      * Convert a long value to the specified Date type for this
-     * <i>Converter</i>.
+     * <em>Converter</em>.
      * <p>
      *
      * This method handles conversion to the following types:
@@ -474,102 +583,6 @@ public abstract class DateTimeConverter extends AbstractConverter {
         throw new ConversionException(msg);
     }
 
-    /**
-     * Return a <code>DateFormat<code> for the Locale.
-     * @param locale The Locale to create the Format with (may be null)
-     * @param timeZone The Time Zone create the Format with (may be null)
-     *
-     * @return A Date Format.
-     */
-    protected DateFormat getFormat(final Locale locale, final TimeZone timeZone) {
-        DateFormat format = null;
-        if (locale == null) {
-            format = DateFormat.getDateInstance(DateFormat.SHORT);
-        } else {
-            format = DateFormat.getDateInstance(DateFormat.SHORT, locale);
-        }
-        if (timeZone != null) {
-            format.setTimeZone(timeZone);
-        }
-        return format;
-    }
-
-    /**
-     * Create a date format for the specified pattern.
-     *
-     * @param pattern The date pattern
-     * @return The DateFormat
-     */
-    private DateFormat getFormat(final String pattern) {
-        final DateFormat format = new SimpleDateFormat(pattern);
-        if (timeZone != null) {
-            format.setTimeZone(timeZone);
-        }
-        return format;
-    }
-
-    /**
-     * Parse a String date value using the set of patterns.
-     *
-     * @param sourceType The type of the value being converted
-     * @param targetType The type to convert the value to.
-     * @param value The String date value.
-     *
-     * @return The converted Date object.
-     * @throws Exception if an error occurs parsing the date.
-     */
-    private Calendar parse(final Class<?> sourceType, final Class<?> targetType, final String value) throws Exception {
-        Exception firstEx = null;
-        for (String pattern : patterns) {
-            try {
-                final DateFormat format = getFormat(pattern);
-                final Calendar calendar = parse(sourceType, targetType, value, format);
-                return calendar;
-            } catch (final Exception ex) {
-                if (firstEx == null) {
-                    firstEx = ex;
-                }
-            }
-        }
-        if (patterns.length > 1) {
-            throw new ConversionException("Error converting '" + toString(sourceType) + "' to '" + toString(targetType)
-                    + "' using  patterns '" + displayPatterns + "'");
-        } else {
-            throw firstEx;
-        }
-    }
-
-    /**
-     * Parse a String into a <code>Calendar</code> object
-     * using the specified <code>DateFormat</code>.
-     *
-     * @param sourceType The type of the value being converted
-     * @param targetType The type to convert the value to
-     * @param value The String date value.
-     * @param format The DateFormat to parse the String value.
-     *
-     * @return The converted Calendar object.
-     * @throws ConversionException if the String cannot be converted.
-     */
-    private Calendar parse(final Class<?> sourceType, final Class<?> targetType, final String value, final DateFormat format) {
-        logFormat("Parsing", format);
-        format.setLenient(false);
-        final ParsePosition pos = new ParsePosition(0);
-        final Date parsedDate = format.parse(value, pos); // ignore the result (use the Calendar)
-        if (pos.getErrorIndex() >= 0 || pos.getIndex() != value.length() || parsedDate == null) {
-            String msg = "Error converting '" + toString(sourceType) + "' to '" + toString(targetType) + "'";
-            if (format instanceof SimpleDateFormat) {
-                msg += " using pattern '" + ((SimpleDateFormat)format).toPattern() + "'";
-            }
-            if (log().isDebugEnabled()) {
-                log().debug("    " + msg);
-            }
-            throw new ConversionException(msg);
-        }
-        final Calendar calendar = format.getCalendar();
-        return calendar;
-    }
-
     /**
      * Provide a String representation of this date/time converter.
      *
@@ -599,37 +612,4 @@ public abstract class DateTimeConverter extends AbstractConverter {
         buffer.append(']');
         return buffer.toString();
     }
-
-    /**
-     * Log the <code>DateFormat<code> creation.
-     * @param action The action the format is being used for
-     * @param format The Date format
-     */
-    private void logFormat(final String action, final DateFormat format) {
-        if (log().isDebugEnabled()) {
-            final StringBuilder buffer = new StringBuilder(45);
-            buffer.append("    ");
-            buffer.append(action);
-            buffer.append(" with Format");
-            if (format instanceof SimpleDateFormat) {
-                buffer.append("[");
-                buffer.append(((SimpleDateFormat)format).toPattern());
-                buffer.append("]");
-            }
-            buffer.append(" for ");
-            if (locale == null) {
-                buffer.append("default locale");
-            } else {
-                buffer.append("locale[");
-                buffer.append(locale);
-                buffer.append("]");
-            }
-            if (timeZone != null) {
-                buffer.append(", TimeZone[");
-                buffer.append(timeZone);
-                buffer.append("]");
-            }
-            log().debug(buffer.toString());
-        }
-    }
 }
