@@ -15,13 +15,11 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.converters;
 
-
 import java.util.List;
-import org.apache.commons.beanutils.ConversionException;
 
+import org.apache.commons.beanutils.ConversionException;
 
 /**
  * <p>Standard {@link org.apache.commons.beanutils.Converter} implementation that converts an incoming
@@ -29,7 +27,6 @@ import org.apache.commons.beanutils.ConversionException;
  * a specified default value or throws a {@link ConversionException} depending
  * on how this instance is constructed.</p>
  *
- * @version $Id$
  * @since 1.4
  * @deprecated Replaced by the new {@link ArrayConverter} implementation
  */
@@ -37,9 +34,10 @@ import org.apache.commons.beanutils.ConversionException;
 @Deprecated
 public final class LongArrayConverter extends AbstractArrayConverter {
 
-
-    // ----------------------------------------------------------- Constructors
-
+    /**
+     * <p>Model object for type comparisons.</p>
+     */
+    private static final long[] MODEL = {};
 
     /**
      * Create a {@link org.apache.commons.beanutils.Converter} that will throw
@@ -52,7 +50,6 @@ public final class LongArrayConverter extends AbstractArrayConverter {
 
     }
 
-
     /**
      * Create a {@link org.apache.commons.beanutils.Converter} that will return
      * the specified default value if a conversion error occurs.
@@ -66,19 +63,6 @@ public final class LongArrayConverter extends AbstractArrayConverter {
 
     }
 
-
-    // ------------------------------------------------------- Static Variables
-
-
-    /**
-     * <p>Model object for type comparisons.</p>
-     */
-    private static final long[] MODEL = new long[0];
-
-
-    // --------------------------------------------------------- Public Methods
-
-
     /**
      * Convert the specified input object into an output object of the
      * specified type.
@@ -86,7 +70,6 @@ public final class LongArrayConverter extends AbstractArrayConverter {
      * @param type Data type to which this value should be converted
      * @param value The input value to be converted
      * @return the converted value
-     *
      * @throws ConversionException if conversion cannot be performed
      *  successfully
      */
@@ -96,15 +79,14 @@ public final class LongArrayConverter extends AbstractArrayConverter {
         // Deal with a null value
         if (value == null) {
             if (useDefault) {
-                return (defaultValue);
-            } else {
-                throw new ConversionException("No value specified");
+                return defaultValue;
             }
+            throw new ConversionException("No value specified");
         }
 
         // Deal with the no-conversion-needed case
         if (MODEL.getClass() == value.getClass()) {
-            return (value);
+            return value;
         }
 
         // Deal with input value as a String array
@@ -115,34 +97,31 @@ public final class LongArrayConverter extends AbstractArrayConverter {
                 for (int i = 0; i < values.length; i++) {
                     results[i] = Long.parseLong(values[i]);
                 }
-                return (results);
+                return results;
             } catch (final Exception e) {
                 if (useDefault) {
-                    return (defaultValue);
-                } else {
-                    throw new ConversionException(value.toString(), e);
+                    return defaultValue;
                 }
+                throw new ConversionException(value.toString(), e);
             }
         }
 
         // Parse the input value as a String into elements
         // and convert to the appropriate type
         try {
-            final List list = parseElements(value.toString());
+            final List<String> list = parseElements(value.toString());
             final long[] results = new long[list.size()];
             for (int i = 0; i < results.length; i++) {
-                results[i] = Long.parseLong((String) list.get(i));
+                results[i] = Long.parseLong(list.get(i));
             }
-            return (results);
+            return results;
         } catch (final Exception e) {
             if (useDefault) {
-                return (defaultValue);
-            } else {
-                throw new ConversionException(value.toString(), e);
+                return defaultValue;
             }
+            throw new ConversionException(value.toString(), e);
         }
 
     }
 
-
 }
