@@ -29,8 +29,8 @@ import java.util.Locale;
 import org.apache.commons.beanutils.ConversionException;
 
 /**
- * {@link org.apache.commons.beanutils.Converter} implementaion that handles conversion
- * to and from <b>java.lang.Number</b> objects.
+ * {@link org.apache.commons.beanutils.Converter} implementation that handles conversion
+ * to and from <strong>java.lang.Number</strong> objects.
  * <p>
  * This implementation handles conversion for the following
  * <code>java.lang.Number</code> types.
@@ -45,27 +45,31 @@ import org.apache.commons.beanutils.ConversionException;
  *     <li><code>java.math.BigInteger</code></li>
  * </ul>
  *
- * <h3>String Conversions (to and from)</h3>
+ * <h2>String Conversions (to and from)</h2>
  * This class provides a number of ways in which number
  * conversions to/from Strings can be achieved:
  * <ul>
- *    <li>Using the default format for the default Locale, configure using:</li>
+ *    <li>Using the default format for the default Locale, configure using:
  *        <ul>
  *           <li><code>setUseLocaleFormat(true)</code></li>
  *        </ul>
- *    <li>Using the default format for a specified Locale, configure using:</li>
+ *    </li>
+ *    <li>Using the default format for a specified Locale, configure using:
  *        <ul>
  *           <li><code>setLocale(Locale)</code></li>
  *        </ul>
- *    <li>Using a specified pattern for the default Locale, configure using:</li>
+ *    </li>
+ *    <li>Using a specified pattern for the default Locale, configure using:
  *        <ul>
  *           <li><code>setPattern(String)</code></li>
  *        </ul>
- *    <li>Using a specified pattern for a specified Locale, configure using:</li>
+ *    </li>
+ *    <li>Using a specified pattern for a specified Locale, configure using:
  *        <ul>
  *           <li><code>setPattern(String)</code></li>
  *           <li><code>setLocale(Locale)</code></li>
  *        </ul>
+ *    </li>
  *    <li>If none of the above are configured the
  *        <code>toNumber(String)</code> method is used to convert
  *        from String to Number and the Number's
@@ -74,122 +78,46 @@ import org.apache.commons.beanutils.ConversionException;
  * </ul>
  *
  * <p>
- * <strong>N.B.</strong>Patterns can only be specified using the <i>standard</i>
- * pattern characters and NOT in <i>localized</i> form (see <code>java.text.DecimalFormat</code>).
+ * <strong>N.B.</strong>Patterns can only be specified using the <em>standard</em>
+ * pattern characters and NOT in <em>localized</em> form (see <code>java.text.DecimalFormat</code>).
  * For example to cater for number styles used in Germany such as <code>0.000,00</code> the pattern
  * is specified in the normal form <code>0,000.00</code> and the locale set to <code>Locale.GERMANY</code>.
+ * </p>
  *
- * @version $Id$
  * @since 1.8.0
  */
 public abstract class NumberConverter extends AbstractConverter {
 
-    private static final Integer ZERO = new Integer(0);
-    private static final Integer ONE  = new Integer(1);
+    private static final Integer ZERO = Integer.valueOf(0);
+    private static final Integer ONE  = Integer.valueOf(1);
 
     private String pattern;
     private final boolean allowDecimals;
     private boolean useLocaleFormat;
     private Locale locale;
 
-    // ----------------------------------------------------------- Constructors
-
     /**
-     * Construct a <b>java.lang.Number</b> <i>Converter</i>
+     * Construct a <strong>java.lang.Number</strong> <em>Converter</em>
      * that throws a <code>ConversionException</code> if a error occurs.
      *
      * @param allowDecimals Indicates whether decimals are allowed
      */
     public NumberConverter(final boolean allowDecimals) {
-        super();
         this.allowDecimals = allowDecimals;
     }
 
     /**
-     * Construct a <code>java.lang.Number</code> <i>Converter</i> that returns
+     * Construct a <code>java.lang.Number</code> <em>Converter</em> that returns
      * a default value if an error occurs.
      *
      * @param allowDecimals Indicates whether decimals are allowed
      * @param defaultValue The default value to be returned
      */
     public NumberConverter(final boolean allowDecimals, final Object defaultValue) {
-        super();
         this.allowDecimals = allowDecimals;
         setDefaultValue(defaultValue);
     }
 
-    // --------------------------------------------------------- Public Methods
-
-    /**
-     * Return whether decimals are allowed in the number.
-     *
-     * @return Whether decimals are allowed in the number
-     */
-    public boolean isAllowDecimals() {
-        return allowDecimals;
-    }
-
-    /**
-     * Set whether a format should be used to convert
-     * the Number.
-     *
-     * @param useLocaleFormat <code>true</code> if a number format
-     * should be used.
-     */
-    public void setUseLocaleFormat(final boolean useLocaleFormat) {
-        this.useLocaleFormat = useLocaleFormat;
-    }
-
-    /**
-     * Return the number format pattern used to convert
-     * Numbers to/from a <code>java.lang.String</code>
-     * (or <code>null</code> if none specified).
-     * <p>
-     * See <code>java.text.DecimalFormat</code> for details
-     * of how to specify the pattern.
-     *
-     * @return The format pattern.
-     */
-    public String getPattern() {
-        return pattern;
-    }
-
-    /**
-     * Set a number format pattern to use to convert
-     * Numbers to/from a <code>java.lang.String</code>.
-     * <p>
-     * See <code>java.text.DecimalFormat</code> for details
-     * of how to specify the pattern.
-     *
-     * @param pattern The format pattern.
-     */
-    public void setPattern(final String pattern) {
-        this.pattern = pattern;
-        setUseLocaleFormat(true);
-    }
-
-    /**
-     * Return the Locale for the <i>Converter</i>
-     * (or <code>null</code> if none specified).
-     *
-     * @return The locale to use for conversion
-     */
-    public Locale getLocale() {
-        return locale;
-    }
-
-    /**
-     * Set the Locale for the <i>Converter</i>.
-     *
-     * @param locale The locale to use for conversion
-     */
-    public void setLocale(final Locale locale) {
-        this.locale = locale;
-        setUseLocaleFormat(true);
-    }
-
-    // ------------------------------------------------------ Protected Methods
-
     /**
      * Convert an input Number object into a String.
      *
@@ -245,12 +173,12 @@ public abstract class NumberConverter extends AbstractConverter {
 
         // Handle Date --> Long
         if (value instanceof Date && Long.class.equals(targetType)) {
-            return targetType.cast(new Long(((Date)value).getTime()));
+            return targetType.cast(Long.valueOf(((Date)value).getTime()));
         }
 
         // Handle Calendar --> Long
         if (value instanceof Calendar  && Long.class.equals(targetType)) {
-            return targetType.cast(new Long(((Calendar)value).getTime().getTime()));
+            return targetType.cast(Long.valueOf(((Calendar)value).getTime().getTime()));
         }
 
         // Convert all other types to String & handle
@@ -276,9 +204,212 @@ public abstract class NumberConverter extends AbstractConverter {
 
     }
 
+    /**
+     * Return a NumberFormat to use for Conversion.
+     *
+     * @return The NumberFormat.
+     */
+    private NumberFormat getFormat() {
+        NumberFormat format = null;
+        if (pattern != null) {
+            if (locale == null) {
+                if (log().isDebugEnabled()) {
+                    log().debug("    Using pattern '" + pattern + "'");
+                }
+                format = new DecimalFormat(pattern);
+            } else {
+                if (log().isDebugEnabled()) {
+                    log().debug("    Using pattern '" + pattern + "'" +
+                              " with Locale[" + locale + "]");
+                }
+                final DecimalFormatSymbols symbols = new DecimalFormatSymbols(locale);
+                format = new DecimalFormat(pattern, symbols);
+            }
+        } else if (locale == null) {
+            if (log().isDebugEnabled()) {
+                log().debug("    Using default Locale format");
+            }
+            format = NumberFormat.getInstance();
+        } else {
+            if (log().isDebugEnabled()) {
+                log().debug("    Using Locale[" + locale + "] format");
+            }
+            format = NumberFormat.getInstance(locale);
+        }
+        if (!allowDecimals) {
+            format.setParseIntegerOnly(true);
+        }
+        return format;
+    }
+
+    /**
+     * Return the Locale for the <em>Converter</em>
+     * (or <code>null</code> if none specified).
+     *
+     * @return The locale to use for conversion
+     */
+    public Locale getLocale() {
+        return locale;
+    }
+
+    /**
+     * Return the number format pattern used to convert
+     * Numbers to/from a <code>java.lang.String</code>
+     * (or <code>null</code> if none specified).
+     * <p>
+     * See <code>java.text.DecimalFormat</code> for details
+     * of how to specify the pattern.
+     *
+     * @return The format pattern.
+     */
+    public String getPattern() {
+        return pattern;
+    }
+
+    /**
+     * Return whether decimals are allowed in the number.
+     *
+     * @return Whether decimals are allowed in the number
+     */
+    public boolean isAllowDecimals() {
+        return allowDecimals;
+    }
+
+    /**
+     * Convert a String into a <code>Number</code> object.
+     * @param sourceType the source type of the conversion
+     * @param targetType The type to convert the value to
+     * @param value The String date value.
+     * @param format The NumberFormat to parse the String value.
+     * @return The converted Number object.
+     * @throws ConversionException if the String cannot be converted.
+     */
+    private Number parse(final Class<?> sourceType, final Class<?> targetType, final String value, final NumberFormat format) {
+        final ParsePosition pos = new ParsePosition(0);
+        final Number parsedNumber = format.parse(value, pos);
+        if (pos.getErrorIndex() >= 0 || pos.getIndex() != value.length() || parsedNumber == null) {
+            String msg = "Error converting from '" + toString(sourceType) + "' to '" + toString(targetType) + "'";
+            if (format instanceof DecimalFormat) {
+                msg += " using pattern '" + ((DecimalFormat)format).toPattern() + "'";
+            }
+            if (locale != null) {
+                msg += " for locale=[" + locale + "]";
+            }
+            if (log().isDebugEnabled()) {
+                log().debug("    " + msg);
+            }
+            throw new ConversionException(msg);
+        }
+        return parsedNumber;
+    }
+
+    /**
+     * Set the Locale for the <em>Converter</em>.
+     *
+     * @param locale The locale to use for conversion
+     */
+    public void setLocale(final Locale locale) {
+        this.locale = locale;
+        setUseLocaleFormat(true);
+    }
+
+    /**
+     * Set a number format pattern to use to convert
+     * Numbers to/from a <code>java.lang.String</code>.
+     * <p>
+     * See <code>java.text.DecimalFormat</code> for details
+     * of how to specify the pattern.
+     *
+     * @param pattern The format pattern.
+     */
+    public void setPattern(final String pattern) {
+        this.pattern = pattern;
+        setUseLocaleFormat(true);
+    }
+
+    /**
+     * Set whether a format should be used to convert
+     * the Number.
+     *
+     * @param useLocaleFormat <code>true</code> if a number format
+     * should be used.
+     */
+    public void setUseLocaleFormat(final boolean useLocaleFormat) {
+        this.useLocaleFormat = useLocaleFormat;
+    }
+
+    /**
+     * Default String to Number conversion.
+     * <p>
+     * This method handles conversion from a String to the following types:
+     * <ul>
+     *     <li><code>java.lang.Byte</code></li>
+     *     <li><code>java.lang.Short</code></li>
+     *     <li><code>java.lang.Integer</code></li>
+     *     <li><code>java.lang.Long</code></li>
+     *     <li><code>java.lang.Float</code></li>
+     *     <li><code>java.lang.Double</code></li>
+     *     <li><code>java.math.BigDecimal</code></li>
+     *     <li><code>java.math.BigInteger</code></li>
+     * </ul>
+     * @param sourceType The type being converted from
+     * @param targetType The Number type to convert to
+     * @param value The String value to convert.
+     * @return The converted Number value.
+     */
+    private Number toNumber(final Class<?> sourceType, final Class<?> targetType, final String value) {
+
+        // Byte
+        if (targetType.equals(Byte.class)) {
+            return Byte.valueOf(value);
+        }
+
+        // Short
+        if (targetType.equals(Short.class)) {
+            return Short.valueOf(value);
+        }
+
+        // Integer
+        if (targetType.equals(Integer.class)) {
+            return Integer.valueOf(value);
+        }
+
+        // Long
+        if (targetType.equals(Long.class)) {
+            return Long.valueOf(value);
+        }
+
+        // Float
+        if (targetType.equals(Float.class)) {
+            return Float.valueOf(value);
+        }
+
+        // Double
+        if (targetType.equals(Double.class)) {
+            return Double.valueOf(value);
+        }
+
+        // BigDecimal
+        if (targetType.equals(BigDecimal.class)) {
+            return new BigDecimal(value);
+        }
+
+        // BigInteger
+        if (targetType.equals(BigInteger.class)) {
+            return new BigInteger(value);
+        }
+
+        final String msg = toString(getClass()) + " cannot handle conversion from '" +
+                     toString(sourceType) + "' to '" + toString(targetType) + "'";
+        if (log().isWarnEnabled()) {
+            log().warn("    " + msg);
+        }
+        throw new ConversionException(msg);
+    }
+
     /**
      * Convert any Number object to the specified type for this
-     * <i>Converter</i>.
+     * <em>Converter</em>.
      * <p>
      * This method handles conversion to the following types:
      * <ul>
@@ -294,7 +425,6 @@ public abstract class NumberConverter extends AbstractConverter {
      * @param sourceType The type being converted from
      * @param targetType The Number type to convert to
      * @param value The Number to convert.
-     *
      * @return The converted value.
      */
     private <T> T toNumber(final Class<?> sourceType, final Class<T> targetType, final Number value) {
@@ -315,7 +445,7 @@ public abstract class NumberConverter extends AbstractConverter {
                 throw new ConversionException(toString(sourceType) + " value '" + value
                         + "' is too small " + toString(targetType));
             }
-            return targetType.cast(new Byte(value.byteValue()));
+            return targetType.cast(Byte.valueOf(value.byteValue()));
         }
 
         // Short
@@ -329,7 +459,7 @@ public abstract class NumberConverter extends AbstractConverter {
                 throw new ConversionException(toString(sourceType) + " value '" + value
                         + "' is too small " + toString(targetType));
             }
-            return targetType.cast(new Short(value.shortValue()));
+            return targetType.cast(Short.valueOf(value.shortValue()));
         }
 
         // Integer
@@ -343,12 +473,12 @@ public abstract class NumberConverter extends AbstractConverter {
                 throw new ConversionException(toString(sourceType) + " value '" + value
                         + "' is too small " + toString(targetType));
             }
-            return targetType.cast(new Integer(value.intValue()));
+            return targetType.cast(Integer.valueOf(value.intValue()));
         }
 
         // Long
         if (targetType.equals(Long.class)) {
-            return targetType.cast(new Long(value.longValue()));
+            return targetType.cast(Long.valueOf(value.longValue()));
         }
 
         // Float
@@ -357,34 +487,34 @@ public abstract class NumberConverter extends AbstractConverter {
                 throw new ConversionException(toString(sourceType) + " value '" + value
                         + "' is too large for " + toString(targetType));
             }
-            return targetType.cast(new Float(value.floatValue()));
+            return targetType.cast(Float.valueOf(value.floatValue()));
         }
 
         // Double
         if (targetType.equals(Double.class)) {
-            return targetType.cast(new Double(value.doubleValue()));
+            return targetType.cast(Double.valueOf(value.doubleValue()));
         }
 
         // BigDecimal
         if (targetType.equals(BigDecimal.class)) {
             if (value instanceof Float || value instanceof Double) {
                 return targetType.cast(new BigDecimal(value.toString()));
-            } else if (value instanceof BigInteger) {
-                return targetType.cast(new BigDecimal((BigInteger)value));
-            } else if (value instanceof BigDecimal) {
-                return targetType.cast(new BigDecimal(value.toString()));
-            } else {
-                return targetType.cast(BigDecimal.valueOf(value.longValue()));
             }
+            if (value instanceof BigInteger) {
+                return targetType.cast(new BigDecimal((BigInteger)value));
+            }
+            if (value instanceof BigDecimal) {
+                return targetType.cast(new BigDecimal(value.toString()));
+            }
+            return targetType.cast(BigDecimal.valueOf(value.longValue()));
         }
 
         // BigInteger
         if (targetType.equals(BigInteger.class)) {
             if (value instanceof BigDecimal) {
                 return targetType.cast(((BigDecimal)value).toBigInteger());
-            } else {
-                return targetType.cast(BigInteger.valueOf(value.longValue()));
             }
+            return targetType.cast(BigInteger.valueOf(value.longValue()));
         }
 
         final String msg = toString(getClass()) + " cannot handle conversion to '"
@@ -396,76 +526,6 @@ public abstract class NumberConverter extends AbstractConverter {
 
     }
 
-    /**
-     * Default String to Number conversion.
-     * <p>
-     * This method handles conversion from a String to the following types:
-     * <ul>
-     *     <li><code>java.lang.Byte</code></li>
-     *     <li><code>java.lang.Short</code></li>
-     *     <li><code>java.lang.Integer</code></li>
-     *     <li><code>java.lang.Long</code></li>
-     *     <li><code>java.lang.Float</code></li>
-     *     <li><code>java.lang.Double</code></li>
-     *     <li><code>java.math.BigDecimal</code></li>
-     *     <li><code>java.math.BigInteger</code></li>
-     * </ul>
-     * @param sourceType The type being converted from
-     * @param targetType The Number type to convert to
-     * @param value The String value to convert.
-     *
-     * @return The converted Number value.
-     */
-    private Number toNumber(final Class<?> sourceType, final Class<?> targetType, final String value) {
-
-        // Byte
-        if (targetType.equals(Byte.class)) {
-            return new Byte(value);
-        }
-
-        // Short
-        if (targetType.equals(Short.class)) {
-            return new Short(value);
-        }
-
-        // Integer
-        if (targetType.equals(Integer.class)) {
-            return new Integer(value);
-        }
-
-        // Long
-        if (targetType.equals(Long.class)) {
-            return new Long(value);
-        }
-
-        // Float
-        if (targetType.equals(Float.class)) {
-            return new Float(value);
-        }
-
-        // Double
-        if (targetType.equals(Double.class)) {
-            return new Double(value);
-        }
-
-        // BigDecimal
-        if (targetType.equals(BigDecimal.class)) {
-            return new BigDecimal(value);
-        }
-
-        // BigInteger
-        if (targetType.equals(BigInteger.class)) {
-            return new BigInteger(value);
-        }
-
-        final String msg = toString(getClass()) + " cannot handle conversion from '" +
-                     toString(sourceType) + "' to '" + toString(targetType) + "'";
-        if (log().isWarnEnabled()) {
-            log().warn("    " + msg);
-        }
-        throw new ConversionException(msg);
-    }
-
     /**
      * Provide a String representation of this number converter.
      *
@@ -491,73 +551,4 @@ public abstract class NumberConverter extends AbstractConverter {
         return buffer.toString();
     }
 
-    /**
-     * Return a NumberFormat to use for Conversion.
-     *
-     * @return The NumberFormat.
-     */
-    private NumberFormat getFormat() {
-        NumberFormat format = null;
-        if (pattern != null) {
-            if (locale == null) {
-                if (log().isDebugEnabled()) {
-                    log().debug("    Using pattern '" + pattern + "'");
-                }
-                format = new DecimalFormat(pattern);
-            } else {
-                if (log().isDebugEnabled()) {
-                    log().debug("    Using pattern '" + pattern + "'" +
-                              " with Locale[" + locale + "]");
-                }
-                final DecimalFormatSymbols symbols = new DecimalFormatSymbols(locale);
-                format = new DecimalFormat(pattern, symbols);
-            }
-        } else {
-            if (locale == null) {
-                if (log().isDebugEnabled()) {
-                    log().debug("    Using default Locale format");
-                }
-                format = NumberFormat.getInstance();
-            } else {
-                if (log().isDebugEnabled()) {
-                    log().debug("    Using Locale[" + locale + "] format");
-                }
-                format = NumberFormat.getInstance(locale);
-            }
-        }
-        if (!allowDecimals) {
-            format.setParseIntegerOnly(true);
-        }
-        return format;
-    }
-
-    /**
-     * Convert a String into a <code>Number</code> object.
-     * @param sourceType the source type of the conversion
-     * @param targetType The type to convert the value to
-     * @param value The String date value.
-     * @param format The NumberFormat to parse the String value.
-     *
-     * @return The converted Number object.
-     * @throws ConversionException if the String cannot be converted.
-     */
-    private Number parse(final Class<?> sourceType, final Class<?> targetType, final String value, final NumberFormat format) {
-        final ParsePosition pos = new ParsePosition(0);
-        final Number parsedNumber = format.parse(value, pos);
-        if (pos.getErrorIndex() >= 0 || pos.getIndex() != value.length() || parsedNumber == null) {
-            String msg = "Error converting from '" + toString(sourceType) + "' to '" + toString(targetType) + "'";
-            if (format instanceof DecimalFormat) {
-                msg += " using pattern '" + ((DecimalFormat)format).toPattern() + "'";
-            }
-            if (locale != null) {
-                msg += " for locale=[" + locale + "]";
-            }
-            if (log().isDebugEnabled()) {
-                log().debug("    " + msg);
-            }
-            throw new ConversionException(msg);
-        }
-        return parsedNumber;
-    }
-
 }
