@@ -25,7 +25,6 @@ import org.apache.commons.beanutils.ConvertUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-
 /**
  * <p>The base class for all standart type locale-sensitive converters.
  * It has {@link LocaleConverter} and {@link org.apache.commons.beanutils.Converter} implementations,
@@ -33,32 +32,57 @@ import org.apache.commons.logging.LogFactory;
  * optionally using a default value or throwing a {@link ConversionException}
  * if a conversion error occurs.</p>
  *
- * @version $Id$
  */
 
 public abstract class BaseLocaleConverter implements LocaleConverter {
 
-    // ----------------------------------------------------- Instance Variables
+    /**
+     * Checks whether the result of a conversion is conform to the specified
+     * target type. If this is the case, the passed in result object is cast to
+     * the correct target type. Otherwise, an exception is thrown.
+     *
+     * @param <T> the desired result type
+     * @param type the target class of the conversion
+     * @param result the conversion result object
+     * @return the result cast to the target class
+     * @throws ConversionException if the result object is not compatible with
+     *         the target type
+     */
+    private static <T> T checkConversionResult(final Class<T> type, final Object result) {
+        if (type == null) {
+            // in this case we cannot do much; the result object is returned
+            @SuppressWarnings("unchecked")
+            final
+            T temp = (T) result;
+            return temp;
+        }
+
+        if (result == null) {
+            return null;
+        }
+        if (type.isInstance(result)) {
+            return type.cast(result);
+        }
+        throw new ConversionException("Unsupported target type: " + type);
+    }
 
     /** All logging goes through this logger */
     private final Log log = LogFactory.getLog(BaseLocaleConverter.class);
 
     /** The default value specified to our Constructor, if any. */
-    private Object defaultValue = null;
+    private Object defaultValue;
 
     /** Should we return the default value on conversion errors? */
-    protected boolean useDefault = false;
+    protected boolean useDefault;
 
     /** The locale specified to our Constructor, by default - system locale. */
     protected Locale locale = Locale.getDefault();
 
     /** The default pattern specified to our Constructor, if any. */
-    protected String pattern = null;
+    protected String pattern;
 
     /** The flag indicating whether the given pattern string is localized or not. */
-    protected boolean locPattern = false;
-
-    // ----------------------------------------------------------- Constructors
+    protected boolean locPattern;
 
     /**
      * Create a {@link LocaleConverter} that will throw a {@link ConversionException}
@@ -140,51 +164,6 @@ public abstract class BaseLocaleConverter implements LocaleConverter {
         this.locPattern = locPattern;
     }
 
-    // --------------------------------------------------------- Methods
-
-    /**
-     * Convert the specified locale-sensitive input object into an output object of the
-     * specified type.
-     *
-     * @param value The input object to be converted
-     * @param pattern The pattern is used for the convertion
-     * @return The converted value
-     *
-     * @throws ParseException if conversion cannot be performed
-     *  successfully
-     */
-
-    abstract protected Object parse(Object value, String pattern) throws ParseException;
-
-
-    /**
-     * Convert the specified locale-sensitive input object into an output object.
-     * The default pattern is used for the conversion.
-     *
-     * @param value The input object to be converted
-     * @return The converted value
-     *
-     * @throws ConversionException if conversion cannot be performed
-     *  successfully
-     */
-    public Object convert(final Object value) {
-        return convert(value, null);
-    }
-
-    /**
-     * Convert the specified locale-sensitive input object into an output object.
-     *
-     * @param value The input object to be converted
-     * @param pattern The pattern is used for the conversion
-     * @return The converted value
-     *
-     * @throws ConversionException if conversion cannot be performed
-     *  successfully
-     */
-    public Object convert(final Object value, final String pattern) {
-        return convert(null, value, pattern);
-    }
-
     /**
      * Convert the specified locale-sensitive input object into an output object of the
      * specified type. The default pattern is used for the convertion.
@@ -193,10 +172,10 @@ public abstract class BaseLocaleConverter implements LocaleConverter {
      * @param type Data type to which this value should be converted
      * @param value The input object to be converted
      * @return The converted value
-     *
      * @throws ConversionException if conversion cannot be performed
      *  successfully
      */
+    @Override
     public <T> T convert(final Class<T> type, final Object value) {
         return convert(type, value, null);
     }
@@ -212,41 +191,64 @@ public abstract class BaseLocaleConverter implements LocaleConverter {
      * passed then the default pattern associated with the converter object
      * will be used.
      * @return The converted value
-     *
      * @throws ConversionException if conversion cannot be performed
      *  successfully
      */
+    @Override
     public <T> T convert(final Class<T> type, final Object value, final String pattern) {
         final Class<T> targetType = ConvertUtils.primitiveToWrapper(type);
         if (value == null) {
             if (useDefault) {
                 return getDefaultAs(targetType);
-            } else {
-                // symmetric beanutils function allows null
-                // so do not: throw new ConversionException("No value specified");
-                log.debug("Null value specified for conversion, returing null");
-                return null;
             }
+            // symmetric beanutils function allows null
+            // so do not: throw new ConversionException("No value specified");
+            log.debug("Null value specified for conversion, returing null");
+            return null;
         }
 
         try {
             if (pattern != null) {
                 return checkConversionResult(targetType, parse(value, pattern));
-            } else {
-                return checkConversionResult(targetType, parse(value, this.pattern));
             }
+            return checkConversionResult(targetType, parse(value, this.pattern));
         } catch (final Exception e) {
             if (useDefault) {
                 return getDefaultAs(targetType);
-            } else {
-                if (e instanceof ConversionException) {
-                    throw (ConversionException)e;
-                }
-                throw new ConversionException(e);
             }
+            if (e instanceof ConversionException) {
+                throw (ConversionException)e;
+            }
+            throw new ConversionException(e);
         }
     }
 
+    /**
+     * Convert the specified locale-sensitive input object into an output object.
+     * The default pattern is used for the conversion.
+     *
+     * @param value The input object to be converted
+     * @return The converted value
+     * @throws ConversionException if conversion cannot be performed
+     *  successfully
+     */
+    public Object convert(final Object value) {
+        return convert(value, null);
+    }
+
+    /**
+     * Convert the specified locale-sensitive input object into an output object.
+     *
+     * @param value The input object to be converted
+     * @param pattern The pattern is used for the conversion
+     * @return The converted value
+     * @throws ConversionException if conversion cannot be performed
+     *  successfully
+     */
+    public Object convert(final Object value, final String pattern) {
+        return convert(null, value, pattern);
+    }
+
     /**
      * Returns the default object specified for this converter cast for the
      * given target type. If the default value is not conform to the given type,
@@ -263,32 +265,15 @@ public abstract class BaseLocaleConverter implements LocaleConverter {
     }
 
     /**
-     * Checks whether the result of a conversion is conform to the specified
-     * target type. If this is the case, the passed in result object is cast to
-     * the correct target type. Otherwise, an exception is thrown.
+     * Convert the specified locale-sensitive input object into an output object of the
+     * specified type.
      *
-     * @param <T> the desired result type
-     * @param type the target class of the conversion
-     * @param result the conversion result object
-     * @return the result cast to the target class
-     * @throws ConversionException if the result object is not compatible with
-     *         the target type
+     * @param value The input object to be converted
+     * @param pattern The pattern is used for the convertion
+     * @return The converted value
+     * @throws ParseException if conversion cannot be performed
+     *  successfully
      */
-    private static <T> T checkConversionResult(final Class<T> type, final Object result) {
-        if (type == null) {
-            // in this case we cannot do much; the result object is returned
-            @SuppressWarnings("unchecked")
-            final
-            T temp = (T) result;
-            return temp;
-        }
 
-        if (result == null) {
-            return null;
-        }
-        if (type.isInstance(result)) {
-            return type.cast(result);
-        }
-        throw new ConversionException("Unsupported target type: " + type);
-    }
+    abstract protected Object parse(Object value, String pattern) throws ParseException;
 }
