@@ -17,11 +17,10 @@
 
 package org.apache.commons.beanutils.locale.converters;
 
-import org.apache.commons.beanutils.ConversionException;
-
-import java.util.Locale;
 import java.text.ParseException;
+import java.util.Locale;
 
+import org.apache.commons.beanutils.ConversionException;
 
 /**
  * <p>Standard {@link org.apache.commons.beanutils.locale.LocaleConverter}
@@ -31,14 +30,10 @@ import java.text.ParseException;
  * {@link org.apache.commons.beanutils.ConversionException}
  * if a conversion error occurs.</p>
  *
- * @version $Id$
  */
 
 public class ByteLocaleConverter extends DecimalLocaleConverter {
 
-
-    // ----------------------------------------------------------- Constructors
-
     /**
      * Create a {@link org.apache.commons.beanutils.locale.LocaleConverter}
      * that will throw a {@link org.apache.commons.beanutils.ConversionException}
@@ -208,7 +203,6 @@ public class ByteLocaleConverter extends DecimalLocaleConverter {
      * @param value The input object to be converted
      * @param pattern The pattern is used for the convertion
      * @return The converted value
-     *
      * @throws org.apache.commons.beanutils.ConversionException if conversion cannot be performed
      *  successfully
      * @throws ParseException if an error occurs parsing a String to a Number
@@ -220,6 +214,6 @@ public class ByteLocaleConverter extends DecimalLocaleConverter {
             throw new ConversionException("Supplied number is not of type Byte: " + parsed.longValue());
         }
         // now returns property Byte
-        return new Byte(parsed.byteValue());
+        return Byte.valueOf(parsed.byteValue());
     }
 }
