@@ -22,6 +22,8 @@ import java.text.DateFormatSymbols;
 import java.text.ParseException;
 import java.text.ParsePosition;
 import java.text.SimpleDateFormat;
+import java.util.Calendar;
+import java.util.Date;
 import java.util.Locale;
 
 import org.apache.commons.beanutils.ConversionException;
@@ -29,7 +31,6 @@ import org.apache.commons.beanutils.locale.BaseLocaleConverter;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-
 /**
  * <p>Standard {@link org.apache.commons.beanutils.locale.LocaleConverter}
  * implementation that converts an incoming
@@ -38,26 +39,31 @@ import org.apache.commons.logging.LogFactory;
  * {@link org.apache.commons.beanutils.ConversionException}
  * if a conversion error occurs.</p>
  *
- * @version $Id$
  */
 
 public class DateLocaleConverter extends BaseLocaleConverter {
 
-    // ----------------------------------------------------- Instance Variables
-
-    /** All logging goes through this logger */
-    private final Log log = LogFactory.getLog(DateLocaleConverter.class);
-
-    /** Should the date conversion be lenient? */
-    boolean isLenient = false;
-
     /**
      * Default Pattern Characters
      *
      */
     private static final String DEFAULT_PATTERN_CHARS = DateLocaleConverter.initDefaultChars();
 
-    // ----------------------------------------------------------- Constructors
+    /**
+     * This method is called at class initialization time to define the
+     * value for constant member DEFAULT_PATTERN_CHARS. All other methods needing
+     * this data should just read that constant.
+     */
+    private static String initDefaultChars() {
+        final DateFormatSymbols defaultSymbols = new DateFormatSymbols(Locale.US);
+        return defaultSymbols.getLocalPatternChars();
+    }
+
+    /** All logging goes through this logger */
+    private final Log log = LogFactory.getLog(DateLocaleConverter.class);
+
+    /** Should the date conversion be lenient? */
+    boolean isLenient;
 
     /**
      * Create a {@link org.apache.commons.beanutils.locale.LocaleConverter}
@@ -192,7 +198,6 @@ public class DateLocaleConverter extends BaseLocaleConverter {
         this(defaultValue, locale, null, locPattern);
     }
 
-
     /**
      * Create a {@link org.apache.commons.beanutils.locale.LocaleConverter}
      * that will return the specified default value
@@ -222,82 +227,7 @@ public class DateLocaleConverter extends BaseLocaleConverter {
         super(defaultValue, locale, pattern, locPattern);
     }
 
-    // --------------------------------------------------------- Methods
-
     /**
-     * Returns whether date formatting is lenient.
-     *
-     * @return true if the <code>DateFormat</code> used for formatting is lenient
-     * @see java.text.DateFormat#isLenient
-     */
-    public boolean isLenient() {
-        return isLenient;
-    }
-
-    /**
-     * Specify whether or not date-time parsing should be lenient.
-     *
-     * @param lenient true if the <code>DateFormat</code> used for formatting should be lenient
-     * @see java.text.DateFormat#setLenient
-     */
-    public void setLenient(final boolean lenient) {
-        isLenient = lenient;
-    }
-
-    // --------------------------------------------------------- Methods
-
-    /**
-     * Convert the specified locale-sensitive input object into an output object of the
-     * specified type.
-     *
-     * @param value The input object to be converted
-     * @param pattern The pattern is used for the convertion
-     * @return the converted Date value
-     *
-     * @throws org.apache.commons.beanutils.ConversionException
-     * if conversion cannot be performed successfully
-     * @throws ParseException if an error occurs parsing
-     */
-    @Override
-    protected Object parse(final Object value, String pattern) throws ParseException {
-
-        // Handle Date
-        if (value instanceof java.util.Date) {
-            return value;
-        }
-
-        // Handle Calendar
-        if (value instanceof java.util.Calendar) {
-            return ((java.util.Calendar)value).getTime();
-        }
-
-         if (locPattern) {
-             pattern = convertLocalizedPattern(pattern, locale);
-         }
-
-         // Create Formatter - use default if pattern is null
-         final DateFormat formatter = pattern == null ? DateFormat.getDateInstance(DateFormat.SHORT, locale)
-                                                : new SimpleDateFormat(pattern, locale);
-         formatter.setLenient(isLenient);
-
-
-         // Parse the Date
-        final ParsePosition pos = new ParsePosition(0);
-        final String strValue = value.toString();
-        final Object parsedValue = formatter.parseObject(strValue, pos);
-        if (pos.getErrorIndex() > -1) {
-            throw new ConversionException("Error parsing date '" + value +
-                    "' at position="+ pos.getErrorIndex());
-        }
-        if (pos.getIndex() < strValue.length()) {
-            throw new ConversionException("Date '" + value +
-                    "' contains unparsed characters from position=" + pos.getIndex());
-        }
-
-        return parsedValue;
-     }
-
-     /**
       * Convert a pattern from a localized format to the default format.
       *
       * @param locale   The locale
@@ -348,18 +278,16 @@ public class DateLocaleConverter extends BaseLocaleConverter {
                 if (thisChar == '\'') {
                     quoted = false;
                 }
-            } else {
-                if (thisChar == '\'') {
-                   quoted = true;
-                } else if ((thisChar >= 'a' && thisChar <= 'z') ||
-                           (thisChar >= 'A' && thisChar <= 'Z')) {
-                    final int index = fromChars.indexOf(thisChar );
-                    if (index == -1) {
-                        throw new IllegalArgumentException(
-                            "Illegal pattern character '" + thisChar + "'");
-                    }
-                    thisChar = toChars.charAt(index);
+            } else if (thisChar == '\'') {
+               quoted = true;
+            } else if (thisChar >= 'a' && thisChar <= 'z' ||
+                       thisChar >= 'A' && thisChar <= 'Z') {
+                final int index = fromChars.indexOf(thisChar);
+                if (index == -1) {
+                    throw new IllegalArgumentException(
+                        "Illegal pattern character '" + thisChar + "'");
                 }
+                thisChar = toChars.charAt(index);
             }
             converted.append(thisChar);
         }
@@ -371,14 +299,73 @@ public class DateLocaleConverter extends BaseLocaleConverter {
         return converted.toString();
     }
 
-    /**
-     * This method is called at class initialization time to define the
-     * value for constant member DEFAULT_PATTERN_CHARS. All other methods needing
-     * this data should just read that constant.
+     /**
+     * Returns whether date formatting is lenient.
+     *
+     * @return true if the <code>DateFormat</code> used for formatting is lenient
+     * @see java.text.DateFormat#isLenient
      */
-    private static String initDefaultChars() {
-        final DateFormatSymbols defaultSymbols = new DateFormatSymbols(Locale.US);
-        return defaultSymbols.getLocalPatternChars();
+    public boolean isLenient() {
+        return isLenient;
+    }
+
+    /**
+     * Convert the specified locale-sensitive input object into an output object of the
+     * specified type.
+     *
+     * @param value The input object to be converted
+     * @param pattern The pattern is used for the convertion
+     * @return the converted Date value
+     * @throws org.apache.commons.beanutils.ConversionException
+     * if conversion cannot be performed successfully
+     * @throws ParseException if an error occurs parsing
+     */
+    @Override
+    protected Object parse(final Object value, String pattern) throws ParseException {
+
+        // Handle Date
+        if (value instanceof Date) {
+            return value;
+        }
+
+        // Handle Calendar
+        if (value instanceof Calendar) {
+            return ((Calendar) value).getTime();
+        }
+
+         if (locPattern) {
+             pattern = convertLocalizedPattern(pattern, locale);
+         }
+
+         // Create Formatter - use default if pattern is null
+         final DateFormat formatter = pattern == null ? DateFormat.getDateInstance(DateFormat.SHORT, locale)
+                                                : new SimpleDateFormat(pattern, locale);
+         formatter.setLenient(isLenient);
+
+         // Parse the Date
+        final ParsePosition pos = new ParsePosition(0);
+        final String strValue = value.toString();
+        final Object parsedValue = formatter.parseObject(strValue, pos);
+        if (pos.getErrorIndex() > -1) {
+            throw new ConversionException("Error parsing date '" + value +
+                    "' at position="+ pos.getErrorIndex());
+        }
+        if (pos.getIndex() < strValue.length()) {
+            throw new ConversionException("Date '" + value +
+                    "' contains unparsed characters from position=" + pos.getIndex());
+        }
+
+        return parsedValue;
+     }
+
+    /**
+     * Specify whether or not date-time parsing should be lenient.
+     *
+     * @param lenient true if the <code>DateFormat</code> used for formatting should be lenient
+     * @see java.text.DateFormat#setLenient
+     */
+    public void setLenient(final boolean lenient) {
+        isLenient = lenient;
     }
 
 }
