@@ -17,11 +17,9 @@
 
 package org.apache.commons.beanutils.locale.converters;
 
-
 import java.text.ParseException;
 import java.util.Locale;
 
-
 /**
  * <p>Standard {@link org.apache.commons.beanutils.locale.LocaleConverter}
  * implementation that converts an incoming
@@ -30,14 +28,10 @@ import java.util.Locale;
  * {@link org.apache.commons.beanutils.ConversionException}
  * if a conversion error occurs.</p>
  *
- * @version $Id$
  */
 
 public class DoubleLocaleConverter extends DecimalLocaleConverter {
 
-
-    // ----------------------------------------------------------- Constructors
-
     /**
      * Create a {@link org.apache.commons.beanutils.locale.LocaleConverter}
      * that will throw a {@link org.apache.commons.beanutils.ConversionException}
@@ -207,7 +201,6 @@ public class DoubleLocaleConverter extends DecimalLocaleConverter {
      * @param value The input object to be converted
      * @param pattern The pattern is used for the convertion
      * @return The converted value
-     *
      * @throws org.apache.commons.beanutils.ConversionException if conversion cannot be performed
      *  successfully
      * @throws ParseException if an error occurs parsing a String to a Number
@@ -216,13 +209,10 @@ public class DoubleLocaleConverter extends DecimalLocaleConverter {
     protected Object parse(final Object value, final String pattern) throws ParseException {
         final Number result = (Number) super.parse(value, pattern);
         if (result instanceof Long) {
-            return new Double(result.doubleValue());
-        } else {
-            return (result);
+            return Double.valueOf(result.doubleValue());
         }
+        return result;
     }
 
-
 }
 
-
