@@ -17,10 +17,10 @@
 
 package org.apache.commons.beanutils.locale.converters;
 
-import java.util.Locale;
 import java.text.ParseException;
-import org.apache.commons.beanutils.ConversionException;
+import java.util.Locale;
 
+import org.apache.commons.beanutils.ConversionException;
 
 /**
  * <p>Standard {@link org.apache.commons.beanutils.locale.LocaleConverter}
@@ -30,13 +30,10 @@ import org.apache.commons.beanutils.ConversionException;
  * {@link org.apache.commons.beanutils.ConversionException}
  * if a conversion error occurs.</p>
  *
- * @version $Id$
  */
 
 public class ShortLocaleConverter extends DecimalLocaleConverter {
 
-    // ----------------------------------------------------------- Constructors
-
     /**
      * Create a {@link org.apache.commons.beanutils.locale.LocaleConverter}
      * that will throw a {@link org.apache.commons.beanutils.ConversionException}
@@ -206,7 +203,6 @@ public class ShortLocaleConverter extends DecimalLocaleConverter {
      * @param value The input object to be converted
      * @param pattern The pattern is used for the convertion
      * @return The converted value
-     *
      * @throws org.apache.commons.beanutils.ConversionException if conversion cannot be performed
      *  successfully
      * @throws ParseException if an error occurs parsing a String to a Number
@@ -227,7 +223,7 @@ public class ShortLocaleConverter extends DecimalLocaleConverter {
         }
 
         // now returns property Short
-        return new Short(parsed.shortValue());
+        return Short.valueOf(parsed.shortValue());
     }
 
 }
