@@ -15,7 +15,6 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
 import java.io.OutputStream;
@@ -23,11 +22,10 @@ import java.io.OutputStream;
 /**
  * <p>Class used in MethodUtils test</p>
  *
- * @version $Id$
  */
 public class A {
 
-    boolean called = false;
+    boolean called;
 
     public void foo(final OutputStream os)
     {
