@@ -15,45 +15,30 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
-
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
-
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import junit.framework.TestCase;
 import junit.framework.Test;
+import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-
 /**
  * <p>Test Case for the <code>BasicDynaBean</code> implementation class.
  * These tests were based on the ones in <code>PropertyUtilsTestCase</code>
  * because the two classes provide similar levels of functionality.</p>
  *
- * @version $Id$
  */
 
 public class BasicDynaBeanTestCase extends TestCase {
 
-
-    // ---------------------------------------------------- Instance Variables
-
-
-    /**
-     * The basic test bean for each test.
-     */
-    protected DynaBean bean = null;
-
-
     /**
      * The set of property names we expect to have returned when calling
      * <code>getDynaProperties()</code>.  You should update this list
@@ -78,9 +63,19 @@ public class BasicDynaBeanTestCase extends TestCase {
         "stringProperty",
     };
 
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
 
-    // ---------------------------------------------------------- Constructors
+        return new TestSuite(BasicDynaBeanTestCase.class);
 
+    }
+
+    /**
+     * The basic test bean for each test.
+     */
+    protected DynaBean bean;
 
     /**
      * Construct a new instance of this test case.
@@ -93,9 +88,37 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
+    /**
+     * Create and return a <code>DynaClass</code> instance for our test
+     * <code>DynaBean</code>.
+     */
+    protected DynaClass createDynaClass() {
 
-    // -------------------------------------------------- Overall Test Methods
+        final int intArray[] = {};
+        final String stringArray[] = {};
 
+        return new BasicDynaClass
+                ("TestDynaClass", null,
+                        new DynaProperty[]{
+                            new DynaProperty("booleanProperty", Boolean.TYPE),
+                            new DynaProperty("booleanSecond", Boolean.TYPE),
+                            new DynaProperty("doubleProperty", Double.TYPE),
+                            new DynaProperty("floatProperty", Float.TYPE),
+                            new DynaProperty("intArray", intArray.getClass()),
+                            new DynaProperty("intIndexed", intArray.getClass()),
+                            new DynaProperty("intProperty", Integer.TYPE),
+                            new DynaProperty("listIndexed", List.class),
+                            new DynaProperty("longProperty", Long.TYPE),
+                            new DynaProperty("mappedProperty", Map.class),
+                            new DynaProperty("mappedIntProperty", Map.class),
+                            new DynaProperty("nullProperty", String.class),
+                            new DynaProperty("shortProperty", Short.TYPE),
+                            new DynaProperty("stringArray", stringArray.getClass()),
+                            new DynaProperty("stringIndexed", stringArray.getClass()),
+                            new DynaProperty("stringProperty", String.class),
+                        });
+
+    }
 
     /**
      * Set up instance variables required by this test case.
@@ -108,33 +131,33 @@ public class BasicDynaBeanTestCase extends TestCase {
         bean = dynaClass.newInstance();
 
         // Initialize the DynaBean's property values (like TestBean)
-        bean.set("booleanProperty", new Boolean(true));
-        bean.set("booleanSecond", new Boolean(true));
-        bean.set("doubleProperty", new Double(321.0));
-        bean.set("floatProperty", new Float((float) 123.0));
+        bean.set("booleanProperty", Boolean.valueOf(true));
+        bean.set("booleanSecond", Boolean.valueOf(true));
+        bean.set("doubleProperty", Double.valueOf(321.0));
+        bean.set("floatProperty", Float.valueOf((float) 123.0));
         final int intArray[] = { 0, 10, 20, 30, 40 };
         bean.set("intArray", intArray);
         final int intIndexed[] = { 0, 10, 20, 30, 40 };
         bean.set("intIndexed", intIndexed);
-        bean.set("intProperty", new Integer(123));
-        final List<String> listIndexed = new ArrayList<String>();
+        bean.set("intProperty", Integer.valueOf(123));
+        final List<String> listIndexed = new ArrayList<>();
         listIndexed.add("String 0");
         listIndexed.add("String 1");
         listIndexed.add("String 2");
         listIndexed.add("String 3");
         listIndexed.add("String 4");
         bean.set("listIndexed", listIndexed);
-        bean.set("longProperty", new Long(321));
-        final HashMap<String, String> mappedProperty = new HashMap<String, String>();
+        bean.set("longProperty", Long.valueOf(321));
+        final HashMap<String, String> mappedProperty = new HashMap<>();
         mappedProperty.put("First Key", "First Value");
         mappedProperty.put("Second Key", "Second Value");
         bean.set("mappedProperty", mappedProperty);
-        final HashMap<String, Integer> mappedIntProperty = new HashMap<String, Integer>();
-        mappedIntProperty.put("One", new Integer(1));
-        mappedIntProperty.put("Two", new Integer(2));
+        final HashMap<String, Integer> mappedIntProperty = new HashMap<>();
+        mappedIntProperty.put("One", Integer.valueOf(1));
+        mappedIntProperty.put("Two", Integer.valueOf(2));
         bean.set("mappedIntProperty", mappedIntProperty);
         // Property "nullProperty" is not initialized, so it should return null
-        bean.set("shortProperty", new Short((short) 987));
+        bean.set("shortProperty", Short.valueOf((short) 987));
         final String stringArray[] =
                 { "String 0", "String 1", "String 2", "String 3", "String 4" };
         bean.set("stringArray", stringArray);
@@ -145,17 +168,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-
-        return (new TestSuite(BasicDynaBeanTestCase.class));
-
-    }
-
-
     /**
      * Tear down instance variables required by this test case.
      */
@@ -166,11 +178,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
-
-    // ------------------------------------------------ Individual Test Methods
-
-
     /**
      * Corner cases on getDynaProperty invalid arguments.
      */
@@ -196,6 +203,24 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
+    /**
+     * Base for testGetDescriptorXxxxx() series of tests.
+     *
+     * @param name Name of the property to be retrieved
+     * @param type Expected class type of this property
+     */
+    protected void testGetDescriptorBase(final String name, final Class<?> type) {
+
+        try {
+            final DynaProperty descriptor =
+                    bean.getDynaClass().getDynaProperty(name);
+            assertNotNull("Got descriptor", descriptor);
+            assertEquals("Got correct type", type, descriptor.getType());
+        } catch (final Throwable t) {
+            fail("Threw an exception: " + t);
+        }
+
+    }
 
     /**
      * Positive getDynaProperty on property <code>booleanProperty</code>.
@@ -206,7 +231,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive getDynaProperty on property <code>doubleProperty</code>.
      */
@@ -216,7 +240,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive getDynaProperty on property <code>floatProperty</code>.
      */
@@ -226,7 +249,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive getDynaProperty on property <code>intProperty</code>.
      */
@@ -236,7 +258,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive getDynaProperty on property <code>longProperty</code>.
      */
@@ -246,38 +267,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
-    /**
-     * Positive getDynaProperty on property <code>booleanSecond</code>
-     * that uses an "is" method as the getter.
-     */
-    public void testGetDescriptorSecond() {
-
-        testGetDescriptorBase("booleanSecond", Boolean.TYPE);
-
-    }
-
-
-    /**
-     * Positive getDynaProperty on property <code>shortProperty</code>.
-     */
-    public void testGetDescriptorShort() {
-
-        testGetDescriptorBase("shortProperty", Short.TYPE);
-
-    }
-
-
-    /**
-     * Positive getDynaProperty on property <code>stringProperty</code>.
-     */
-    public void testGetDescriptorString() {
-
-        testGetDescriptorBase("stringProperty", String.class);
-
-    }
-
-
     /**
      * Positive test for getDynaPropertys().  Each property name
      * listed in <code>properties</code> should be returned exactly once.
@@ -287,7 +276,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         final DynaProperty pd[] = bean.getDynaClass().getDynaProperties();
         assertNotNull("Got descriptors", pd);
         final int count[] = new int[properties.length];
-        for (DynaProperty element : pd) {
+        for (final DynaProperty element : pd) {
             final String name = element.getName();
             for (int j = 0; j < properties.length; j++) {
                 if (name.equals(properties[j])) {
@@ -305,6 +294,33 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
+    /**
+     * Positive getDynaProperty on property <code>booleanSecond</code>
+     * that uses an "is" method as the getter.
+     */
+    public void testGetDescriptorSecond() {
+
+        testGetDescriptorBase("booleanSecond", Boolean.TYPE);
+
+    }
+
+    /**
+     * Positive getDynaProperty on property <code>shortProperty</code>.
+     */
+    public void testGetDescriptorShort() {
+
+        testGetDescriptorBase("shortProperty", Short.TYPE);
+
+    }
+
+    /**
+     * Positive getDynaProperty on property <code>stringProperty</code>.
+     */
+    public void testGetDescriptorString() {
+
+        testGetDescriptorBase("stringProperty", String.class);
+
+    }
 
     /**
      * Corner cases on getIndexedProperty invalid arguments.
@@ -320,10 +336,8 @@ public class BasicDynaBeanTestCase extends TestCase {
             fail("Threw " + t + " instead of IndexOutOfBoundsException");
         }
 
-
     }
 
-
     /**
      * Positive and negative tests on getIndexedProperty valid arguments.
      */
@@ -390,16 +404,13 @@ public class BasicDynaBeanTestCase extends TestCase {
 
         }
 
-
     }
 
-
     /**
      * Corner cases on getMappedProperty invalid arguments.
      */
     public void testGetMappedArguments() {
 
-
         try {
             final Object value = bean.get("mappedProperty", "unknown");
             assertNull("Should not return a value", value);
@@ -407,10 +418,8 @@ public class BasicDynaBeanTestCase extends TestCase {
             fail("Threw " + t + " instead of returning null");
         }
 
-
     }
 
-
     /**
      * Positive and negative tests on getMappedProperty valid arguments.
      */
@@ -441,7 +450,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Corner cases on getSimpleProperty invalid arguments.
      */
@@ -458,7 +466,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test getSimpleProperty on a boolean property.
      */
@@ -467,16 +474,15 @@ public class BasicDynaBeanTestCase extends TestCase {
         try {
             final Object value = bean.get("booleanProperty");
             assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Boolean));
+            assertTrue("Got correct type", value instanceof Boolean);
             assertTrue("Got correct value",
-                    ((Boolean) value).booleanValue() == true);
+                    ((Boolean) value).booleanValue());
         } catch (final Throwable e) {
             fail("Exception: " + e);
         }
 
     }
 
-
     /**
      * Test getSimpleProperty on a double property.
      */
@@ -485,7 +491,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         try {
             final Object value = bean.get("doubleProperty");
             assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Double));
+            assertTrue("Got correct type", value instanceof Double);
             assertEquals("Got correct value",
                     ((Double) value).doubleValue(),
                     321.0, 0.005);
@@ -495,7 +501,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test getSimpleProperty on a float property.
      */
@@ -504,7 +509,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         try {
             final Object value = bean.get("floatProperty");
             assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Float));
+            assertTrue("Got correct type", value instanceof Float);
             assertEquals("Got correct value",
                     ((Float) value).floatValue(),
                     (float) 123.0,
@@ -515,7 +520,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test getSimpleProperty on a int property.
      */
@@ -524,7 +528,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         try {
             final Object value = bean.get("intProperty");
             assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Integer));
+            assertTrue("Got correct type", value instanceof Integer);
             assertEquals("Got correct value",
                     ((Integer) value).intValue(),
                     123);
@@ -534,7 +538,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test getSimpleProperty on a long property.
      */
@@ -543,7 +546,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         try {
             final Object value = bean.get("longProperty");
             assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Long));
+            assertTrue("Got correct type", value instanceof Long);
             assertEquals("Got correct value",
                     ((Long) value).longValue(),
                     321);
@@ -553,7 +556,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test getSimpleProperty on a short property.
      */
@@ -562,7 +564,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         try {
             final Object value = bean.get("shortProperty");
             assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof Short));
+            assertTrue("Got correct type", value instanceof Short);
             assertEquals("Got correct value",
                     ((Short) value).shortValue(),
                     (short) 987);
@@ -572,7 +574,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test getSimpleProperty on a String property.
      */
@@ -581,7 +582,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         try {
             final Object value = bean.get("stringProperty");
             assertNotNull("Got a value", value);
-            assertTrue("Got correct type", (value instanceof String));
+            assertTrue("Got correct type", value instanceof String);
             assertEquals("Got correct value",
                     (String) value,
                     "This is a string");
@@ -591,7 +592,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test <code>contains()</code> method for mapped properties.
      */
@@ -604,7 +604,6 @@ public class BasicDynaBeanTestCase extends TestCase {
             fail("Exception: " + t);
         }
 
-
         try {
             assertTrue("Can not see unknown key",
                     !bean.contains("mappedProperty", "Unknown Key"));
@@ -614,7 +613,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test <code>remove()</code> method for mapped properties.
      */
@@ -642,7 +640,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test serialization and deserialization.
      */
@@ -716,14 +713,13 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Corner cases on setIndexedProperty invalid arguments.
      */
     public void testSetIndexedArguments() {
 
         try {
-            bean.set("intArray", -1, new Integer(0));
+            bean.set("intArray", -1, Integer.valueOf(0));
             fail("Should throw IndexOutOfBoundsException");
         } catch (final IndexOutOfBoundsException e) {
             // Expected response
@@ -733,7 +729,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive and negative tests on setIndexedProperty valid arguments.
      */
@@ -742,7 +737,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         Object value = null;
 
         try {
-            bean.set("intArray", 0, new Integer(1));
+            bean.set("intArray", 0, Integer.valueOf(1));
             value = bean.get("intArray", 0);
             assertNotNull("Returned new value 0", value);
             assertTrue("Returned Integer new value 0",
@@ -754,7 +749,7 @@ public class BasicDynaBeanTestCase extends TestCase {
         }
 
         try {
-            bean.set("intIndexed", 1, new Integer(11));
+            bean.set("intIndexed", 1, Integer.valueOf(11));
             value = bean.get("intIndexed", 1);
             assertNotNull("Returned new value 1", value);
             assertTrue("Returned Integer new value 1",
@@ -801,10 +796,8 @@ public class BasicDynaBeanTestCase extends TestCase {
             fail("Threw " + t);
         }
 
-
     }
 
-
     /**
      * Positive and negative tests on setMappedProperty valid arguments.
      */
@@ -828,10 +821,8 @@ public class BasicDynaBeanTestCase extends TestCase {
             fail("Finding fourth value threw " + t);
         }
 
-
     }
 
-
     /**
      * Test setSimpleProperty on a boolean property.
      */
@@ -841,7 +832,7 @@ public class BasicDynaBeanTestCase extends TestCase {
             final boolean oldValue =
                     ((Boolean) bean.get("booleanProperty")).booleanValue();
             final boolean newValue = !oldValue;
-            bean.set("booleanProperty", new Boolean(newValue));
+            bean.set("booleanProperty", Boolean.valueOf(newValue));
             assertTrue("Matched new value",
                     newValue ==
                     ((Boolean) bean.get("booleanProperty")).booleanValue());
@@ -851,7 +842,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test setSimpleProperty on a double property.
      */
@@ -861,7 +851,7 @@ public class BasicDynaBeanTestCase extends TestCase {
             final double oldValue =
                     ((Double) bean.get("doubleProperty")).doubleValue();
             final double newValue = oldValue + 1.0;
-            bean.set("doubleProperty", new Double(newValue));
+            bean.set("doubleProperty", Double.valueOf(newValue));
             assertEquals("Matched new value",
                     newValue,
                     ((Double) bean.get("doubleProperty")).doubleValue(),
@@ -872,7 +862,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test setSimpleProperty on a float property.
      */
@@ -882,7 +871,7 @@ public class BasicDynaBeanTestCase extends TestCase {
             final float oldValue =
                     ((Float) bean.get("floatProperty")).floatValue();
             final float newValue = oldValue + (float) 1.0;
-            bean.set("floatProperty", new Float(newValue));
+            bean.set("floatProperty", Float.valueOf(newValue));
             assertEquals("Matched new value",
                     newValue,
                     ((Float) bean.get("floatProperty")).floatValue(),
@@ -893,7 +882,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test setSimpleProperty on a int property.
      */
@@ -903,7 +891,7 @@ public class BasicDynaBeanTestCase extends TestCase {
             final int oldValue =
                     ((Integer) bean.get("intProperty")).intValue();
             final int newValue = oldValue + 1;
-            bean.set("intProperty", new Integer(newValue));
+            bean.set("intProperty", Integer.valueOf(newValue));
             assertEquals("Matched new value",
                     newValue,
                     ((Integer) bean.get("intProperty")).intValue());
@@ -913,7 +901,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test setSimpleProperty on a long property.
      */
@@ -923,7 +910,7 @@ public class BasicDynaBeanTestCase extends TestCase {
             final long oldValue =
                     ((Long) bean.get("longProperty")).longValue();
             final long newValue = oldValue + 1;
-            bean.set("longProperty", new Long(newValue));
+            bean.set("longProperty", Long.valueOf(newValue));
             assertEquals("Matched new value",
                     newValue,
                     ((Long) bean.get("longProperty")).longValue());
@@ -933,7 +920,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test setSimpleProperty on a short property.
      */
@@ -943,7 +929,7 @@ public class BasicDynaBeanTestCase extends TestCase {
             final short oldValue =
                     ((Short) bean.get("shortProperty")).shortValue();
             final short newValue = (short) (oldValue + 1);
-            bean.set("shortProperty", new Short(newValue));
+            bean.set("shortProperty", Short.valueOf(newValue));
             assertEquals("Matched new value",
                     newValue,
                     ((Short) bean.get("shortProperty")).shortValue());
@@ -953,7 +939,6 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
     /**
      * Test setSimpleProperty on a String property.
      */
@@ -972,62 +957,4 @@ public class BasicDynaBeanTestCase extends TestCase {
 
     }
 
-
-    // ------------------------------------------------------ Protected Methods
-
-
-    /**
-     * Create and return a <code>DynaClass</code> instance for our test
-     * <code>DynaBean</code>.
-     */
-    protected DynaClass createDynaClass() {
-
-        final int intArray[] = new int[0];
-        final String stringArray[] = new String[0];
-
-        final DynaClass dynaClass = new BasicDynaClass
-                ("TestDynaClass", null,
-                        new DynaProperty[]{
-                            new DynaProperty("booleanProperty", Boolean.TYPE),
-                            new DynaProperty("booleanSecond", Boolean.TYPE),
-                            new DynaProperty("doubleProperty", Double.TYPE),
-                            new DynaProperty("floatProperty", Float.TYPE),
-                            new DynaProperty("intArray", intArray.getClass()),
-                            new DynaProperty("intIndexed", intArray.getClass()),
-                            new DynaProperty("intProperty", Integer.TYPE),
-                            new DynaProperty("listIndexed", List.class),
-                            new DynaProperty("longProperty", Long.TYPE),
-                            new DynaProperty("mappedProperty", Map.class),
-                            new DynaProperty("mappedIntProperty", Map.class),
-                            new DynaProperty("nullProperty", String.class),
-                            new DynaProperty("shortProperty", Short.TYPE),
-                            new DynaProperty("stringArray", stringArray.getClass()),
-                            new DynaProperty("stringIndexed", stringArray.getClass()),
-                            new DynaProperty("stringProperty", String.class),
-                        });
-        return (dynaClass);
-
-    }
-
-
-    /**
-     * Base for testGetDescriptorXxxxx() series of tests.
-     *
-     * @param name Name of the property to be retrieved
-     * @param type Expected class type of this property
-     */
-    protected void testGetDescriptorBase(final String name, final Class<?> type) {
-
-        try {
-            final DynaProperty descriptor =
-                    bean.getDynaClass().getDynaProperty(name);
-            assertNotNull("Got descriptor", descriptor);
-            assertEquals("Got correct type", type, descriptor.getType());
-        } catch (final Throwable t) {
-            fail("Threw an exception: " + t);
-        }
-
-    }
-
-
 }
