@@ -22,11 +22,15 @@ import junit.framework.TestSuite;
 /**
  * Test Case for the {@link BeanUtilsBean2}.
  *
- * @version $Id$
  */
 public class BeanUtils2TestCase extends BeanUtilsTestCase {
 
-    // ---------------------------------------------------------- Constructors
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
+        return new TestSuite(BeanUtils2TestCase.class);
+    }
 
     /**
      * Construct a new instance of this test case.
@@ -37,10 +41,6 @@ public class BeanUtils2TestCase extends BeanUtilsTestCase {
         super(name);
     }
 
-
-    // -------------------------------------------------- Overall Test Methods
-
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -51,14 +51,6 @@ public class BeanUtils2TestCase extends BeanUtilsTestCase {
         setUpShared();
     }
 
-
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-        return (new TestSuite(BeanUtils2TestCase.class));
-    }
-
     /**
      * Tear down instance variables required by this test case.
      */
