@@ -15,10 +15,8 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
-
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
@@ -27,18 +25,40 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-
 /**
  * JUnit Test Case containing microbenchmarks for BeanUtils.
  *
- * @version $Id$
  */
 
 public class BeanUtilsBenchCase extends TestCase {
 
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
 
-    // ------------------------------------------------------------ Constructors
+        return new TestSuite(BeanUtilsBenchCase.class);
 
+    }
+
+    // Basic loop counter
+    private long counter = 100000;
+
+    // DynaClass for inDyna and outDyna
+    private DynaClass dynaClass;
+
+    // Input objects that have identical sets of properties and values.
+    private BenchBean inBean;
+    private DynaBean inDyna;
+    private Map<String, Object> inMap;  // Map of Objects requiring no conversion
+    private Map<String, String> inStrs; // Map of Strings requiring conversion
+
+    // Output objects that have identical sets of properties.
+    private BenchBean outBean;
+    private DynaBean outDyna;
+
+    // BeanUtilsBean instance to be used
+    private BeanUtilsBean bu;
 
     /**
      * Construct a new instance of this test case.
@@ -51,33 +71,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
-    // ------------------------------------------------------ Instance Variables
-
-
-    // Basic loop counter
-    private long counter = 100000;
-
-    // DynaClass for inDyna and outDyna
-    private DynaClass dynaClass = null;
-
-    // Input objects that have identical sets of properties and values.
-    private BenchBean inBean = null;
-    private DynaBean inDyna = null;
-    private Map<String, Object> inMap = null;  // Map of Objects requiring no conversion
-    private Map<String, String> inStrs = null; // Map of Strings requiring conversion
-
-    // Output objects that have identical sets of properties.
-    private BenchBean outBean = null;
-    private DynaBean outDyna = null;
-
-    // BeanUtilsBean instance to be used
-    private BeanUtilsBean bu = null;
-
-
-    // ---------------------------------------------------- Overall Test Methods
-
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -106,14 +99,14 @@ public class BeanUtilsBenchCase extends TestCase {
 
         // Create input instances
         inBean = new BenchBean();
-        inMap = new HashMap<String, Object>();
-        inMap.put("booleanProperty", new Boolean(inBean.getBooleanProperty()));
-        inMap.put("byteProperty", new Byte(inBean.getByteProperty()));
-        inMap.put("doubleProperty", new Double(inBean.getDoubleProperty()));
-        inMap.put("floatProperty", new Float(inBean.getFloatProperty()));
-        inMap.put("intProperty", new Integer(inBean.getIntProperty()));
-        inMap.put("longProperty", new Long(inBean.getLongProperty()));
-        inMap.put("shortProperty", new Short(inBean.getShortProperty()));
+        inMap = new HashMap<>();
+        inMap.put("booleanProperty", Boolean.valueOf(inBean.getBooleanProperty()));
+        inMap.put("byteProperty", Byte.valueOf(inBean.getByteProperty()));
+        inMap.put("doubleProperty", Double.valueOf(inBean.getDoubleProperty()));
+        inMap.put("floatProperty", Float.valueOf(inBean.getFloatProperty()));
+        inMap.put("intProperty", Integer.valueOf(inBean.getIntProperty()));
+        inMap.put("longProperty", Long.valueOf(inBean.getLongProperty()));
+        inMap.put("shortProperty", Short.valueOf(inBean.getShortProperty()));
         inMap.put("stringProperty", inBean.getStringProperty());
         inDyna = dynaClass.newInstance();
         Iterator<String> inKeys = inMap.keySet().iterator();
@@ -121,7 +114,7 @@ public class BeanUtilsBenchCase extends TestCase {
             final String inKey = inKeys.next();
             inDyna.set(inKey, inMap.get(inKey));
         }
-        inStrs = new HashMap<String, String>();
+        inStrs = new HashMap<>();
         inKeys = inMap.keySet().iterator();
         while (inKeys.hasNext()) {
             final String inKey = inKeys.next();
@@ -131,9 +124,7 @@ public class BeanUtilsBenchCase extends TestCase {
         // Create output instances
         outBean = new BenchBean();
         outDyna = dynaClass.newInstance();
-        final Iterator<String> outKeys = inMap.keySet().iterator();
-        while (outKeys.hasNext()) {
-            final String outKey = outKeys.next();
+        for (final String outKey : inMap.keySet()) {
             outDyna.set(outKey, inMap.get(outKey));
         }
 
@@ -142,17 +133,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-
-        return (new TestSuite(BeanUtilsBenchCase.class));
-
-    }
-
-
     /**
      * Tear down instance variables required by this test case.
      */
@@ -169,11 +149,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
-
-    // ------------------------------------------------- Individual Test Methods
-
-
     // Time copyProperties() from a bean
     public void testCopyPropertiesBean() throws Exception {
 
@@ -206,7 +181,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
     // Time copyProperties() from a DynaBean
     public void testCopyPropertiesDyna() throws Exception {
 
@@ -239,7 +213,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
     // Time copyProperties() from a Map of Objects
     public void testCopyPropertiesMap() throws Exception {
 
@@ -272,7 +245,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
     // Time copyProperties() from a Map of Strings
     public void testCopyPropertiesStrs() throws Exception {
 
@@ -305,7 +277,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
     // Time populate() from a Map of Objects
     public void testPopulateMap() throws Exception {
 
@@ -338,7 +309,6 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
     // Time populate() from a Map of Strings
     // NOTE - This simulates what Struts does when processing form beans
     public void testPopulateStrs() throws Exception {
@@ -372,8 +342,4 @@ public class BeanUtilsBenchCase extends TestCase {
 
     }
 
-
-    // --------------------------------------------------------- Support Methods
-
-
 }
