@@ -15,13 +15,11 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
 /**
- * @version $Id$
  */
 public interface Child {
 
-    public String getName();
+    String getName();
 }
