@@ -15,10 +15,8 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
-
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;
 
@@ -26,15 +24,18 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-
 /**
  * <p> Test case for <code>ConstructorUtils</code> </p>
  *
- * @version $Id$
  */
 public class ConstructorUtilsTestCase extends TestCase {
 
-    // ---------------------------------------------------------- Constructors
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
+        return new TestSuite(ConstructorUtilsTestCase.class);
+    }
 
     /**
      * Construct a new instance of this test case.
@@ -45,10 +46,6 @@ public class ConstructorUtilsTestCase extends TestCase {
         super(name);
     }
 
-
-    // -------------------------------------------------- Overall Test Methods
-
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -57,14 +54,6 @@ public class ConstructorUtilsTestCase extends TestCase {
         super.setUp();
     }
 
-
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-        return (new TestSuite(ConstructorUtilsTestCase.class));
-    }
-
     /**
      * Tear down instance variables required by this test case.
      */
@@ -73,8 +62,59 @@ public class ConstructorUtilsTestCase extends TestCase {
         super.tearDown();
     }
 
+    public void testGetAccessibleConstructor() throws Exception {
+        {
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,String.class);
+            assertNotNull(ctor);
+            assertTrue(Modifier.isPublic(ctor.getModifiers()));
+        }
+        {
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,Integer.class);
+            assertNotNull(ctor);
+            assertTrue(Modifier.isPublic(ctor.getModifiers()));
+        }
+        {
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,Integer.TYPE);
+            assertNull(ctor);
+        }
+    }
 
-    // ------------------------------------------------ Individual Test Methods
+    public void testGetAccessibleConstructorWithConstructorArg() throws Exception {
+        {
+            final Class<?>[] types = { Integer.class };
+            final Constructor<?> c1 = TestBean.class.getConstructor(types);
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(c1);
+            assertNotNull(ctor);
+            assertTrue(Modifier.isPublic(ctor.getModifiers()));
+        }
+        {
+            final Class<?>[] types = { Integer.class };
+            final Constructor<?> c1 = TestBean.class.getDeclaredConstructor(types);
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(c1);
+            assertNotNull(ctor);
+            assertTrue(Modifier.isPublic(ctor.getModifiers()));
+        }
+        {
+            final Class<?>[] types = { Integer.TYPE };
+            final Constructor<?> c1 = TestBean.class.getDeclaredConstructor(types);
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(c1);
+            assertNull(ctor);
+        }
+    }
+
+    public void testGetAccessibleConstructorWithTypeArray() throws Exception {
+        {
+            final Class<?>[] types = { Boolean.TYPE, String.class };
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,types);
+            assertNotNull(ctor);
+            assertTrue(Modifier.isPublic(ctor.getModifiers()));
+        }
+        {
+            final Class<?>[] types = { Boolean.TYPE, Boolean.TYPE, String.class };
+            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,types);
+            assertNull(ctor);
+        }
+    }
 
     public void testInvokeConstructor() throws Exception {
         {
@@ -84,7 +124,7 @@ public class ConstructorUtilsTestCase extends TestCase {
             assertEquals("TEST",((TestBean)obj).getStringProperty());
         }
         {
-            final Object obj = ConstructorUtils.invokeConstructor(TestBean.class,new Float(17.3f));
+            final Object obj = ConstructorUtils.invokeConstructor(TestBean.class,Float.valueOf(17.3f));
             assertNotNull(obj);
             assertTrue(obj instanceof TestBean);
             assertEquals(17.3f,((TestBean)obj).getFloatProperty(),0.0f);
@@ -98,7 +138,7 @@ public class ConstructorUtilsTestCase extends TestCase {
     }
 
     public void testInvokeConstructorWithArgArray() throws Exception {
-        final Object[] args = { new Float(17.3f), "TEST" };
+        final Object[] args = { Float.valueOf(17.3f), "TEST" };
         final Object obj = ConstructorUtils.invokeConstructor(TestBean.class,args);
         assertNotNull(obj);
         assertTrue(obj instanceof TestBean);
@@ -136,7 +176,7 @@ public class ConstructorUtilsTestCase extends TestCase {
         }
         {
             try {
-                ConstructorUtils.invokeExactConstructor(TestBean.class,new Float(17.3f));
+                ConstructorUtils.invokeExactConstructor(TestBean.class,Float.valueOf(17.3f));
                 fail("Expected NoSuchMethodException");
             } catch(final NoSuchMethodException e) {
                 // expected
@@ -150,15 +190,9 @@ public class ConstructorUtilsTestCase extends TestCase {
         }
     }
 
-    public void testInvokeExactConstructorWithNull() throws Exception {
-        final Object obj = ConstructorUtils.invokeExactConstructor(TestBean.class, (Object) null);
-        assertNotNull(obj);
-        assertTrue(obj instanceof TestBean);
-    }
-
     public void testInvokeExactConstructorWithArgArray() throws Exception {
         {
-            final Object[] args = { new Float(17.3f), "TEST" };
+            final Object[] args = { Float.valueOf(17.3f), "TEST" };
             try {
                 ConstructorUtils.invokeExactConstructor(TestBean.class,args);
                 fail("Expected NoSuchMethodException");
@@ -176,6 +210,12 @@ public class ConstructorUtilsTestCase extends TestCase {
         }
     }
 
+    public void testInvokeExactConstructorWithNull() throws Exception {
+        final Object obj = ConstructorUtils.invokeExactConstructor(TestBean.class, (Object) null);
+        assertNotNull(obj);
+        assertTrue(obj instanceof TestBean);
+    }
+
     public void testInvokeExactConstructorWithTypeArray() throws Exception {
         {
             final Object[] args = { Boolean.TRUE, "TEST" };
@@ -196,7 +236,7 @@ public class ConstructorUtilsTestCase extends TestCase {
             assertEquals("TEST",((TestBean)obj).getStringProperty());
         }
         {
-            final Object[] args = { new Float(17.3f), "TEST" };
+            final Object[] args = { Float.valueOf(17.3f), "TEST" };
             final Class<?>[] types = { Float.TYPE, String.class };
             final Object obj = ConstructorUtils.invokeExactConstructor(TestBean.class,args,types);
             assertNotNull(obj);
@@ -205,7 +245,7 @@ public class ConstructorUtilsTestCase extends TestCase {
             assertEquals("TEST",((TestBean)obj).getStringProperty());
         }
         {
-            final Object[] args = { new Float(17.3f), "TEST" };
+            final Object[] args = { Float.valueOf(17.3f), "TEST" };
             final Class<?>[] types = { Float.class, String.class };
             try {
                 ConstructorUtils.invokeExactConstructor(TestBean.class,args,types);
@@ -216,58 +256,4 @@ public class ConstructorUtilsTestCase extends TestCase {
         }
     }
 
-    public void testGetAccessibleConstructor() throws Exception {
-        {
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,String.class);
-            assertNotNull(ctor);
-            assertTrue(Modifier.isPublic(ctor.getModifiers()));
-        }
-        {
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,Integer.class);
-            assertNotNull(ctor);
-            assertTrue(Modifier.isPublic(ctor.getModifiers()));
-        }
-        {
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,Integer.TYPE);
-            assertNull(ctor);
-        }
-    }
-
-    public void testGetAccessibleConstructorWithTypeArray() throws Exception {
-        {
-            final Class<?>[] types = { Boolean.TYPE, String.class };
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,types);
-            assertNotNull(ctor);
-            assertTrue(Modifier.isPublic(ctor.getModifiers()));
-        }
-        {
-            final Class<?>[] types = { Boolean.TYPE, Boolean.TYPE, String.class };
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(TestBean.class,types);
-            assertNull(ctor);
-        }
-    }
-
-    public void testGetAccessibleConstructorWithConstructorArg() throws Exception {
-        {
-            final Class<?>[] types = { Integer.class };
-            final Constructor<?> c1 = TestBean.class.getConstructor(types);
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(c1);
-            assertNotNull(ctor);
-            assertTrue(Modifier.isPublic(ctor.getModifiers()));
-        }
-        {
-            final Class<?>[] types = { Integer.class };
-            final Constructor<?> c1 = TestBean.class.getDeclaredConstructor(types);
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(c1);
-            assertNotNull(ctor);
-            assertTrue(Modifier.isPublic(ctor.getModifiers()));
-        }
-        {
-            final Class<?>[] types = { Integer.TYPE };
-            final Constructor<?> c1 = TestBean.class.getDeclaredConstructor(types);
-            final Constructor<?> ctor = ConstructorUtils.getAccessibleConstructor(c1);
-            assertNull(ctor);
-        }
-    }
-
 }
