@@ -17,7 +17,6 @@
 
 package org.apache.commons.beanutils;
 
-
 import java.sql.Date;
 import java.sql.Time;
 import java.sql.Timestamp;
@@ -25,28 +24,27 @@ import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 import java.util.Locale;
 
+import org.apache.commons.beanutils.converters.DateConverter;
+
 import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.beanutils.converters.DateConverter;
-
-
 /**
  * <p>
  *  Test Case for the ConvertUtils class.
  * </p>
  *
- * @version $Id$
  */
 
 public class ConvertUtilsTestCase extends TestCase {
 
-    // ---------------------------------------------------- Instance Variables
-
-
-    // ---------------------------------------------------------- Constructors
-
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
+        return new TestSuite(ConvertUtilsTestCase.class);
+    }
 
     /**
      * Construct a new instance of this test case.
@@ -57,9 +55,34 @@ public class ConvertUtilsTestCase extends TestCase {
         super(name);
     }
 
+    private void checkIntegerArray(final Object value, final int intArray[]) {
 
-    // -------------------------------------------------- Overall Test Methods
+        assertNotNull("Returned value is not null", value);
+        assertEquals("Returned value is int[]",
+                     intArray.getClass(), value.getClass());
+        final int results[] = (int[]) value;
+        assertEquals("Returned array length", intArray.length, results.length);
+        for (int i = 0; i < intArray.length; i++) {
+            assertEquals("Returned array value " + i,
+                         intArray[i], results[i]);
+        }
 
+    }
+
+    private void checkStringArray(final Object value, final String stringArray[]) {
+
+        assertNotNull("Returned value is not null", value);
+        assertEquals("Returned value is String[]",
+                     stringArray.getClass(), value.getClass());
+        final String results[] = (String[]) value;
+        assertEquals("Returned array length",
+                     stringArray.length, results.length);
+        for (int i = 0; i < stringArray.length; i++) {
+            assertEquals("Returned array value " + i,
+                         stringArray[i], results[i]);
+        }
+
+    }
 
     /**
      * Set up instance variables required by this test case.
@@ -71,15 +94,6 @@ public class ConvertUtilsTestCase extends TestCase {
 
     }
 
-
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-        return (new TestSuite(ConvertUtilsTestCase.class));
-    }
-
-
     /**
      * Tear down instance variables required by this test case.
      */
@@ -88,9 +102,79 @@ public class ConvertUtilsTestCase extends TestCase {
         // No action required
     }
 
+    @SuppressWarnings({ "unchecked", "rawtypes" })
+    // We need to use raw types in order to test legacy converters
+    public void testConvertToString() throws Exception {
+        final Converter dummyConverter = new Converter() {
+            @Override
+            public Object convert(final Class type, final Object value) {
+                return value;
+            }
+        };
 
-    // ------------------------------------------------ Individual Test Methods
+        final Converter fooConverter = new Converter() {
+            @Override
+            public Object convert(final Class type, final Object value) {
+                return "Foo-Converter";
+            }
+        };
 
+        final DateConverter dateConverter = new DateConverter();
+        dateConverter.setLocale(Locale.US);
+
+        final ConvertUtilsBean utils = new ConvertUtilsBean();
+        utils.register(dateConverter, java.util.Date.class);
+        utils.register(fooConverter, String.class);
+
+        // Convert using registerd DateConverter
+        final java.util.Date today = new java.util.Date();
+        final DateFormat fmt = new SimpleDateFormat("M/d/yy"); /* US Short Format */
+        final String expected = fmt.format(today);
+        assertEquals("DateConverter M/d/yy", expected, utils.convert(today, String.class));
+
+        // Date converter doesn't do String conversion - use String Converter
+        utils.register(dummyConverter, java.util.Date.class);
+        assertEquals("Date Converter doesn't do String conversion", "Foo-Converter", utils.convert(today, String.class));
+
+        // No registered Date converter - use String Converter
+        utils.deregister(java.util.Date.class);
+        assertEquals("No registered Date converter", "Foo-Converter", utils.convert(today, String.class));
+
+        // String Converter doesn't do Strings!!!
+        utils.register(dummyConverter, String.class);
+        assertEquals("String Converter doesn't do Strings!!!", today.toString(), utils.convert(today, String.class));
+
+        // No registered Date or String converter - use Object's toString()
+        utils.deregister(String.class);
+        assertEquals("Object's toString()", today.toString(), utils.convert(today, String.class));
+
+    }
+
+    /**
+     * Tests a conversion to an unsupported target type.
+     */
+    public void testConvertUnsupportedTargetType() {
+        final ConvertUtilsBean utils = new ConvertUtilsBean();
+        final Object value = "A test value";
+        assertSame("Got different object", value,
+                utils.convert(value, getClass()));
+    }
+
+    public void testDeregisteringSingleConverter() throws Exception {
+        // make sure that the test work ok before anything's changed
+        final Object
+        value = ConvertUtils.convert("true", Boolean.TYPE);
+        assertTrue(value instanceof Boolean);
+        assertEquals(
+                    "Standard conversion failed (1)",
+                    ((Boolean) value).booleanValue(),
+                    true);
+
+        // we'll test deregister
+        ConvertUtils.deregister(Boolean.TYPE);
+        assertNull("Converter should be null",ConvertUtils.lookup(Boolean.TYPE));
+
+    }
 
     /**
      * Negative String to primitive integer array tests.
@@ -98,7 +182,7 @@ public class ConvertUtilsTestCase extends TestCase {
     public void testNegativeIntegerArray() {
 
         Object value = null;
-        final int intArray[] = new int[0];
+        final int intArray[] = {};
 
         value = ConvertUtils.convert((String) null, intArray.getClass());
         checkIntegerArray(value, intArray);
@@ -115,10 +199,8 @@ public class ConvertUtilsTestCase extends TestCase {
         value = ConvertUtils.convert("{ 0, 1a3 }", intArray.getClass());
         checkIntegerArray(value, intArray);
 
-
     }
 
-
     /**
      * Negative scalar conversion tests.  These rely on the standard
      * default value conversions in ConvertUtils.
@@ -196,30 +278,28 @@ public class ConvertUtilsTestCase extends TestCase {
 
     }
 
-
     /**
      * Negative String to String array tests.
      */
     public void testNegativeStringArray() {
 
         Object value = null;
-        final String stringArray[] = new String[0];
+        final String stringArray[] = {};
 
         value = ConvertUtils.convert((String) null, stringArray.getClass());
         checkStringArray(value, stringArray);
 
     }
 
-
     /**
      * Test conversion of object to string for arrays.
      */
     public void testObjectToStringArray() {
 
-        final int intArray0[] = new int[0];
+        final int intArray0[] = {};
         final int intArray1[] = { 123 };
         final int intArray2[] = { 123, 456 };
-        final String stringArray0[] = new String[0];
+        final String stringArray0[] = {};
         final String stringArray1[] = { "abc" };
         final String stringArray2[] = { "abc", "def" };
 
@@ -239,7 +319,6 @@ public class ConvertUtilsTestCase extends TestCase {
 
     }
 
-
     /**
      * Test conversion of object to string for scalars.
      */
@@ -250,19 +329,19 @@ public class ConvertUtilsTestCase extends TestCase {
         assertEquals("Boolean->String", "true",
                      ConvertUtils.convert(Boolean.TRUE));
         assertEquals("Byte->String", "123",
-                     ConvertUtils.convert(new Byte((byte) 123)));
+                     ConvertUtils.convert(Byte.valueOf((byte) 123)));
         assertEquals("Character->String", "a",
-                     ConvertUtils.convert(new Character('a')));
+                     ConvertUtils.convert(Character.valueOf('a')));
         assertEquals("Double->String", "123.0",
-                     ConvertUtils.convert(new Double(123.0)));
+                     ConvertUtils.convert(Double.valueOf(123.0)));
         assertEquals("Float->String", "123.0",
-                     ConvertUtils.convert(new Float((float) 123.0)));
+                     ConvertUtils.convert(Float.valueOf((float) 123.0)));
         assertEquals("Integer->String", "123",
-                     ConvertUtils.convert(new Integer(123)));
+                     ConvertUtils.convert(Integer.valueOf(123)));
         assertEquals("Long->String", "123",
-                     ConvertUtils.convert(new Long(123)));
+                     ConvertUtils.convert(Long.valueOf(123)));
         assertEquals("Short->String", "123",
-                     ConvertUtils.convert(new Short((short) 123)));
+                     ConvertUtils.convert(Short.valueOf((short) 123)));
         assertEquals("String->String", "abc",
                      ConvertUtils.convert("abc"));
         assertEquals("String->String null", null,
@@ -270,7 +349,6 @@ public class ConvertUtilsTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive array conversion tests.
      */
@@ -278,7 +356,7 @@ public class ConvertUtilsTestCase extends TestCase {
 
         final String values1[] = { "10", "20", "30" };
         Object value = ConvertUtils.convert(values1, Integer.TYPE);
-        final int shape[] = new int[0];
+        final int shape[] = {};
         assertEquals(shape.getClass(), value.getClass());
         final int results1[] = (int[]) value;
         assertEquals(results1[0], 10);
@@ -295,16 +373,15 @@ public class ConvertUtilsTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive String to primitive integer array tests.
      */
     public void testPositiveIntegerArray() {
 
         Object value = null;
-        final int intArray[] = new int[0];
-        final int intArray1[] = new int[] { 0 };
-        final int intArray2[] = new int[] { 0, 10 };
+        final int intArray[] = {};
+        final int intArray1[] = { 0 };
+        final int intArray2[] = { 0, 10 };
 
         value = ConvertUtils.convert("{  }", intArray.getClass());
         checkIntegerArray(value, intArray);
@@ -331,7 +408,6 @@ public class ConvertUtilsTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive scalar conversion tests.
      */
@@ -484,18 +560,15 @@ public class ConvertUtilsTestCase extends TestCase {
 
     }
 
-
     /**
      * Positive String to String array tests.
      */
     public void testPositiveStringArray() {
 
         Object value = null;
-        final String stringArray[] = new String[0];
-        final String stringArray1[] = new String[]
-            { "abc" };
-        final String stringArray2[] = new String[]
-            { "abc", "de,f" };
+        final String stringArray[] = {};
+        final String stringArray1[] = { "abc" };
+        final String stringArray2[] = { "abc", "de,f" };
 
         value = ConvertUtils.convert("", stringArray.getClass());
         checkStringArray(value, stringArray);
@@ -538,7 +611,6 @@ public class ConvertUtilsTestCase extends TestCase {
                                      stringArray.getClass());
         checkStringArray(value, stringArray2);
 
-
     }
 
     public void testSeparateConvertInstances() throws Exception {
@@ -600,111 +672,5 @@ public class ConvertUtilsTestCase extends TestCase {
                     true);
     }
 
-    public void testDeregisteringSingleConverter() throws Exception {
-        // make sure that the test work ok before anything's changed
-        final Object
-        value = ConvertUtils.convert("true", Boolean.TYPE);
-        assertTrue(value instanceof Boolean);
-        assertEquals(
-                    "Standard conversion failed (1)",
-                    ((Boolean) value).booleanValue(),
-                    true);
-
-        // we'll test deregister
-        ConvertUtils.deregister(Boolean.TYPE);
-        assertNull("Converter should be null",ConvertUtils.lookup(Boolean.TYPE));
-
-    }
-
-    @SuppressWarnings({ "unchecked", "rawtypes" })
-    // We need to use raw types in order to test legacy converters
-    public void testConvertToString() throws Exception {
-        final Converter dummyConverter = new Converter() {
-            public Object convert(final Class type, final Object value) {
-                return value;
-            }
-        };
-
-        final Converter fooConverter = new Converter() {
-            public Object convert(final Class type, final Object value) {
-                return "Foo-Converter";
-            }
-        };
-
-        final DateConverter dateConverter = new DateConverter();
-        dateConverter.setLocale(Locale.US);
-
-        final ConvertUtilsBean utils = new ConvertUtilsBean();
-        utils.register(dateConverter, java.util.Date.class);
-        utils.register(fooConverter, String.class);
-
-        // Convert using registerd DateConverter
-        final java.util.Date today = new java.util.Date();
-        final DateFormat fmt = new SimpleDateFormat("M/d/yy"); /* US Short Format */
-        final String expected = fmt.format(today);
-        assertEquals("DateConverter M/d/yy", expected, utils.convert(today, String.class));
-
-        // Date converter doesn't do String conversion - use String Converter
-        utils.register(dummyConverter, java.util.Date.class);
-        assertEquals("Date Converter doesn't do String conversion", "Foo-Converter", utils.convert(today, String.class));
-
-        // No registered Date converter - use String Converter
-        utils.deregister(java.util.Date.class);
-        assertEquals("No registered Date converter", "Foo-Converter", utils.convert(today, String.class));
-
-        // String Converter doesn't do Strings!!!
-        utils.register(dummyConverter, String.class);
-        assertEquals("String Converter doesn't do Strings!!!", today.toString(), utils.convert(today, String.class));
-
-        // No registered Date or String converter - use Object's toString()
-        utils.deregister(String.class);
-        assertEquals("Object's toString()", today.toString(), utils.convert(today, String.class));
-
-    }
-
-    /**
-     * Tests a conversion to an unsupported target type.
-     */
-    public void testConvertUnsupportedTargetType() {
-        final ConvertUtilsBean utils = new ConvertUtilsBean();
-        final Object value = "A test value";
-        assertSame("Got different object", value,
-                utils.convert(value, getClass()));
-    }
-
-    // -------------------------------------------------------- Private Methods
-
-
-    private void checkIntegerArray(final Object value, final int intArray[]) {
-
-        assertNotNull("Returned value is not null", value);
-        assertEquals("Returned value is int[]",
-                     intArray.getClass(), value.getClass());
-        final int results[] = (int[]) value;
-        assertEquals("Returned array length", intArray.length, results.length);
-        for (int i = 0; i < intArray.length; i++) {
-            assertEquals("Returned array value " + i,
-                         intArray[i], results[i]);
-        }
-
-    }
-
-
-    private void checkStringArray(final Object value, final String stringArray[]) {
-
-        assertNotNull("Returned value is not null", value);
-        assertEquals("Returned value is String[]",
-                     stringArray.getClass(), value.getClass());
-        final String results[] = (String[]) value;
-        assertEquals("Returned array length",
-                     stringArray.length, results.length);
-        for (int i = 0; i < stringArray.length; i++) {
-            assertEquals("Returned array value " + i,
-                         stringArray[i], results[i]);
-        }
-
-    }
-
-
 }
 
