@@ -26,21 +26,11 @@ import junit.framework.TestCase;
 /**
  * Test class for {@code IntrospectionContext}.
  *
- * @version $Id$
  */
 public class DefaultIntrospectionContextTestCase extends TestCase {
     /** Constant for the name of a property. */
     private static final String PROP = "foo";
 
-    /** The context to be tested. */
-    private DefaultIntrospectionContext context;
-
-    @Override
-    protected void setUp() throws Exception {
-        super.setUp();
-        context = new DefaultIntrospectionContext(getClass());
-    }
-
     /**
      * Creates a property descriptor object for a property with the given name.
      *
@@ -56,13 +46,13 @@ public class DefaultIntrospectionContextTestCase extends TestCase {
         }
     }
 
-    /**
-     * Tests a newly created instance.
-     */
-    public void testInit() {
-        assertEquals("Wrong current class", getClass(),
-                context.getTargetClass());
-        assertTrue("Got property names", context.propertyNames().isEmpty());
+    /** The context to be tested. */
+    private DefaultIntrospectionContext context;
+
+    @Override
+    protected void setUp() throws Exception {
+        super.setUp();
+        context = new DefaultIntrospectionContext(getClass());
     }
 
     /**
@@ -94,7 +84,7 @@ public class DefaultIntrospectionContextTestCase extends TestCase {
     public void testAddPropertyDescriptors() {
         final int count = 4;
         final PropertyDescriptor[] descs = new PropertyDescriptor[count];
-        final Set<PropertyDescriptor> descSet = new HashSet<PropertyDescriptor>();
+        final Set<PropertyDescriptor> descSet = new HashSet<>();
         for (int i = 0; i < count; i++) {
             descs[i] = createDescriptor(PROP + i);
             descSet.add(descs[i]);
@@ -107,7 +97,7 @@ public class DefaultIntrospectionContextTestCase extends TestCase {
         assertEquals("Wrong number of property names", count + 1, names.size());
         assertTrue("Property not found: " + PROP, names.contains(PROP));
         for (int i = 0; i < count; i++) {
-            assertTrue("Property not found: " + (PROP + i),
+            assertTrue("Property not found: " + PROP + i,
                     names.contains(PROP + i));
         }
         final PropertyDescriptor[] addedDescs = context.getPropertyDescriptors();
@@ -130,6 +120,15 @@ public class DefaultIntrospectionContextTestCase extends TestCase {
         }
     }
 
+    /**
+     * Tests getPropertyDescriptor() if the property name is unknown.
+     */
+    public void testGetPropertyDescriptorUnknown() {
+        assertNull("Got a property (1)", context.getPropertyDescriptor(PROP));
+        context.addPropertyDescriptor(createDescriptor(PROP));
+        assertNull("Got a property (2)", context.getPropertyDescriptor("other"));
+    }
+
     /**
      * Tests hasProperty() if the expected result is false.
      */
@@ -140,12 +139,12 @@ public class DefaultIntrospectionContextTestCase extends TestCase {
     }
 
     /**
-     * Tests getPropertyDescriptor() if the property name is unknown.
+     * Tests a newly created instance.
      */
-    public void testGetPropertyDescriptorUnknown() {
-        assertNull("Got a property (1)", context.getPropertyDescriptor(PROP));
-        context.addPropertyDescriptor(createDescriptor(PROP));
-        assertNull("Got a property (2)", context.getPropertyDescriptor("other"));
+    public void testInit() {
+        assertEquals("Wrong current class", getClass(),
+                context.getTargetClass());
+        assertTrue("Got property names", context.propertyNames().isEmpty());
     }
 
     /**
