@@ -20,9 +20,9 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
 
 import junit.framework.Test;
@@ -32,7 +32,6 @@ import junit.framework.TestSuite;
 /**
  * <p>Test Case for the <code>DynaBeanMapDecorator</code> implementation class.</p>
  *
- * @version $Id$
  */
 @SuppressWarnings("deprecation")
 public class DynaBeanMapDecoratorTestCase extends TestCase {
@@ -42,35 +41,15 @@ public class DynaBeanMapDecoratorTestCase extends TestCase {
     private static final DynaProperty intProp    = new DynaProperty("intProp",    Integer.class);
     private static final DynaProperty dateProp   = new DynaProperty("dateProp",   Date.class);
     private static final DynaProperty mapProp    = new DynaProperty("mapProp",    Map.class);
-    private static final DynaProperty[] properties = new DynaProperty[] {
+    private static final DynaProperty[] properties = {
                       stringProp, nullProp, intProp, dateProp, mapProp};
     private static final DynaClass dynaClass = new BasicDynaClass("testDynaClass", BasicDynaBean.class, properties);
 
     private static String  stringVal = "somevalue";
-    private static Integer intVal    = new Integer(5);
+    private static Integer intVal    = Integer.valueOf(5);
     private static Date    dateVal   = new Date();
-    private final Map<Object, Object>     mapVal    = new HashMap<Object, Object>();
-
-    private final Object[] values = new Object[] {stringVal, null, intVal, dateVal, mapVal};
-
-    private BasicDynaBean dynaBean;
-    private Map<Object, Object> decoratedMap;
-    private Map<Object, Object> modifiableMap;
     private static final Map<Object, Object> emptyMap = new DynaBeanMapDecorator(new BasicDynaBean(new BasicDynaClass()));
 
-    // ---------------------------------------------------------- Constructors
-
-    /**
-     * Construct a new instance of this test case.
-     *
-     * @param name Name of the test case
-     */
-    public DynaBeanMapDecoratorTestCase(final String name) {
-        super(name);
-    }
-
-    // -------------------------------------------------- Overall Test Methods
-
     /**
      * Run thus Test
      */
@@ -82,7 +61,78 @@ public class DynaBeanMapDecoratorTestCase extends TestCase {
      * Return the tests included in this test suite.
      */
     public static Test suite() {
-        return (new TestSuite(DynaBeanMapDecoratorTestCase.class));
+        return new TestSuite(DynaBeanMapDecoratorTestCase.class);
+    }
+    private final Map<Object, Object>     mapVal    = new HashMap<>();
+    private final Object[] values = {stringVal, null, intVal, dateVal, mapVal};
+    private BasicDynaBean dynaBean;
+
+    private Map<Object, Object> decoratedMap;
+
+    private Map<Object, Object> modifiableMap;
+
+    /**
+     * Construct a new instance of this test case.
+     *
+     * @param name Name of the test case
+     */
+    public DynaBeanMapDecoratorTestCase(final String name) {
+        super(name);
+    }
+
+    /**
+     * Check that a Collection is not modifiable
+     */
+    private <E> void checkUnmodifiable(final String desc, final Collection<E> collection, final E addElem) {
+        // Check can't add()
+        try {
+            collection.add(addElem);
+            fail(desc + ".add()");
+        } catch(final UnsupportedOperationException ignore) {
+            // expected result
+        }
+
+        // Check can't addAll()
+        final List<E> list = new ArrayList<>(1);
+        list.add(addElem);
+        try {
+            collection.addAll(list);
+            fail(desc + ".addAll()");
+        } catch(final UnsupportedOperationException ignore) {
+            // expected result
+        }
+
+        // Check can't clear()
+        try {
+            collection.clear();
+            fail(desc + ".clear()");
+        } catch(final UnsupportedOperationException ignore) {
+            // expected result
+        }
+
+        // Check can't remove()
+        try {
+            collection.remove("abc");
+            fail(desc + ".remove()");
+        } catch(final UnsupportedOperationException ignore) {
+            // expected result
+        }
+
+        // Check can't removeAll()
+        try {
+            collection.removeAll(list);
+            fail(desc + ".removeAll()");
+        } catch(final UnsupportedOperationException ignore) {
+            // expected result
+        }
+
+        // Check can't retainAll()
+        try {
+            collection.retainAll(list);
+            fail(desc + ".retainAll()");
+        } catch(final UnsupportedOperationException ignore) {
+            // expected result
+        }
     }
 
     /**
@@ -117,16 +167,6 @@ public class DynaBeanMapDecoratorTestCase extends TestCase {
         modifiableMap = null;
     }
 
-    // ------------------------------------------------ Individual Test Methods
-
-    /**
-     * Test isReadOnly() method
-     */
-    public void testIsReadOnly() {
-        assertTrue("decoratedMap true",   ((DynaBeanMapDecorator)decoratedMap).isReadOnly());
-        assertFalse("modifiableMap false", ((DynaBeanMapDecorator)modifiableMap).isReadOnly());
-    }
-
     /**
      * Test clear() method
      */
@@ -168,17 +208,15 @@ public class DynaBeanMapDecoratorTestCase extends TestCase {
         final Set<Map.Entry<Object, Object>> set = modifiableMap.entrySet();
 
         // Check the Set can't be modified
-        final Map<Object, Object> m = new HashMap<Object, Object>();
+        final Map<Object, Object> m = new HashMap<>();
         m.put("key", "value");
         checkUnmodifiable("entrySet()", set, m.entrySet().iterator().next());
 
         assertEquals("entrySet size", properties.length, set.size());
 
-        final Iterator<Map.Entry<Object, Object>> iterator = set.iterator();
-        final List<String> namesList = new ArrayList<String>();
+        final List<String> namesList = new ArrayList<>();
         int i = 0;
-        while (iterator.hasNext()) {
-            final Map.Entry<Object, Object> entry = iterator.next();
+        for (final Entry<Object, Object> entry : set) {
             final String name  = (String)entry.getKey();
             namesList.add(name);
             final Object expectValue = decoratedMap.get(name);
@@ -216,6 +254,14 @@ public class DynaBeanMapDecoratorTestCase extends TestCase {
         assertFalse("Not Empty", decoratedMap.isEmpty());
     }
 
+    /**
+     * Test isReadOnly() method
+     */
+    public void testIsReadOnly() {
+        assertTrue("decoratedMap true",   ((DynaBeanMapDecorator)decoratedMap).isReadOnly());
+        assertFalse("modifiableMap false", ((DynaBeanMapDecorator)modifiableMap).isReadOnly());
+    }
+
     /**
      * Test keySet() method
      */
@@ -260,7 +306,7 @@ public class DynaBeanMapDecoratorTestCase extends TestCase {
     public void testPutAll() {
 
         final String newValue = "ABC";
-        final Map<Object, Object> newMap = new HashMap<Object, Object>();
+        final Map<Object, Object> newMap = new HashMap<>();
         newMap.put(stringProp.getName(), newValue);
 
         // Test read only
@@ -314,67 +360,11 @@ public class DynaBeanMapDecoratorTestCase extends TestCase {
 
         assertEquals("values size", values.length, collection.size());
 
-        // Collection should be ordered in same sequence as properties
-        final Iterator<Object> iterator = collection.iterator();
         int i = 0;
-        while (iterator.hasNext()) {
-            assertEquals("values("+i+")", values[i], iterator.next());
+        // Collection should be ordered in same sequence as properties
+        for (final Object element : collection) {
+            assertEquals("values(" + i + ")", values[i], element);
             i++;
         }
     }
-
-    /**
-     * Check that a Collection is not modifiable
-     */
-    private <E> void checkUnmodifiable(final String desc, final Collection<E> collection, final E addElem) {
-        // Check can't add()
-        try {
-            collection.add(addElem);
-            fail(desc + ".add()");
-        } catch(final UnsupportedOperationException ignore) {
-            // expected result
-        }
-
-        // Check can't addAll()
-        final List<E> list = new ArrayList<E>(1);
-        list.add(addElem);
-        try {
-            collection.addAll(list);
-            fail(desc + ".addAll()");
-        } catch(final UnsupportedOperationException ignore) {
-            // expected result
-        }
-
-        // Check can't clear()
-        try {
-            collection.clear();
-            fail(desc + ".clear()");
-        } catch(final UnsupportedOperationException ignore) {
-            // expected result
-        }
-
-        // Check can't remove()
-        try {
-            collection.remove("abc");
-            fail(desc + ".remove()");
-        } catch(final UnsupportedOperationException ignore) {
-            // expected result
-        }
-
-        // Check can't removeAll()
-        try {
-            collection.removeAll(list);
-            fail(desc + ".removeAll()");
-        } catch(final UnsupportedOperationException ignore) {
-            // expected result
-        }
-
-        // Check can't retainAll()
-        try {
-            collection.retainAll(list);
-            fail(desc + ".retainAll()");
-        } catch(final UnsupportedOperationException ignore) {
-            // expected result
-        }
-    }
-}
\ No newline at end of file
+}
