@@ -27,19 +27,28 @@ import junit.framework.TestCase;
 /**
  * Test class for {@code FluentPropertyBeanIntrospector}.
  *
- * @version $Id$
  */
 public class FluentPropertyBeanIntrospectorTestCase extends TestCase {
+    public static final class CapsBean {
+        private URI mURI;
+
+        public URI getURI() {
+            return mURI;
+        }
+
+        public void setURI(final URI theURI) {
+            mURI = theURI;
+        }
+    }
+
     /**
-     * Puts all property descriptors into a map so that they can be accessed by
-     * property name.
+     * Puts all property descriptors into a map so that they can be accessed by property name.
      *
      * @param descs the array with descriptors
      * @return a map with property names as keys
      */
-    private static Map<String, PropertyDescriptor> createDescriptorMap(
-            final PropertyDescriptor[] descs) {
-        final Map<String, PropertyDescriptor> map = new HashMap<String, PropertyDescriptor>();
+    private static Map<String, PropertyDescriptor> createDescriptorMap(final PropertyDescriptor[] descs) {
+        final Map<String, PropertyDescriptor> map = new HashMap<>();
         for (final PropertyDescriptor pd : descs) {
             map.put(pd.getName(), pd);
         }
@@ -47,15 +56,13 @@ public class FluentPropertyBeanIntrospectorTestCase extends TestCase {
     }
 
     /**
-     * Convenience method for obtaining a specific property descriptor and
-     * checking whether it exists.
+     * Convenience method for obtaining a specific property descriptor and checking whether it exists.
      *
      * @param props the map with property descriptors
-     * @param name the name of the desired descriptor
+     * @param name  the name of the desired descriptor
      * @return the descriptor from the map
      */
-    private static PropertyDescriptor fetchDescriptor(
-            final Map<String, PropertyDescriptor> props, final String name) {
+    private static PropertyDescriptor fetchDescriptor(final Map<String, PropertyDescriptor> props, final String name) {
         assertTrue("Property not found: " + name, props.containsKey(name));
         return props.get(name);
     }
@@ -79,8 +86,7 @@ public class FluentPropertyBeanIntrospectorTestCase extends TestCase {
         final PropertyUtilsBean pu = new PropertyUtilsBean();
         final FluentPropertyBeanIntrospector introspector = new FluentPropertyBeanIntrospector();
         pu.addBeanIntrospector(introspector);
-        final Map<String, PropertyDescriptor> props = createDescriptorMap(pu
-                .getPropertyDescriptors(FluentIntrospectionTestBean.class));
+        final Map<String, PropertyDescriptor> props = createDescriptorMap(pu.getPropertyDescriptors(FluentIntrospectionTestBean.class));
         PropertyDescriptor pd = fetchDescriptor(props, "name");
         assertNotNull("No read method for name", pd.getReadMethod());
         assertNotNull("No write method for name", pd.getWriteMethod());
@@ -89,41 +95,26 @@ public class FluentPropertyBeanIntrospectorTestCase extends TestCase {
         assertNull("Read method for fluentProperty", pd.getReadMethod());
         assertNotNull("No write method for fluentProperty", pd.getWriteMethod());
         pd = fetchDescriptor(props, "fluentGetProperty");
-        assertNotNull("No read method for fluentGetProperty",
-                pd.getReadMethod());
-        assertNotNull("No write method for fluentGetProperty",
-                pd.getWriteMethod());
+        assertNotNull("No read method for fluentGetProperty", pd.getReadMethod());
+        assertNotNull("No write method for fluentGetProperty", pd.getWriteMethod());
     }
 
     public void testIntrospectionCaps() throws Exception {
-	    final PropertyUtilsBean pu = new PropertyUtilsBean();
+        final PropertyUtilsBean pu = new PropertyUtilsBean();
 
         final FluentPropertyBeanIntrospector introspector = new FluentPropertyBeanIntrospector();
 
-	    pu.addBeanIntrospector(introspector);
+        pu.addBeanIntrospector(introspector);
 
-	    final Map<String, PropertyDescriptor> props = createDescriptorMap(
-			pu.getPropertyDescriptors(CapsBean.class));
+        final Map<String, PropertyDescriptor> props = createDescriptorMap(pu.getPropertyDescriptors(CapsBean.class));
 
-	    PropertyDescriptor aDescriptor = fetchDescriptor(props, "URI");
+        final PropertyDescriptor aDescriptor = fetchDescriptor(props, "URI");
 
-	    assertNotNull("missing property", aDescriptor);
+        assertNotNull("missing property", aDescriptor);
 
-	    assertNotNull("No read method for uri", aDescriptor.getReadMethod());
-	    assertNotNull("No write method for uri", aDescriptor.getWriteMethod());
+        assertNotNull("No read method for uri", aDescriptor.getReadMethod());
+        assertNotNull("No write method for uri", aDescriptor.getWriteMethod());
 
-	    assertNull("Should not find mis-capitalized property", props.get("uRI"));
+        assertNull("Should not find mis-capitalized property", props.get("uRI"));
     }
-
-	public static final class CapsBean {
-		private URI mURI;
-
-		public URI getURI() {
-			return mURI;
-		}
-
-		public void setURI(final URI theURI) {
-			mURI = theURI;
-		}
-	}
 }
