@@ -31,21 +31,17 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
-
 /**
  * <p>Test Case for the Indexed Properties.</p>
  *
- * @version $Id$
  */
 
 public class IndexedPropertyTestCase {
 
-    // ---------------------------------------------------- Instance Variables
-
     /**
      * The test bean for each test.
      */
-    private IndexedTestBean bean = null;
+    private IndexedTestBean bean;
     private BeanUtilsBean beanUtilsBean;
     private PropertyUtilsBean propertyUtilsBean;
     private String[] testArray;
@@ -54,10 +50,6 @@ public class IndexedPropertyTestCase {
     private List<Object> newList;
     private ArrayList<Object> arrayList;
 
-
-    // -------------------------------------------------- Overall Test Methods
-
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -72,17 +64,17 @@ public class IndexedPropertyTestCase {
         testArray= new String[] {"array-0", "array-1", "array-2"};
         newArray = new String[]  {"newArray-0", "newArray-1", "newArray-2"};
 
-        testList = new ArrayList<String>();
+        testList = new ArrayList<>();
         testList.add("list-0");
         testList.add("list-1");
         testList.add("list-2");
 
-        newList = new ArrayList<Object>();
+        newList = new ArrayList<>();
         newList.add("newList-0");
         newList.add("newList-1");
         newList.add("newList-2");
 
-        arrayList = new ArrayList<Object>();
+        arrayList = new ArrayList<>();
         arrayList.add("arrayList-0");
         arrayList.add("arrayList-1");
         arrayList.add("arrayList-2");
@@ -102,9 +94,6 @@ public class IndexedPropertyTestCase {
         bean = null;
     }
 
-
-    // ------------------------------------------------ Individual Test Methods
-
     /**
      * Test IndexedPropertyDescriptor for an Array
      */
@@ -120,59 +109,6 @@ public class IndexedPropertyTestCase {
                      descriptor.getPropertyType());
     }
 
-    /**
-     * Test IndexedPropertyDescriptor for a List
-     */
-    @Test
-    public void testListIndexedPropertyDescriptor() throws Exception {
-        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
-        assertNotNull("No List Descriptor", descriptor);
-        if (Jira492IndexedListsSupport.supportsIndexedLists()) {
-            // BEANUTILS-492 - can't assume lists are handled as arrays in Java 8+
-            assertEquals("Not IndexedPropertyDescriptor",
-                         IndexedPropertyDescriptor.class, descriptor.getClass());
-        }
-        assertEquals("PropertDescriptor Type invalid",
-                     List.class,
-                     descriptor.getPropertyType());
-    }
-
-    /**
-     * Test IndexedPropertyDescriptor for an ArrayList
-     */
-    @Test
-    public void testArrayListIndexedPropertyDescriptor() throws Exception {
-        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "arrayList");
-        assertNotNull("No ArrayList Descriptor", descriptor);
-        if (Jira492IndexedListsSupport.supportsIndexedLists()) {
-            assertEquals("Not IndexedPropertyDescriptor",
-                    IndexedPropertyDescriptor.class, descriptor.getClass());
-        }
-        assertEquals("PropertDescriptor Type invalid",
-                     ArrayList.class,
-                     descriptor.getPropertyType());
-    }
-
-    /**
-     * Test Read Method for an Array
-     */
-    @Test
-    public void testArrayReadMethod() throws Exception {
-        final PropertyDescriptor descriptor =
-             (PropertyDescriptor)propertyUtilsBean.getPropertyDescriptor(bean, "stringArray");
-        assertNotNull("No Array Read Method", descriptor.getReadMethod());
-    }
-
-    /**
-     * Test Write Method for an Array
-     */
-    @Test
-    public void testArrayWriteMethod() throws Exception {
-        final PropertyDescriptor descriptor =
-             (PropertyDescriptor)propertyUtilsBean.getPropertyDescriptor(bean, "stringArray");
-        assertNotNull("No Array Write Method", descriptor.getWriteMethod());
-    }
-
     /**
      * Test Indexed Read Method for an Array
      */
@@ -194,55 +130,19 @@ public class IndexedPropertyTestCase {
     }
 
     /**
-     * Test Read Method for a List
-     *
-     * JDK 1.3.1_04: Test Passes
-     * JDK 1.4.2_05: Test Fails - getter which returns java.util.List not returned
-     *                            by IndexedPropertyDescriptor.getReadMethod();
+     * Test IndexedPropertyDescriptor for an ArrayList
      */
     @Test
-    public void testListReadMethod() throws Exception {
-        final PropertyDescriptor descriptor =
-             (PropertyDescriptor)propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
-        assertNotNull("No List Read Method", descriptor.getReadMethod());
-    }
-
-    /**
-     * Test Write Method for a List
-     *
-     * JDK 1.3.1_04: Test Passes
-     * JDK 1.4.2_05: Test Fails - setter whith java.util.List argument not returned
-     *                            by IndexedPropertyDescriptor.getWriteMethod();
-     */
-    @Test
-    public void testListWriteMethod() throws Exception {
-        final PropertyDescriptor descriptor =
-             (PropertyDescriptor)propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
-        assertNotNull("No List Write Method", descriptor.getWriteMethod());
-    }
-
-    /**
-     * Test Indexed Read Method for a List
-     */
-    @Test
-    public void testListIndexedReadMethod() throws Exception {
-        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
-        assertNotNull("stringList descriptor not found", descriptor);
-        assumeTrue("JDK does not support index bean properties on java.util.List",
-                Jira492IndexedListsSupport.supportsIndexedLists());
-        assertNotNull("No List Indexed Read Method",  ((IndexedPropertyDescriptor)descriptor).getIndexedReadMethod());
-    }
-
-    /**
-     * Test Indexed Write Method for a List
-     */
-    @Test
-    public void testListIndexedWriteMethod() throws Exception {
-        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
-        assertNotNull("stringList descriptor not found", descriptor);
-        assumeTrue("JDK does not support index bean properties on java.util.List",
-                Jira492IndexedListsSupport.supportsIndexedLists());
-        assertNotNull("No List Indexed Write Method", ((IndexedPropertyDescriptor)descriptor).getIndexedWriteMethod());
+    public void testArrayListIndexedPropertyDescriptor() throws Exception {
+        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "arrayList");
+        assertNotNull("No ArrayList Descriptor", descriptor);
+        if (Jira492IndexedListsSupport.supportsIndexedLists()) {
+            assertEquals("Not IndexedPropertyDescriptor",
+                    IndexedPropertyDescriptor.class, descriptor.getClass());
+        }
+        assertEquals("PropertDescriptor Type invalid",
+                     ArrayList.class,
+                     descriptor.getPropertyType());
     }
 
     /**
@@ -251,7 +151,7 @@ public class IndexedPropertyTestCase {
     @Test
     public void testArrayListReadMethod() throws Exception {
         final PropertyDescriptor descriptor =
-             (PropertyDescriptor)propertyUtilsBean.getPropertyDescriptor(bean, "arrayList");
+             propertyUtilsBean.getPropertyDescriptor(bean, "arrayList");
         assertNotNull("No ArrayList Read Method", descriptor.getReadMethod());
     }
 
@@ -265,6 +165,26 @@ public class IndexedPropertyTestCase {
         assertNotNull("No ArrayList Write Method", descriptor.getWriteMethod());
     }
 
+    /**
+     * Test Read Method for an Array
+     */
+    @Test
+    public void testArrayReadMethod() throws Exception {
+        final PropertyDescriptor descriptor =
+             propertyUtilsBean.getPropertyDescriptor(bean, "stringArray");
+        assertNotNull("No Array Read Method", descriptor.getReadMethod());
+    }
+
+    /**
+     * Test Write Method for an Array
+     */
+    @Test
+    public void testArrayWriteMethod() throws Exception {
+        final PropertyDescriptor descriptor =
+             propertyUtilsBean.getPropertyDescriptor(bean, "stringArray");
+        assertNotNull("No Array Write Method", descriptor.getWriteMethod());
+    }
+
     /**
      * Test getting an array property
      */
@@ -304,6 +224,15 @@ public class IndexedPropertyTestCase {
                      beanUtilsBean.getIndexedProperty(bean, "stringArray", 1));
     }
 
+    /**
+     * Test getting an ArrayList
+     */
+    @Test
+    public void testGetArrayList() throws Exception {
+        assertEquals(arrayList,
+                     propertyUtilsBean.getProperty(bean, "arrayList"));
+    }
+
     /**
      * Test getting a List
      *
@@ -348,6 +277,75 @@ public class IndexedPropertyTestCase {
                      beanUtilsBean.getIndexedProperty(bean, "stringList", 1));
     }
 
+    /**
+     * Test IndexedPropertyDescriptor for a List
+     */
+    @Test
+    public void testListIndexedPropertyDescriptor() throws Exception {
+        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
+        assertNotNull("No List Descriptor", descriptor);
+        if (Jira492IndexedListsSupport.supportsIndexedLists()) {
+            // BEANUTILS-492 - can't assume lists are handled as arrays in Java 8+
+            assertEquals("Not IndexedPropertyDescriptor",
+                         IndexedPropertyDescriptor.class, descriptor.getClass());
+        }
+        assertEquals("PropertDescriptor Type invalid",
+                     List.class,
+                     descriptor.getPropertyType());
+    }
+
+    /**
+     * Test Indexed Read Method for a List
+     */
+    @Test
+    public void testListIndexedReadMethod() throws Exception {
+        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
+        assertNotNull("stringList descriptor not found", descriptor);
+        assumeTrue("JDK does not support index bean properties on java.util.List",
+                Jira492IndexedListsSupport.supportsIndexedLists());
+        assertNotNull("No List Indexed Read Method",  ((IndexedPropertyDescriptor)descriptor).getIndexedReadMethod());
+    }
+
+    /**
+     * Test Indexed Write Method for a List
+     */
+    @Test
+    public void testListIndexedWriteMethod() throws Exception {
+        final PropertyDescriptor descriptor = propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
+        assertNotNull("stringList descriptor not found", descriptor);
+        assumeTrue("JDK does not support index bean properties on java.util.List",
+                Jira492IndexedListsSupport.supportsIndexedLists());
+        assertNotNull("No List Indexed Write Method", ((IndexedPropertyDescriptor)descriptor).getIndexedWriteMethod());
+    }
+
+    /**
+     * Test Read Method for a List
+     *
+     * JDK 1.3.1_04: Test Passes
+     * JDK 1.4.2_05: Test Fails - getter which returns java.util.List not returned
+     *                            by IndexedPropertyDescriptor.getReadMethod();
+     */
+    @Test
+    public void testListReadMethod() throws Exception {
+        final PropertyDescriptor descriptor =
+             propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
+        assertNotNull("No List Read Method", descriptor.getReadMethod());
+    }
+
+    /**
+     * Test Write Method for a List
+     *
+     * JDK 1.3.1_04: Test Passes
+     * JDK 1.4.2_05: Test Fails - setter whith java.util.List argument not returned
+     *                            by IndexedPropertyDescriptor.getWriteMethod();
+     */
+    @Test
+    public void testListWriteMethod() throws Exception {
+        final PropertyDescriptor descriptor =
+             propertyUtilsBean.getPropertyDescriptor(bean, "stringList");
+        assertNotNull("No List Write Method", descriptor.getWriteMethod());
+    }
+
     /**
      * Test setting an Array property
      *
@@ -371,7 +369,6 @@ public class IndexedPropertyTestCase {
         }
     }
 
-
     /**
      * Test setting an indexed item of an Array using setProperty("name[x]", value)
      */
@@ -390,6 +387,21 @@ public class IndexedPropertyTestCase {
         assertEquals("modified-1", bean.getStringArray(1));
     }
 
+    /**
+     * Test setting an ArrayList property
+     */
+    @Test
+    public void testSetArrayList() throws Exception {
+        beanUtilsBean.setProperty(bean, "arrayList", newList);
+        final Object value = bean.getArrayList();
+        assertEquals("Type is different", newList.getClass(), value.getClass());
+        final List<?> list  = (List<?>)value;
+        assertEquals("List size is different", newList.size(), list.size());
+        for (int i = 0; i < list.size(); i++) {
+            assertEquals("Element " + i + " is different", newList.get(i), list.get(i));
+        }
+    }
+
     /**
      * Test setting a List property
      *
@@ -410,7 +422,6 @@ public class IndexedPropertyTestCase {
         }
     }
 
-
     /**
      * Test setting an indexed item of a List using setProperty("name[x]", value)
      */
@@ -429,29 +440,4 @@ public class IndexedPropertyTestCase {
         assertEquals("modified-1", bean.getStringList(1));
     }
 
-
-    /**
-     * Test getting an ArrayList
-     */
-    @Test
-    public void testGetArrayList() throws Exception {
-        assertEquals(arrayList,
-                     propertyUtilsBean.getProperty(bean, "arrayList"));
-    }
-
-    /**
-     * Test setting an ArrayList property
-     */
-    @Test
-    public void testSetArrayList() throws Exception {
-        beanUtilsBean.setProperty(bean, "arrayList", newList);
-        final Object value = bean.getArrayList();
-        assertEquals("Type is different", newList.getClass(), value.getClass());
-        final List<?> list  = (List<?>)value;
-        assertEquals("List size is different", newList.size(), list.size());
-        for (int i = 0; i < list.size(); i++) {
-            assertEquals("Element " + i + " is different", newList.get(i), list.get(i));
-        }
-    }
-
 }
