@@ -16,21 +16,32 @@
  */
 package org.apache.commons.beanutils;
 
-import junit.framework.TestCase;
 import junit.framework.Test;
+import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
 /**
  * <p>Test Case for the <code>LazyDynaClass</code> implementation class.</p>
  *
- * @version $Id$
  */
 public class LazyDynaClassTestCase extends TestCase {
 
-    protected LazyDynaClass dynaClass = null;
-    protected String testProperty     = "myProperty";
+    /**
+     * Run this Test
+     */
+    public static void main(final String[] args) {
+      junit.textui.TestRunner.run(suite());
+    }
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
+        return new TestSuite(LazyDynaClassTestCase.class);
+    }
 
-    // ---------------------------------------------------------- Constructors
+    protected LazyDynaClass dynaClass;
+
+    protected String testProperty     = "myProperty";
 
     /**
      * Construct a new instance of this test case.
@@ -41,15 +52,6 @@ public class LazyDynaClassTestCase extends TestCase {
         super(name);
     }
 
-    // -------------------------------------------------- Overall Test Methods
-
-    /**
-     * Run this Test
-     */
-    public static void main(final String[] args) {
-      junit.textui.TestRunner.run(suite());
-    }
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -58,13 +60,6 @@ public class LazyDynaClassTestCase extends TestCase {
         dynaClass = new LazyDynaClass();
     }
 
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-        return (new TestSuite(LazyDynaClassTestCase.class));
-    }
-
     /**
      * Tear down instance variables required by this test case.
      */
@@ -73,8 +68,6 @@ public class LazyDynaClassTestCase extends TestCase {
         dynaClass = null;
     }
 
-    // ------------------------------------------------ Individual Test Methods
-
     /**
      * Test add(name) method
      */
@@ -197,7 +190,6 @@ public class LazyDynaClassTestCase extends TestCase {
         assertFalse("property doesnt exist", dynaClass.isDynaProperty(testProperty));
     }
 
-
     /**
      * Test retrieving a property which doesn't exist (returnNull is 'true')
      */
@@ -220,6 +212,15 @@ public class LazyDynaClassTestCase extends TestCase {
         assertNull("property is null", dynaClass.getDynaProperty(testProperty));
     }
 
+    /**
+     * Test removing a property which doesn't exist
+     */
+    public void testRemovePropertyDoesntExist() {
+        assertFalse("property doesn't exist", dynaClass.isDynaProperty(testProperty));
+        dynaClass.remove(testProperty);
+        assertFalse("property still doesn't exist", dynaClass.isDynaProperty(testProperty));
+    }
+
     /**
      * Test removing a property, name is null
      */
@@ -247,13 +248,4 @@ public class LazyDynaClassTestCase extends TestCase {
             // expected result
         }
     }
-
-    /**
-     * Test removing a property which doesn't exist
-     */
-    public void testRemovePropertyDoesntExist() {
-        assertFalse("property doesn't exist", dynaClass.isDynaProperty(testProperty));
-        dynaClass.remove(testProperty);
-        assertFalse("property still doesn't exist", dynaClass.isDynaProperty(testProperty));
-    }
-}
\ No newline at end of file
+}
