@@ -33,35 +33,12 @@ import junit.framework.TestSuite;
 /**
  * <p>Test Case for the <code>LazyDynaList</code>class.</p>
  *
- * @version $Id$
  */
 public class LazyDynaListTestCase extends TestCase {
 
     private static final String BASIC_PROP1 = "BasicDynaClass_Property1";
     private static final String BASIC_PROP2 = "BasicDynaClass_Property2";
 
-    protected DynaProperty[] properties = new DynaProperty[] {
-                                               new DynaProperty(BASIC_PROP1, String.class),
-                                               new DynaProperty(BASIC_PROP2, HashMap.class)};
-
-    protected DynaClass treeMapDynaClass = new LazyDynaMap(new TreeMap<String, Object>());
-    protected DynaClass hashMapDynaClass = new LazyDynaMap(new HashMap<String, Object>());
-    protected DynaClass pojoDynaClass = new WrapDynaBean(new TestBean()).getDynaClass();
-    protected DynaClass basicDynaClass = new BasicDynaClass("test", BasicDynaBean.class, properties);
-
-    // ---------------------------------------------------------- Constructors
-
-    /**
-     * Construct a new instance of this test case.
-     *
-     * @param name Name of the test case
-     */
-    public LazyDynaListTestCase(final String name) {
-        super(name);
-    }
-
-    // -------------------------------------------------- Overall Test Methods
-
     /**
      * Run thus Test
      */
@@ -73,162 +50,25 @@ public class LazyDynaListTestCase extends TestCase {
      * Return the tests included in this test suite.
      */
     public static Test suite() {
-        return (new TestSuite(LazyDynaListTestCase.class));
+        return new TestSuite(LazyDynaListTestCase.class);
     }
+    protected DynaProperty[] properties = {
+                                               new DynaProperty(BASIC_PROP1, String.class),
+                                               new DynaProperty(BASIC_PROP2, HashMap.class)};
+    protected DynaClass treeMapDynaClass = new LazyDynaMap(new TreeMap<>());
+    protected DynaClass hashMapDynaClass = new LazyDynaMap(new HashMap<>());
+
+    protected DynaClass pojoDynaClass = new WrapDynaBean(new TestBean()).getDynaClass();
+
+    protected DynaClass basicDynaClass = new BasicDynaClass("test", BasicDynaBean.class, properties);
 
     /**
-     * Set up instance variables required by this test case.
+     * Construct a new instance of this test case.
+     *
+     * @param name Name of the test case
      */
-    @Override
-    public void setUp() throws Exception {
-    }
-
-    /**
-     * Tear down instance variables required by this test case.
-     */
-    @Override
-    public void tearDown() {
-    }
-
-    // ------------------------------------------------ Individual Test Methods
-
-    /**
-     * Test DynaBean Create
-     */
-    public void testDynaBeanDynaClass() {
-
-        // Create LazyArrayList for DynaBeans
-        final LazyDynaList list = new LazyDynaList(basicDynaClass);
-
-        // test
-        dynaBeanTest(list, BasicDynaBean.class, basicDynaClass, new BenchBean());
-    }
-
-    /**
-     * Test DynaBean Create
-     */
-    public void testDynaBeanType() {
-
-        // Create LazyArrayList for DynaBeans
-        final LazyDynaList list = new LazyDynaList(LazyDynaBean.class);
-
-
-        final LazyDynaBean bean = new LazyDynaBean();
-        bean.set("prop1", "val");
-
-        // test
-        dynaBeanTest(list, LazyDynaBean.class, bean.getDynaClass(), new BenchBean());
-    }
-
-    /**
-     * Test Map Create
-     */
-    public void testMapDynaClass() {
-
-        // Create LazyArrayList for TreeMap's
-        final LazyDynaList list = new LazyDynaList(treeMapDynaClass);
-
-        // test
-        mapTest(list, TreeMap.class, new BenchBean());
-
-    }
-
-    /**
-     * Test Map Create
-     */
-    public void testMapType() {
-
-        // Create LazyArrayList for HashMap's
-        final LazyDynaList list = new LazyDynaList(HashMap.class);
-
-        // test
-        mapTest(list, HashMap.class, new BenchBean());
-
-    }
-
-    /**
-     * Test Pojo Create
-     */
-    public void testPojoDynaClass() {
-
-        // Create LazyArrayList for POJO's
-        final LazyDynaList list = new LazyDynaList(pojoDynaClass);
-
-        // test
-        pojoTest(list, TestBean.class, new BenchBean());
-
-    }
-
-    /**
-     * Test Pojo Create
-     */
-    public void testPojoType() {
-
-        // Create LazyArrayList for POJO's
-        final LazyDynaList list = new LazyDynaList(TestBean.class);
-
-        // test
-        pojoTest(list, TestBean.class, new BenchBean());
-
-    }
-
-    /**
-     * Test Collection
-     */
-    public void testCollection(final LazyDynaList list, final Class<?> testClass, final DynaClass testDynaClass, final Object wrongBean) {
-
-        // ----- Create Collection & Array of Maps -----
-        final int size = 5;
-        final List<Object> testList = new ArrayList<Object>(size);
-        final TreeMap<?, ?>[] testArray = new TreeMap[size];
-        for (int i = 0; i < size; i++) {
-            final TreeMap<String, Object> map = new TreeMap<String, Object>();
-            map.put("prop"+i, "val"+i);
-            testArray[i] = map;
-            testList.add(testArray[i]);
-        }
-
-
-        // ----- Create LazyArrayList from Collection -----
-        LazyDynaList lazyList = new LazyDynaList(testList);
-        assertEquals("1. check size", size, lazyList.size());
-
-        DynaBean[] dynaArray = lazyList.toDynaBeanArray();
-        TreeMap<?, ?>[]  mapArray  = (TreeMap[])lazyList.toArray();
-
-        // Check values
-        assertEquals("2. check size", size, dynaArray.length);
-        assertEquals("3. check size", size, mapArray.length);
-        for (int i = 0; i < size; i++) {
-            assertEquals("4."+i+" DynaBean error ", "val"+i, dynaArray[i].get("prop"+i));
-            assertEquals("5."+i+" Map error ", "val"+i, mapArray[i].get("prop"+i));
-        }
-
-
-
-        // ----- Create LazyArrayList from Array -----
-        lazyList = new LazyDynaList(testArray);
-        assertEquals("6. check size", size, lazyList.size());
-
-        dynaArray = lazyList.toDynaBeanArray();
-        mapArray  = (TreeMap[])lazyList.toArray();
-
-        // Check values
-        assertEquals("7. check size", size, dynaArray.length);
-        assertEquals("8. check size", size, mapArray.length);
-        for (int i = 0; i < size; i++) {
-            assertEquals("9."+i+" DynaBean error ", "val"+i, dynaArray[i].get("prop"+i));
-            assertEquals("10."+i+" Map error ", "val"+i, mapArray[i].get("prop"+i));
-        }
-
-    }
-
-    /**
-     * Test adding a map to List with no type set.
-     */
-    public void testNullType() {
-        final LazyDynaList lazyList = new LazyDynaList();
-        lazyList.add(new HashMap<String, Object>());
+    public LazyDynaListTestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -268,7 +108,6 @@ public class LazyDynaListTestCase extends TestCase {
             // expected result
         }
 
-
         // find a String property to set
         final String testProperty = findStringProperty(testDynaClass);
         assertNotNull("Test Property Not Found", testProperty);
@@ -278,7 +117,7 @@ public class LazyDynaListTestCase extends TestCase {
         }
 
         // Create Collection
-        final List<Object> collection = new ArrayList<Object>();
+        final List<Object> collection = new ArrayList<>();
         try {
             collection.add(testDynaClass.newInstance());
             collection.add(testDynaClass.newInstance());
@@ -307,7 +146,6 @@ public class LazyDynaListTestCase extends TestCase {
         assertEquals("15. Wrong Value", origValue+"_updated_"+2, dynaArray[3].get(testProperty));
         assertEquals("16. Wrong Value", "orig_pos1",             dynaArray[4].get(testProperty));
 
-
         // Test Insert - add(index, Object)
         try {
             final DynaBean extraElement = testDynaClass.newInstance();
@@ -328,7 +166,7 @@ public class LazyDynaListTestCase extends TestCase {
      */
     private String findStringProperty(final DynaClass dynaClass) {
         final DynaProperty[] properties = dynaClass.getDynaProperties();
-        for (DynaProperty propertie : properties) {
+        for (final DynaProperty propertie : properties) {
             if (propertie.getType() == String.class) {
                 return propertie.getName();
             }
@@ -336,8 +174,6 @@ public class LazyDynaListTestCase extends TestCase {
         return null;
     }
 
-
-
     /**
      * Test Map Create
      */
@@ -436,6 +272,183 @@ public class LazyDynaListTestCase extends TestCase {
 
     }
 
+    /**
+     * Do serialization and deserialization.
+     */
+    private Object serializeDeserialize(final Object target, final String text) {
+
+        // Serialize the test object
+        final ByteArrayOutputStream baos = new ByteArrayOutputStream();
+        try {
+            final ObjectOutputStream oos = new ObjectOutputStream(baos);
+            oos.writeObject(target);
+            oos.flush();
+            oos.close();
+        } catch (final Exception e) {
+            fail(text + ": Exception during serialization: " + e);
+        }
+
+        // Deserialize the test object
+        Object result = null;
+        try {
+            final ByteArrayInputStream bais =
+                new ByteArrayInputStream(baos.toByteArray());
+            final ObjectInputStream ois = new ObjectInputStream(bais);
+            result = ois.readObject();
+            bais.close();
+        } catch (final Exception e) {
+            fail(text + ": Exception during deserialization: " + e);
+        }
+        return result;
+
+    }
+
+    /**
+     * Set up instance variables required by this test case.
+     */
+    @Override
+    public void setUp() throws Exception {
+    }
+
+    /**
+     * Tear down instance variables required by this test case.
+     */
+    @Override
+    public void tearDown() {
+    }
+
+    /**
+     * Test Collection
+     */
+    public void testCollection(final LazyDynaList list, final Class<?> testClass, final DynaClass testDynaClass, final Object wrongBean) {
+
+        final int size = 5;
+        final List<Object> testList = new ArrayList<>(size);
+        final TreeMap<?, ?>[] testArray = new TreeMap[size];
+        for (int i = 0; i < size; i++) {
+            final TreeMap<String, Object> map = new TreeMap<>();
+            map.put("prop"+i, "val"+i);
+            testArray[i] = map;
+            testList.add(testArray[i]);
+        }
+
+        LazyDynaList lazyList = new LazyDynaList(testList);
+        assertEquals("1. check size", size, lazyList.size());
+
+        DynaBean[] dynaArray = lazyList.toDynaBeanArray();
+        TreeMap<?, ?>[]  mapArray  = (TreeMap[])lazyList.toArray();
+
+        // Check values
+        assertEquals("2. check size", size, dynaArray.length);
+        assertEquals("3. check size", size, mapArray.length);
+        for (int i = 0; i < size; i++) {
+            assertEquals("4."+i+" DynaBean error ", "val"+i, dynaArray[i].get("prop"+i));
+            assertEquals("5."+i+" Map error ", "val"+i, mapArray[i].get("prop"+i));
+        }
+
+        lazyList = new LazyDynaList(testArray);
+        assertEquals("6. check size", size, lazyList.size());
+
+        dynaArray = lazyList.toDynaBeanArray();
+        mapArray  = (TreeMap[])lazyList.toArray();
+
+        // Check values
+        assertEquals("7. check size", size, dynaArray.length);
+        assertEquals("8. check size", size, mapArray.length);
+        for (int i = 0; i < size; i++) {
+            assertEquals("9."+i+" DynaBean error ", "val"+i, dynaArray[i].get("prop"+i));
+            assertEquals("10."+i+" Map error ", "val"+i, mapArray[i].get("prop"+i));
+        }
+
+    }
+
+    /**
+     * Test DynaBean Create
+     */
+    public void testDynaBeanDynaClass() {
+
+        // Create LazyArrayList for DynaBeans
+        final LazyDynaList list = new LazyDynaList(basicDynaClass);
+
+        // test
+        dynaBeanTest(list, BasicDynaBean.class, basicDynaClass, new BenchBean());
+    }
+
+    /**
+     * Test DynaBean Create
+     */
+    public void testDynaBeanType() {
+
+        // Create LazyArrayList for DynaBeans
+        final LazyDynaList list = new LazyDynaList(LazyDynaBean.class);
+
+        final LazyDynaBean bean = new LazyDynaBean();
+        bean.set("prop1", "val");
+
+        // test
+        dynaBeanTest(list, LazyDynaBean.class, bean.getDynaClass(), new BenchBean());
+    }
+
+    /**
+     * Test Map Create
+     */
+    public void testMapDynaClass() {
+
+        // Create LazyArrayList for TreeMap's
+        final LazyDynaList list = new LazyDynaList(treeMapDynaClass);
+
+        // test
+        mapTest(list, TreeMap.class, new BenchBean());
+
+    }
+
+    /**
+     * Test Map Create
+     */
+    public void testMapType() {
+
+        // Create LazyArrayList for HashMap's
+        final LazyDynaList list = new LazyDynaList(HashMap.class);
+
+        // test
+        mapTest(list, HashMap.class, new BenchBean());
+
+    }
+
+    /**
+     * Test adding a map to List with no type set.
+     */
+    public void testNullType() {
+        final LazyDynaList lazyList = new LazyDynaList();
+        lazyList.add(new HashMap<>());
+    }
+
+    /**
+     * Test Pojo Create
+     */
+    public void testPojoDynaClass() {
+
+        // Create LazyArrayList for POJO's
+        final LazyDynaList list = new LazyDynaList(pojoDynaClass);
+
+        // test
+        pojoTest(list, TestBean.class, new BenchBean());
+
+    }
+
+    /**
+     * Test Pojo Create
+     */
+    public void testPojoType() {
+
+        // Create LazyArrayList for POJO's
+        final LazyDynaList list = new LazyDynaList(TestBean.class);
+
+        // test
+        pojoTest(list, TestBean.class, new BenchBean());
+
+    }
+
     /**
      * Test DynaBean serialization.
      */
@@ -539,37 +552,6 @@ public class LazyDynaListTestCase extends TestCase {
 
     }
 
-    /**
-     * Do serialization and deserialization.
-     */
-    private Object serializeDeserialize(final Object target, final String text) {
-
-        // Serialize the test object
-        final ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        try {
-            final ObjectOutputStream oos = new ObjectOutputStream(baos);
-            oos.writeObject(target);
-            oos.flush();
-            oos.close();
-        } catch (final Exception e) {
-            fail(text + ": Exception during serialization: " + e);
-        }
-
-        // Deserialize the test object
-        Object result = null;
-        try {
-            final ByteArrayInputStream bais =
-                new ByteArrayInputStream(baos.toByteArray());
-            final ObjectInputStream ois = new ObjectInputStream(bais);
-            result = ois.readObject();
-            bais.close();
-        } catch (final Exception e) {
-            fail(text + ": Exception during deserialization: " + e);
-        }
-        return result;
-
-    }
-
     /**
      * Tests toArray() if the list contains DynaBean objects.
      */
@@ -587,7 +569,7 @@ public class LazyDynaListTestCase extends TestCase {
      */
     public void testToArrayMapType() {
         final LazyDynaList list = new LazyDynaList(HashMap.class);
-        final HashMap<String, Object> elem = new HashMap<String, Object>();
+        final HashMap<String, Object> elem = new HashMap<>();
         list.add(elem);
         final Map<?, ?>[] array = new Map[1];
         assertSame("Wrong array", array, list.toArray(array));
