@@ -15,20 +15,17 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
 /**
  * Test Interface
  *
- * @version $Id$
  */
 
 public interface MappedPropertyTestInterface {
 
+    String getMapproperty(String key);
 
-    public String getMapproperty(String key);
-
-    public void setMapproperty(String key, String value);
+    void setMapproperty(String key, String value);
 
 }
