@@ -15,10 +15,8 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
-
 import java.util.HashMap;
 import java.util.Map;
 
@@ -26,18 +24,39 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-
 /**
  * JUnit Test Case containing microbenchmarks for PropertyUtils.
  *
- * @version $Id$
  */
 
 public class PropertyUtilsBenchCase extends TestCase {
 
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
 
-    // ------------------------------------------------------------ Constructors
+        return new TestSuite(PropertyUtilsBenchCase.class);
 
+    }
+
+    // Basic loop counter
+    private long counter = 100000;
+
+    // DynaClass for inDyna and outDyna
+    private DynaClass dynaClass;
+
+    // Input objects that have identical sets of properties and values.
+    private BenchBean inBean;
+    private DynaBean inDyna;
+    private Map<String, Object> inMap;
+
+    // Output objects that have identical sets of properties.
+    private BenchBean outBean;
+    private DynaBean outDyna;
+
+    // PropertyUtilsBean instance to be used
+    private PropertyUtilsBean pu;
 
     /**
      * Construct a new instance of this test case.
@@ -50,32 +69,6 @@ public class PropertyUtilsBenchCase extends TestCase {
 
     }
 
-
-    // ------------------------------------------------------ Instance Variables
-
-
-    // Basic loop counter
-    private long counter = 100000;
-
-    // DynaClass for inDyna and outDyna
-    private DynaClass dynaClass = null;
-
-    // Input objects that have identical sets of properties and values.
-    private BenchBean inBean = null;
-    private DynaBean inDyna = null;
-    private Map<String, Object> inMap = null;
-
-    // Output objects that have identical sets of properties.
-    private BenchBean outBean = null;
-    private DynaBean outDyna = null;
-
-    // PropertyUtilsBean instance to be used
-    private PropertyUtilsBean pu = null;
-
-
-    // ---------------------------------------------------- Overall Test Methods
-
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -104,14 +97,14 @@ public class PropertyUtilsBenchCase extends TestCase {
 
         // Create input instances
         inBean = new BenchBean();
-        inMap = new HashMap<String, Object>();
-        inMap.put("booleanProperty", new Boolean(inBean.getBooleanProperty()));
-        inMap.put("byteProperty", new Byte(inBean.getByteProperty()));
-        inMap.put("doubleProperty", new Double(inBean.getDoubleProperty()));
-        inMap.put("floatProperty", new Float(inBean.getFloatProperty()));
-        inMap.put("intProperty", new Integer(inBean.getIntProperty()));
-        inMap.put("longProperty", new Long(inBean.getLongProperty()));
-        inMap.put("shortProperty", new Short(inBean.getShortProperty()));
+        inMap = new HashMap<>();
+        inMap.put("booleanProperty", Boolean.valueOf(inBean.getBooleanProperty()));
+        inMap.put("byteProperty", Byte.valueOf(inBean.getByteProperty()));
+        inMap.put("doubleProperty", Double.valueOf(inBean.getDoubleProperty()));
+        inMap.put("floatProperty", Float.valueOf(inBean.getFloatProperty()));
+        inMap.put("intProperty", Integer.valueOf(inBean.getIntProperty()));
+        inMap.put("longProperty", Long.valueOf(inBean.getLongProperty()));
+        inMap.put("shortProperty", Short.valueOf(inBean.getShortProperty()));
         inMap.put("stringProperty", inBean.getStringProperty());
         inDyna = dynaClass.newInstance();
         for (final Map.Entry<String, Object> e : inMap.entrySet()) {
@@ -131,17 +124,6 @@ public class PropertyUtilsBenchCase extends TestCase {
 
     }
 
-
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-
-        return (new TestSuite(PropertyUtilsBenchCase.class));
-
-    }
-
-
     /**
      * Tear down instance variables required by this test case.
      */
@@ -158,11 +140,6 @@ public class PropertyUtilsBenchCase extends TestCase {
 
     }
 
-
-
-    // ------------------------------------------------- Individual Test Methods
-
-
     // Time copyProperties() from a bean
     public void testCopyPropertiesBean() throws Exception {
 
@@ -195,7 +172,6 @@ public class PropertyUtilsBenchCase extends TestCase {
 
     }
 
-
     // Time copyProperties() from a DynaBean
     public void testCopyPropertiesDyna() throws Exception {
 
@@ -228,7 +204,6 @@ public class PropertyUtilsBenchCase extends TestCase {
 
     }
 
-
     // Time copyProperties() from a Map
     public void testCopyPropertiesMap() throws Exception {
 
@@ -261,8 +236,4 @@ public class PropertyUtilsBenchCase extends TestCase {
 
     }
 
-
-    // --------------------------------------------------------- Support Methods
-
-
 }
