@@ -28,9 +28,76 @@ import junit.framework.TestCase;
 /**
  * Test class for {@code SuppressPropertiesBeanIntrospector}.
  *
- * @version $Id$
  */
 public class SuppressPropertiesBeanIntrospectorTestCase extends TestCase {
+    /**
+     * A test implementation of IntrospectionContext which collects the properties which
+     * have been removed.
+     */
+    private static class IntrospectionContextTestImpl implements IntrospectionContext {
+        /** Stores the names of properties which have been removed. */
+        private final Set<String> removedProperties = new HashSet<>();
+
+        @Override
+        public void addPropertyDescriptor(final PropertyDescriptor desc) {
+            throw new UnsupportedOperationException("Unexpected method call!");
+        }
+
+        @Override
+        public void addPropertyDescriptors(final PropertyDescriptor[] descriptors) {
+            throw new UnsupportedOperationException("Unexpected method call!");
+        }
+
+        @Override
+        public PropertyDescriptor getPropertyDescriptor(final String name) {
+            throw new UnsupportedOperationException("Unexpected method call!");
+        }
+
+        /**
+         * Returns the names of properties which have been removed.
+         *
+         * @return the set with removed properties
+         */
+        public Set<String> getRemovedProperties() {
+            return removedProperties;
+        }
+
+        @Override
+        public Class<?> getTargetClass() {
+            throw new UnsupportedOperationException("Unexpected method call!");
+        }
+
+        @Override
+        public boolean hasProperty(final String name) {
+            throw new UnsupportedOperationException("Unexpected method call!");
+        }
+
+        @Override
+        public Set<String> propertyNames() {
+            throw new UnsupportedOperationException("Unexpected method call!");
+        }
+
+        @Override
+        public void removePropertyDescriptor(final String name) {
+            removedProperties.add(name);
+        }
+    }
+
+    /**
+     * Tests that the set with properties to be removed cannot be modified.
+     */
+    public void testGetSuppressedPropertiesModify() {
+        final SuppressPropertiesBeanIntrospector introspector = new SuppressPropertiesBeanIntrospector(
+                Arrays.asList("p1", "p2"));
+        final Set<String> properties = introspector.getSuppressedProperties();
+        try {
+            properties.add("anotherProperty");
+            fail("Could modify properties");
+        } catch (final UnsupportedOperationException uoex) {
+            // ok
+        }
+    }
+
     /**
      * Tries to create an instance without properties.
      */
@@ -43,6 +110,25 @@ public class SuppressPropertiesBeanIntrospectorTestCase extends TestCase {
         }
     }
 
+    /**
+     * Tests that a defensive copy is created from the collection with properties to be
+     * removed.
+     */
+    public void testPropertyNamesDefensiveCopy() throws IntrospectionException {
+        final Collection<String> properties = new HashSet<>();
+        properties.add("prop1");
+        final SuppressPropertiesBeanIntrospector introspector = new SuppressPropertiesBeanIntrospector(
+                properties);
+        properties.add("prop2");
+        final IntrospectionContextTestImpl context = new IntrospectionContextTestImpl();
+
+        introspector.introspect(context);
+        assertEquals("Wrong number of removed properties", 1, context
+                .getRemovedProperties().size());
+        assertTrue("Wrong removed property",
+                context.getRemovedProperties().contains("prop1"));
+    }
+
     /**
      * Tests whether the expected properties have been removed during introspection.
      */
@@ -60,84 +146,4 @@ public class SuppressPropertiesBeanIntrospectorTestCase extends TestCase {
                     .getRemovedProperties().contains(property));
         }
     }
-
-    /**
-     * Tests that a defensive copy is created from the collection with properties to be
-     * removed.
-     */
-    public void testPropertyNamesDefensiveCopy() throws IntrospectionException {
-        final Collection<String> properties = new HashSet<String>();
-        properties.add("prop1");
-        final SuppressPropertiesBeanIntrospector introspector = new SuppressPropertiesBeanIntrospector(
-                properties);
-        properties.add("prop2");
-        final IntrospectionContextTestImpl context = new IntrospectionContextTestImpl();
-
-        introspector.introspect(context);
-        assertEquals("Wrong number of removed properties", 1, context
-                .getRemovedProperties().size());
-        assertTrue("Wrong removed property",
-                context.getRemovedProperties().contains("prop1"));
-    }
-
-    /**
-     * Tests that the set with properties to be removed cannot be modified.
-     */
-    public void testGetSuppressedPropertiesModify() {
-        final SuppressPropertiesBeanIntrospector introspector = new SuppressPropertiesBeanIntrospector(
-                Arrays.asList("p1", "p2"));
-        final Set<String> properties = introspector.getSuppressedProperties();
-        try {
-            properties.add("anotherProperty");
-            fail("Could modify properties");
-        } catch (final UnsupportedOperationException uoex) {
-            // ok
-        }
-    }
-
-    /**
-     * A test implementation of IntrospectionContext which collects the properties which
-     * have been removed.
-     */
-    private static class IntrospectionContextTestImpl implements IntrospectionContext {
-        /** Stores the names of properties which have been removed. */
-        private final Set<String> removedProperties = new HashSet<String>();
-
-        /**
-         * Returns the names of properties which have been removed.
-         *
-         * @return the set with removed properties
-         */
-        public Set<String> getRemovedProperties() {
-            return removedProperties;
-        }
-
-        public Class<?> getTargetClass() {
-            throw new UnsupportedOperationException("Unexpected method call!");
-        }
-
-        public void addPropertyDescriptor(final PropertyDescriptor desc) {
-            throw new UnsupportedOperationException("Unexpected method call!");
-        }
-
-        public void addPropertyDescriptors(final PropertyDescriptor[] descriptors) {
-            throw new UnsupportedOperationException("Unexpected method call!");
-        }
-
-        public boolean hasProperty(final String name) {
-            throw new UnsupportedOperationException("Unexpected method call!");
-        }
-
-        public PropertyDescriptor getPropertyDescriptor(final String name) {
-            throw new UnsupportedOperationException("Unexpected method call!");
-        }
-
-        public void removePropertyDescriptor(final String name) {
-            removedProperties.add(name);
-        }
-
-        public Set<String> propertyNames() {
-            throw new UnsupportedOperationException("Unexpected method call!");
-        }
-    }
 }
