@@ -15,10 +15,8 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
-
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.Method;
 import java.lang.reflect.Proxy;
@@ -26,41 +24,15 @@ import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
 import java.sql.Types;
 
-
 /**
  * <p>Mock object that implements enough of
  * <code>java.sql.ResultSetMetaData</code>
  * to exercise the {@link ResultSetDynaClass} functionality.</p>
  *
- * @version $Id$
  */
 
 public class TestResultSetMetaData implements InvocationHandler {
 
-
-    // ----------------------------------------------------- Instance Variables
-
-
-    /**
-     * <p>Array of column names and class names for metadata.</p>
-     */
-    protected String metadata[][] = {
-        { "bigDecimalProperty", java.math.BigDecimal.class.getName() },
-        { "booleanProperty", Boolean.class.getName() },
-        { "byteProperty", Byte.class.getName() },
-        { "dateProperty", java.sql.Date.class.getName() },
-        { "doubleProperty", Double.class.getName() },
-        { "floatProperty", Float.class.getName() },
-        { "intProperty", Integer.class.getName() },
-        { "longProperty", Long.class.getName() },
-        { "nullProperty", String.class.getName() },
-        { "shortProperty", Short.class.getName() },
-        { "stringProperty", String.class.getName() },
-        { "timeProperty", java.sql.Time.class.getName() },
-        { "timestampProperty", java.sql.Timestamp.class.getName() },
-    };
-
-
     /**
      * Factory method for creating {@link ResultSetMetaData} proxies.
      *
@@ -81,6 +53,119 @@ public class TestResultSetMetaData implements InvocationHandler {
         return (ResultSetMetaData)Proxy.newProxyInstance(classLoader, interfaces, invocationHandler);
     }
 
+    /**
+     * <p>Array of column names and class names for metadata.</p>
+     */
+    protected String metadata[][] = {
+        { "bigDecimalProperty", java.math.BigDecimal.class.getName() },
+        { "booleanProperty", Boolean.class.getName() },
+        { "byteProperty", Byte.class.getName() },
+        { "dateProperty", java.sql.Date.class.getName() },
+        { "doubleProperty", Double.class.getName() },
+        { "floatProperty", Float.class.getName() },
+        { "intProperty", Integer.class.getName() },
+        { "longProperty", Long.class.getName() },
+        { "nullProperty", String.class.getName() },
+        { "shortProperty", Short.class.getName() },
+        { "stringProperty", String.class.getName() },
+        { "timeProperty", java.sql.Time.class.getName() },
+        { "timestampProperty", java.sql.Timestamp.class.getName() },
+    };
+
+    public String getCatalogName(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
+    public String getColumnClassName(final int columnIndex) throws SQLException {
+        return metadata[columnIndex - 1][1];
+    }
+
+    public int getColumnCount() throws SQLException {
+        return metadata.length;
+    }
+
+    public int getColumnDisplaySize(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
+    public String getColumnLabel(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
+    public String getColumnName(final int columnIndex) throws SQLException {
+        return metadata[columnIndex - 1][0];
+    }
+
+    public Integer getColumnType(final int columnIndex) throws SQLException {
+        final String columnName = getColumnName(columnIndex);
+        int sqlType = Types.OTHER;
+        switch (columnName) {
+        case "bigDecimalProperty":
+            sqlType = Types.DECIMAL;
+// Types.BOOLEAN only introduced in JDK 1.4
+//        } else if (columnName.equals("booleanProperty")) {
+//            sqlType = Types.BOOLEAN;
+            break;
+        case "byteProperty":
+            sqlType = Types.TINYINT;
+            break;
+        case "dateProperty":
+            sqlType = Types.DATE;
+            break;
+        case "doubleProperty":
+            sqlType = Types.DOUBLE;
+            break;
+        case "floatProperty":
+            sqlType = Types.FLOAT;
+            break;
+        case "intProperty":
+            sqlType = Types.INTEGER;
+            break;
+        case "longProperty":
+            sqlType = Types.BIGINT;
+            break;
+        case "nullProperty":
+            sqlType = Types.VARCHAR;
+            break;
+        case "shortProperty":
+            sqlType = Types.SMALLINT;
+            break;
+        case "stringProperty":
+            sqlType = Types.VARCHAR;
+            break;
+        case "timeProperty":
+            sqlType = Types.TIME;
+            break;
+        case "timestampProperty":
+            sqlType = Types.TIMESTAMP;
+            break;
+        default:
+            sqlType = Types.OTHER;
+            break;
+        }
+        return Integer.valueOf(sqlType);
+    }
+
+    public String getColumnTypeName(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
+    public int getPrecision(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
+    public int getScale(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
+    public String getSchemaName(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
+    public String getTableName(final int columnIndex) throws SQLException {
+        throw new UnsupportedOperationException();
+    }
+
     /**
      * Handles method invocation on the {@link ResultSetMetaData} proxy.
      *
@@ -90,161 +175,59 @@ public class TestResultSetMetaData implements InvocationHandler {
      * @return The result of invoking the method.
      * @throws Throwable if an error occurs.
      */
+    @Override
     public Object invoke(final Object proxy, final Method method, final Object[] args) throws Throwable {
         final String methodName = method.getName();
-        if ("getColumnClassName".equals(methodName)) {
+        switch (methodName) {
+        case "getColumnClassName":
             return getColumnClassName(((Integer)args[0]).intValue());
-        } if ("getColumnCount".equals(methodName)) {
-            return new Integer(getColumnCount());
-        } if ("getColumnName".equals(methodName)) {
+        case "getColumnCount":
+            return Integer.valueOf(getColumnCount());
+        case "getColumnName":
             return getColumnName(((Integer)args[0]).intValue());
-        } if ("getColumnType".equals(methodName)) {
+        case "getColumnType":
             return getColumnType(((Integer)args[0]).intValue());
+        default:
+            break;
         }
 
         throw new UnsupportedOperationException(methodName + " not implemented");
     }
 
-    // ---------------------------------------------------- Implemented Methods
-
-
-    public String getColumnClassName(final int columnIndex) throws SQLException {
-        return (metadata[columnIndex - 1][1]);
-    }
-
-
-    public int getColumnCount() throws SQLException {
-        return (metadata.length);
-    }
-
-    public String getColumnName(final int columnIndex) throws SQLException {
-        return (metadata[columnIndex - 1][0]);
-    }
-
-
-    public Integer getColumnType(final int columnIndex) throws SQLException {
-        final String columnName = getColumnName(columnIndex);
-        int sqlType = Types.OTHER;
-        if (columnName.equals("bigDecimalProperty")) {
-            sqlType = Types.DECIMAL;
-// Types.BOOLEAN only introduced in JDK 1.4
-//        } else if (columnName.equals("booleanProperty")) {
-//            sqlType = Types.BOOLEAN;
-        } else if (columnName.equals("byteProperty")) {
-            sqlType = Types.TINYINT;
-        } else if (columnName.equals("dateProperty")) {
-            sqlType = Types.DATE;
-        } else if (columnName.equals("doubleProperty")) {
-            sqlType = Types.DOUBLE;
-        } else if (columnName.equals("floatProperty")) {
-            sqlType = Types.FLOAT;
-        } else if (columnName.equals("intProperty")) {
-            sqlType = Types.INTEGER;
-        } else if (columnName.equals("longProperty")) {
-            sqlType = Types.BIGINT;
-        } else if (columnName.equals("nullProperty")) {
-            sqlType = Types.VARCHAR;
-        } else if (columnName.equals("shortProperty")) {
-            sqlType = Types.SMALLINT;
-        } else if (columnName.equals("stringProperty")) {
-            sqlType = Types.VARCHAR;
-        } else if (columnName.equals("timeProperty")) {
-            sqlType = Types.TIME;
-        } else if (columnName.equals("timestampProperty")) {
-            sqlType = Types.TIMESTAMP;
-        } else {
-            sqlType = Types.OTHER;
-        }
-        return new Integer(sqlType);
-    }
-
-
-    // -------------------------------------------------- Unimplemented Methods
-
-
-    public String getCatalogName(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
-    public int getColumnDisplaySize(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
-    public String getColumnLabel(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
-    public String getColumnTypeName(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
-    public int getPrecision(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
-    public int getScale(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
-    public String getSchemaName(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
-    public String getTableName(final int columnIndex) throws SQLException {
-        throw new UnsupportedOperationException();
-    }
-
-
     public boolean isAutoIncrement(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public boolean isCaseSensitive(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public boolean isCurrency(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public boolean isDefinitelyWritable(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public int isNullable(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public boolean isReadOnly(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public boolean isSearchable(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public boolean isSigned(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
     public boolean isWritable(final int columnIndex) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
-
 }
