@@ -15,7 +15,6 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils;
 
 import java.io.ByteArrayInputStream;
@@ -26,23 +25,23 @@ import java.io.ObjectOutputStream;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 
-
 /**
  * <p>Test Case for the <code>WrapDynaBean</code> implementation class.
  * These tests were based on the ones in <code>PropertyUtilsTestCase</code>
  * because the two classes provide similar levels of functionality.</p>
  *
- * @version $Id$
  */
 
 public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
 
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
 
-    // ---------------------------------------------------- Instance Variables
-
-
-    // ---------------------------------------------------------- Constructors
+        return new TestSuite(WrapDynaBeanTestCase.class);
 
+    }
 
     /**
      * Construct a new instance of this test case.
@@ -55,56 +54,6 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
 
     }
 
-
-    // -------------------------------------------------- Overall Test Methods
-
-
-    /**
-     * Set up instance variables required by this test case.
-     */
-    @Override
-    public void setUp() throws Exception {
-
-        bean = new WrapDynaBean(new TestBean());
-
-    }
-
-
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-
-        return (new TestSuite(WrapDynaBeanTestCase.class));
-
-    }
-
-
-    /**
-     * Tear down instance variables required by this test case.
-     */
-    @Override
-    public void tearDown() {
-
-        bean = null;
-
-    }
-
-
-
-    // ------------------------------------------------ Individual Test Methods
-
-
-    /**
-     * The <code>set()</code> method.
-     */
-    public void testSimpleProperties() {
-
-        checkSimplePropertyAccess();
-
-    }
-
-
     /**
      * Helper method for testing whether basic access to properties works as
      * expected.
@@ -144,6 +93,87 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
         }
     }
 
+    /**
+     * Do serialization and deserialization.
+     */
+    private Object serializeDeserialize(final Object target, final String text) {
+
+        // Serialize the test object
+        final ByteArrayOutputStream baos = new ByteArrayOutputStream();
+        try {
+            final ObjectOutputStream oos = new ObjectOutputStream(baos);
+            oos.writeObject(target);
+            oos.flush();
+            oos.close();
+        } catch (final Exception e) {
+            fail(text + ": Exception during serialization: " + e);
+        }
+
+        // Deserialize the test object
+        Object result = null;
+        try {
+            final ByteArrayInputStream bais =
+                new ByteArrayInputStream(baos.toByteArray());
+            final ObjectInputStream ois = new ObjectInputStream(bais);
+            result = ois.readObject();
+            bais.close();
+        } catch (final Exception e) {
+            fail(text + ": Exception during deserialization: " + e);
+        }
+        return result;
+
+    }
+
+    /**
+     * Set up instance variables required by this test case.
+     */
+    @Override
+    public void setUp() throws Exception {
+
+        bean = new WrapDynaBean(new TestBean());
+
+    }
+
+    /**
+     * Tear down instance variables required by this test case.
+     */
+    @Override
+    public void tearDown() {
+
+        bean = null;
+
+    }
+
+    /** Tests getInstance method */
+    public void testGetInstance() {
+        final AlphaBean alphaBean = new AlphaBean("Now On Air... John Peel");
+        final WrapDynaBean dynaBean = new WrapDynaBean(alphaBean);
+        final Object wrappedInstance = dynaBean.getInstance();
+        assertTrue("Object type is AlphaBean", wrappedInstance instanceof AlphaBean);
+        final AlphaBean wrappedAlphaBean = (AlphaBean) wrappedInstance;
+        assertTrue("Same Object", wrappedAlphaBean == alphaBean);
+    }
+
+    /**
+     * Tests whether caching works for WrapDynaClass objects.
+     */
+    public void testGetWrapDynaClassFromCache() {
+        final WrapDynaClass clazz = WrapDynaClass.createDynaClass(TestBean.class);
+        assertSame("Instance not cached", clazz,
+                WrapDynaClass.createDynaClass(TestBean.class));
+    }
+
+    /**
+     * Tests whether the PropertyUtilsBean instance associated with a WrapDynaClass is
+     * taken into account when accessing an instance from the cache.
+     */
+    public void testGetWrapDynaClassFromCacheWithPropUtils() {
+        final WrapDynaClass clazz = WrapDynaClass.createDynaClass(TestBean.class);
+        final PropertyUtilsBean pu = new PropertyUtilsBean();
+        final WrapDynaClass clazz2 = WrapDynaClass.createDynaClass(TestBean.class, pu);
+        assertNotSame("Got same instance from cache", clazz, clazz2);
+    }
+
     /**
      * The <code>set()</code> method.
      */
@@ -184,6 +214,31 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
 
     }
 
+    /**
+     * Tests whether a WrapDynaClass can be provided when constructing a bean.
+     */
+    public void testInitWithDynaClass() {
+        final WrapDynaClass clazz = WrapDynaClass.createDynaClass(TestBean.class);
+        bean = new WrapDynaBean(new TestBean(), clazz);
+        assertSame("Wrong DynaClass", clazz, bean.getDynaClass());
+        checkSimplePropertyAccess();
+    }
+
+    /**
+     * Tests whether a custom PropertyUtilsBean instance can be used for introspection of
+     * bean properties.
+     */
+    public void testIntrospectionWithCustomPropUtils() {
+        final PropertyUtilsBean pu = new PropertyUtilsBean();
+        pu.addBeanIntrospector(new FluentPropertyBeanIntrospector());
+        final WrapDynaClass dynaClass = WrapDynaClass.createDynaClass(
+                FluentIntrospectionTestBean.class, pu);
+        final FluentIntrospectionTestBean obj = new FluentIntrospectionTestBean();
+        bean = new WrapDynaBean(obj, dynaClass);
+        bean.set("fluentProperty", "testvalue");
+        assertEquals("Property not set", "testvalue", obj.getStringProperty());
+    }
+
     /**
      * The <code>contains()</code> method is not supported by the
      * <code>WrapDynaBean</code> implementation class.
@@ -201,7 +256,6 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
             fail("Exception: " + t);
         }
 
-
         try {
             assertTrue("Can not see unknown key",
                     !bean.contains("mappedProperty", "Unknown Key"));
@@ -214,7 +268,6 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
 
     }
 
-
     /**
      * The <code>remove()</code> method is not supported by the
      * <code>WrapDynaBean</code> implementation class.
@@ -250,16 +303,6 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
 
     }
 
-    /** Tests getInstance method */
-    public void testGetInstance() {
-        final AlphaBean alphaBean = new AlphaBean("Now On Air... John Peel");
-        final WrapDynaBean dynaBean = new WrapDynaBean(alphaBean);
-        final Object wrappedInstance = dynaBean.getInstance();
-        assertTrue("Object type is AlphaBean", wrappedInstance instanceof AlphaBean);
-        final AlphaBean wrappedAlphaBean = (AlphaBean) wrappedInstance;
-        assertTrue("Same Object", wrappedAlphaBean == alphaBean);
-    }
-
     /** Tests the newInstance implementation for WrapDynaClass */
     public void testNewInstance() throws Exception {
         final WrapDynaClass dynaClass = WrapDynaClass.createDynaClass(AlphaBean.class);
@@ -269,7 +312,6 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
         assertTrue("Object type is AlphaBean", dynaBean.getInstance() instanceof AlphaBean);
     }
 
-
     /**
      * Serialization and deserialization tests.
      * (WrapDynaBean is now serializable, although WrapDynaClass still is not)
@@ -279,8 +321,8 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
 
         // Create a bean and set a value
         final WrapDynaBean origBean = new WrapDynaBean(new TestBean());
-        final Integer newValue = new Integer(789);
-        assertEquals("origBean default", new Integer(123), origBean.get("intProperty"));
+        final Integer newValue = Integer.valueOf(789);
+        assertEquals("origBean default", Integer.valueOf(123), origBean.get("intProperty"));
         origBean.set("intProperty", newValue);
         assertEquals("origBean new value", newValue, origBean.get("intProperty"));
 
@@ -291,78 +333,11 @@ public class WrapDynaBeanTestCase extends BasicDynaBeanTestCase {
     }
 
     /**
-     * Do serialization and deserialization.
+     * The <code>set()</code> method.
      */
-    private Object serializeDeserialize(final Object target, final String text) {
+    public void testSimpleProperties() {
 
-        // Serialize the test object
-        final ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        try {
-            final ObjectOutputStream oos = new ObjectOutputStream(baos);
-            oos.writeObject(target);
-            oos.flush();
-            oos.close();
-        } catch (final Exception e) {
-            fail(text + ": Exception during serialization: " + e);
-        }
-
-        // Deserialize the test object
-        Object result = null;
-        try {
-            final ByteArrayInputStream bais =
-                new ByteArrayInputStream(baos.toByteArray());
-            final ObjectInputStream ois = new ObjectInputStream(bais);
-            result = ois.readObject();
-            bais.close();
-        } catch (final Exception e) {
-            fail(text + ": Exception during deserialization: " + e);
-        }
-        return result;
-
-    }
-
-    /**
-     * Tests whether a WrapDynaClass can be provided when constructing a bean.
-     */
-    public void testInitWithDynaClass() {
-        final WrapDynaClass clazz = WrapDynaClass.createDynaClass(TestBean.class);
-        bean = new WrapDynaBean(new TestBean(), clazz);
-        assertSame("Wrong DynaClass", clazz, bean.getDynaClass());
         checkSimplePropertyAccess();
-    }
 
-    /**
-     * Tests whether caching works for WrapDynaClass objects.
-     */
-    public void testGetWrapDynaClassFromCache() {
-        final WrapDynaClass clazz = WrapDynaClass.createDynaClass(TestBean.class);
-        assertSame("Instance not cached", clazz,
-                WrapDynaClass.createDynaClass(TestBean.class));
-    }
-
-    /**
-     * Tests whether the PropertyUtilsBean instance associated with a WrapDynaClass is
-     * taken into account when accessing an instance from the cache.
-     */
-    public void testGetWrapDynaClassFromCacheWithPropUtils() {
-        final WrapDynaClass clazz = WrapDynaClass.createDynaClass(TestBean.class);
-        final PropertyUtilsBean pu = new PropertyUtilsBean();
-        final WrapDynaClass clazz2 = WrapDynaClass.createDynaClass(TestBean.class, pu);
-        assertNotSame("Got same instance from cache", clazz, clazz2);
-    }
-
-    /**
-     * Tests whether a custom PropertyUtilsBean instance can be used for introspection of
-     * bean properties.
-     */
-    public void testIntrospectionWithCustomPropUtils() {
-        final PropertyUtilsBean pu = new PropertyUtilsBean();
-        pu.addBeanIntrospector(new FluentPropertyBeanIntrospector());
-        final WrapDynaClass dynaClass = WrapDynaClass.createDynaClass(
-                FluentIntrospectionTestBean.class, pu);
-        final FluentIntrospectionTestBean obj = new FluentIntrospectionTestBean();
-        bean = new WrapDynaBean(obj, dynaClass);
-        bean.set("fluentProperty", "testvalue");
-        assertEquals("Property not set", "testvalue", obj.getStringProperty());
     }
 }
