@@ -16,37 +16,24 @@
  */
 package org.apache.commons.beanutils.bugs;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.PropertyUtils;
 import org.apache.commons.beanutils.bugs.other.Jira18BeanFactory;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Test case for Jira issue# BEANUTILS-18.
 
  * <p>This test case demonstrates the issue.
  *
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-18">https://issues.apache.org/jira/browse/BEANUTILS-18</a>
  */
 public class Jira18TestCase extends TestCase {
 
-    private final Log log = LogFactory.getLog(Jira18TestCase.class);
-    private Object bean;
-
-    /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
-     */
-    public Jira18TestCase(final String name) {
-        super(name);
-    }
-
     /**
      * Run the Test.
      *
@@ -55,14 +42,26 @@ public class Jira18TestCase extends TestCase {
     public static void main(final String[] args) {
         junit.textui.TestRunner.run(suite());
     }
-
     /**
      * Create a test suite for this test.
      *
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira18TestCase.class));
+        return new TestSuite(Jira18TestCase.class);
+    }
+
+    private final Log log = LogFactory.getLog(Jira18TestCase.class);
+
+    private Object bean;
+
+    /**
+     * Create a test case with the specified name.
+     *
+     * @param name The name of the test
+     */
+    public Jira18TestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -86,96 +85,6 @@ public class Jira18TestCase extends TestCase {
         super.tearDown();
     }
 
-    /**
-     * Test {@link PropertyUtils#isReadable(Object, String)}
-     * for simple properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_isReadable() {
-        boolean result = false;
-        try {
-            result = PropertyUtils.isReadable(bean, "simple");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertFalse("PropertyUtils.isReadable(bean, \"simple\") returned true", result);
-    }
-
-    /**
-     * Test {@link PropertyUtils#isWriteable(Object, String)}
-     * for simple properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_isWriteable() {
-        boolean result = false;
-        try {
-            result = PropertyUtils.isWriteable(bean, "simple");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertFalse("PropertyUtils.isWriteable(bean, \"simple\") returned true", result);
-    }
-
-    /**
-     * Test {@link PropertyUtils#isReadable(Object, String)}
-     * for indexed properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_isReadable_Indexed() {
-        boolean result = false;
-        try {
-            result = PropertyUtils.isReadable(bean, "indexed");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertFalse("PropertyUtils.isReadable(bean, \"indexed\") returned true", result);
-    }
-
-    /**
-     * Test {@link PropertyUtils#isWriteable(Object, String)}
-     * for indexed properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_isWriteable_Indexed() {
-        boolean result = false;
-        try {
-            result = PropertyUtils.isWriteable(bean, "indexed");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertFalse("PropertyUtils.isWriteable(bean, \"indexed\") returned true", result);
-    }
-
-    /**
-     * Test {@link PropertyUtils#isReadable(Object, String)}
-     * for Mapped properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_isReadable_Mapped() {
-        boolean result = false;
-        try {
-            result = PropertyUtils.isReadable(bean, "mapped");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertFalse("PropertyUtils.isReadable(bean, \"mapped\") returned true", result);
-    }
-
-    /**
-     * Test {@link PropertyUtils#isWriteable(Object, String)}
-     * for Mapped properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_isWriteable_Mapped() {
-        boolean result = false;
-        try {
-            result = PropertyUtils.isWriteable(bean, "mapped");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertFalse("PropertyUtils.isWriteable(bean, \"mapped\") returned true", result);
-    }
-
     /**
      * Test {@link PropertyUtils#getProperty(Object, String)}
      * for simple properties.
@@ -194,23 +103,6 @@ public class Jira18TestCase extends TestCase {
         assertTrue("Expected NoSuchMethodException but returned '" + result + "'", threwNoSuchMethodException);
     }
 
-    /**
-     * Test {@link PropertyUtils#setProperty(Object, String, Object)}
-     * for simple properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_setProperty() {
-        boolean threwNoSuchMethodException = false;
-        try {
-            PropertyUtils.setProperty(bean, "simple", "BAR");
-        } catch (final NoSuchMethodException ex) {
-            threwNoSuchMethodException = true; // expected result
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertTrue("Expected NoSuchMethodException", threwNoSuchMethodException);
-    }
-
     /**
      * Test {@link PropertyUtils#getProperty(Object, String)}
      * for indexed properties.
@@ -229,23 +121,6 @@ public class Jira18TestCase extends TestCase {
         assertTrue("Expected NoSuchMethodException but returned '" + result + "'", threwNoSuchMethodException);
     }
 
-    /**
-     * Test {@link PropertyUtils#setProperty(Object, String, Object)}
-     * for indexed properties.
-     */
-    public void testIssue_BEANUTILS_18_PropertyUtils_setProperty_Indexed() {
-        boolean threwNoSuchMethodException = false;
-        try {
-            PropertyUtils.setProperty(bean, "indexed[0]", "BAR");
-        } catch (final NoSuchMethodException ex) {
-            threwNoSuchMethodException = true; // expected result
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("Threw exception: " + t);
-        }
-        assertTrue("Expected NoSuchMethodException", threwNoSuchMethodException);
-    }
-
     /**
      * Test {@link PropertyUtils#getProperty(Object, String)}
      * for mapped properties.
@@ -264,6 +139,130 @@ public class Jira18TestCase extends TestCase {
         assertTrue("Expected NoSuchMethodException but returned '" + result + "'", threwNoSuchMethodException);
     }
 
+    /**
+     * Test {@link PropertyUtils#isReadable(Object, String)}
+     * for simple properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_isReadable() {
+        boolean result = false;
+        try {
+            result = PropertyUtils.isReadable(bean, "simple");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertFalse("PropertyUtils.isReadable(bean, \"simple\") returned true", result);
+    }
+
+    /**
+     * Test {@link PropertyUtils#isReadable(Object, String)}
+     * for indexed properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_isReadable_Indexed() {
+        boolean result = false;
+        try {
+            result = PropertyUtils.isReadable(bean, "indexed");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertFalse("PropertyUtils.isReadable(bean, \"indexed\") returned true", result);
+    }
+
+    /**
+     * Test {@link PropertyUtils#isReadable(Object, String)}
+     * for Mapped properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_isReadable_Mapped() {
+        boolean result = false;
+        try {
+            result = PropertyUtils.isReadable(bean, "mapped");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertFalse("PropertyUtils.isReadable(bean, \"mapped\") returned true", result);
+    }
+
+    /**
+     * Test {@link PropertyUtils#isWriteable(Object, String)}
+     * for simple properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_isWriteable() {
+        boolean result = false;
+        try {
+            result = PropertyUtils.isWriteable(bean, "simple");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertFalse("PropertyUtils.isWriteable(bean, \"simple\") returned true", result);
+    }
+
+    /**
+     * Test {@link PropertyUtils#isWriteable(Object, String)}
+     * for indexed properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_isWriteable_Indexed() {
+        boolean result = false;
+        try {
+            result = PropertyUtils.isWriteable(bean, "indexed");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertFalse("PropertyUtils.isWriteable(bean, \"indexed\") returned true", result);
+    }
+
+    /**
+     * Test {@link PropertyUtils#isWriteable(Object, String)}
+     * for Mapped properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_isWriteable_Mapped() {
+        boolean result = false;
+        try {
+            result = PropertyUtils.isWriteable(bean, "mapped");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertFalse("PropertyUtils.isWriteable(bean, \"mapped\") returned true", result);
+    }
+
+    /**
+     * Test {@link PropertyUtils#setProperty(Object, String, Object)}
+     * for simple properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_setProperty() {
+        boolean threwNoSuchMethodException = false;
+        try {
+            PropertyUtils.setProperty(bean, "simple", "BAR");
+        } catch (final NoSuchMethodException ex) {
+            threwNoSuchMethodException = true; // expected result
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertTrue("Expected NoSuchMethodException", threwNoSuchMethodException);
+    }
+
+    /**
+     * Test {@link PropertyUtils#setProperty(Object, String, Object)}
+     * for indexed properties.
+     */
+    public void testIssue_BEANUTILS_18_PropertyUtils_setProperty_Indexed() {
+        boolean threwNoSuchMethodException = false;
+        try {
+            PropertyUtils.setProperty(bean, "indexed[0]", "BAR");
+        } catch (final NoSuchMethodException ex) {
+            threwNoSuchMethodException = true; // expected result
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("Threw exception: " + t);
+        }
+        assertTrue("Expected NoSuchMethodException", threwNoSuchMethodException);
+    }
+
     /**
      * Test {@link PropertyUtils#setProperty(Object, String, Object)}
      * for mapped properties.
