@@ -18,10 +18,6 @@ package org.apache.commons.beanutils.bugs;
 
 import java.lang.reflect.Method;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.MethodUtils;
 import org.apache.commons.beanutils.PropertyUtils;
 import org.apache.commons.beanutils.bugs.other.Jira298BeanFactory;
@@ -29,23 +25,15 @@ import org.apache.commons.beanutils.bugs.other.Jira298BeanFactory.IX;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-298">https://issues.apache.org/jira/browse/BEANUTILS-298</a>
  */
 public class Jira298TestCase extends TestCase {
 
-    private final Log log = LogFactory.getLog(Jira298TestCase.class);
-
-    /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
-     */
-    public Jira298TestCase(final String name) {
-        super(name);
-    }
-
     /**
      * Run the Test.
      *
@@ -61,7 +49,18 @@ public class Jira298TestCase extends TestCase {
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira298TestCase.class));
+        return new TestSuite(Jira298TestCase.class);
+    }
+
+    private final Log log = LogFactory.getLog(Jira298TestCase.class);
+
+    /**
+     * Create a test case with the specified name.
+     *
+     * @param name The name of the test
+     */
+    public Jira298TestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -84,6 +83,22 @@ public class Jira298TestCase extends TestCase {
         super.tearDown();
     }
 
+    /**
+     * Test {@link MethodUtils#getAccessibleMethod(Class, Method)}
+     */
+    public void testIssue_BEANUTILS_298_MethodUtils_getAccessibleMethod() {
+        final Object bean = Jira298BeanFactory.createImplX();
+        Object result = null;
+        try {
+            final Method m2 = MethodUtils.getAccessibleMethod(bean.getClass(), "getName", new Class[0]);
+            result = m2.invoke(bean);
+        } catch (final Throwable t) {
+            log.error("Failed: " + t.getMessage(), t);
+            fail("Threw exception: " + t);
+        }
+        assertEquals("BaseX name value", result);
+    }
+
     /**
      * Test {@link PropertyUtils#getProperty(Object, String)}
      */
@@ -113,20 +128,4 @@ public class Jira298TestCase extends TestCase {
         }
         assertEquals("new name", ((IX)bean).getName());
     }
-
-    /**
-     * Test {@link MethodUtils#getAccessibleMethod(Class, Method)}
-     */
-    public void testIssue_BEANUTILS_298_MethodUtils_getAccessibleMethod() {
-        final Object bean = Jira298BeanFactory.createImplX();
-        Object result = null;
-        try {
-            final Method m2 = MethodUtils.getAccessibleMethod(bean.getClass(), "getName", new Class[0]);
-            result = m2.invoke(bean);
-        } catch (final Throwable t) {
-            log.error("Failed: " + t.getMessage(), t);
-            fail("Threw exception: " + t);
-        }
-        assertEquals("BaseX name value", result);
-    }
 }
