@@ -16,25 +16,39 @@
  */
 package org.apache.commons.beanutils.bugs;
 
+import org.apache.commons.beanutils.BeanUtils;
+
 import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.beanutils.BeanUtils;
-
 /**
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-345">https://issues.apache.org/jira/browse/BEANUTILS-345</a>
  */
 public class Jira345TestCase extends TestCase {
 
-    /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
-     */
-    public Jira345TestCase(final String name) {
-        super(name);
+    /** Example Bean */
+    public static class MyBean {
+
+        private String[][] matr = {{"1","2"},{"3","4"}};
+
+        private String[][][] matr3D = {
+                {{"11","12"}, {"13","14"}},
+                {{"21","22"}, {"23","24"}},
+        };
+
+        public String[][] getMatr() {
+            return matr;
+        }
+        public String[][][] getMatr3D() {
+            return matr3D;
+        }
+        public void setMatr(final String[][] matr) {
+            this.matr = matr;
+        }
+        public void setMatr3D(final String[][][] matr3D) {
+            this.matr3D = matr3D;
+        }
     }
 
     /**
@@ -52,7 +66,16 @@ public class Jira345TestCase extends TestCase {
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira345TestCase.class));
+        return new TestSuite(Jira345TestCase.class);
+    }
+
+    /**
+     * Create a test case with the specified name.
+     *
+     * @param name The name of the test
+     */
+    public Jira345TestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -92,28 +115,4 @@ public class Jira345TestCase extends TestCase {
         BeanUtils.setProperty(myBean, "matr3D[0][0][0]","Sample");
         assertEquals("Sample", myBean.getMatr3D()[0][0][0]);
     }
-
-    /** Example Bean */
-    public static class MyBean {
-
-        private String[][] matr = new String[][]{{"1","2"},{"3","4"}};
-
-        private String[][][] matr3D = new String[][][] {
-                {{"11","12"}, {"13","14"}},
-                {{"21","22"}, {"23","24"}},
-        };
-
-        public String[][] getMatr() {
-            return matr;
-        }
-        public void setMatr(final String[][] matr) {
-            this.matr = matr;
-        }
-        public String[][][] getMatr3D() {
-            return matr3D;
-        }
-        public void setMatr3D(final String[][][] matr3D) {
-            this.matr3D = matr3D;
-        }
-    }
 }
