@@ -16,29 +16,43 @@
  */
 package org.apache.commons.beanutils.bugs;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.PropertyUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-349">https://issues.apache.org/jira/browse/BEANUTILS-349</a>
  */
 public class Jira349TestCase extends TestCase {
 
-    private final Log log = LogFactory.getLog(Jira349TestCase .class);
+    /**
+     * Test Bean with a Boolean object property.
+     */
+    public static class ObjectBean {
+        private Boolean testProperty;
+        public Boolean getTestProperty() {
+            return testProperty;
+        }
+        public void setTestProperty(final Boolean testProperty) {
+            this.testProperty = testProperty;
+        }
+    }
 
     /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
+     * Test Bean with a primitive boolean property.
      */
-    public Jira349TestCase(final String name) {
-        super(name);
+    public static class PrimitiveBean {
+        private boolean testProperty;
+        public boolean getTestProperty() {
+            return testProperty;
+        }
+        public void setTestProperty(final boolean testProperty) {
+            this.testProperty = testProperty;
+        }
     }
 
     /**
@@ -56,7 +70,18 @@ public class Jira349TestCase extends TestCase {
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira349TestCase.class));
+        return new TestSuite(Jira349TestCase.class);
+    }
+
+    private final Log log = LogFactory.getLog(Jira349TestCase .class);
+
+    /**
+     * Create a test case with the specified name.
+     *
+     * @param name The name of the test
+     */
+    public Jira349TestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -97,30 +122,4 @@ public class Jira349TestCase extends TestCase {
             fail("Threw exception: " + t);
         }
     }
-
-    /**
-     * Test Bean with a primitive boolean property.
-     */
-    public static class PrimitiveBean {
-        private boolean testProperty;
-        public boolean getTestProperty() {
-            return testProperty;
-        }
-        public void setTestProperty(final boolean testProperty) {
-            this.testProperty = testProperty;
-        }
-    }
-
-    /**
-     * Test Bean with a Boolean object property.
-     */
-    public static class ObjectBean {
-        private Boolean testProperty;
-        public Boolean getTestProperty() {
-            return testProperty;
-        }
-        public void setTestProperty(final Boolean testProperty) {
-            this.testProperty = testProperty;
-        }
-    }
 }
