@@ -18,25 +18,74 @@ package org.apache.commons.beanutils.bugs;
 
 import java.beans.PropertyDescriptor;
 
+import org.apache.commons.beanutils.PropertyUtils;
+
 import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.beanutils.PropertyUtils;
-
 /**
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-357">https://issues.apache.org/jira/browse/BEANUTILS-357</a>
  */
 public class Jira357TestCase extends TestCase {
 
     /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
+     * Abstract test bean.
      */
-    public Jira357TestCase(final String name) {
-        super(name);
+    public abstract static class AbstractTestBean {
+
+        /** Inner Class */
+        public abstract static class InnerClass {
+            private String firstName;
+            public String getInnerName() {
+                return firstName;
+            }
+            public void setInnerName(final String firstName) {
+                this.firstName = firstName;
+            }
+        }
+        public abstract String getFoo();
+
+        public abstract AbstractTestBean.InnerClass getInnerClassProperty();
+        public abstract boolean isBar();
+
+        public abstract void setBar(boolean bar);
+
+        public abstract void setFoo(String foo);
+    }
+
+    /**
+     * Concrete bean implementation.
+     */
+    public static class ConcreteTestBean extends AbstractTestBean {
+
+        private String foo;
+        private boolean bar;
+        private ConcreteTestBean.InnerClass innerClassProperty;
+
+        @Override
+        public String getFoo() {
+            return foo;
+        }
+        @Override
+        public ConcreteTestBean.InnerClass getInnerClassProperty() {
+            return innerClassProperty;
+        }
+        @Override
+        public boolean isBar() {
+            return bar;
+        }
+        @Override
+        public void setBar(final boolean bar) {
+            this.bar = bar;
+        }
+        @Override
+        public void setFoo(final String foo) {
+            this.foo = foo;
+        }
+        public void setInnerClassProperty(final ConcreteTestBean.InnerClass innerClassProperty) {
+            this.innerClassProperty = innerClassProperty;
+        }
     }
 
     /**
@@ -54,52 +103,16 @@ public class Jira357TestCase extends TestCase {
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira357TestCase.class));
+        return new TestSuite(Jira357TestCase.class);
     }
 
     /**
-     * Set up.
+     * Create a test case with the specified name.
      *
-     * @throws java.lang.Exception
+     * @param name The name of the test
      */
-    @Override
-    protected void setUp() throws Exception {
-        super.setUp();
-    }
-
-    /**
-     * Tear Down.
-     *
-     * @throws java.lang.Exception
-     */
-    @Override
-    protected void tearDown() throws Exception {
-        super.tearDown();
-    }
-
-    /**
-     * Test {@link PropertyUtils#getPropertyDescriptors(Class)}
-     */
-    public void testPropertyUtils_getPropertyDescriptors_Foo() throws Exception {
-        checkReadMethod("foo", ConcreteTestBean.class);
-    }
-
-    /**
-     * Test {@link PropertyUtils#getPropertyDescriptors(Class)}
-     */
-    public void testPropertyUtils_getPropertyDescriptors_Bar() throws Exception {
-
-        // FIXME the isBar() method returning AbstractTestBean.class as the
-        //       declaring class instead of ConcreteTestBean.class
-        //       causing this test to fail - so its commented out for now
-        //checkReadMethod("bar", ConcreteTestBean.class);
-    }
-
-    /**
-     * Test {@link PropertyUtils#getPropertyDescriptors(Class)}
-     */
-    public void testPropertyUtils_getPropertyDescriptors_InnerClassProperty() throws Exception {
-        checkReadMethod("innerClassProperty", ConcreteTestBean.class);
+    public Jira357TestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -126,7 +139,7 @@ public class Jira357TestCase extends TestCase {
      */
     private PropertyDescriptor findDescriptor(final String propertyName, final PropertyDescriptor[] descriptors) {
         if (descriptors != null) {
-            for (PropertyDescriptor descriptor : descriptors) {
+            for (final PropertyDescriptor descriptor : descriptors) {
                 if (propertyName.equals(descriptor.getName())) {
                     return descriptor;
                 }
@@ -136,61 +149,47 @@ public class Jira357TestCase extends TestCase {
     }
 
     /**
-     * Abstract test bean.
+     * Set up.
+     *
+     * @throws java.lang.Exception
      */
-    public abstract static class AbstractTestBean {
-
-        public abstract String getFoo();
-        public abstract void setFoo(String foo);
-
-        public abstract boolean isBar();
-        public abstract void setBar(boolean bar);
-
-        public abstract AbstractTestBean.InnerClass getInnerClassProperty();
-
-        /** Inner Class */
-        public abstract static class InnerClass {
-            private String firstName;
-            public String getInnerName() {
-                return firstName;
-            }
-            public void setInnerName(final String firstName) {
-                this.firstName = firstName;
-            }
-        }
+    @Override
+    protected void setUp() throws Exception {
+        super.setUp();
     }
 
     /**
-     * Concrete bean implementation.
+     * Tear Down.
+     *
+     * @throws java.lang.Exception
      */
-    public static class ConcreteTestBean extends AbstractTestBean {
+    @Override
+    protected void tearDown() throws Exception {
+        super.tearDown();
+    }
 
-        private String foo;
-        private boolean bar;
-        private ConcreteTestBean.InnerClass innerClassProperty;
+    /**
+     * Test {@link PropertyUtils#getPropertyDescriptors(Class)}
+     */
+    public void testPropertyUtils_getPropertyDescriptors_Bar() throws Exception {
 
-        @Override
-        public String getFoo() {
-            return foo;
-        }
-        @Override
-        public void setFoo(final String foo) {
-            this.foo = foo;
-        }
-        @Override
-        public boolean isBar() {
-            return bar;
-        }
-        @Override
-        public void setBar(final boolean bar) {
-            this.bar = bar;
-        }
-        @Override
-        public ConcreteTestBean.InnerClass getInnerClassProperty() {
-            return innerClassProperty;
-        }
-        public void setInnerClassProperty(final ConcreteTestBean.InnerClass innerClassProperty) {
-            this.innerClassProperty = innerClassProperty;
-        }
+        // FIXME the isBar() method returning AbstractTestBean.class as the
+        //       declaring class instead of ConcreteTestBean.class
+        //       causing this test to fail - so its commented out for now
+        //checkReadMethod("bar", ConcreteTestBean.class);
+    }
+
+    /**
+     * Test {@link PropertyUtils#getPropertyDescriptors(Class)}
+     */
+    public void testPropertyUtils_getPropertyDescriptors_Foo() throws Exception {
+        checkReadMethod("foo", ConcreteTestBean.class);
+    }
+
+    /**
+     * Test {@link PropertyUtils#getPropertyDescriptors(Class)}
+     */
+    public void testPropertyUtils_getPropertyDescriptors_InnerClassProperty() throws Exception {
+        checkReadMethod("innerClassProperty", ConcreteTestBean.class);
     }
 }
