@@ -16,28 +16,18 @@
  */
 package org.apache.commons.beanutils.bugs;
 
+import org.apache.commons.beanutils.PropertyUtils;
+import org.apache.commons.beanutils.TestBean;
+
 import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.beanutils.PropertyUtils;
-import org.apache.commons.beanutils.TestBean;
-
 /**
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-358">https://issues.apache.org/jira/browse/BEANUTILS-358</a>
  */
 public class Jira358TestCase extends TestCase {
 
-    /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
-     */
-    public Jira358TestCase(final String name) {
-        super(name);
-    }
-
     /**
      * Run the Test.
      *
@@ -53,7 +43,16 @@ public class Jira358TestCase extends TestCase {
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira358TestCase.class));
+        return new TestSuite(Jira358TestCase.class);
+    }
+
+    /**
+     * Create a test case with the specified name.
+     *
+     * @param name The name of the test
+     */
+    public Jira358TestCase(final String name) {
+        super(name);
     }
 
     /**
