@@ -16,25 +16,39 @@
  */
 package org.apache.commons.beanutils.bugs;
 
+import org.apache.commons.beanutils.BeanUtils;
+
 import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.beanutils.BeanUtils;
-
 /**
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-369">https://issues.apache.org/jira/browse/BEANUTILS-369</a>
  */
 public class Jira369TestCase extends TestCase {
 
     /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
+     * Test Bean
      */
-    public Jira369TestCase(final String name) {
-        super(name);
+    public static class TestBean {
+        private String aproperty;
+        private String bproperty;
+
+        public String getARatedCd() {
+            return aproperty;
+        }
+
+        public String getbRatedCd() {
+            return bproperty;
+        }
+
+        public void setARatedCd(final String aproperty) {
+            this.aproperty = aproperty;
+        }
+
+        public void setbRatedCd(final String bproperty) {
+            this.bproperty = bproperty;
+        }
     }
 
     /**
@@ -52,7 +66,16 @@ public class Jira369TestCase extends TestCase {
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira369TestCase.class));
+        return new TestSuite(Jira369TestCase.class);
+    }
+
+    /**
+     * Create a test case with the specified name.
+     *
+     * @param name The name of the test
+     */
+    public Jira369TestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -117,28 +140,4 @@ public class Jira369TestCase extends TestCase {
             fail("Threw " + e);
         }
     }
-
-    /**
-     * Test Bean
-     */
-    public static class TestBean {
-        private String aproperty;
-        private String bproperty;
-
-        public String getARatedCd() {
-            return aproperty;
-        }
-
-        public void setARatedCd(final String aproperty) {
-            this.aproperty = aproperty;
-        }
-
-        public String getbRatedCd() {
-            return bproperty;
-        }
-
-        public void setbRatedCd(final String bproperty) {
-            this.bproperty = bproperty;
-        }
-    }
 }
