@@ -18,45 +18,29 @@ package org.apache.commons.beanutils.bugs;
 
 import java.lang.reflect.Method;
 
-import junit.framework.TestCase;
-
 import org.apache.commons.beanutils.MethodUtils;
 
+import junit.framework.TestCase;
+
 /**
  * MethodUtils's getMatchingAccessibleMethod() does not correctly
  * handle inheritance and method overloading.
  *
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-381">https://issues.apache.org/jira/browse/BEANUTILS-381</a>
  */
 public class Jira381TestCase extends TestCase {
 
     /**
-     * Create a test case with the specified name.
+     * Test object.
      *
-     * @param name The name of the test
      */
-    public Jira381TestCase(final String name) {
-        super(name);
+    public class TestObject{
     }
 
     /**
-     * Test with an private class that overrides a public method
-     * of a "grand parent" public class.
-     * <p />
-     * See Jira issue# BEANUTILS-381.
+     * Used to match performop with test object
      */
-    public void testIssue_BEANUTILS_381_getMatchingAccessibleMethod() {
-
-        final Class<?> target = TestServiceBean.class;
-        final String methodName = "performOp";
-        final Class<?>[] runtimeClasses = new Class<?>[]{TestObjectSubclass.class};
-
-        final Method returned = MethodUtils.getMatchingAccessibleMethod(target, methodName, runtimeClasses);
-
-        assertEquals(target, returned.getDeclaringClass());
-        assertEquals(methodName, returned.getName());
-        assertEquals(TestObject.class, returned.getParameterTypes()[0]);
+    public class TestObjectSubclass extends TestObject{
     }
 
     /**
@@ -78,15 +62,30 @@ public class Jira381TestCase extends TestCase {
     }
 
     /**
-     * Test object.
+     * Create a test case with the specified name.
      *
+     * @param name The name of the test
      */
-    public class TestObject{
+    public Jira381TestCase(final String name) {
+        super(name);
     }
 
     /**
-     * Used to match performop with test object
+     * Test with an private class that overrides a public method
+     * of a "grand parent" public class.
+     * <p />
+     * See Jira issue# BEANUTILS-381.
      */
-    public class TestObjectSubclass extends TestObject{
+    public void testIssue_BEANUTILS_381_getMatchingAccessibleMethod() {
+
+        final Class<?> target = TestServiceBean.class;
+        final String methodName = "performOp";
+        final Class<?>[] runtimeClasses = {TestObjectSubclass.class};
+
+        final Method returned = MethodUtils.getMatchingAccessibleMethod(target, methodName, runtimeClasses);
+
+        assertEquals(target, returned.getDeclaringClass());
+        assertEquals(methodName, returned.getName());
+        assertEquals(TestObject.class, returned.getParameterTypes()[0]);
     }
 }
