@@ -16,20 +16,32 @@
  */
 package org.apache.commons.beanutils.bugs;
 
-import junit.framework.TestCase;
-
 import org.apache.commons.beanutils.BeanUtilsBean;
 
+import junit.framework.TestCase;
+
 /**
  * BeanUtilsBean.setProperty throws IllegalArgumentException if getter of nested
  * property returns null
  *
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-411">https://issues.apache.org/jira/browse/BEANUTILS-411</a>
  */
 public class Jira411TestCase extends TestCase {
 
+    public class DummyBean {
+
+        private String imgLink;
+
+        public String getImgLink() {
+            return imgLink;
+        }
+
+        public void setImgLink(final String imgLink) {
+            this.imgLink = imgLink;
+        }
+    }
     private BeanUtilsBean instance;
+
     private DummyBean testBean;
 
     @Override
@@ -41,17 +53,4 @@ public class Jira411TestCase extends TestCase {
     public void testSetProperty() throws Exception {
         instance.setProperty(testBean, "imgLink.x", "1");
     }
-
-    public class DummyBean {
-
-        private String imgLink = null;
-
-        public String getImgLink() {
-            return imgLink;
-        }
-
-        public void setImgLink(final String imgLink) {
-            this.imgLink = imgLink;
-        }
-    }
 }
