@@ -19,10 +19,6 @@ package org.apache.commons.beanutils.bugs;
 import java.util.HashMap;
 import java.util.Map;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.BeanUtils;
 import org.apache.commons.beanutils.PropertyUtils;
 import org.apache.commons.beanutils.WrapDynaBean;
@@ -31,6 +27,10 @@ import org.apache.commons.beanutils.bugs.other.Jira61BeanFactory.TestBean;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Test case for Jira issue# BEANUTILS-61.
  *
@@ -40,24 +40,10 @@ import org.apache.commons.logging.LogFactory;
  * wrapped may have read-only or write-only properties (unlike
  * regular DynaBeans.
  *
- * @version $Id$
  * @see <a href="https://issues.apache.org/jira/browse/BEANUTILS-61">https://issues.apache.org/jira/browse/BEANUTILS-61</a>
  */
 public class Jira61TestCase extends TestCase {
 
-    private final Log log = LogFactory.getLog(Jira61TestCase.class);
-    private Jira61BeanFactory.TestBean testBean;
-    private WrapDynaBean wrapDynaBean;
-
-    /**
-     * Create a test case with the specified name.
-     *
-     * @param name The name of the test
-     */
-    public Jira61TestCase(final String name) {
-        super(name);
-    }
-
     /**
      * Run the Test.
      *
@@ -66,14 +52,27 @@ public class Jira61TestCase extends TestCase {
     public static void main(final String[] args) {
         junit.textui.TestRunner.run(suite());
     }
-
     /**
      * Create a test suite for this test.
      *
      * @return a test suite
      */
     public static Test suite() {
-        return (new TestSuite(Jira61TestCase.class));
+        return new TestSuite(Jira61TestCase.class);
+    }
+    private final Log log = LogFactory.getLog(Jira61TestCase.class);
+
+    private Jira61BeanFactory.TestBean testBean;
+
+    private WrapDynaBean wrapDynaBean;
+
+    /**
+     * Create a test case with the specified name.
+     *
+     * @param name The name of the test
+     */
+    public Jira61TestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -100,6 +99,152 @@ public class Jira61TestCase extends TestCase {
         super.tearDown();
     }
 
+    /**
+     * Test {@link BeanUtils#copyProperties(Object, Object)}
+     * to a read-only WrapDynaBean property.
+     */
+    public void testIssue_BEANUTILS_61_BeanUtils_copyProperties_from_WrapDynaBean() {
+        final String value = "ORIG TARGET VALUE";
+        final TestBean targetBean = Jira61BeanFactory.createBean();
+        targetBean.setSimpleWriteOnly(value);
+        try {
+            BeanUtils.copyProperties(targetBean, wrapDynaBean);
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("copyProperties Threw exception: " + t);
+        }
+        assertTrue("Target value='" + targetBean.getSimpleReadOnly() + "'", value.equals(targetBean.getSimpleReadOnly()));
+    }
+
+    /**
+     * Test {@link BeanUtils#copyProperties(Object, Object)}
+     * to a read-only WrapDynaBean property.
+     */
+    public void testIssue_BEANUTILS_61_BeanUtils_copyProperties_to_WrapDynaBean() {
+        final String value = "copied simpleReadOnly";
+        final Map<String, Object> source = new HashMap<>();
+        source.put("simpleReadOnly", value);
+        try {
+            BeanUtils.copyProperties(wrapDynaBean, source);
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("copyProperties Threw exception: " + t);
+        }
+        assertFalse("Target value='" + value + "'", value.equals(testBean.getSimpleReadOnly()));
+    }
+
+    /**
+     * Test {@link PropertyUtils#copyProperties(Object, Object)}
+     * to a read-only WrapDynaBean property.
+     */
+    public void testIssue_BEANUTILS_61_PropertyUtils_copyProperties_from_WrapDynaBean() {
+        final String value = "ORIG TARGET VALUE";
+        final TestBean targetBean = Jira61BeanFactory.createBean();
+        targetBean.setSimpleWriteOnly(value);
+        try {
+            PropertyUtils.copyProperties(targetBean, wrapDynaBean);
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("copyProperties Threw exception: " + t);
+        }
+        assertTrue("Target value='" + targetBean.getSimpleReadOnly() + "'", value.equals(targetBean.getSimpleReadOnly()));
+    }
+
+    /**
+     * Test {@link PropertyUtils#copyProperties(Object, Object)}
+     * to a read-only WrapDynaBean property.
+     */
+    public void testIssue_BEANUTILS_61_PropertyUtils_copyProperties_to_WrapDynaBean() {
+        final String value = "copied simpleReadOnly";
+        final Map<String, Object> source = new HashMap<>();
+        source.put("simpleReadOnly", value);
+        try {
+            PropertyUtils.copyProperties(wrapDynaBean, source);
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("copyProperties Threw exception: " + t);
+        }
+        assertFalse("Target value='" + value + "'", value.equals(testBean.getSimpleReadOnly()));
+    }
+
+    /**
+     * Test {@link PropertyUtils#getProperty(Object, String)}
+     * for simple properties.
+     */
+    public void testIssue_BEANUTILS_61_PropertyUtils_getProperty() {
+        boolean threwIllegalArgumentException = false;
+        Object result = null;
+        try {
+            result = PropertyUtils.getProperty(wrapDynaBean, "simpleReadOnly");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("simpleWriteOnly Threw exception: " + t);
+        }
+        assertEquals("simpleReadOnly", testBean.getSimpleReadOnly(), result);
+
+        try {
+            result = PropertyUtils.getProperty(wrapDynaBean, "simpleWriteOnly");
+        } catch (final IllegalArgumentException ex) {
+            threwIllegalArgumentException = true; // expected result
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("simpleWriteOnly Threw exception: " + t);
+        }
+        assertTrue("Expected IllegalArgumentException but returned '" + result + "'", threwIllegalArgumentException);
+    }
+
+    /**
+     * Test {@link PropertyUtils#getProperty(Object, String)}
+     * for indexed properties.
+     */
+    public void testIssue_BEANUTILS_61_PropertyUtils_getProperty_Indexed() {
+        boolean threwIllegalArgumentException = false;
+        Object result = null;
+        try {
+            result = PropertyUtils.getProperty(wrapDynaBean, "indexedReadOnly[0]");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("indexedReadOnly Threw exception: " + t);
+        }
+        assertEquals("indexedReadOnly", testBean.getIndexedReadOnly(0), result);
+
+        try {
+            result = PropertyUtils.getProperty(wrapDynaBean, "indexedWriteOnly[0]");
+        } catch (final IllegalArgumentException ex) {
+            threwIllegalArgumentException = true; // expected result
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("indexedWriteOnly Threw exception: " + t);
+        }
+        assertTrue("Expected IllegalArgumentException but returned '" + result + "'", threwIllegalArgumentException);
+    }
+
+    /**
+     * Test {@link PropertyUtils#getProperty(Object, String)}
+     * for mapped properties.
+     */
+    public void testIssue_BEANUTILS_61_PropertyUtils_getProperty_Mapped() {
+        boolean threwIllegalArgumentException = false;
+        Object result = null;
+        try {
+            result = PropertyUtils.getProperty(wrapDynaBean, "mappedReadOnly(foo-key)");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("mappedReadOnly Threw exception: " + t);
+        }
+        assertEquals("mappedReadOnly", testBean.getMappedReadOnly("foo-key"), result);
+
+        try {
+            result = PropertyUtils.getProperty(wrapDynaBean, "mappedWriteOnly(foo-key)");
+        } catch (final IllegalArgumentException ex) {
+            threwIllegalArgumentException = true; // expected result
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("mappedWriteOnly Threw exception: " + t);
+        }
+        assertTrue("Expected IllegalArgumentException but returned '" + result + "'", threwIllegalArgumentException);
+    }
+
     /**
      * Test {@link PropertyUtils#isReadable(Object, String)}
      * for simple properties.
@@ -124,30 +269,6 @@ public class Jira61TestCase extends TestCase {
         assertFalse("PropertyUtils.isReadable(bean, \"simpleWriteOnly\") returned " + result, result);
     }
 
-    /**
-     * Test {@link PropertyUtils#isWriteable(Object, String)}
-     * for simple properties.
-     */
-    public void testIssue_BEANUTILS_61_PropertyUtils_isWriteable() {
-        boolean result = false;
-
-        try {
-            result = PropertyUtils.isWriteable(wrapDynaBean, "simpleReadOnly");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("simpleReadOnly Threw exception: " + t);
-        }
-        assertFalse("PropertyUtils.isWriteable(bean, \"simpleReadOnly\") returned " + result, result);
-
-        try {
-            result = PropertyUtils.isWriteable(wrapDynaBean, "simpleWriteOnly");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("simpleWriteOnly Threw exception: " + t);
-        }
-        assertTrue("PropertyUtils.isWriteable(bean, \"simpleWriteOnly\") returned " + result, result);
-    }
-
     /**
      * Test {@link PropertyUtils#isReadable(Object, String)}
      * for indexed properties.
@@ -196,6 +317,30 @@ public class Jira61TestCase extends TestCase {
         assertFalse("PropertyUtils.isReadable(bean, \"mappedWriteOnly\") returned " + result, result);
     }
 
+    /**
+     * Test {@link PropertyUtils#isWriteable(Object, String)}
+     * for simple properties.
+     */
+    public void testIssue_BEANUTILS_61_PropertyUtils_isWriteable() {
+        boolean result = false;
+
+        try {
+            result = PropertyUtils.isWriteable(wrapDynaBean, "simpleReadOnly");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("simpleReadOnly Threw exception: " + t);
+        }
+        assertFalse("PropertyUtils.isWriteable(bean, \"simpleReadOnly\") returned " + result, result);
+
+        try {
+            result = PropertyUtils.isWriteable(wrapDynaBean, "simpleWriteOnly");
+        } catch (final Throwable t) {
+            log.error("ERROR " + t, t);
+            fail("simpleWriteOnly Threw exception: " + t);
+        }
+        assertTrue("PropertyUtils.isWriteable(bean, \"simpleWriteOnly\") returned " + result, result);
+    }
+
     /**
      * Test {@link PropertyUtils#isWriteable(Object, String)}
      * for indexed properties.
@@ -244,32 +389,6 @@ public class Jira61TestCase extends TestCase {
         assertTrue("PropertyUtils.isWriteable(bean, \"mappedWriteOnly\") returned " + result, result);
     }
 
-    /**
-     * Test {@link PropertyUtils#getProperty(Object, String)}
-     * for simple properties.
-     */
-    public void testIssue_BEANUTILS_61_PropertyUtils_getProperty() {
-        boolean threwIllegalArgumentException = false;
-        Object result = null;
-        try {
-            result = PropertyUtils.getProperty(wrapDynaBean, "simpleReadOnly");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("simpleWriteOnly Threw exception: " + t);
-        }
-        assertEquals("simpleReadOnly", testBean.getSimpleReadOnly(), result);
-
-        try {
-            result = PropertyUtils.getProperty(wrapDynaBean, "simpleWriteOnly");
-        } catch (final IllegalArgumentException ex) {
-            threwIllegalArgumentException = true; // expected result
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("simpleWriteOnly Threw exception: " + t);
-        }
-        assertTrue("Expected IllegalArgumentException but returned '" + result + "'", threwIllegalArgumentException);
-    }
-
     /**
      * Test {@link PropertyUtils#setProperty(Object, String, Object)}
      * for simple properties.
@@ -295,32 +414,6 @@ public class Jira61TestCase extends TestCase {
         assertEquals("simpleWriteOnly", testBean.getSimpleReadOnly(), "SIMPLE-BAR");
     }
 
-    /**
-     * Test {@link PropertyUtils#getProperty(Object, String)}
-     * for indexed properties.
-     */
-    public void testIssue_BEANUTILS_61_PropertyUtils_getProperty_Indexed() {
-        boolean threwIllegalArgumentException = false;
-        Object result = null;
-        try {
-            result = PropertyUtils.getProperty(wrapDynaBean, "indexedReadOnly[0]");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("indexedReadOnly Threw exception: " + t);
-        }
-        assertEquals("indexedReadOnly", testBean.getIndexedReadOnly(0), result);
-
-        try {
-            result = PropertyUtils.getProperty(wrapDynaBean, "indexedWriteOnly[0]");
-        } catch (final IllegalArgumentException ex) {
-            threwIllegalArgumentException = true; // expected result
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("indexedWriteOnly Threw exception: " + t);
-        }
-        assertTrue("Expected IllegalArgumentException but returned '" + result + "'", threwIllegalArgumentException);
-    }
-
     /**
      * Test {@link PropertyUtils#setProperty(Object, String, Object)}
      * for indexed properties.
@@ -346,32 +439,6 @@ public class Jira61TestCase extends TestCase {
         assertEquals("indexedWriteOnly", testBean.getIndexedReadOnly(0), "INDEXED-BAR");
     }
 
-    /**
-     * Test {@link PropertyUtils#getProperty(Object, String)}
-     * for mapped properties.
-     */
-    public void testIssue_BEANUTILS_61_PropertyUtils_getProperty_Mapped() {
-        boolean threwIllegalArgumentException = false;
-        Object result = null;
-        try {
-            result = PropertyUtils.getProperty(wrapDynaBean, "mappedReadOnly(foo-key)");
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("mappedReadOnly Threw exception: " + t);
-        }
-        assertEquals("mappedReadOnly", testBean.getMappedReadOnly("foo-key"), result);
-
-        try {
-            result = PropertyUtils.getProperty(wrapDynaBean, "mappedWriteOnly(foo-key)");
-        } catch (final IllegalArgumentException ex) {
-            threwIllegalArgumentException = true; // expected result
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("mappedWriteOnly Threw exception: " + t);
-        }
-        assertTrue("Expected IllegalArgumentException but returned '" + result + "'", threwIllegalArgumentException);
-    }
-
     /**
      * Test {@link PropertyUtils#setProperty(Object, String, Object)}
      * for mapped properties.
@@ -396,72 +463,4 @@ public class Jira61TestCase extends TestCase {
         }
         assertEquals("mappedWriteOnly", testBean.getMappedReadOnly("foo-key"), "MAPPED-BAR");
     }
-
-    /**
-     * Test {@link PropertyUtils#copyProperties(Object, Object)}
-     * to a read-only WrapDynaBean property.
-     */
-    public void testIssue_BEANUTILS_61_PropertyUtils_copyProperties_to_WrapDynaBean() {
-        final String value = "copied simpleReadOnly";
-        final Map<String, Object> source = new HashMap<String, Object>();
-        source.put("simpleReadOnly", value);
-        try {
-            PropertyUtils.copyProperties(wrapDynaBean, source);
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("copyProperties Threw exception: " + t);
-        }
-        assertFalse("Target value='" + value + "'", value.equals(testBean.getSimpleReadOnly()));
-    }
-
-    /**
-     * Test {@link PropertyUtils#copyProperties(Object, Object)}
-     * to a read-only WrapDynaBean property.
-     */
-    public void testIssue_BEANUTILS_61_PropertyUtils_copyProperties_from_WrapDynaBean() {
-        final String value = "ORIG TARGET VALUE";
-        final TestBean targetBean = Jira61BeanFactory.createBean();
-        targetBean.setSimpleWriteOnly(value);
-        try {
-            PropertyUtils.copyProperties(targetBean, wrapDynaBean);
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("copyProperties Threw exception: " + t);
-        }
-        assertTrue("Target value='" + targetBean.getSimpleReadOnly() + "'", value.equals(targetBean.getSimpleReadOnly()));
-    }
-
-    /**
-     * Test {@link BeanUtils#copyProperties(Object, Object)}
-     * to a read-only WrapDynaBean property.
-     */
-    public void testIssue_BEANUTILS_61_BeanUtils_copyProperties_to_WrapDynaBean() {
-        final String value = "copied simpleReadOnly";
-        final Map<String, Object> source = new HashMap<String, Object>();
-        source.put("simpleReadOnly", value);
-        try {
-            BeanUtils.copyProperties(wrapDynaBean, source);
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("copyProperties Threw exception: " + t);
-        }
-        assertFalse("Target value='" + value + "'", value.equals(testBean.getSimpleReadOnly()));
-    }
-
-    /**
-     * Test {@link BeanUtils#copyProperties(Object, Object)}
-     * to a read-only WrapDynaBean property.
-     */
-    public void testIssue_BEANUTILS_61_BeanUtils_copyProperties_from_WrapDynaBean() {
-        final String value = "ORIG TARGET VALUE";
-        final TestBean targetBean = Jira61BeanFactory.createBean();
-        targetBean.setSimpleWriteOnly(value);
-        try {
-            BeanUtils.copyProperties(targetBean, wrapDynaBean);
-        } catch (final Throwable t) {
-            log.error("ERROR " + t, t);
-            fail("copyProperties Threw exception: " + t);
-        }
-        assertTrue("Target value='" + targetBean.getSimpleReadOnly() + "'", value.equals(targetBean.getSimpleReadOnly()));
-    }
 }
