@@ -22,52 +22,24 @@ import java.util.Map;
 import org.apache.commons.beanutils.bugs.Jira18TestCase;
 
 /**
- * Factory which creates <i>package</i> scope beans with
+ * Factory which creates <em>package</em> scope beans with
  * public methods for {@link Jira18TestCase}.
  *
- * @version $Id$
  */
 public class Jira18BeanFactory {
 
-    /**
-     * Factory method which creates package friendly beans.
-     *
-     * @return The a package friendly bean with public methods
-     */
-    public static Object createBean() {
-        return new PackageFriendlyBean();
-    }
-
     /* =============== Package Friendly Bean =============== */
     static class PackageFriendlyBean {
 
-        private final String[] indexed = new String[] {"one", "two", "three"};
+        private final String[] indexed = {"one", "two", "three"};
         private String simple = "FOO";
-        private final Map<String, Object> mapped = new HashMap<String, Object>();
+        private final Map<String, Object> mapped = new HashMap<>();
 
         /** Default Constructor */
         public PackageFriendlyBean() {
             mapped.put("foo-key", "foo-value");
             mapped.put("bar-key", "bar-value");
         }
-        /**
-         * Return simple property.
-         *
-         * @return The simple value
-         */
-        public String getSimple() {
-            return simple;
-        }
-
-        /**
-         * Set simple property.
-         *
-         * @param simple The simple value
-         */
-        public void setSimple(final String simple) {
-            this.simple = simple;
-        }
-
         /**
          * Return indexed property.
          *
@@ -78,16 +50,6 @@ public class Jira18BeanFactory {
             return indexed[index];
         }
 
-        /**
-         * Set indexed property.
-         *
-         * @param index The index
-         * @param value The indexed value
-         */
-        public void setIndexed(final int index, final String value) {
-            this.indexed[index] = value;
-        }
-
         /**
          * Return mapped property.
          *
@@ -98,6 +60,25 @@ public class Jira18BeanFactory {
             return (String)mapped.get(key);
         }
 
+        /**
+         * Return simple property.
+         *
+         * @return The simple value
+         */
+        public String getSimple() {
+            return simple;
+        }
+
+        /**
+         * Set indexed property.
+         *
+         * @param index The index
+         * @param value The indexed value
+         */
+        public void setIndexed(final int index, final String value) {
+            this.indexed[index] = value;
+        }
+
         /**
          * Set mapped property.
          *
@@ -108,6 +89,24 @@ public class Jira18BeanFactory {
             mapped.put(key, value);
         }
 
+        /**
+         * Set simple property.
+         *
+         * @param simple The simple value
+         */
+        public void setSimple(final String simple) {
+            this.simple = simple;
+        }
+
+    }
+
+    /**
+     * Factory method which creates package friendly beans.
+     *
+     * @return The a package friendly bean with public methods
+     */
+    public static Object createBean() {
+        return new PackageFriendlyBean();
     }
 
 }
