@@ -24,27 +24,17 @@ import org.apache.commons.beanutils.bugs.Jira61TestCase;
 /**
  * Factory which creates beans for {@link Jira61TestCase}.
  *
- * @version $Id$
  */
 public class Jira61BeanFactory {
 
-    /**
-     * Factory method which creates a new {@link TestBean}.
-     *
-     * @return a new {@link TestBean}.
-     */
-    public static TestBean createBean() {
-        return new TestBean();
-    }
-
     /**
      * Test Bean
      */
     public static class TestBean {
 
-        private final String[] indexed = new String[] {"one", "two", "three"};
+        private final String[] indexed = {"one", "two", "three"};
         private String simple = "FOO";
-        private final Map<String, Object> mapped = new HashMap<String, Object>();
+        private final Map<String, Object> mapped = new HashMap<>();
 
         /** Default Constructor */
         public TestBean() {
@@ -52,24 +42,6 @@ public class Jira61BeanFactory {
             mapped.put("bar-key", "bar-value");
         }
 
-        /**
-         * Return simpleReadOnly
-         *
-         * @return the simple value
-         */
-        public String getSimpleReadOnly() {
-            return simple;
-        }
-
-        /**
-         * Set simpleWriteOnly
-         *
-         * @param simple simple value
-         */
-        public void setSimpleWriteOnly(final String simple) {
-            this.simple = simple;
-        }
-
         /**
          * Return indexed property.
          *
@@ -80,16 +52,6 @@ public class Jira61BeanFactory {
             return indexed[index];
         }
 
-        /**
-         * Set indexed property.
-         *
-         * @param index The index
-         * @param value The indexed value
-         */
-        public void setIndexedWriteOnly(final int index, final String value) {
-            this.indexed[index] = value;
-        }
-
         /**
          * Return mapped property.
          *
@@ -100,6 +62,25 @@ public class Jira61BeanFactory {
             return (String)mapped.get(key);
         }
 
+        /**
+         * Return simpleReadOnly
+         *
+         * @return the simple value
+         */
+        public String getSimpleReadOnly() {
+            return simple;
+        }
+
+        /**
+         * Set indexed property.
+         *
+         * @param index The index
+         * @param value The indexed value
+         */
+        public void setIndexedWriteOnly(final int index, final String value) {
+            this.indexed[index] = value;
+        }
+
         /**
          * Set mapped property.
          *
@@ -110,6 +91,24 @@ public class Jira61BeanFactory {
             mapped.put(key, value);
         }
 
+        /**
+         * Set simpleWriteOnly
+         *
+         * @param simple simple value
+         */
+        public void setSimpleWriteOnly(final String simple) {
+            this.simple = simple;
+        }
+
+    }
+
+    /**
+     * Factory method which creates a new {@link TestBean}.
+     *
+     * @return a new {@link TestBean}.
+     */
+    public static TestBean createBean() {
+        return new TestBean();
     }
 
 }
