@@ -19,47 +19,30 @@ package org.apache.commons.beanutils.converters;
 
 import java.math.BigInteger;
 
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.Converter;
 
+import junit.framework.TestSuite;
 
 /**
  * Test Case for the BigInteger class.
  *
- * @version $Id$
  */
 public class BigIntegerConverterTestCase extends NumberConverterTestBase {
 
-    private Converter converter = null;
-
-    // ------------------------------------------------------------------------
-
-    public BigIntegerConverterTestCase(final String name) {
-        super(name);
-    }
-
-    // ------------------------------------------------------------------------
-
-    @Override
-    public void setUp() throws Exception {
-        converter = makeConverter();
-        numbers[0] = new BigInteger("-12");
-        numbers[1] = new BigInteger("13");
-        numbers[2] = new BigInteger("-22");
-        numbers[3] = new BigInteger("23");
-    }
-
     public static TestSuite suite() {
         return new TestSuite(BigIntegerConverterTestCase.class);
     }
 
-    @Override
-    public void tearDown() throws Exception {
-        converter = null;
+    private Converter converter;
+
+    public BigIntegerConverterTestCase(final String name) {
+        super(name);
     }
 
-    // ------------------------------------------------------------------------
+    @Override
+    protected Class<?> getExpectedType() {
+        return BigInteger.class;
+    }
 
     @Override
     protected NumberConverter makeConverter() {
@@ -72,11 +55,18 @@ public class BigIntegerConverterTestCase extends NumberConverterTestBase {
     }
 
     @Override
-    protected Class<?> getExpectedType() {
-        return BigInteger.class;
+    public void setUp() throws Exception {
+        converter = makeConverter();
+        numbers[0] = new BigInteger("-12");
+        numbers[1] = new BigInteger("13");
+        numbers[2] = new BigInteger("-22");
+        numbers[3] = new BigInteger("23");
     }
 
-    // ------------------------------------------------------------------------
+    @Override
+    public void tearDown() throws Exception {
+        converter = null;
+    }
 
     public void testSimpleConversion() throws Exception {
         final String[] message= {
@@ -103,12 +93,12 @@ public class BigIntegerConverterTestCase extends NumberConverterTestBase {
             "1",
             "17",
             String.valueOf(Long.MAX_VALUE),
-            new Byte((byte)7),
-            new Short((short)8),
-            new Integer(9),
-            new Long(10),
-            new Float(11.1),
-            new Double(12.2)
+            Byte.valueOf((byte)7),
+            Short.valueOf((short)8),
+            Integer.valueOf(9),
+            Long.valueOf(10),
+            Float.valueOf((float) 11.1),
+            Double.valueOf(12.2)
         };
 
         final BigInteger[] expected = {
