@@ -16,29 +16,18 @@
  */
 package org.apache.commons.beanutils.converters;
 
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.Converter;
 
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Test Case for the ClassConverter class.
  *
- * @version $Id$
  */
 public class ClassConverterTestCase extends TestCase {
 
-    /**
-     * Construct a new Class Converter test case.
-     * @param name Test Name
-     */
-    public ClassConverterTestCase(final String name) {
-        super(name);
-    }
-
-    // ------------------------------------------------------------------------
-
     /**
      * Create Test Suite
      * @return test suite
@@ -47,6 +36,14 @@ public class ClassConverterTestCase extends TestCase {
         return new TestSuite(ClassConverterTestCase.class);
     }
 
+    /**
+     * Construct a new Class Converter test case.
+     * @param name Test Name
+     */
+    public ClassConverterTestCase(final String name) {
+        super(name);
+    }
+
     /** Set Up */
     @Override
     public void setUp() throws Exception {
@@ -57,19 +54,18 @@ public class ClassConverterTestCase extends TestCase {
     public void tearDown() throws Exception {
     }
 
-
-    // ------------------------------------------------------------------------
-
     /**
-     * Test Conversion to String
+     * Test Array Conversion
      */
-    public void testConvertToString() {
+    public void testArray() {
         final Converter converter = new ClassConverter();
 
-        assertEquals("Class Test", "java.lang.Integer", converter.convert(String.class, Integer.class));
-        assertEquals("Value Test", "foo", converter.convert(String.class, "foo"));
-        assertEquals("Value Test", "bar", converter.convert(String.class, new StringBuilder("bar")));
-        assertEquals("Null Test",   null, converter.convert(String.class, null));
+        // Test Array Class to String
+        assertEquals("Array to String", "[Ljava.lang.Boolean;", converter.convert(String.class, Boolean[].class));
+
+        // *** N.B. for some reason the following works on m1, but not m2
+        // Test String to Array Class
+        // assertEquals("String to Array", Boolean[].class, converter.convert(Class.class, "[Ljava.lang.Boolean;"));
     }
 
     /**
@@ -84,7 +80,7 @@ public class ClassConverterTestCase extends TestCase {
 
         // Invalid Test
         try {
-            converter.convert(Class.class, new Integer(6));
+            converter.convert(Class.class, Integer.valueOf(6));
             fail("Expected invalid value to fail");
         } catch (final ConversionException e) {
             // expected result
@@ -106,7 +102,7 @@ public class ClassConverterTestCase extends TestCase {
 
         final Converter converter = new ClassConverter(Object.class);
 
-        assertEquals("Invalid Test", Object.class, converter.convert(Class.class, new Integer(6)));
+        assertEquals("Invalid Test", Object.class, converter.convert(Class.class, Integer.valueOf(6)));
         assertEquals("Null Test",    Object.class, converter.convert(Class.class, null));
     }
 
@@ -117,22 +113,20 @@ public class ClassConverterTestCase extends TestCase {
 
         final Converter converter = new ClassConverter(null);
 
-        assertEquals("Invalid Test", null, converter.convert(Class.class, new Integer(6)));
+        assertEquals("Invalid Test", null, converter.convert(Class.class, Integer.valueOf(6)));
         assertEquals("Null Test",    null, converter.convert(Class.class, null));
     }
 
     /**
-     * Test Array Conversion
+     * Test Conversion to String
      */
-    public void testArray() {
+    public void testConvertToString() {
         final Converter converter = new ClassConverter();
 
-        // Test Array Class to String
-        assertEquals("Array to String", "[Ljava.lang.Boolean;", converter.convert(String.class, Boolean[].class));
-
-        // *** N.B. for some reason the following works on m1, but not m2
-        // Test String to Array Class
-        // assertEquals("String to Array", Boolean[].class, converter.convert(Class.class, "[Ljava.lang.Boolean;"));
+        assertEquals("Class Test", "java.lang.Integer", converter.convert(String.class, Integer.class));
+        assertEquals("Value Test", "foo", converter.convert(String.class, "foo"));
+        assertEquals("Value Test", "bar", converter.convert(String.class, new StringBuilder("bar")));
+        assertEquals("Null Test",   null, converter.convert(String.class, null));
     }
 
     /**
