@@ -23,25 +23,19 @@ import junit.framework.TestSuite;
 /**
  * Tests for the ClassReloader utility class.
  *
- * @version $Id$
  */
 
 public class ClassReloaderTestCase extends TestCase {
 
-    // ------------------------------------------------------------------------
-
-    public ClassReloaderTestCase(final String name) {
-        super(name);
+    public static class DummyClass {
     }
 
-
     public static TestSuite suite() {
         return new TestSuite(ClassReloaderTestCase.class);
     }
 
-    // ------------------------------------------------------------------------
-
-    public static class DummyClass {
+    public ClassReloaderTestCase(final String name) {
+        super(name);
     }
 
     /**
@@ -63,8 +57,8 @@ public class ClassReloaderTestCase extends TestCase {
         assertTrue(sharedLoader != componentLoader);
 
         // verify that objects of these two types are not assignment-compatible
-        final Object obj1 = sharedClass.newInstance();
-        final Object obj2 = componentClass.newInstance();
+        final Object obj1 = sharedClass.getConstructor().newInstance();
+        final Object obj2 = componentClass.getConstructor().newInstance();
 
         assertTrue("Obj1 class incorrect", sharedClass.isInstance(obj1));
         assertFalse("Obj1 class incorrect", componentClass.isInstance(obj1));
