@@ -17,49 +17,32 @@
 
 package org.apache.commons.beanutils.converters;
 
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.Converter;
 
+import junit.framework.TestSuite;
 
 /**
  * Test Case for the IntegerConverter class.
  *
- * @version $Id$
  */
 
 public class IntegerConverterTestCase extends NumberConverterTestBase {
 
-    private Converter converter = null;
-
-    // ------------------------------------------------------------------------
-
-    public IntegerConverterTestCase(final String name) {
-        super(name);
-    }
-
-    // ------------------------------------------------------------------------
-
-    @Override
-    public void setUp() throws Exception {
-        converter = makeConverter();
-        numbers[0] = new Integer("-12");
-        numbers[1] = new Integer("13");
-        numbers[2] = new Integer("-22");
-        numbers[3] = new Integer("23");
-    }
-
     public static TestSuite suite() {
         return new TestSuite(IntegerConverterTestCase.class);
     }
 
-    @Override
-    public void tearDown() throws Exception {
-        converter = null;
+    private Converter converter;
+
+    public IntegerConverterTestCase(final String name) {
+        super(name);
     }
 
-    // ------------------------------------------------------------------------
+    @Override
+    protected Class<?> getExpectedType() {
+        return Integer.class;
+    }
 
     @Override
     protected NumberConverter makeConverter() {
@@ -72,66 +55,17 @@ public class IntegerConverterTestCase extends NumberConverterTestBase {
     }
 
     @Override
-    protected Class<?> getExpectedType() {
-        return Integer.class;
+    public void setUp() throws Exception {
+        converter = makeConverter();
+        numbers[0] = Integer.valueOf("-12");
+        numbers[1] = Integer.valueOf("13");
+        numbers[2] = Integer.valueOf("-22");
+        numbers[3] = Integer.valueOf("23");
     }
 
-    // ------------------------------------------------------------------------
-
-    public void testSimpleConversion() throws Exception {
-        final String[] message= {
-            "from String",
-            "from String",
-            "from String",
-            "from String",
-            "from String",
-            "from String",
-            "from String",
-            "from Byte",
-            "from Short",
-            "from Integer",
-            "from Long",
-            "from Float",
-            "from Double"
-        };
-
-        final Object[] input = {
-            String.valueOf(Integer.MIN_VALUE),
-            "-17",
-            "-1",
-            "0",
-            "1",
-            "17",
-            String.valueOf(Integer.MAX_VALUE),
-            new Byte((byte)7),
-            new Short((short)8),
-            new Integer(9),
-            new Long(10),
-            new Float(11.1),
-            new Double(12.2)
-        };
-
-        final Integer[] expected = {
-            new Integer(Integer.MIN_VALUE),
-            new Integer(-17),
-            new Integer(-1),
-            new Integer(0),
-            new Integer(1),
-            new Integer(17),
-            new Integer(Integer.MAX_VALUE),
-            new Integer(7),
-            new Integer(8),
-            new Integer(9),
-            new Integer(10),
-            new Integer(11),
-            new Integer(12)
-        };
-
-        for(int i=0;i<expected.length;i++) {
-            assertEquals(message[i] + " to Integer",expected[i],converter.convert(Integer.class,input[i]));
-            assertEquals(message[i] + " to int",expected[i],converter.convert(Integer.TYPE,input[i]));
-            assertEquals(message[i] + " to null type",expected[i],converter.convert(null,input[i]));
-        }
+    @Override
+    public void tearDown() throws Exception {
+        converter = null;
     }
 
     /**
@@ -141,16 +75,16 @@ public class IntegerConverterTestCase extends NumberConverterTestBase {
         final Converter converter = makeConverter();
         final Class<?> clazz = Integer.class;
 
-        final Long min         = new Long(Integer.MIN_VALUE);
-        final Long max         = new Long(Integer.MAX_VALUE);
-        final Long minMinusOne = new Long(min.longValue() - 1);
-        final Long maxPlusOne  = new Long(max.longValue() + 1);
+        final Long min         = Long.valueOf(Integer.MIN_VALUE);
+        final Long max         = Long.valueOf(Integer.MAX_VALUE);
+        final Long minMinusOne = Long.valueOf(min.longValue() - 1);
+        final Long maxPlusOne  = Long.valueOf(max.longValue() + 1);
 
         // Minimum
-        assertEquals("Minimum", new Integer(Integer.MIN_VALUE), converter.convert(clazz, min));
+        assertEquals("Minimum", Integer.valueOf(Integer.MIN_VALUE), converter.convert(clazz, min));
 
         // Maximum
-        assertEquals("Maximum", new Integer(Integer.MAX_VALUE), converter.convert(clazz, max));
+        assertEquals("Maximum", Integer.valueOf(Integer.MAX_VALUE), converter.convert(clazz, max));
 
         // Too Small
         try {
@@ -181,5 +115,61 @@ public class IntegerConverterTestCase extends NumberConverterTestBase {
             // expected result
         }
     }
+
+    public void testSimpleConversion() throws Exception {
+        final String[] message= {
+            "from String",
+            "from String",
+            "from String",
+            "from String",
+            "from String",
+            "from String",
+            "from String",
+            "from Byte",
+            "from Short",
+            "from Integer",
+            "from Long",
+            "from Float",
+            "from Double"
+        };
+
+        final Object[] input = {
+            String.valueOf(Integer.MIN_VALUE),
+            "-17",
+            "-1",
+            "0",
+            "1",
+            "17",
+            String.valueOf(Integer.MAX_VALUE),
+            Byte.valueOf((byte)7),
+            Short.valueOf((short)8),
+            Integer.valueOf(9),
+            Long.valueOf(10),
+            Float.valueOf((float) 11.1),
+            Double.valueOf(12.2)
+        };
+
+        final Integer[] expected = {
+            Integer.valueOf(Integer.MIN_VALUE),
+            Integer.valueOf(-17),
+            Integer.valueOf(-1),
+            Integer.valueOf(0),
+            Integer.valueOf(1),
+            Integer.valueOf(17),
+            Integer.valueOf(Integer.MAX_VALUE),
+            Integer.valueOf(7),
+            Integer.valueOf(8),
+            Integer.valueOf(9),
+            Integer.valueOf(10),
+            Integer.valueOf(11),
+            Integer.valueOf(12)
+        };
+
+        for(int i=0;i<expected.length;i++) {
+            assertEquals(message[i] + " to Integer",expected[i],converter.convert(Integer.class,input[i]));
+            assertEquals(message[i] + " to int",expected[i],converter.convert(Integer.TYPE,input[i]));
+            assertEquals(message[i] + " to null type",expected[i],converter.convert(null,input[i]));
+        }
+    }
 }
 
