@@ -17,48 +17,31 @@
 
 package org.apache.commons.beanutils.converters;
 
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.Converter;
 
+import junit.framework.TestSuite;
 
 /**
  * Test Case for the LongConverter class.
  *
- * @version $Id$
  */
 
 public class LongConverterTestCase extends NumberConverterTestBase {
 
-    private Converter converter = null;
-
-    // ------------------------------------------------------------------------
-
-    public LongConverterTestCase(final String name) {
-        super(name);
-    }
-
-    // ------------------------------------------------------------------------
-
-    @Override
-    public void setUp() throws Exception {
-        converter = makeConverter();
-        numbers[0] = new Long("-12");
-        numbers[1] = new Long("13");
-        numbers[2] = new Long("-22");
-        numbers[3] = new Long("23");
-    }
-
     public static TestSuite suite() {
         return new TestSuite(LongConverterTestCase.class);
     }
 
-    @Override
-    public void tearDown() throws Exception {
-        converter = null;
+    private Converter converter;
+
+    public LongConverterTestCase(final String name) {
+        super(name);
     }
 
-    // ------------------------------------------------------------------------
+    @Override
+    protected Class<?> getExpectedType() {
+        return Long.class;
+    }
 
     @Override
     protected NumberConverter makeConverter() {
@@ -71,11 +54,18 @@ public class LongConverterTestCase extends NumberConverterTestBase {
     }
 
     @Override
-    protected Class<?> getExpectedType() {
-        return Long.class;
+    public void setUp() throws Exception {
+        converter = makeConverter();
+        numbers[0] = Long.valueOf("-12");
+        numbers[1] = Long.valueOf("13");
+        numbers[2] = Long.valueOf("-22");
+        numbers[3] = Long.valueOf("23");
     }
 
-    // ------------------------------------------------------------------------
+    @Override
+    public void tearDown() throws Exception {
+        converter = null;
+    }
 
     public void testSimpleConversion() throws Exception {
         final String[] message= {
@@ -102,28 +92,28 @@ public class LongConverterTestCase extends NumberConverterTestBase {
             "1",
             "17",
             String.valueOf(Long.MAX_VALUE),
-            new Byte((byte)7),
-            new Short((short)8),
-            new Integer(9),
-            new Long(10),
-            new Float(11.1),
-            new Double(12.2)
+            Byte.valueOf((byte)7),
+            Short.valueOf((short)8),
+            Integer.valueOf(9),
+            Long.valueOf(10),
+            Float.valueOf((float) 11.1),
+            Double.valueOf(12.2)
         };
 
         final Long[] expected = {
-            new Long(Long.MIN_VALUE),
-            new Long(-17),
-            new Long(-1),
-            new Long(0),
-            new Long(1),
-            new Long(17),
-            new Long(Long.MAX_VALUE),
-            new Long(7),
-            new Long(8),
-            new Long(9),
-            new Long(10),
-            new Long(11),
-            new Long(12)
+            Long.valueOf(Long.MIN_VALUE),
+            Long.valueOf(-17),
+            Long.valueOf(-1),
+            Long.valueOf(0),
+            Long.valueOf(1),
+            Long.valueOf(17),
+            Long.valueOf(Long.MAX_VALUE),
+            Long.valueOf(7),
+            Long.valueOf(8),
+            Long.valueOf(9),
+            Long.valueOf(10),
+            Long.valueOf(11),
+            Long.valueOf(12)
         };
 
         for(int i=0;i<expected.length;i++) {
