@@ -17,48 +17,31 @@
 
 package org.apache.commons.beanutils.converters;
 
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.Converter;
 
+import junit.framework.TestSuite;
 
 /**
  * Test Case for the ShortConverter class.
  *
- * @version $Id$
  */
 
 public class ShortConverterTestCase extends NumberConverterTestBase {
 
-    private Converter converter = null;
-
-    // ------------------------------------------------------------------------
-
-    public ShortConverterTestCase(final String name) {
-        super(name);
-    }
-
-    // ------------------------------------------------------------------------
-
-    @Override
-    public void setUp() throws Exception {
-        converter = makeConverter();
-        numbers[0] = new Short("-12");
-        numbers[1] = new Short("13");
-        numbers[2] = new Short("-22");
-        numbers[3] = new Short("23");
-    }
-
     public static TestSuite suite() {
         return new TestSuite(ShortConverterTestCase.class);
     }
 
-    @Override
-    public void tearDown() throws Exception {
-        converter = null;
+    private Converter converter;
+
+    public ShortConverterTestCase(final String name) {
+        super(name);
     }
 
-    // ------------------------------------------------------------------------
+    @Override
+    protected Class<?> getExpectedType() {
+        return Short.class;
+    }
 
     @Override
     protected NumberConverter makeConverter() {
@@ -71,11 +54,53 @@ public class ShortConverterTestCase extends NumberConverterTestBase {
     }
 
     @Override
-    protected Class<?> getExpectedType() {
-        return Short.class;
+    public void setUp() throws Exception {
+        converter = makeConverter();
+        numbers[0] = Short.valueOf("-12");
+        numbers[1] = Short.valueOf("13");
+        numbers[2] = Short.valueOf("-22");
+        numbers[3] = Short.valueOf("23");
     }
 
-    // ------------------------------------------------------------------------
+    @Override
+    public void tearDown() throws Exception {
+        converter = null;
+    }
+
+    /**
+     * Test Invalid Amounts (too big/small)
+     */
+    public void testInvalidAmount() {
+        final Converter converter = makeConverter();
+        final Class<?> clazz = Short.class;
+
+        final Long min         = Long.valueOf(Short.MIN_VALUE);
+        final Long max         = Long.valueOf(Short.MAX_VALUE);
+        final Long minMinusOne = Long.valueOf(min.longValue() - 1);
+        final Long maxPlusOne  = Long.valueOf(max.longValue() + 1);
+
+        // Minimum
+        assertEquals("Minimum", Short.valueOf(Short.MIN_VALUE), converter.convert(clazz, min));
+
+        // Maximum
+        assertEquals("Maximum", Short.valueOf(Short.MAX_VALUE), converter.convert(clazz, max));
+
+        // Too Small
+        try {
+            assertEquals("Minimum - 1", null, converter.convert(clazz, minMinusOne));
+            fail("Less than minimum, expected ConversionException");
+        } catch (final Exception e) {
+            // expected result
+        }
+
+        // Too Large
+        try {
+            assertEquals("Maximum + 1", null, converter.convert(clazz, maxPlusOne));
+            fail("More than maximum, expected ConversionException");
+        } catch (final Exception e) {
+            // expected result
+        }
+    }
 
     public void testSimpleConversion() throws Exception {
         final String[] message= {
@@ -102,28 +127,28 @@ public class ShortConverterTestCase extends NumberConverterTestBase {
             "1",
             "17",
             String.valueOf(Short.MAX_VALUE),
-            new Byte((byte)7),
-            new Short((short)8),
-            new Integer(9),
-            new Long(10),
-            new Float(11.1),
-            new Double(12.2)
+            Byte.valueOf((byte)7),
+            Short.valueOf((short)8),
+            Integer.valueOf(9),
+            Long.valueOf(10),
+            Float.valueOf((float) 11.1),
+            Double.valueOf(12.2)
         };
 
         final Short[] expected = {
-            new Short(Short.MIN_VALUE),
-            new Short((short)-17),
-            new Short((short)-1),
-            new Short((short)0),
-            new Short((short)1),
-            new Short((short)17),
-            new Short(Short.MAX_VALUE),
-            new Short((short)7),
-            new Short((short)8),
-            new Short((short)9),
-            new Short((short)10),
-            new Short((short)11),
-            new Short((short)12)
+            Short.valueOf(Short.MIN_VALUE),
+            Short.valueOf((short)-17),
+            Short.valueOf((short)-1),
+            Short.valueOf((short)0),
+            Short.valueOf((short)1),
+            Short.valueOf((short)17),
+            Short.valueOf(Short.MAX_VALUE),
+            Short.valueOf((short)7),
+            Short.valueOf((short)8),
+            Short.valueOf((short)9),
+            Short.valueOf((short)10),
+            Short.valueOf((short)11),
+            Short.valueOf((short)12)
         };
 
         for(int i=0;i<expected.length;i++) {
@@ -132,40 +157,5 @@ public class ShortConverterTestCase extends NumberConverterTestBase {
             assertEquals(message[i] + " to null type",expected[i],converter.convert(null,input[i]));
         }
     }
-
-    /**
-     * Test Invalid Amounts (too big/small)
-     */
-    public void testInvalidAmount() {
-        final Converter converter = makeConverter();
-        final Class<?> clazz = Short.class;
-
-        final Long min         = new Long(Short.MIN_VALUE);
-        final Long max         = new Long(Short.MAX_VALUE);
-        final Long minMinusOne = new Long(min.longValue() - 1);
-        final Long maxPlusOne  = new Long(max.longValue() + 1);
-
-        // Minimum
-        assertEquals("Minimum", new Short(Short.MIN_VALUE), converter.convert(clazz, min));
-
-        // Maximum
-        assertEquals("Maximum", new Short(Short.MAX_VALUE), converter.convert(clazz, max));
-
-        // Too Small
-        try {
-            assertEquals("Minimum - 1", null, converter.convert(clazz, minMinusOne));
-            fail("Less than minimum, expected ConversionException");
-        } catch (final Exception e) {
-            // expected result
-        }
-
-        // Too Large
-        try {
-            assertEquals("Maximum + 1", null, converter.convert(clazz, maxPlusOne));
-            fail("More than maximum, expected ConversionException");
-        } catch (final Exception e) {
-            // expected result
-        }
-    }
 }
 
