@@ -19,56 +19,46 @@ package org.apache.commons.beanutils.converters;
 
 import java.net.URL;
 
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.Converter;
 
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
 
 /**
  * Test Case for the URLConverter class.
  *
- * @version $Id$
  */
 
 public class URLConverterTestCase extends TestCase {
 
-    private Converter converter = null;
-
-    // ------------------------------------------------------------------------
-
-    public URLConverterTestCase(final String name) {
-        super(name);
-    }
-
-    // ------------------------------------------------------------------------
-
-    @Override
-    public void setUp() throws Exception {
-        converter = makeConverter();
-    }
-
     public static TestSuite suite() {
         return new TestSuite(URLConverterTestCase.class);
     }
 
-    @Override
-    public void tearDown() throws Exception {
-        converter = null;
-    }
+    private Converter converter;
 
-    // ------------------------------------------------------------------------
-
-    protected Converter makeConverter() {
-        return new URLConverter();
+    public URLConverterTestCase(final String name) {
+        super(name);
     }
 
     protected Class<?> getExpectedType() {
         return URL.class;
     }
 
-    // ------------------------------------------------------------------------
+    protected Converter makeConverter() {
+        return new URLConverter();
+    }
+
+    @Override
+    public void setUp() throws Exception {
+        converter = makeConverter();
+    }
+
+    @Override
+    public void tearDown() throws Exception {
+        converter = null;
+    }
 
     public void testSimpleConversion() throws Exception {
         final String[] message= {
