@@ -16,23 +16,30 @@
  */
 package org.apache.commons.beanutils.locale;
 
-import junit.framework.TestCase;
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
 import org.apache.commons.beanutils.TestBean;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Test Case for {@link LocaleBeanUtils}.
  *
- * @version $Id$
  */
 public class LocaleBeanUtilsTestCase extends TestCase {
 
     private static Log log = LogFactory.getLog(LocaleBeanUtilsTestCase.class);
 
+    /**
+     * Return the tests included in this test suite.
+     * @return Test Suite
+     */
+    public static Test suite() {
+        return new TestSuite(LocaleBeanUtilsTestCase.class);
+    }
+
     /**
      * Construct a new instance of this test case.
      *
@@ -42,10 +49,6 @@ public class LocaleBeanUtilsTestCase extends TestCase {
         super(name);
     }
 
-
-    // -------------------------------------------------- Overall Test Methods
-
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -53,16 +56,6 @@ public class LocaleBeanUtilsTestCase extends TestCase {
     public void setUp() {
     }
 
-
-    /**
-     * Return the tests included in this test suite.
-     * @return Test Suite
-     */
-    public static Test suite() {
-        return (new TestSuite(LocaleBeanUtilsTestCase.class));
-    }
-
-
     /**
      * Tear down instance variables required by this test case.
      */
@@ -70,25 +63,6 @@ public class LocaleBeanUtilsTestCase extends TestCase {
     public void tearDown() {
     }
 
-
-    // ------------------------------------------------ Individual Test Methods
-
-    /**
-     * Test setting a nested simple property
-     */
-    public void testSetNestedPropertySimple() {
-        final TestBean bean = new TestBean();
-        bean.getNested().setIntProperty(5);
-        assertEquals("Initial value 5", 5, bean.getNested().getIntProperty());
-        try {
-            LocaleBeanUtils.setProperty(bean, "nested.intProperty", "123", null);
-        } catch (final Throwable t) {
-            log.error(t);
-            fail("Threw " + t);
-        }
-        assertEquals("Check Set Value", 123, bean.getNested().getIntProperty());
-    }
-
     /**
      * Test setting a nested indexed property
      */
@@ -104,5 +78,21 @@ public class LocaleBeanUtilsTestCase extends TestCase {
         }
         assertEquals("Check Set Value", 123, bean.getNested().getIntIndexed(1));
     }
+
+    /**
+     * Test setting a nested simple property
+     */
+    public void testSetNestedPropertySimple() {
+        final TestBean bean = new TestBean();
+        bean.getNested().setIntProperty(5);
+        assertEquals("Initial value 5", 5, bean.getNested().getIntProperty());
+        try {
+            LocaleBeanUtils.setProperty(bean, "nested.intProperty", "123", null);
+        } catch (final Throwable t) {
+            log.error(t);
+            fail("Threw " + t);
+        }
+        assertEquals("Check Set Value", 123, bean.getNested().getIntProperty());
+    }
 }
 
