@@ -17,39 +17,37 @@
 
 package org.apache.commons.beanutils.locale;
 
-
 import java.sql.Date;
 import java.sql.Time;
 import java.sql.Timestamp;
-import java.text.DecimalFormat;
 import java.text.NumberFormat;
 import java.util.Locale;
 
+import org.apache.commons.beanutils.ConversionException;
+
 import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.beanutils.ConversionException;
-
-
 /**
  * <p>
  *  Test Case for the LocaleConvertUtils class.
  *  See unimplemented functionality of the convert utils in the method begining with fixme
  * </p>
  *
- * @version $Id$
  */
 
 public class LocaleConvertUtilsTestCase extends TestCase {
 
-    // ---------------------------------------------------- Instance Variables
+    /**
+     * Return the tests included in this test suite.
+     */
+    public static Test suite() {
+        return new TestSuite(LocaleConvertUtilsTestCase.class);
+    }
 
     private char m_decimalSeparator;
 
-    // ---------------------------------------------------------- Constructors
-
-
     /**
      * Construct a new instance of this test case.
      *
@@ -59,48 +57,35 @@ public class LocaleConvertUtilsTestCase extends TestCase {
         super(name);
     }
 
+    private void checkIntegerArray(final Object value, final int intArray[]) {
 
-    // -------------------------------------------------- Overall Test Methods
-
-
-    /**
-     * Set up instance variables required by this test case.
-     */
-    @Override
-    public void setUp() {
-
-        LocaleConvertUtils.deregister();
-
-        final NumberFormat nf = DecimalFormat.getNumberInstance();
-        final String result = nf.format(1.1);
-
-        // could be commas instead of stops in Europe.
-        m_decimalSeparator = result.charAt(1);
-
+        assertNotNull("Returned value is not null", value);
+        assertEquals("Returned value is int[]",
+                intArray.getClass(), value.getClass());
+        final int results[] = (int[]) value;
+        assertEquals("Returned array length", intArray.length, results.length);
+        for (int i = 0; i < intArray.length; i++) {
+            assertEquals("Returned array value " + i,
+                    intArray[i], results[i]);
+        }
 
     }
 
+    private void checkStringArray(final Object value, final String stringArray[]) {
+
+        assertNotNull("Returned value is not null", value);
+        assertEquals("Returned value is String[]",
+                stringArray.getClass(), value.getClass());
+        final String results[] = (String[]) value;
+        assertEquals("Returned array length",
+                stringArray.length, results.length);
+        for (int i = 0; i < stringArray.length; i++) {
+            assertEquals("Returned array value " + i,
+                    stringArray[i], results[i]);
+        }
 
-    /**
-     * Return the tests included in this test suite.
-     */
-    public static Test suite() {
-        return (new TestSuite(LocaleConvertUtilsTestCase.class));
     }
 
-
-    /**
-     * Tear down instance variables required by this test case.
-     */
-    @Override
-    public void tearDown() {
-        // No action required
-    }
-
-
-    // ------------------------------------------------ Individual Test Methods
-
-
     /**
      * Negative String to primitive integer array tests.
      */
@@ -109,7 +94,7 @@ public class LocaleConvertUtilsTestCase extends TestCase {
         fail("Array conversions not implemented yet.");
 
         Object value = null;
-        final int intArray[] = new int[0];
+        final int intArray[] = {};
 
         value = LocaleConvertUtils.convert((String) null, intArray.getClass());
         checkIntegerArray(value, intArray);
@@ -128,6 +113,233 @@ public class LocaleConvertUtilsTestCase extends TestCase {
 
     }
 
+    /**
+     * Negative String to String array tests.
+     */
+    public void fixmetestNegativeStringArray() {
+
+        fail("Array conversions not implemented yet.");
+
+        Object value = null;
+        final String stringArray[] = {};
+
+        value = LocaleConvertUtils.convert((String) null, stringArray.getClass());
+        checkStringArray(value, stringArray);
+    }
+
+    /**
+     * Test conversion of object to string for arrays - .
+     */
+    public void fixmetestObjectToStringArray() {
+
+        fail("Array conversions not implemented yet.");
+        final int intArray0[] = {};
+        final int intArray1[] = {123};
+        final int intArray2[] = {123, 456};
+        final String stringArray0[] = {};
+        final String stringArray1[] = {"abc"};
+        final String stringArray2[] = {"abc", "def"};
+
+        assertEquals("intArray0", null,
+                LocaleConvertUtils.convert(intArray0));
+        assertEquals("intArray1", "123",
+                LocaleConvertUtils.convert(intArray1));
+        assertEquals("intArray2", "123",
+                LocaleConvertUtils.convert(intArray2));
+
+        assertEquals("stringArray0", null,
+                LocaleConvertUtils.convert(stringArray0));
+        assertEquals("stringArray1", "abc",
+                LocaleConvertUtils.convert(stringArray1));
+        assertEquals("stringArray2", "abc",
+                LocaleConvertUtils.convert(stringArray2));
+
+    }
+
+    /**
+     * Positive array conversion tests.
+     */
+    public void fixmetestPositiveArray() {
+
+        fail("Array conversions not implemented yet.");
+
+        final String values1[] = {"10", "20", "30"};
+        Object value = LocaleConvertUtils.convert(values1, Integer.TYPE);
+        final int shape[] = {};
+        assertEquals(shape.getClass(), value.getClass());
+        final int results1[] = (int[]) value;
+        assertEquals(results1[0], 10);
+        assertEquals(results1[1], 20);
+        assertEquals(results1[2], 30);
+
+        final String values2[] = {"100", "200", "300"};
+        value = LocaleConvertUtils.convert(values2, shape.getClass());
+        assertEquals(shape.getClass(), value.getClass());
+        final int results2[] = (int[]) value;
+        assertEquals(results2[0], 100);
+        assertEquals(results2[1], 200);
+        assertEquals(results2[2], 300);
+    }
+
+    /**
+     * Positive String to primitive integer array tests.
+     */
+    public void fixmetestPositiveIntegerArray() {
+
+        fail("Array conversions not implemented yet.");
+
+        Object value = null;
+        final int intArray[] = {};
+        final int intArray1[] = {0};
+        final int intArray2[] = {0, 10};
+
+        value = LocaleConvertUtils.convert("{  }", intArray.getClass());
+        checkIntegerArray(value, intArray);
+
+        value = LocaleConvertUtils.convert("0", intArray.getClass());
+        checkIntegerArray(value, intArray1);
+        value = LocaleConvertUtils.convert(" 0 ", intArray.getClass());
+        checkIntegerArray(value, intArray1);
+        value = LocaleConvertUtils.convert("{ 0 }", intArray.getClass());
+        checkIntegerArray(value, intArray1);
+
+        value = LocaleConvertUtils.convert("0,10", intArray.getClass());
+        checkIntegerArray(value, intArray2);
+        value = LocaleConvertUtils.convert("0 10", intArray.getClass());
+        checkIntegerArray(value, intArray2);
+        value = LocaleConvertUtils.convert("{0,10}", intArray.getClass());
+        checkIntegerArray(value, intArray2);
+        value = LocaleConvertUtils.convert("{0 10}", intArray.getClass());
+        checkIntegerArray(value, intArray2);
+        value = LocaleConvertUtils.convert("{ 0, 10 }", intArray.getClass());
+        checkIntegerArray(value, intArray2);
+        value = LocaleConvertUtils.convert("{ 0 10 }", intArray.getClass());
+        checkIntegerArray(value, intArray2);
+    }
+
+    /**
+     * Positive String to String array tests.
+     */
+    public void fixmetestPositiveStringArray() {
+
+        fail("Array conversions not implemented yet.");
+
+        Object value = null;
+        final String stringArray[] = {};
+        final String stringArray1[] = {"abc"};
+        final String stringArray2[] = {"abc", "de,f"};
+
+        value = LocaleConvertUtils.convert("", stringArray.getClass());
+        checkStringArray(value, stringArray);
+        value = LocaleConvertUtils.convert(" ", stringArray.getClass());
+        checkStringArray(value, stringArray);
+        value = LocaleConvertUtils.convert("{}", stringArray.getClass());
+        checkStringArray(value, stringArray);
+        value = LocaleConvertUtils.convert("{  }", stringArray.getClass());
+        checkStringArray(value, stringArray);
+
+        value = LocaleConvertUtils.convert("abc", stringArray.getClass());
+        checkStringArray(value, stringArray1);
+        value = LocaleConvertUtils.convert("{abc}", stringArray.getClass());
+        checkStringArray(value, stringArray1);
+        value = LocaleConvertUtils.convert("\"abc\"", stringArray.getClass());
+        checkStringArray(value, stringArray1);
+        value = LocaleConvertUtils.convert("{\"abc\"}", stringArray.getClass());
+        checkStringArray(value, stringArray1);
+        value = LocaleConvertUtils.convert("'abc'", stringArray.getClass());
+        checkStringArray(value, stringArray1);
+        value = LocaleConvertUtils.convert("{'abc'}", stringArray.getClass());
+        checkStringArray(value, stringArray1);
+
+        value = LocaleConvertUtils.convert("abc 'de,f'",
+                stringArray.getClass());
+        checkStringArray(value, stringArray2);
+        value = LocaleConvertUtils.convert("{abc, 'de,f'}",
+                stringArray.getClass());
+        checkStringArray(value, stringArray2);
+        value = LocaleConvertUtils.convert("\"abc\",\"de,f\"",
+                stringArray.getClass());
+        checkStringArray(value, stringArray2);
+        value = LocaleConvertUtils.convert("{\"abc\" 'de,f'}",
+                stringArray.getClass());
+        checkStringArray(value, stringArray2);
+        value = LocaleConvertUtils.convert("'abc' 'de,f'",
+                stringArray.getClass());
+        checkStringArray(value, stringArray2);
+        value = LocaleConvertUtils.convert("{'abc', \"de,f\"}",
+                stringArray.getClass());
+        checkStringArray(value, stringArray2);
+
+    }
+
+    /**
+     * Set up instance variables required by this test case.
+     */
+    @Override
+    public void setUp() {
+
+        LocaleConvertUtils.deregister();
+
+        final NumberFormat nf = NumberFormat.getNumberInstance();
+        final String result = nf.format(1.1);
+
+        // could be commas instead of stops in Europe.
+        m_decimalSeparator = result.charAt(1);
+
+    }
+
+    /**
+     * Tear down instance variables required by this test case.
+     */
+    @Override
+    public void tearDown() {
+        // No action required
+    }
+
+    /**
+     * Test conversion of a String array using a Locale and pattern.
+     */
+    public void testConvertStringArrayLocaleNull() {
+        Object result = null;
+        try {
+            result = LocaleConvertUtils.convert(new String[] {"123"}, Integer[].class, (Locale)null, "#,###");
+        } catch (final Exception e) {
+            e.printStackTrace();
+            fail("Threw: " + e);
+        }
+        assertNotNull("Null Result", result);
+        assertEquals("Integer Array Type", Integer[].class, result.getClass());
+        assertEquals("Integer Array Length", 1, ((Integer[])result).length);
+        assertEquals("Integer Array Value", Integer.valueOf(123), ((Integer[])result)[0]);
+    }
+
+    /**
+     * Test conversion of a String using a Locale and pattern.
+     */
+    public void testConvertStringLocaleNull() {
+        Object result = null;
+        try {
+            result = LocaleConvertUtils.convert("123", Integer.class, (Locale)null, "#,###");
+        } catch (final Exception e) {
+            e.printStackTrace();
+            fail("Threw: " + e);
+        }
+        assertNotNull("Null Result", result);
+        assertEquals("Integer Type", Integer.class, result.getClass());
+        assertEquals("Integer Value", Integer.valueOf(123), result);
+    }
+
+    /**
+     * Tests a conversion if there is no suitable converter registered. In this
+     * case, the string converter is used, and the passed in target type is
+     * ignored. (This test is added to prevent a regression after the locale
+     * converters have been generified.)
+     */
+    public void testDefaultToStringConversionUnsupportedType() {
+        final int value = 20131101;
+        assertEquals("Wrong result", Integer.toString(value),
+                LocaleConvertUtils.convert(Integer.toString(value), getClass()));
+    }
 
     /**
      * Negative scalar conversion tests.  These rely on the standard
@@ -143,7 +355,6 @@ public class LocaleConvertUtilsTestCase extends TestCase {
         ...
         */
 
-
         try {
             LocaleConvertUtils.convert("foo", Byte.TYPE);
             fail("Should have thrown conversion exception (1)");
@@ -239,52 +450,6 @@ public class LocaleConvertUtilsTestCase extends TestCase {
 
     }
 
-
-    /**
-     * Negative String to String array tests.
-     */
-    public void fixmetestNegativeStringArray() {
-
-        fail("Array conversions not implemented yet.");
-
-        Object value = null;
-        final String stringArray[] = new String[0];
-
-        value = LocaleConvertUtils.convert((String) null, stringArray.getClass());
-        checkStringArray(value, stringArray);
-    }
-
-
-    /**
-     * Test conversion of object to string for arrays - .
-     */
-    public void fixmetestObjectToStringArray() {
-
-        fail("Array conversions not implemented yet.");
-        final int intArray0[] = new int[0];
-        final int intArray1[] = {123};
-        final int intArray2[] = {123, 456};
-        final String stringArray0[] = new String[0];
-        final String stringArray1[] = {"abc"};
-        final String stringArray2[] = {"abc", "def"};
-
-        assertEquals("intArray0", null,
-                LocaleConvertUtils.convert(intArray0));
-        assertEquals("intArray1", "123",
-                LocaleConvertUtils.convert(intArray1));
-        assertEquals("intArray2", "123",
-                LocaleConvertUtils.convert(intArray2));
-
-        assertEquals("stringArray0", null,
-                LocaleConvertUtils.convert(stringArray0));
-        assertEquals("stringArray1", "abc",
-                LocaleConvertUtils.convert(stringArray1));
-        assertEquals("stringArray2", "abc",
-                LocaleConvertUtils.convert(stringArray2));
-
-    }
-
-
     /**
      * Test conversion of object to string for scalars.
      */
@@ -295,19 +460,19 @@ public class LocaleConvertUtilsTestCase extends TestCase {
         assertEquals("Boolean->String", "true",
                 LocaleConvertUtils.convert(Boolean.TRUE));
         assertEquals("Byte->String", "123",
-                LocaleConvertUtils.convert(new Byte((byte) 123)));
+                LocaleConvertUtils.convert(Byte.valueOf((byte) 123)));
         assertEquals("Character->String", "a",
-                LocaleConvertUtils.convert(new Character('a')));
+                LocaleConvertUtils.convert(Character.valueOf('a')));
         assertEquals("Double->String", "123" + m_decimalSeparator + "4",
-                LocaleConvertUtils.convert(new Double(123.4)));
+                LocaleConvertUtils.convert(Double.valueOf(123.4)));
         assertEquals("Float->String", "123" + m_decimalSeparator + "4",
-                LocaleConvertUtils.convert(new Float((float) 123.4)));
+                LocaleConvertUtils.convert(Float.valueOf((float) 123.4)));
         assertEquals("Integer->String", "123",
-                LocaleConvertUtils.convert(new Integer(123)));
+                LocaleConvertUtils.convert(Integer.valueOf(123)));
         assertEquals("Long->String", "123",
-                LocaleConvertUtils.convert(new Long(123)));
+                LocaleConvertUtils.convert(Long.valueOf(123)));
         assertEquals("Short->String", "123",
-                LocaleConvertUtils.convert(new Short((short) 123)));
+                LocaleConvertUtils.convert(Short.valueOf((short) 123)));
         assertEquals("String->String", "abc",
                 LocaleConvertUtils.convert("abc"));
         assertEquals("String->String null", null,
@@ -315,70 +480,6 @@ public class LocaleConvertUtilsTestCase extends TestCase {
 
     }
 
-
-    /**
-     * Positive array conversion tests.
-     */
-    public void fixmetestPositiveArray() {
-
-        fail("Array conversions not implemented yet.");
-
-        final String values1[] = {"10", "20", "30"};
-        Object value = LocaleConvertUtils.convert(values1, Integer.TYPE);
-        final int shape[] = new int[0];
-        assertEquals(shape.getClass(), value.getClass());
-        final int results1[] = (int[]) value;
-        assertEquals(results1[0], 10);
-        assertEquals(results1[1], 20);
-        assertEquals(results1[2], 30);
-
-        final String values2[] = {"100", "200", "300"};
-        value = LocaleConvertUtils.convert(values2, shape.getClass());
-        assertEquals(shape.getClass(), value.getClass());
-        final int results2[] = (int[]) value;
-        assertEquals(results2[0], 100);
-        assertEquals(results2[1], 200);
-        assertEquals(results2[2], 300);
-    }
-
-
-    /**
-     * Positive String to primitive integer array tests.
-     */
-    public void fixmetestPositiveIntegerArray() {
-
-        fail("Array conversions not implemented yet.");
-
-        Object value = null;
-        final int intArray[] = new int[0];
-        final int intArray1[] = new int[]{0};
-        final int intArray2[] = new int[]{0, 10};
-
-        value = LocaleConvertUtils.convert("{  }", intArray.getClass());
-        checkIntegerArray(value, intArray);
-
-        value = LocaleConvertUtils.convert("0", intArray.getClass());
-        checkIntegerArray(value, intArray1);
-        value = LocaleConvertUtils.convert(" 0 ", intArray.getClass());
-        checkIntegerArray(value, intArray1);
-        value = LocaleConvertUtils.convert("{ 0 }", intArray.getClass());
-        checkIntegerArray(value, intArray1);
-
-        value = LocaleConvertUtils.convert("0,10", intArray.getClass());
-        checkIntegerArray(value, intArray2);
-        value = LocaleConvertUtils.convert("0 10", intArray.getClass());
-        checkIntegerArray(value, intArray2);
-        value = LocaleConvertUtils.convert("{0,10}", intArray.getClass());
-        checkIntegerArray(value, intArray2);
-        value = LocaleConvertUtils.convert("{0 10}", intArray.getClass());
-        checkIntegerArray(value, intArray2);
-        value = LocaleConvertUtils.convert("{ 0, 10 }", intArray.getClass());
-        checkIntegerArray(value, intArray2);
-        value = LocaleConvertUtils.convert("{ 0 10 }", intArray.getClass());
-        checkIntegerArray(value, intArray2);
-    }
-
-
     /**
      * Positive scalar conversion tests.
      */
@@ -537,142 +638,5 @@ public class LocaleConvertUtilsTestCase extends TestCase {
 
     }
 
-
-    /**
-     * Positive String to String array tests.
-     */
-    public void fixmetestPositiveStringArray() {
-
-        fail("Array conversions not implemented yet.");
-
-        Object value = null;
-        final String stringArray[] = new String[0];
-        final String stringArray1[] = new String[]
-        {"abc"};
-        final String stringArray2[] = new String[]
-        {"abc", "de,f"};
-
-        value = LocaleConvertUtils.convert("", stringArray.getClass());
-        checkStringArray(value, stringArray);
-        value = LocaleConvertUtils.convert(" ", stringArray.getClass());
-        checkStringArray(value, stringArray);
-        value = LocaleConvertUtils.convert("{}", stringArray.getClass());
-        checkStringArray(value, stringArray);
-        value = LocaleConvertUtils.convert("{  }", stringArray.getClass());
-        checkStringArray(value, stringArray);
-
-        value = LocaleConvertUtils.convert("abc", stringArray.getClass());
-        checkStringArray(value, stringArray1);
-        value = LocaleConvertUtils.convert("{abc}", stringArray.getClass());
-        checkStringArray(value, stringArray1);
-        value = LocaleConvertUtils.convert("\"abc\"", stringArray.getClass());
-        checkStringArray(value, stringArray1);
-        value = LocaleConvertUtils.convert("{\"abc\"}", stringArray.getClass());
-        checkStringArray(value, stringArray1);
-        value = LocaleConvertUtils.convert("'abc'", stringArray.getClass());
-        checkStringArray(value, stringArray1);
-        value = LocaleConvertUtils.convert("{'abc'}", stringArray.getClass());
-        checkStringArray(value, stringArray1);
-
-        value = LocaleConvertUtils.convert("abc 'de,f'",
-                stringArray.getClass());
-        checkStringArray(value, stringArray2);
-        value = LocaleConvertUtils.convert("{abc, 'de,f'}",
-                stringArray.getClass());
-        checkStringArray(value, stringArray2);
-        value = LocaleConvertUtils.convert("\"abc\",\"de,f\"",
-                stringArray.getClass());
-        checkStringArray(value, stringArray2);
-        value = LocaleConvertUtils.convert("{\"abc\" 'de,f'}",
-                stringArray.getClass());
-        checkStringArray(value, stringArray2);
-        value = LocaleConvertUtils.convert("'abc' 'de,f'",
-                stringArray.getClass());
-        checkStringArray(value, stringArray2);
-        value = LocaleConvertUtils.convert("{'abc', \"de,f\"}",
-                stringArray.getClass());
-        checkStringArray(value, stringArray2);
-
-    }
-
-    /**
-     * Test conversion of a String using a Locale and pattern.
-     */
-    public void testConvertStringLocaleNull() {
-        Object result = null;
-        try {
-            result = LocaleConvertUtils.convert("123", Integer.class, (Locale)null, "#,###");
-        } catch (final Exception e) {
-            e.printStackTrace();
-            fail("Threw: " + e);
-        }
-        assertNotNull("Null Result", result);
-        assertEquals("Integer Type", Integer.class, result.getClass());
-        assertEquals("Integer Value", new Integer(123), result);
-    }
-
-    /**
-     * Test conversion of a String array using a Locale and pattern.
-     */
-    public void testConvertStringArrayLocaleNull() {
-        Object result = null;
-        try {
-            result = LocaleConvertUtils.convert(new String[] {"123"}, Integer[].class, (Locale)null, "#,###");
-        } catch (final Exception e) {
-            e.printStackTrace();
-            fail("Threw: " + e);
-        }
-        assertNotNull("Null Result", result);
-        assertEquals("Integer Array Type", Integer[].class, result.getClass());
-        assertEquals("Integer Array Length", 1, ((Integer[])result).length);
-        assertEquals("Integer Array Value", new Integer(123), ((Integer[])result)[0]);
-    }
-
-    /**
-     * Tests a conversion if there is no suitable converter registered. In this
-     * case, the string converter is used, and the passed in target type is
-     * ignored. (This test is added to prevent a regression after the locale
-     * converters have been generified.)
-     */
-    public void testDefaultToStringConversionUnsupportedType() {
-        final Integer value = 20131101;
-        assertEquals("Wrong result", value.toString(),
-                LocaleConvertUtils.convert(value.toString(), getClass()));
-    }
-
-    // -------------------------------------------------------- Private Methods
-
-
-    private void checkIntegerArray(final Object value, final int intArray[]) {
-
-        assertNotNull("Returned value is not null", value);
-        assertEquals("Returned value is int[]",
-                intArray.getClass(), value.getClass());
-        final int results[] = (int[]) value;
-        assertEquals("Returned array length", intArray.length, results.length);
-        for (int i = 0; i < intArray.length; i++) {
-            assertEquals("Returned array value " + i,
-                    intArray[i], results[i]);
-        }
-
-    }
-
-
-    private void checkStringArray(final Object value, final String stringArray[]) {
-
-        assertNotNull("Returned value is not null", value);
-        assertEquals("Returned value is String[]",
-                stringArray.getClass(), value.getClass());
-        final String results[] = (String[]) value;
-        assertEquals("Returned array length",
-                stringArray.length, results.length);
-        for (int i = 0; i < stringArray.length; i++) {
-            assertEquals("Returned array value " + i,
-                    stringArray[i], results[i]);
-        }
-
-    }
-
-
 }
 
