@@ -17,25 +17,17 @@
 
 package org.apache.commons.beanutils.locale.converters;
 
-
 /**
  * Test Case for the DoubleLocaleConverter class.
  *
- * @version $Id$
  */
 
 public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
-
-
-    // ---------------------------------------------------------- Constructors
-
     public DoubleLocaleConverterTestCase(final String name) {
         super(name);
     }
 
-    // -------------------------------------------------- Overall Test Methods
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -44,8 +36,8 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
         super.setUp();
 
-        defaultValue  = new Double("9.99");
-        expectedValue = new Double(expectedDecimalValue);
+        defaultValue  = Double.valueOf("9.99");
+        expectedValue = Double.valueOf(expectedDecimalValue);
 
     }
 
@@ -57,70 +49,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         super.tearDown();
     }
 
-
-    // ------------------------------------------------------------------------
-
-    /**
-     * Test Converter(defaultValue, locale, pattern, localizedPattern) constructor
-     */
-    public void testConstructorMain() {
-
-        // ------------- Construct with localized pattern ------------
-        converter = new DoubleLocaleConverter(defaultValue,
-                                                  localizedLocale,
-                                                  localizedDecimalPattern,
-                                                  true);
-
-
-        convertValueNoPattern(converter, "(A)", localizedDecimalValue, expectedValue);
-        convertValueWithPattern(converter, "(A)", localizedDecimalValue, localizedDecimalPattern, expectedValue);
-        convertInvalid(converter, "(A)", defaultValue);
-        convertNull(converter, "(A)", defaultValue);
-
-
-        // **************************************************************************
-        // Convert value in the wrong format - maybe you would expect it to throw an
-        // exception and return the default - it doesn't, DecimalFormat parses it
-        // quite happily turning "1,234.56" into "1.234"
-        // I guess this is one of the limitations of DecimalFormat
-        // **************************************************************************
-        convertValueNoPattern(converter, "(B)", defaultDecimalValue, new Double("1.234"));
-
-
-        // **************************************************************************
-        // Convert with non-localized pattern - this causes an exception in parse()
-        // but it gets swallowed in convert() method and returns default.
-        //  **** IS THIS THE EXPECTED BEHAVIOUR? ****
-        // Maybe if the pattern is no good, we should use a default pattern rather
-        // than just returning the default value.
-        // **************************************************************************
-        convertValueWithPattern(converter, "(B)", localizedDecimalValue, defaultDecimalPattern, defaultValue);
-
-
-        // **************************************************************************
-        // Convert with specified type
-        //
-        // BaseLocaleConverter completely ignores the type - so even if we specify
-        // Double.class here it still returns a Double.
-        //  **** This has been changed due to BEANUTILS-449 ****
-        // **************************************************************************
-        //convertValueToType(converter, "(B)", Integer.class, localizedDecimalValue, localizedDecimalPattern, expectedValue);
-
-
-        // ------------- Construct with non-localized pattern ------------
-        converter = new DoubleLocaleConverter(defaultValue,
-                                                  localizedLocale,
-                                                  defaultDecimalPattern,
-                                                  false);
-
-
-        convertValueNoPattern(converter, "(C)", localizedDecimalValue, expectedValue);
-        convertValueWithPattern(converter, "(C)", localizedDecimalValue, defaultDecimalPattern, expectedValue);
-        convertInvalid(converter, "(C)", defaultValue);
-        convertNull(converter, "(C)", defaultValue);
-
-    }
-
     /**
      * Test Converter() constructor
      *
@@ -129,7 +57,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_2() {
 
-        // ------------- Construct using default locale ------------
         converter = new DoubleLocaleConverter();
 
         // Perform Tests
@@ -148,7 +75,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_3() {
 
-        // ------------- Construct using localized pattern (default locale) --------
         converter = new DoubleLocaleConverter(true);
 
         // Perform Tests
@@ -157,7 +83,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
     /**
@@ -165,7 +90,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_4() {
 
-        // ------------- Construct using specified Locale --------
         converter = new DoubleLocaleConverter(localizedLocale);
 
         // Perform Tests
@@ -174,16 +98,13 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
-
     /**
      * Test Converter(Locale, locPattern) constructor
      */
     public void testConstructor_5() {
 
-        // ------------- Construct using specified Locale --------
         converter = new DoubleLocaleConverter(localizedLocale, true);
 
         // Perform Tests
@@ -192,7 +113,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
     /**
@@ -200,7 +120,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_6() {
 
-        // ------------- Construct using specified Locale --------
         converter = new DoubleLocaleConverter(localizedLocale, defaultDecimalPattern);
 
         // Perform Tests
@@ -216,7 +135,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_7() {
 
-        // ------------- Construct using specified Locale --------
         converter = new DoubleLocaleConverter(localizedLocale, localizedDecimalPattern, true);
 
         // Perform Tests
@@ -232,7 +150,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_8() {
 
-        // ------------- Construct using specified Locale --------
         converter = new DoubleLocaleConverter(defaultValue);
 
         // Perform Tests
@@ -248,7 +165,6 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_9() {
 
-        // ------------- Construct using specified Locale --------
         converter = new DoubleLocaleConverter(defaultValue, true);
 
         // Perform Tests
@@ -259,7 +175,58 @@ public class DoubleLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
     }
 
+    /**
+     * Test Converter(defaultValue, locale, pattern, localizedPattern) constructor
+     */
+    public void testConstructorMain() {
 
+        converter = new DoubleLocaleConverter(defaultValue,
+                                                  localizedLocale,
+                                                  localizedDecimalPattern,
+                                                  true);
+
+        convertValueNoPattern(converter, "(A)", localizedDecimalValue, expectedValue);
+        convertValueWithPattern(converter, "(A)", localizedDecimalValue, localizedDecimalPattern, expectedValue);
+        convertInvalid(converter, "(A)", defaultValue);
+        convertNull(converter, "(A)", defaultValue);
+
+        // **************************************************************************
+        // Convert value in the wrong format - maybe you would expect it to throw an
+        // exception and return the default - it doesn't, DecimalFormat parses it
+        // quite happily turning "1,234.56" into "1.234"
+        // I guess this is one of the limitations of DecimalFormat
+        // **************************************************************************
+        convertValueNoPattern(converter, "(B)", defaultDecimalValue, Double.valueOf("1.234"));
+
+        // **************************************************************************
+        // Convert with non-localized pattern - this causes an exception in parse()
+        // but it gets swallowed in convert() method and returns default.
+        //  **** IS THIS THE EXPECTED BEHAVIOUR? ****
+        // Maybe if the pattern is no good, we should use a default pattern rather
+        // than just returning the default value.
+        // **************************************************************************
+        convertValueWithPattern(converter, "(B)", localizedDecimalValue, defaultDecimalPattern, defaultValue);
+
+        // **************************************************************************
+        // Convert with specified type
+        //
+        // BaseLocaleConverter completely ignores the type - so even if we specify
+        // Double.class here it still returns a Double.
+        //  **** This has been changed due to BEANUTILS-449 ****
+        // **************************************************************************
+        //convertValueToType(converter, "(B)", Integer.class, localizedDecimalValue, localizedDecimalPattern, expectedValue);
+
+        converter = new DoubleLocaleConverter(defaultValue,
+                                                  localizedLocale,
+                                                  defaultDecimalPattern,
+                                                  false);
+
+        convertValueNoPattern(converter, "(C)", localizedDecimalValue, expectedValue);
+        convertValueWithPattern(converter, "(C)", localizedDecimalValue, defaultDecimalPattern, expectedValue);
+        convertInvalid(converter, "(C)", defaultValue);
+        convertNull(converter, "(C)", defaultValue);
+
+    }
 
 }
 
