@@ -26,21 +26,14 @@ import org.apache.commons.beanutils.locale.LocaleConvertUtils;
 /**
  * Test Case for the FloatLocaleConverter class.
  *
- * @version $Id$
  */
 
 public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
-
-
-    // ---------------------------------------------------------- Constructors
-
     public FloatLocaleConverterTestCase(final String name) {
         super(name);
     }
 
-    // -------------------------------------------------- Overall Test Methods
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -49,8 +42,8 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
         super.setUp();
 
-        defaultValue  = new Float("9.99");
-        expectedValue = new Float(expectedDecimalValue);
+        defaultValue  = Float.valueOf("9.99");
+        expectedValue = Float.valueOf(expectedDecimalValue);
 
     }
 
@@ -62,70 +55,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         super.tearDown();
     }
 
-
-    // ------------------------------------------------------------------------
-
-    /**
-     * Test Converter(defaultValue, locale, pattern, localizedPattern) constructor
-     */
-    public void testConstructorMain() {
-
-        // ------------- Construct with localized pattern ------------
-        converter = new FloatLocaleConverter(defaultValue,
-                                                  localizedLocale,
-                                                  localizedDecimalPattern,
-                                                  true);
-
-
-        convertValueNoPattern(converter, "(A)", localizedDecimalValue, expectedValue);
-        convertValueWithPattern(converter, "(A)", localizedDecimalValue, localizedDecimalPattern, expectedValue);
-        convertInvalid(converter, "(A)", defaultValue);
-        convertNull(converter, "(A)", defaultValue);
-
-
-        // **************************************************************************
-        // Convert value in the wrong format - maybe you would expect it to throw an
-        // exception and return the default - it doesn't, DecimalFormat parses it
-        // quite happily turning "1,234.56" into "1.234"
-        // I guess this is one of the limitations of DecimalFormat
-        // **************************************************************************
-        convertValueNoPattern(converter, "(B)", defaultDecimalValue, new Float("1.234"));
-
-
-        // **************************************************************************
-        // Convert with non-localized pattern - this causes an exception in parse()
-        // but it gets swallowed in convert() method and returns default.
-        //  **** IS THIS THE EXPECTED BEHAVIOUR? ****
-        // Maybe if the pattern is no good, we should use a default pattern rather
-        // than just returning the default value.
-        // **************************************************************************
-        convertValueWithPattern(converter, "(B)", localizedDecimalValue, defaultDecimalPattern, defaultValue);
-
-
-        // **************************************************************************
-        // Convert with specified type
-        //
-        // BaseLocaleConverter completely ignores the type - so even if we specify
-        // Float.class here it still returns a Float.
-        //  **** This has been changed due to BEANUTILS-449 ****
-        // **************************************************************************
-        //convertValueToType(converter, "(B)", Integer.class, localizedDecimalValue, localizedDecimalPattern, expectedValue);
-
-
-        // ------------- Construct with non-localized pattern ------------
-        converter = new FloatLocaleConverter(defaultValue,
-                                                  localizedLocale,
-                                                  defaultDecimalPattern,
-                                                  false);
-
-
-        convertValueNoPattern(converter, "(C)", localizedDecimalValue, expectedValue);
-        convertValueWithPattern(converter, "(C)", localizedDecimalValue, defaultDecimalPattern, expectedValue);
-        convertInvalid(converter, "(C)", defaultValue);
-        convertNull(converter, "(C)", defaultValue);
-
-    }
-
     /**
      * Test Converter() constructor
      *
@@ -134,7 +63,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_2() {
 
-        // ------------- Construct using default locale ------------
         converter = new FloatLocaleConverter();
 
         // Perform Tests
@@ -153,7 +81,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_3() {
 
-        // ------------- Construct using localized pattern (default locale) --------
         converter = new FloatLocaleConverter(true);
 
         // Perform Tests
@@ -162,7 +89,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
     /**
@@ -170,7 +96,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_4() {
 
-        // ------------- Construct using specified Locale --------
         converter = new FloatLocaleConverter(localizedLocale);
 
         // Perform Tests
@@ -179,16 +104,13 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
-
     /**
      * Test Converter(Locale, locPattern) constructor
      */
     public void testConstructor_5() {
 
-        // ------------- Construct using specified Locale --------
         converter = new FloatLocaleConverter(localizedLocale, true);
 
         // Perform Tests
@@ -197,7 +119,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
     /**
@@ -205,7 +126,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_6() {
 
-        // ------------- Construct using specified Locale --------
         converter = new FloatLocaleConverter(localizedLocale, defaultDecimalPattern);
 
         // Perform Tests
@@ -221,7 +141,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_7() {
 
-        // ------------- Construct using specified Locale --------
         converter = new FloatLocaleConverter(localizedLocale, localizedDecimalPattern, true);
 
         // Perform Tests
@@ -237,7 +156,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_8() {
 
-        // ------------- Construct using specified Locale --------
         converter = new FloatLocaleConverter(defaultValue);
 
         // Perform Tests
@@ -253,7 +171,6 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_9() {
 
-        // ------------- Construct using specified Locale --------
         converter = new FloatLocaleConverter(defaultValue, true);
 
         // Perform Tests
@@ -264,6 +181,59 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
     }
 
+    /**
+     * Test Converter(defaultValue, locale, pattern, localizedPattern) constructor
+     */
+    public void testConstructorMain() {
+
+        converter = new FloatLocaleConverter(defaultValue,
+                                                  localizedLocale,
+                                                  localizedDecimalPattern,
+                                                  true);
+
+        convertValueNoPattern(converter, "(A)", localizedDecimalValue, expectedValue);
+        convertValueWithPattern(converter, "(A)", localizedDecimalValue, localizedDecimalPattern, expectedValue);
+        convertInvalid(converter, "(A)", defaultValue);
+        convertNull(converter, "(A)", defaultValue);
+
+        // **************************************************************************
+        // Convert value in the wrong format - maybe you would expect it to throw an
+        // exception and return the default - it doesn't, DecimalFormat parses it
+        // quite happily turning "1,234.56" into "1.234"
+        // I guess this is one of the limitations of DecimalFormat
+        // **************************************************************************
+        convertValueNoPattern(converter, "(B)", defaultDecimalValue, Float.valueOf("1.234"));
+
+        // **************************************************************************
+        // Convert with non-localized pattern - this causes an exception in parse()
+        // but it gets swallowed in convert() method and returns default.
+        //  **** IS THIS THE EXPECTED BEHAVIOUR? ****
+        // Maybe if the pattern is no good, we should use a default pattern rather
+        // than just returning the default value.
+        // **************************************************************************
+        convertValueWithPattern(converter, "(B)", localizedDecimalValue, defaultDecimalPattern, defaultValue);
+
+        // **************************************************************************
+        // Convert with specified type
+        //
+        // BaseLocaleConverter completely ignores the type - so even if we specify
+        // Float.class here it still returns a Float.
+        //  **** This has been changed due to BEANUTILS-449 ****
+        // **************************************************************************
+        //convertValueToType(converter, "(B)", Integer.class, localizedDecimalValue, localizedDecimalPattern, expectedValue);
+
+        converter = new FloatLocaleConverter(defaultValue,
+                                                  localizedLocale,
+                                                  defaultDecimalPattern,
+                                                  false);
+
+        convertValueNoPattern(converter, "(C)", localizedDecimalValue, expectedValue);
+        convertValueWithPattern(converter, "(C)", localizedDecimalValue, defaultDecimalPattern, expectedValue);
+        convertInvalid(converter, "(C)", defaultValue);
+        convertNull(converter, "(C)", defaultValue);
+
+    }
+
     /**
      * Test Float limits
      */
@@ -272,13 +242,12 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         converter = new FloatLocaleConverter(defaultLocale, defaultDecimalPattern);
         final DecimalFormat fmt = new DecimalFormat("#.#############################################################");
 
-        assertEquals(new Float(-0.12), converter.convert("-0.12"));
-        assertEquals("Positive Float.MAX_VALUE", new Float(Float.MAX_VALUE), converter.convert(fmt.format(Float.MAX_VALUE)));
-        assertEquals("Positive Float.MIN_VALUE", new Float(Float.MIN_VALUE), converter.convert(fmt.format(Float.MIN_VALUE)));
-
-        assertEquals("Negative Float.MAX_VALUE", new Float(Float.MAX_VALUE * -1), converter.convert(fmt.format(Float.MAX_VALUE * -1)));
-        assertEquals("Negative Float.MIN_VALUE", new Float(Float.MIN_VALUE * -1), converter.convert(fmt.format(Float.MIN_VALUE * -1)));
+        assertEquals(Float.valueOf((float) -0.12), converter.convert("-0.12"));
+        assertEquals("Positive Float.MAX_VALUE", Float.valueOf(Float.MAX_VALUE), converter.convert(fmt.format(Float.MAX_VALUE)));
+        assertEquals("Positive Float.MIN_VALUE", Float.valueOf(Float.MIN_VALUE), converter.convert(fmt.format(Float.MIN_VALUE)));
 
+        assertEquals("Negative Float.MAX_VALUE", Float.valueOf(Float.MAX_VALUE * -1), converter.convert(fmt.format(Float.MAX_VALUE * -1)));
+        assertEquals("Negative Float.MIN_VALUE", Float.valueOf(Float.MIN_VALUE * -1), converter.convert(fmt.format(Float.MIN_VALUE * -1)));
 
         try {
             converter.convert(fmt.format((double)Float.MAX_VALUE * (double)10));
@@ -313,13 +282,12 @@ public class FloatLocaleConverterTestCase extends BaseLocaleConverterTestCase {
     public void testParseZero() {
         try {
             final Object result = LocaleConvertUtils.convert("0", Float.class, Locale.US, null);
-            assertEquals(new Float(0), result);
+            assertEquals(Float.valueOf(0), result);
         } catch (final ConversionException e) {
             fail("Zero threw ConversionException: " + e);
         }
 
     }
 
-
 }
 
