@@ -17,25 +17,17 @@
 
 package org.apache.commons.beanutils.locale.converters;
 
-
 /**
  * Test Case for the ShortLocaleConverter class.
  *
- * @version $Id$
  */
 
 public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
-
-
-    // ---------------------------------------------------------- Constructors
-
     public ShortLocaleConverterTestCase(final String name) {
         super(name);
     }
 
-    // -------------------------------------------------- Overall Test Methods
-
     /**
      * Set up instance variables required by this test case.
      */
@@ -44,8 +36,8 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
         super.setUp();
 
-        defaultValue  = new Short("999");
-        expectedValue = new Short(expectedIntegerValue);
+        defaultValue  = Short.valueOf("999");
+        expectedValue = Short.valueOf(expectedIntegerValue);
 
     }
 
@@ -57,69 +49,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         super.tearDown();
     }
 
-
-    // ------------------------------------------------------------------------
-
-    /**
-     * Test Converter(defaultValue, locale, pattern, localizedPattern) constructor
-     */
-    public void testConstructorMain() {
-
-        // ------------- Construct with localized pattern ------------
-        converter = new ShortLocaleConverter(defaultValue,
-                                                  localizedLocale,
-                                                  localizedIntegerPattern,
-                                                  true);
-
-
-        convertValueNoPattern(converter, "(A)", localizedIntegerValue, expectedValue);
-        convertValueWithPattern(converter, "(A)", localizedIntegerValue, localizedIntegerPattern, expectedValue);
-        convertInvalid(converter, "(A)", defaultValue);
-        convertNull(converter, "(A)", defaultValue);
-
-
-        // **************************************************************************
-        // Convert value in the wrong format - maybe you would expect it to throw an
-        // exception and return the default - it doesn't, DecimalFormat parses it
-        // quite happily turning "1,234" into "1"
-        // I guess this is one of the limitations of DecimalFormat
-        // **************************************************************************
-        convertValueNoPattern(converter, "(B)", defaultIntegerValue, new Short("1"));
-
-
-        // **************************************************************************
-        // Convert with non-localized pattern - unlike the equivalent BigDecimal Test Case
-        // it doesn't causes an exception in parse() - DecimalFormat parses it
-        // quite happily turning "1,234" into "1"
-        // Again this is one of the limitations of DecimalFormat
-        // **************************************************************************
-        convertValueWithPattern(converter, "(B)", localizedIntegerValue, defaultIntegerPattern, new Short("1"));
-
-
-        // **************************************************************************
-        // Convert with specified type
-        //
-        // BaseLocaleConverter completely ignores the type - so even if we specify
-        // Double.class here it still returns a Short.
-        //  **** This has been changed due to BEANUTILS-449 ****
-        // **************************************************************************
-        //convertValueToType(converter, "(B)", Double.class, localizedIntegerValue, localizedIntegerPattern, expectedValue);
-
-
-        // ------------- Construct with non-localized pattern ------------
-        converter = new ShortLocaleConverter(defaultValue,
-                                                  localizedLocale,
-                                                  defaultIntegerPattern,
-                                                  false);
-
-
-        convertValueNoPattern(converter, "(C)", localizedIntegerValue, expectedValue);
-        convertValueWithPattern(converter, "(C)", localizedIntegerValue, defaultIntegerPattern, expectedValue);
-        convertInvalid(converter, "(C)", defaultValue);
-        convertNull(converter, "(C)", defaultValue);
-
-    }
-
     /**
      * Test Converter() constructor
      *
@@ -128,7 +57,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_2() {
 
-        // ------------- Construct using default locale ------------
         converter = new ShortLocaleConverter();
 
         // Perform Tests
@@ -147,7 +75,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_3() {
 
-        // ------------- Construct using localized pattern (default locale) --------
         converter = new ShortLocaleConverter(true);
 
         // Perform Tests
@@ -156,7 +83,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
     /**
@@ -164,7 +90,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_4() {
 
-        // ------------- Construct using specified Locale --------
         converter = new ShortLocaleConverter(localizedLocale);
 
         // Perform Tests
@@ -173,16 +98,13 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
-
     /**
      * Test Converter(Locale, locPattern) constructor
      */
     public void testConstructor_5() {
 
-        // ------------- Construct using specified Locale --------
         converter = new ShortLocaleConverter(localizedLocale, true);
 
         // Perform Tests
@@ -191,7 +113,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
         convertInvalid(converter, null);
         convertNull(converter, null);
 
-
     }
 
     /**
@@ -199,7 +120,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_6() {
 
-        // ------------- Construct using specified Locale --------
         converter = new ShortLocaleConverter(localizedLocale, defaultIntegerPattern);
 
         // Perform Tests
@@ -215,7 +135,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_7() {
 
-        // ------------- Construct using specified Locale --------
         converter = new ShortLocaleConverter(localizedLocale, localizedIntegerPattern, true);
 
         // Perform Tests
@@ -231,7 +150,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_8() {
 
-        // ------------- Construct using specified Locale --------
         converter = new ShortLocaleConverter(defaultValue);
 
         // Perform Tests
@@ -247,7 +165,6 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
      */
     public void testConstructor_9() {
 
-        // ------------- Construct using specified Locale --------
         converter = new ShortLocaleConverter(defaultValue, true);
 
         // Perform Tests
@@ -258,7 +175,57 @@ public class ShortLocaleConverterTestCase extends BaseLocaleConverterTestCase {
 
     }
 
+    /**
+     * Test Converter(defaultValue, locale, pattern, localizedPattern) constructor
+     */
+    public void testConstructorMain() {
 
+        converter = new ShortLocaleConverter(defaultValue,
+                                                  localizedLocale,
+                                                  localizedIntegerPattern,
+                                                  true);
+
+        convertValueNoPattern(converter, "(A)", localizedIntegerValue, expectedValue);
+        convertValueWithPattern(converter, "(A)", localizedIntegerValue, localizedIntegerPattern, expectedValue);
+        convertInvalid(converter, "(A)", defaultValue);
+        convertNull(converter, "(A)", defaultValue);
+
+        // **************************************************************************
+        // Convert value in the wrong format - maybe you would expect it to throw an
+        // exception and return the default - it doesn't, DecimalFormat parses it
+        // quite happily turning "1,234" into "1"
+        // I guess this is one of the limitations of DecimalFormat
+        // **************************************************************************
+        convertValueNoPattern(converter, "(B)", defaultIntegerValue, Short.valueOf("1"));
+
+        // **************************************************************************
+        // Convert with non-localized pattern - unlike the equivalent BigDecimal Test Case
+        // it doesn't causes an exception in parse() - DecimalFormat parses it
+        // quite happily turning "1,234" into "1"
+        // Again this is one of the limitations of DecimalFormat
+        // **************************************************************************
+        convertValueWithPattern(converter, "(B)", localizedIntegerValue, defaultIntegerPattern, Short.valueOf("1"));
+
+        // **************************************************************************
+        // Convert with specified type
+        //
+        // BaseLocaleConverter completely ignores the type - so even if we specify
+        // Double.class here it still returns a Short.
+        //  **** This has been changed due to BEANUTILS-449 ****
+        // **************************************************************************
+        //convertValueToType(converter, "(B)", Double.class, localizedIntegerValue, localizedIntegerPattern, expectedValue);
+
+        converter = new ShortLocaleConverter(defaultValue,
+                                                  localizedLocale,
+                                                  defaultIntegerPattern,
+                                                  false);
+
+        convertValueNoPattern(converter, "(C)", localizedIntegerValue, expectedValue);
+        convertValueWithPattern(converter, "(C)", localizedIntegerValue, defaultIntegerPattern, expectedValue);
+        convertInvalid(converter, "(C)", defaultValue);
+        convertNull(converter, "(C)", defaultValue);
+
+    }
 
 }
 
