@@ -15,10 +15,8 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.priv;
 
-
 /**
  * Bean that has a private constructor that exposes properties via
  * various mechanisms (based on property name):
@@ -28,14 +26,24 @@ package org.apache.commons.beanutils.priv;
  * <li><strong>baz</strong> - Via indirectly implemented interface
  * </ul>
  *
- * @version $Id$
  */
 
 class PrivateBean implements PrivateDirect {
 
+    /**
+     * A directly implemented property.
+     */
+    private final String foo = "This is foo";
 
-    // ----------------------------------------------------------- Constructors
+    /**
+     * A property accessible via a directly implemented interface.
+     */
+    private final String bar = "This is bar";
 
+    /**
+     * A property accessible via an indirectly implemented interface.
+     */
+    private final String baz = "This is baz";
 
     /**
      * Package private constructor - can only use factory method to create
@@ -43,68 +51,46 @@ class PrivateBean implements PrivateDirect {
      */
     PrivateBean() {
 
-        super();
+    }
+
+    @Override
+    public String getBar() {
+
+        return this.bar;
 
     }
 
+    @Override
+    public String getBaz() {
 
-    // ------------------------------------------------------------- Properties
+        return this.baz;
 
-
-    /**
-     * A directly implemented property.
-     */
-    private final String foo = "This is foo";
+    }
 
     public String getFoo() {
 
-        return (this.foo);
+        return this.foo;
 
     }
 
-
-    /**
-     * A property accessible via a directly implemented interface.
-     */
-    private final String bar = "This is bar";
-
-    public String getBar() {
-
-        return (this.bar);
-
-    }
-
-
     /**
      * A method accessible via a directly implemented interface.
      */
+    @Override
     public String methodBar(final String in) {
 
-        return (in);
+        return in;
 
     }
 
-
-    /**
-     * A property accessible via an indirectly implemented interface.
-     */
-    private final String baz = "This is baz";
-
-    public String getBaz() {
-
-        return (this.baz);
-
-    }
-
-
     /**
      * A method accessible via an indirectly implemented interface.
      */
+    @Override
     public String methodBaz(final String in) {
 
-        return (in);
+        return in;
 
     }
 
-
 }
