@@ -15,37 +15,31 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.priv;
 
-
 /**
  * Factory class for PrivateBean instances.
  *
- * @version $Id$
  */
 
 public class PrivateBeanFactory {
 
-
     /**
      * Factory method to create new beans.
      */
     public static PrivateDirect create() {
 
-        return (new PrivateBean());
+        return new PrivateBean();
 
     }
 
-
     /**
      * Factory method to create new beans.
      */
     public static PrivateDirect createSubclass() {
 
-        return (new PrivateBeanSubclass());
+        return new PrivateBeanSubclass();
 
     }
 
-
 }
