@@ -15,45 +15,31 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.priv;
 
-
 /**
  * Bean that exposes methods defined by an interface that is implemented
  * in the superclass.
  *
- * @version $Id$
  */
 
 class PrivateBeanSubclass extends PrivateBean {
 
-
-    // ----------------------------------------------------------- Constructors
-
-
     /**
      * Create a new PrivateBeanSubclass instance.
      */
     PrivateBeanSubclass() {
 
-        super();
-
     }
 
-
-    // ------------------------------------------------------------- Properties
-
-
     /**
      * A property accessible via the superclass.
      */
     @Override
     public String getBar() {
 
-        return (super.getBar());
+        return super.getBar();
 
     }
 
-
 }
