@@ -15,32 +15,23 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.priv;
 
-
 /**
  * Interface that is indirectly implemented by PrivateBean.
  *
- * @version $Id$
  */
 
 public interface PrivateIndirect {
 
-
-    // ------------------------------------------------------------- Properties
-
-
     /**
      * A property accessible via an indirectly implemented interface.
      */
-    public String getBaz();
-
+    String getBaz();
 
     /**
      * A method accessible via an indirectly implemented interface.
      */
-    public String methodBaz(String in);
-
+    String methodBaz(String in);
 
 }
