@@ -15,10 +15,8 @@
  * limitations under the License.
  */
 
-
 package org.apache.commons.beanutils.priv;
 
-
 /**
  * <p>This class is designed to test the default access jvm problem workaround.
  * The issue is that public methods of a public subclass contained in a default access
@@ -27,14 +25,14 @@ package org.apache.commons.beanutils.priv;
  *
  * <p>This is the default access superclass</p>
  *
- * @version $Id$
  */
 
 public class PublicSubBean extends PackageBean {
 
-
-    // ----------------------------------------------------------- Constructors
-
+    /**
+     * A directly implemented property.
+     */
+    private String foo = "This is foo";
 
     /**
      * Package private constructor - can only use factory method to create
@@ -42,22 +40,11 @@ public class PublicSubBean extends PackageBean {
      */
     public PublicSubBean() {
 
-        super();
-
     }
 
-
-    // ------------------------------------------------------------- Properties
-
-
-    /**
-     * A directly implemented property.
-     */
-    private String foo = "This is foo";
-
     public String getFoo() {
 
-        return (this.foo);
+        return this.foo;
 
     }
 
